import{c as e}from"./createElementId-DhjFt1I9-B2HCdIOx.chunk.mjs";import{n as s}from"./index-4VW8tlR1.chunk.mjs";const i={name:"NcEmptyContent",props:{name:{type:String,default:""},description:{type:String,default:""}},setup(){return{nameId:e()}},computed:{hasName(){return this.name!==""||this.$slots.name},hasDescription(){return this.description!==""||this.$slots.description?.[0]}}};var a=function(){var t=this,n=t._self._c;return n("div",{staticClass:"empty-content",attrs:{"aria-labelledby":t.nameId,role:"note"}},[t.$slots.icon?n("div",{staticClass:"empty-content__icon",attrs:{"aria-hidden":"true"}},[t._t("icon")],2):t._e(),t.hasName?n("div",{staticClass:"empty-content__name",attrs:{id:t.nameId}},[t._t("name",function(){return[t._v(" "+t._s(t.name)+" ")]})],2):t._e(),t.hasDescription?n("p",{staticClass:"empty-content__description"},[t._t("description",function(){return[t._v(" "+t._s(t.description)+" ")]})],2):t._e(),t.$slots.action?n("div",{staticClass:"empty-content__action"},[t._t("action")],2):t._e()])},o=[],r=s(i,a,o,!1,null,"c3123941");const m=r.exports;export{m as N};
//# sourceMappingURL=NcEmptyContent-BKX-oWV6.chunk.mjs.map
