OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "ແບ່ງປັນໃຫ້ {email}",
    "Shared with {email} by {actor}" : "ແບ່ງປັນໃຫ້ {email} ໂດຍ {actor}",
    "Unshared from {email}" : "Unshared from {email}",
    "Unshared from {email} by {actor}" : "Unshared from {email} by {actor}",
    "Password for mail share sent to {email}" : "Password for mail share sent to {email}",
    "Password for mail share sent to you" : "Password for mail share sent to you",
    "You shared {file} with {email} by mail" : "You shared {file} with {email} by mail",
    "{actor} shared {file} with {email} by mail" : "{actor} shared {file} with {email} by mail",
    "You unshared {file} from {email} by mail" : "You unshared {file} from {email} by mail",
    "{actor} unshared {file} from {email} by mail" : "{actor} unshared {file} from {email} by mail",
    "Password to access {file} was sent to {email}" : "Password to access {file} was sent to {email}",
    "Password to access {file} was sent to you" : "Password to access {file} was sent to you",
    "Share by mail" : "Share by mail",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Sharing %1$s failed, because this item is already shared with the account %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again.",
    "Failed to send share by email. Got an invalid email address" : "Failed to send share by email. Got an invalid email address",
    "Failed to send share by email" : "Failed to send share by email",
    "%1$s shared %2$s with you" : "%1$s ໄດ້ແບ່ງປັນ %2$s ໃຫ້ທ່ານ",
    "Note:" : "ໝາຍເຫດ:",
    "This share is valid until %s at midnight" : "This share is valid until %s at midnight",
    "Expiration:" : "Expiration:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it.",
    "Password to access %1$s shared to you by %2$s" : "Password to access %1$s shared to you by %2$s",
    "Password to access %s" : "Password to access %s",
    "It is protected with the following password:" : "It is protected with the following password:",
    "This password will expire at %s" : "This password will expire at %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s shared %2$s with you and wants to add:",
    "%1$s shared %2$s with you and wants to add" : "%1$s shared %2$s with you and wants to add",
    "%s added a note to a file shared with you" : "%s added a note to a file shared with you",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient.",
    "Password to access %1$s shared by you with %2$s" : "Password to access %1$s shared by you with %2$s",
    "This is the password:" : "This is the password:",
    "You can choose a different password at any time in the share dialog." : "You can choose a different password at any time in the share dialog.",
    "Could not find share" : "Could not find share",
    "Share provider which allows you to share files by mail" : "Share provider which allows you to share files by mail",
    "Unable to update share by mail config" : "Unable to update share by mail config",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Allows people to share a personalized link to a file or folder by putting in an email address.",
    "Send password by mail" : "Send password by mail",
    "Reply to initiator" : "Reply to initiator"
},
"nplurals=1; plural=0;");
