OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "おすすめファイル",
    "Recommendations" : "おすすめ",
    "Shows recommended files" : "おすすめファイルの表示",
    "Shows recommended files for quick access of files and folders with recent activity" : "最近の利用したファイルやフォルダーにすばやくアクセスできるようにおすすめファイルを表示します",
    "No recommendations yet" : "おすすめはまだありません",
    "Last updated {timeAgo}" : "最終更新 {timeAgo}",
    "Shared with you {timeAgo}" : "あなたと共有 {timeAgo}",
    "Last commented on {timeAgo}" : "{timeAgo}に最新コメント",
    "Path name {path}" : "パス名 {path}",
    "Show recommendations" : "おすすめを表示"
},
"nplurals=1; plural=0;");
