var n,t;function a(){if(t)return n;t=1;function e(r){return{name:"Clojure REPL",contains:[{className:"meta.prompt",begin:/^([\w.-]+|\s*#_)?=>/,starts:{end:/$/,subLanguage:"clojure"}}]}}return n=e,n}export{a as r};
//# sourceMappingURL=clojure-repl-Dlkv8lxl.chunk.mjs.map
