OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendář",
    "Tasks" : "Úkoly",
    "Personal" : "Osobní",
    "{actor} created calendar {calendar}" : "{actor} vytvořil(a) kalendář {calendar}",
    "You created calendar {calendar}" : "Vytvořili jste kalendář {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} smazal(a) kalendář {calendar}",
    "You deleted calendar {calendar}" : "Smazali jste kalendář {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} aktualizoval(a) kalendář {calendar}",
    "You updated calendar {calendar}" : "Aktualizovali jste kalendář {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} obnovil(a) kalendář {calendar}",
    "You restored calendar {calendar}" : "Obnovili jste kalendář {calendar}",
    "You shared calendar {calendar} as public link" : "Sdíleli jste kalendář {calendar} jako veřejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstranili jste veřejný odkaz pro kalendář {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} vám nasdílel(a) kalendář {calendar}",
    "You shared calendar {calendar} with {user}" : "S uživatelem {user} jste začali sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} začal(a) sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} vám přestal(a) sdílet kalendář {calendar}",
    "You unshared calendar {calendar} from {user}" : "S uživatelem {user} jste přestali sdílet kalendář {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} přestal(a) sdílet kalendář {calendar} uživateli {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} přestal(a) sdílet kalendář {calendar} sám se sebou",
    "You shared calendar {calendar} with group {group}" : "Se skupinou {group} jste začali sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} nasdílel(a) kalendář {calendar} skupině {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili jste sdílení kalendáře {calendar} skupině {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} přestal(a) sdílet kalendář {calendar} se skupinou {group}",
    "Untitled event" : "Událost bez názvu",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvořil(a) událost {event} v kalendáři {calendar}",
    "You created event {event} in calendar {calendar}" : "V kalendáři {calendar} jste vytvořili událost {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} z kalendáře {calendar} smazal(a) událost {event}",
    "You deleted event {event} from calendar {calendar}" : "Smazali jste událost {event} z kalendáře {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} aktualizoval(a) událost {event} v kalendáři {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizovali jste událost {event} v kalendáři {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} přesunul(a) událost {event} z kalendáře {sourceCalendar} do kalendáře {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Přesunuli jste událost {event} z kalendáře {sourceCalendar} do kalendáře {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} obnovil(a) událost {event} kalendáře {calendar}",
    "You restored event {event} of calendar {calendar}" : "Obnovili jste událost {event} kalendáře {calendar}",
    "Busy" : "Zaneprázdněn(a)",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} vytvořil(a) úkol {todo} v seznamu {calendar}",
    "You created to-do {todo} in list {calendar}" : "Vytvořili jste úkol {todo} v seznamu {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} vymazal(a) úkol {todo} ze seznamu {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Vymazali jste úkol {todo} ze seznamu {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} aktualizoval(a) úkol {todo} v seznamu {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Aktualizovali jste úkol {todo} v seznamu {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} vyřešil(a) úkol {todo} v seznamu {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Vyřešili jste úkol {todo} v seznamu {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} znovu otevřel(a) úkol {todo} v seznamu {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Znovuotevřeli jste úkol {todo} v seznamu {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} přesunul(a) úkol {todo} ze seznamu {sourceCalendar} do seznamu {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Přesunuli jste úkol {todo} ze seznamu {sourceCalendar} do seznamu {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalendář, kontakty a úkoly",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendář</strong> byl změněn",
    "A calendar <strong>event</strong> was modified" : "<strong>Událost</strong> v kalendáři byla změněna",
    "A calendar <strong>to-do</strong> was modified" : "Kalendář <strong>úkoly</strong> byl upraven",
    "Contact birthdays" : "Narozeniny kontaktů",
    "Death of %s" : "Datum úmrtí %s",
    "Untitled calendar" : "Nepojmenovaný kalendář",
    "Calendar:" : "Kalendář:",
    "Date:" : "Datum:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "_%n year_::_%n years_" : ["%n rok","%n roky","%n let","%n roky"],
    "_%n month_::_%n months_" : ["%n měsíc","%n měsíce","%n měsíců","%n měsíce"],
    "_%n day_::_%n days_" : ["%n den","%n dny","%n dnů","%n dny"],
    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodin","%n hodiny"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuty","%n minut","%n minuty"],
    "%s (in %s)" : "%s (v %s)",
    "%s (%s ago)" : "%s (před %s)",
    "Calendar: %s" : "Kalendář: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Popis: %s",
    "Where: %s" : "Kde: %s",
    "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
    "In the past on %1$s for the entire day" : "V minulosti %1$s po celý den",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Za %n minutu v %1$s po celý den","Za %n minuty v %1$s po celý den","Za %n minut v %1$s po celý den","Za %n minuty v %1$s po celý den"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Za %n hodinu v %1$s po celý den","Za %n hodiny v %1$s po celý den","Za %n hodin v %1$s po celý den","Za %n hodiny v %1$s po celý den"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Za %n den v %1$s po celý den","Za %n dny v %1$s po celý den","Za %n dnů v %1$s po celý den","Za %n dny v %1$s po celý den"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Za %n týden v %1$s po celý den","Za %n týdny v %1$s po celý den","Za %n týdnů v %1$s po celý den","Za %n týdny v %1$s po celý den"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Za %n měsíc v %1$s po celý den","Za %n měsíce v %1$s po celý den","Za %n měsíců v %1$s po celý den","Za %n měsíce v %1$s po celý den"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Za %n rok v %1$s po celý den","Za %n roky v %1$s po celý den","Za %n let v %1$s po celý den","Za %n roky v %1$s po celý den"],
    "In the past on %1$s between %2$s - %3$s" : "V minulosti %1$s mezi %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Za %n minutu v %1$s mezi %2$s - %3$s","Za %n minuty v %1$s mezi %2$s - %3$s","Za %n minut v %1$s mezi %2$s - %3$s","Za %n minuty v %1$s mezi %2$s - %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Za %n hodinu v %1$s mezi %2$s - %3$s ","Za %n hodiny v %1$s mezi %2$s - %3$s ","Za %n hodin v %1$s mezi %2$s - %3$s ","Za %n hodiny v %1$s mezi %2$s - %3$s "],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Za %n den v %1$s mezi %2$s - %3$s","Za %n dny v %1$s mezi %2$s - %3$s","Za %n dnů v %1$s mezi %2$s - %3$s","Za %n dny v %1$s mezi %2$s - %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Za %n týden v %1$s mezi %2$s - %3$s","Za %n týdny v %1$s mezi %2$s - %3$s","Za %n týdnů v %1$s mezi %2$s - %3$s","Za %n týdny v %1$s mezi %2$s - %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Za %n měsíc v %1$s mezi %2$s - %3$s","Za %n měsíce v %1$s mezi %2$s - %3$s","Za %n měsíců v %1$s mezi %2$s - %3$s","Za %n měsíce v %1$s mezi %2$s - %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Za %n rok v %1$s mezi %2$s - %3$s","Za %n roky v %1$s mezi %2$s - %3$s","Za %n let v %1$s mezi %2$s - %3$s","Za %n roky v %1$s mezi %2$s - %3$s"],
    "Could not generate when statement" : "Nepodařilo se vytvořit výrok kdy",
    "Every Day for the entire day" : "Každý den pro celý den",
    "Every Day for the entire day until %1$s" : "Každý den pro celý den až do %1$s",
    "Every Day between %1$s - %2$s" : "Každý den mezi %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Každý den mezi %1$s - %2$s až do %3$s",
    "Every %1$d Days for the entire day" : "Co %1$d dnů po celý den",
    "Every %1$d Days for the entire day until %2$s" : "Co %1$d dnů po celý den až do %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Co %1$d dnů mezi %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Co %1$d dnů mezi %2$s - %3$s až do %4$s",
    "Could not generate event recurrence statement" : "Nepodařilo se vytvořit výrok o opakování události",
    "Every Week on %1$s for the entire day" : "Každý týden v(e) %1$s po celý den",
    "Every Week on %1$s for the entire day until %2$s" : "Každý týden v(e) %1$s po celý den až do %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Každý týden v %1$s mezi %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Každý týden v(e) %1$s mezi %2$s - %3$s až do %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Každých %1$d týdnů v(e) %2$s po celý den",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Co %1$d týdnů v(e) %2$s po celý den až do %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Co %1$d týdnů v(e) %2$s mezi %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Co %1$d týdnů v(e) %2$s mezi %3$s - %4$s až do %5$s",
    "Every Month on the %1$s for the entire day" : "Každý měsíc v %1$s po celý den",
    "Every Month on the %1$s for the entire day until %2$s" : "Každý měsíc v %1$s po celý den až do %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Každý měsíc v %1$s mezi %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Každý měsíc v %1$s mezi %2$s - %3$s až do %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Co %1$d měsíců v %2$s po celý den",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Co %1$d měsíců v %2$s po celý den až do %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Co %1$d měsíců v %2$s mezi %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Co %1$d měsíců v %2$s mezi %3$s - %4$s až do %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Každoročně %1$s v %2$s po celý den",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Každoročně v %1$s v %2$s po celý den až do %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Každoročně v %1$s v %2$s mezi %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Každoročně v %1$s v %2$s mezi %3$s - %4$s až do %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Co %1$d let v %2$s v %3$s po celý den",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Co %1$d let v %2$s v %3$s po celý den až do %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Co %1$d let v %2$s v %3$s mezi %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Co %1$d let %2$s v %3$s mezi %4$s - %5$s až do %6$s",
    "On specific dates for the entire day until %1$s" : "V konkrétních datech pro celý den až do %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "V konkrétních datech mezi %1$s - %2$s až do %3$s",
    "In the past on %1$s" : "V minulosti %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["Za %n minutu v %1$s","Za %n minuty v %1$s","Za %n minut v %1$s","Za %n minuty v %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["Za %n hodinu v %1$s","Za %n hodiny v %1$s","Za %n hodin v %1$s","Za %n hodiny v %1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["Za %n den v %1$s","Za %n dny v %1$s","Za %n dnů v %1$s","Za %n dny v %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["Za %n týden na %1$s","Za %n týdny na %1$s","Za %n týdnů na %1$s","Za %n týdny na %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["Za %n měsíc v %1$s","Za %n měsíce v %1$s","Za %n měsíců v %1$s","Za %n měsíce v %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["Za %n rok v %1$s","Za %n roky v %1$s","Za %n let v %1$s","Za %n roky v %1$s"],
    "In the past on %1$s then on %2$s" : "V minulosti %1$s, pak %2$s ",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Za %n minutu v %1$s, poté v %2$s","Za %n minuty v %1$s, poté v %2$s","Za %n minut v %1$s, poté v %2$s","Za %n minuty v %1$s, poté v %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Za %n hodinu v %1$s, poté v %2$s","Za %n hodiny v %1$s, poté v %2$s","Za %n hodin v %1$s, poté v %2$s","Za %n hodiny v %1$s, poté v %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Za %n den v %1$s, poté v %2$s","Za %n dny v %1$s, poté v %2$s","Za %n dnů v %1$s, poté v %2$s","Za %n dny v %1$s, poté v %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Za %n týden v %1$s, poté v %2$s","Za %n týdny v %1$s, poté v %2$s","Za %n týdnů v %1$s, poté v %2$s","Za %n týdny v %1$s, poté v %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Za %n měsíc v %1$s, poté v %2$s","Za %n měsíce v %1$s, poté v %2$s","Za %n měsíců v %1$s, poté v %2$s","Za %n měsíce v %1$s, poté v %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Za %n rok v %1$s, poté v %2$s","Za %n roky v %1$s, poté v %2$s","Za %n let v %1$s, poté v %2$s","Za %n roky v %1$s, poté v %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "V minulosti %1$s, poté %2$s a %3$s ",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Za %n minutu v %1$s, poté v %2$s a %3$s ","Za %n minuty v %1$s, poté v %2$s a %3$s ","Za %n minut v %1$s, poté v %2$s a %3$s ","Za %n minuty v %1$s, poté v %2$s a %3$s "],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Za %n hodinu v %1$s, poté v %2$s a %3$s","Za %n hodiny v %1$s, poté v %2$s a %3$s","Za %n hodin v %1$s, poté v %2$s a %3$s","Za %n hodiny v %1$s, poté v %2$s a %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Za %n den v %1$s, poté v %2$s a %3$s","Za %n dny v %1$s, poté v %2$s a %3$s","Za %n dnů v %1$s, poté v %2$s a %3$s","Za %n dny v %1$s, poté v %2$s a %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Za %n týden v %1$s, poté v %2$s a %3$s","Za %n týdny v %1$s, poté v %2$s a %3$s","Za %n týdnů v %1$s, poté v %2$s a %3$s","Za %n týdny v %1$s, poté v %2$s a %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Za %n měsíc v %1$s, poté v %2$s a %3$s","Za %n měsíce v %1$s, poté v %2$s a %3$s","Za %n měsíců v %1$s, poté v %2$s a %3$s","Za %n měsíce v %1$s, poté v %2$s a %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Za %n rok v %1$s, poté v %2$s a %3$s","Za %n roky v %1$s, poté v %2$s a %3$s","Za %n let v %1$s, poté v %2$s a %3$s","Za %n roky v %1$s, poté v %2$s a %3$s"],
    "Could not generate next recurrence statement" : "Nepodařilo se vytvořit výrok o příštím opakování",
    "Cancelled: %1$s" : "Zrušeno: %1$s",
    "\"%1$s\" has been canceled" : "„%1$s“ bylo zrušeno",
    "Re: %1$s" : "Odp.: %1$s",
    "%1$s has accepted your invitation" : "%1$s přijal(a) vaše pozvání",
    "%1$s has tentatively accepted your invitation" : "%1$s nezávazně přijal(a) vaši pozvánku",
    "%1$s has declined your invitation" : "%1$s odmítla(a) vaši pozvánku",
    "%1$s has responded to your invitation" : "%1$s odpověděl(a) na vaši pozvánku",
    "Invitation updated: %1$s" : "Pozvánka aktualizována: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s zaktualizoval(a) událost „%2$s",
    "Invitation: %1$s" : "Pozvánka: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s by vás ráda pozval(a) na „%2$s“",
    "Organizer:" : "Organizátor:",
    "Attendees:" : "Účastníci:",
    "Title:" : "Název:",
    "When:" : "Kdy:",
    "Location:" : "Umístění:",
    "Link:" : "Odkaz:",
    "Occurring:" : "Opakuje se::",
    "Accept" : "Přijmout",
    "Decline" : "Odmítnout",
    "More options …" : "Další volby …",
    "More options at %s" : "Další volby viz %s",
    "Monday" : "pondělí",
    "Tuesday" : "úterý",
    "Wednesday" : "středa",
    "Thursday" : "čtvrtek",
    "Friday" : "pátek",
    "Saturday" : "sobota",
    "Sunday" : "neděle",
    "January" : "leden",
    "February" : "únor",
    "March" : "březen",
    "April" : "duben",
    "May" : "květen",
    "June" : "červen",
    "July" : "červenec",
    "August" : "srpen",
    "September" : "září",
    "October" : "říjen",
    "November" : "listopad",
    "December" : "prosinec",
    "First" : "První",
    "Second" : "Sekund",
    "Third" : "Třetí",
    "Fourth" : "Čtvrtý",
    "Fifth" : "Páté",
    "Last" : "Poslední",
    "Second Last" : "Druhý poslední",
    "Third Last" : "Třetí poslední",
    "Fourth Last" : "Čtvrtý poslední",
    "Fifth Last" : "Pátý poslední",
    "Contacts" : "Kontakty",
    "{actor} created address book {addressbook}" : "{actor} vytvořil(a) adresář kontaktů {addressbook}",
    "You created address book {addressbook}" : "Vytvořili jste adresář kontaktů {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} vymazal(a) adresář kontaktů {addressbook}",
    "You deleted address book {addressbook}" : "Vymazali jste adresář kontaktů {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} aktualizoval(a) adresář kontaktů {addressbook}",
    "You updated address book {addressbook}" : "Aktualizovali jste adresář kontaktů {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} vám nasdílel(a) adresář kontaktů {addressbook}",
    "You shared address book {addressbook} with {user}" : "Nasdíleli jste adresář kontaktů {addressbook} uživateli {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} nasdílel(a) adresář kontaktů {addressbook} uživateli {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} vám zrušil(a) přístup ke sdílenému adresáři kontaktů {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Zrušili jste přístup ke sdílenému adresáři kontaktů {addressbook} uživateli {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} zrušil(a) přístup ke sdílenému adresáři kontaktů {addressbook} uživateli {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} si zrušil(a) přístup ke sdílenému adresáři kontaktů {addressbook}",
    "You shared address book {addressbook} with group {group}" : "Nasdíleli jste adresář kontaktů {addressbook} skupině {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} nasdílel(a) adresář kontaktů {addressbook} skupině {group}",
    "You unshared address book {addressbook} from group {group}" : "Zrušili jste přístup ke sdílenému adresáři kontaktů {addressbook} skupině {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} zrušil(a) sdílení adresáře kontaktů {addressbook} skupině {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} vytvořil(a) kontakt {card} v adresáři kontaktů {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Vytvořili jste kontakt {card} v adresáři kontaktů {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} vymazal(a) kontakt {card} z adresáře kontaktů {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Vymazali jste kontakt {card} z adresáře kontaktů {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} upravil(a) kontakt {card} v adresáři kontaktů {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Upravili jste kontakt {card} v adresáři kontaktů {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Kontakt</strong> nebo <strong>adresář kontaktů</strong> byl upraven",
    "System address book disabled" : "Systémový adresář kontaktů vypnut",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Systémový adresář kontaktů byl automaticky vypnut v průběhu přechodu na novější verzi serveru. To znamená, že adresář kontaktů už nebude k dispozici uživatelům v aplikaci Kontakty či jiných klientech. Systémový adresář kontaktů byl vypnut z toho důvodu, že množství kontaktů v něm přesahovalo nejvyšší doporučený počet kontaktů. Tento limit je nastaven jako prevence problémům s výkonem. I tak je ale možné systémový adresář kontaktů pomocí následujícího příkazu {command}",
    "Accounts" : "Účty",
    "System address book which holds all accounts" : "Systémový adresář kontaktů, který obsahuje veškeré účty",
    "File is not updatable: %1$s" : "Soubor není možné zaktualizovat: %1$s",
    "Failed to get storage for file" : "Nepodařilo se získat úložiště pro soubor",
    "Could not write to final file, canceled by hook" : "Nedaří se zapsat do konečného souboru – zrušeno háčkem (hook)",
    "Could not write file contents" : "Nedaří se zapsat obsahy souborů",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů","%n bajty"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Chyba při kopírování souboru do cílového umístění (zkopírováno: %1$s, očekávaná velikost souboru: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Očekávána velikost souboru %1$s, ale čtení (z Nextcloud klienta) a zápis (na Nextcloud úložiště) %2$s. Mohlo by se jednat buď o problém na síti na odesílající straně, nebo o problém se zápisem na úložiště na straně serveru.",
    "Could not rename part file to final file, canceled by hook" : "Nedaří se zapsat přejmenovat částečný soubor na ten končený – zrušeno háčkem (hook)",
    "Could not rename part file to final file" : "Nedaří se přejmenovat částečný soubor na ten konečný",
    "Failed to check file size: %1$s" : "Nepodařilo se zkontrolovat velikost souboru: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Nebylo možné otevřít soubor: %1$s (%2$d) – zdá se, že soubor existuje",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Nebylo možné otevřít soubor: %1$s (%2$d) – zdá se, že soubor neexistuje",
    "Failed to get size for : %1$s" : "Nepodařilo se získat velikost pro: %1$s",
    "Encryption not ready: %1$s" : "Šifrování není připraveno: %1$s",
    "Failed to open file: %1$s" : "Nepodařilo se otevřít soubor: %1$s",
    "Failed to unlink: %1$s" : "Nepodařilo se zrušit propojení: %1$s",
    "Failed to write file contents: %1$s" : "Nepodařilo se zapsat obsahy souborů: %1$s",
    "File not found: %1$s" : "Soubor nenalezen: %1$s",
    "Invalid target path" : "Neplatný popis umístění cíle",
    "System is in maintenance mode." : "Systém se právě nachází v režimu údržby.",
    "Upgrade needed" : "Je třeba přejít na novější verzi",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Váš %s potřebuje být nastavený aby používal HTTPS, aby bylo možné používat CalDAV a CardDAV s iOS/macOS.",
    "Configures a CalDAV account" : "Nastaví CalDAV účet",
    "Configures a CardDAV account" : "Nastaví CardDAV účet",
    "Events" : "Události",
    "Untitled task" : "Nepojmenovaný úkol",
    "Completed on %s" : "Dokončeno %s",
    "Due on %s by %s" : "Termín do %s od %s",
    "Due on %s" : "Termín do %s",
    "This is an example contact" : "Toto je kontakt pro ukázku",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Vítejte v Nextcloud Kalendáři!\n\nToto je událost pro ukázku – prozkoumejte flexibilitu plánování pomoc Nextcloud Kalendáře upravením čeho chcete!\n\nS Nextcloud Kalendářem je možné:\n- Jednoduše vytvářet, upravovat a spravovat události.\n- Vytvářet vícero kalendářů a sdílet je s kolegy, přáteli či rodinou.\n- Zjišťovat dostupnost a zobrazovat své doby nedostupnosti ostatním.\n- Hladce napojovat na aplikace a zřízení prostřednictvím CalDAV.\n- Přizpůsobit si svůj dojem z používání: plánovat opakující se události, upravovat notifikace a ostatní nastavení.",
    "Example event - open me!" : "Událost pro ukázku – otevřete ji!",
    "System Address Book" : "Systémový adresář kontaktů",
    "The system address book contains contact information for all users in your instance." : "Systémový adresář kontaktů obsahuje informace pro všechny uživatele ve vámi využívané instanci.",
    "Enable System Address Book" : "Zapnout systémový adresář kontaktů",
    "DAV system address book" : "Systémový DAV adresář kontaktů",
    "No outstanding DAV system address book sync." : "Žádná zbývající synchronizace systémového DAV adresáře kontaktů.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV synchronizace systémového adresáře kontaktů ještě nebyla spuštěná protože vámi využívaná instance má více než 1 000 uživatelů nebo protože došlo k chybě. Spusťte ji ručně  příkazem „occ dav:sync-system-addressbook“.",
    "DAV system address book size" : "Velikost systémového DAV adresáře kontaktů",
    "The system address book is disabled" : "Systémový adresář kontaktů je vypnutý",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Systémový adresář kontaktů je zapnutý, ale obsahuje více než jeden nastavený limit %d kontaktů",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Systémový adresář kontaktů je zapnutý a obsahuje méně než nastavený limit %d kontaktů",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Nepodařilo se zkontrolovat že vámi využívaný webový server je správně nastaven tak, aby umožňoval synchronizaci přes WebDAV. Zkontrolujte to ručně.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Váš webový server ještě není správně nastaven, pro umožnění synchronizace souborů, rozhraní WebDAV pravděpodobně není funkční.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Vámi využívaný webový server je správně nastaven pro umotnění synchronizace souborů přes WebDAV",
    "Calendars including events, details and attendees" : "Kalendáře včetně událostí, podrobností a účastníků",
    "Migrated calendar (%1$s)" : "Přesunut kalendář (%1$s)",
    "Contacts and groups" : "Kontakty a skupiny",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Nepřítomnost uložena",
    "Failed to save your absence settings" : "Nepodařilo se uložit nastavení vaší nepřítomnosti",
    "Absence cleared" : "Nepřítomnost vyčištěna",
    "Failed to clear your absence settings" : "Nepodařilo se vymazat nastavení vaší nepřítomnosti",
    "First day" : "První den",
    "Last day (inclusive)" : "Poslední den (včetně)",
    "Out of office replacement (optional)" : "Zástup když mimo kancelář (volitelné)",
    "Name of the replacement" : "Jméno zástupu",
    "Short absence status" : "Stav krátké nepřítomnosti",
    "Long absence Message" : "Zpráva pro dlouhou nepřítomnost",
    "Save" : "Uložit",
    "Disable absence" : "Vypnout nepřítomnost",
    "Failed to load availability" : "Nepodařilo se načíst dostupnost",
    "Saved availability" : "Uložena dostupnost",
    "Failed to save availability" : "Nepodařilo se uložit dostupnost",
    "to" : "do",
    "Delete slot" : "Smazat slot",
    "No working hours set" : "Nenastaveny pracovní hodiny",
    "Add slot" : "Přidat slot",
    "Weekdays" : "Dny v týdnu",
    "Pick a start time for {dayName}" : "Vyberte začátek pro {dayName}",
    "Pick a end time for {dayName}" : "Vyberte konec pro {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "V době, kdy není k dispozici, automaticky nastavit stav uživatele na „Nerušit“ a ztlumit tak veškerá upozornění.",
    "Cancel" : "Storno",
    "Import" : "Naimportovat",
    "Error while saving settings" : "Chyba při ukládání nastavení",
    "Contact reset successfully" : "Kontakt úspěšně resetován",
    "Error while resetting contact" : "Chyba při resetování kontaktu",
    "Contact imported successfully" : "Kontakt úspěšně naimportován",
    "Error while importing contact" : "Chyba při importování kontaktu",
    "Import contact" : "Importovat kontakt",
    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
    "Import contacts" : "Importovat kontakty",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Naimportování nového .vcf souboru smaže stávající výchozí kontakt a nahradí ho novým. Chcete pokračovat?",
    "Failed to save example event creation setting" : "Nepodařilo se uložit nastavení vytváření události pro ukázku",
    "Failed to upload the example event" : "Nepodařilo se nahrát událost pro ukázku",
    "Custom example event was saved successfully" : "Uživatelsky určená událost pro ukázku byla úspěšně uložena",
    "Failed to delete the custom example event" : "Nepodařilo se smazat uživatelsky určenou událost pro ukázku",
    "Custom example event was deleted successfully" : "Uživatelsky určená událost pro ukázku byla úspěšně smazána",
    "Import calendar event" : "Naimportovat událost kalendáře",
    "Uploading a new event will overwrite the existing one." : "Nahrání nové události přepíše tu existující.",
    "Upload event" : "Nahrát událost",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Také nainstalujte {calendarappstoreopen}aplikaci Kalendář{linkclose}, nebo {calendardocopen}připojte svůj počítač a telefon pro synchronizaci ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ověřte, že jste správně nastavili {emailopen}e-mailový server{linkclose}.",
    "Calendar server" : "Kalendářový server",
    "Send invitations to attendees" : "Poslat účastníkům pozvánky",
    "Automatically generate a birthday calendar" : "Automaticky vytvořit kalendář s narozeninami",
    "Birthday calendars will be generated by a background job." : "Kalendáře s narozeninami budou vytvářeny úlohou na pozadí.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "A tedy nebudou zpřístupněny ihned po povolení, ale objeví se až se zpožděním.",
    "Send notifications for events" : "Posílat upozornění na události",
    "Notifications are sent via background jobs, so these must occur often enough." : "Upozornění jsou odesílána prostřednictvím úloh na pozadí – proto je třeba, aby tyto probíhaly dostatečně často.",
    "Send reminder notifications to calendar sharees as well" : "Poslat připomínky také těm, kteří mají tento sdílený kalendář připojený",
    "Reminders are always sent to organizers and attendees." : "Připomínky jsou vždy poslány organizátorům a účastníkům.",
    "Enable notifications for events via push" : "Upozorňovat na události prostřednictvím služby push",
    "Example content" : "Obsah pro ukázku",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Obsah pro ukázku slouží pro předvedení funkcí Nextcloud. Výchozí obsah je dodáván s Nextcloud a je možné ho nahradit uživatelsky určeným.",
    "Availability" : "Dostupnost",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Když sem zadáte svou pracovní dobu, ostatní lidé při rezervování schůzky uvidí, kdy jste mimo kancelář.",
    "Absence" : "Nepřítomnost",
    "Configure your next absence period." : "Nastavte období své nepřítomnosti.",
    "There was an error updating your attendance status." : "Vyskytla se chyba při aktualizaci vašeho stavu účasti.",
    "Please contact the organizer directly." : "Kontaktujte organizátora přímo.",
    "Are you accepting the invitation?" : "Přijímáte pozvání?",
    "Tentative" : "Nezávazně",
    "Your attendance was updated successfully." : "Vaše účast byla úspěšně aktualizována.",
    "No results." : "Nic nenalezeno.",
    "Start typing." : "Začněte psát."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
