OC.L10N.register(
    "photos",
    {
    "Public link" : "Link public",
    "Photos" : "Poze",
    "Videos" : "Fișiere video",
    "People" : "Persoane",
    "Folders" : "Director",
    "Favorites" : "Favorite",
    "Shared with you" : "Partajat cu tine",
    "Tags" : "Etichete",
    "Places" : "Locuri",
    "Back" : "Înapoi",
    "Save" : "Salvează",
    "Shared by" : "Partajat de",
    "No recommendations. Start typing." : "Nu am găsit recomandări. Începeți să scrieți.",
    "Copy public link" : "Copiză link-ul public",
    "An error occurred" : "A apărut o eraore",
    "Favorite" : "Favorite",
    "Go back" : "Înapoi",
    "General" : "General",
    "Unselect all" : "Deselectează tot",
    "Remove from favorites" : "Șterge din favorite",
    "Loading folders…" : "Încărcare dosare…",
    "Details" : "Detalii",
    "Cancel" : "Cancel",
    "Confirm" : "Confirmă",
    "Group" : "Grup",
    "View" : "Vizualizare"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
