OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календарь",
    "Tasks" : "Задачи",
    "Personal" : "Личное",
    "{actor} created calendar {calendar}" : "{actor} создал(а) календарь «{calendar}»",
    "You created calendar {calendar}" : "Вы создали календарь «{calendar}»",
    "{actor} deleted calendar {calendar}" : "{actor} удалил(а) календарь «{calendar}»",
    "You deleted calendar {calendar}" : "Вы удалили календарь «{calendar}»",
    "{actor} updated calendar {calendar}" : "{actor} обновил(а) календарь «{calendar}»",
    "You updated calendar {calendar}" : "Вы обновили календарь «{calendar}»",
    "{actor} restored calendar {calendar}" : "{actor} восстановил(а) календарь «{calendar}»",
    "You restored calendar {calendar}" : "Вы восстановили календарь «{calendar}»",
    "You shared calendar {calendar} as public link" : "Вы предоставили общий доступ к календарю «{calendar}» созданием общедоступной ссылки",
    "You removed public link for calendar {calendar}" : "Вы удалили общедоступную ссылку на календарь «{calendar}»",
    "{actor} shared calendar {calendar} with you" : "{actor} предоставил(а) вам общий доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with {user}" : "Вы предоставили пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with {user}" : "{actor} предоставил(а) пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from you" : "{actor} закрыл(а) вам доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from {user}" : "Вы закрыли пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} закрыл(а) пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} закрыл(а) себе доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with group {group}" : "Вы предоставили группе {group} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} предоставил(а) группе {group} общий доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from group {group}" : "Вы закрыли группе {group} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} закрыл(а) группе {group} общий доступ к календарю «{calendar}»",
    "Untitled event" : "Событие без названия",
    "{actor} created event {event} in calendar {calendar}" : "{actor} создал(а) событие «{event}» в календаре «{calendar}»",
    "You created event {event} in calendar {calendar}" : "Вы создали событие «{event}» в календаре «{calendar}»",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} удалил(а) событие «{event}» из календаря «{calendar}»",
    "You deleted event {event} from calendar {calendar}" : "Вы удалили событие «{event}» из календаря «{calendar}»",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} обновил(а) событие «{event}» в календаре «{calendar}»",
    "You updated event {event} in calendar {calendar}" : "Вы обновили событие «{event}» в календаре «{calendar}»",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} переместил(а) событие «{event}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Вы переместили событие «{event}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} восстановил(а) событие {event} в календаре {calendar}",
    "You restored event {event} of calendar {calendar}" : "Вы восстановили событие {event} в календаре {calendar}",
    "Busy" : "Занято",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} создал(а) задачу «{todo}» в списке «{calendar}»",
    "You created to-do {todo} in list {calendar}" : "Вы создали задачу «{todo}» в списке «{calendar}»",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} удалил(а) задачу «{todo}» из списка «{calendar}»",
    "You deleted to-do {todo} from list {calendar}" : "Вы удалили задачу «{todo}» из списка «{calendar}»",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} обновил(а) задачу «{todo}» из списка «{calendar}»",
    "You updated to-do {todo} in list {calendar}" : "Вы обновили задачу «{todo}» из списка «{calendar}»",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} завершил(а) задачу «{todo}» из списка «{calendar}»",
    "You solved to-do {todo} in list {calendar}" : "Вы завершили задачу «{todo}» из списка «{calendar}»",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} повторно(а) открыл задачу «{todo}» из списка «{calendar}»",
    "You reopened to-do {todo} in list {calendar}" : "Вы повторно открыли задачу «{todo}» из списка «{calendar}»",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} переместил(а) задачу «{todo}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Вы переместили задачу «{todo}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "Calendar, contacts and tasks" : "Календарь, контакты и задачи",
    "A <strong>calendar</strong> was modified" : "Изменения <strong>календаря</strong> ",
    "A calendar <strong>event</strong> was modified" : "В календаре изменено <strong>событие</strong>",
    "A calendar <strong>to-do</strong> was modified" : "В календаре изменена <strong>задача</strong> ",
    "Contact birthdays" : "Дни рождения контакта",
    "Death of %s" : "Смерть %s",
    "Untitled calendar" : "Календарь без названия",
    "Calendar:" : "Календарь:",
    "Date:" : "Дата:",
    "Where:" : "Где:",
    "Description:" : "Описание:",
    "_%n year_::_%n years_" : ["%n год","%n года","%n лет","%n лет"],
    "_%n month_::_%n months_" : ["%n месяц","%n месяца","%n месяцев","%n месяцев"],
    "_%n day_::_%n days_" : ["%n день","%n дня","%n дней","%n дней"],
    "_%n hour_::_%n hours_" : ["%n час","%n часа","%n часов","%n часов"],
    "_%n minute_::_%n minutes_" : ["%n минута","%n минуты","%n минут","%n минут"],
    "%s (in %s)" : "%s (в %s)",
    "%s (%s ago)" : "%s (%s назад)",
    "Calendar: %s" : "Календарь: %s",
    "Date: %s" : "Дата: %s",
    "Description: %s" : "Описание: %s",
    "Where: %s" : "Где: %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "In the past on %1$s for the entire day" : "В прошлом, %1$s, в течение всего дня",
    "In the past on %1$s between %2$s - %3$s" : "В прошлом, %1$s, с %2$s до %3$s",
    "Could not generate when statement" : "Не удалось сгенерировать выражение времени",
    "Every Day for the entire day" : "Каждый день в течение всего дня",
    "Every Day for the entire day until %1$s" : "Каждый день весь день до %1$s",
    "Every Day between %1$s - %2$s" : "Каждый день с %1$s по %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Каждый день с %1$s до %2$s до %3$s",
    "Every %1$d Days for the entire day" : "Каждые %1$d дней в течение всего дня",
    "Every %1$d Days for the entire day until %2$s" : "Каждые %1$d дней в течение всего дня до %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Каждые %1$d дней с %2$s до %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Каждые %1$d дней с %2$s до %3$s до %4$s",
    "Could not generate event recurrence statement" : "Не удалось сгенерировать правило повторения события",
    "Every Week on %1$s for the entire day" : "Каждую неделю в %1$s в течение всего дня",
    "Every Week on %1$s for the entire day until %2$s" : "Каждую неделю по %1$s в течение всего дня до %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Каждую неделю в %1$s с %2$s до %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Каждую неделю по %1$s с %2$s до %3$s до %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Каждые %1$d недель по %2$s в течение всего дня",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Каждые %1$d недель по %2$s в течение всего дня до %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Каждые %1$d недель по %2$s с %3$s до %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Каждые %1$d недель по %2$s с %3$s до %4$s до %5$s",
    "Every Month on the %1$s for the entire day" : "Каждый месяц %1$s в течение всего дня",
    "Every Month on the %1$s for the entire day until %2$s" : "Каждый месяц %1$s в течение всего дня до %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Каждый месяц %1$s с %2$s до %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Каждый месяц %1$s с %2$s до %3$s до %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Каждые %1$d месяцев %2$s в течение всего дня",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Каждые %1$d месяцев %2$s в течение всего дня до %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Каждые %1$d месяцев %2$s с %3$s до %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Каждые %1$d месяцев %2$s с %3$s до %4$s до %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Каждый год в %1$s %2$s в течение всего дня",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Каждый год в %1$s %2$s в течение всего дня до %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Каждый год в %1$s %2$s с %3$s до %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Каждый год в %1$s %2$s с %3$s до %4$s до %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Каждые %1$d лет в %2$s %3$s в течение всего дня",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Каждые %1$d лет в %2$s %3$s в течение всего дня до %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Каждые %1$d лет в %2$s %3$s с %4$s до %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Каждые %1$d лет в %2$s %3$s с %4$s до %5$s до %6$s",
    "On specific dates for the entire day until %1$s" : "В определённые даты, весь день до %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "В определённые даты с %1$s по %2$s до %3$s",
    "In the past on %1$s" : "В прошлом, %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["Через минуту, %1$s","Через %n минуты, %1$s","Через %n минут, %1$s","Через %n минут, %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["Через час, %1$s","Через %n часа, %1$s","Через %n часов, %1$s","Через %n часов, %1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["Через день, %1$s","Через %n дня, %1$s","Через %n дней, %1$s","Через %n дней, %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["Через неделю, %1$s","Через %n недели,%1$s","Через %n недель, %1$s","Через %n недель, %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["Через месяц, %1$s","Через %n месяца, %1$s","Через %n месяцев, %1$s","Через %n месяцев, %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["Через год, %1$s","Через %n года, %1$s","Через %n лет, %1$s","Через %n лет, %1$s"],
    "In the past on %1$s then on %2$s" : "В прошлом, %1$s, затем %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Через минуту, %1$s, затем %2$s","Через %n минуты, %1$s, затем %2$s","Через %n минут, %1$s, затем %2$s","Через %n минут, %1$s, затем %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Через час, %1$s, затем %2$s","Через %n часа, %1$s, затем %2$s","Через %n часов, %1$s, затем %2$s","Через %n часов, %1$s, затем %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Через день, %1$s, затем %2$s","Через %n дня, %1$s, затем %2$s","Через %n дней, %1$s, затем %2$s","Через %n дней, %1$s, затем %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Через неделю, %1$s, затем %2$s","Через %n недели, %1$s, затем %2$s","Через %n недель, %1$s, затем %2$s","Через %n недель, %1$s, затем %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Через месяц, %1$s, затем %2$s","Через %n месяца, %1$s, затем %2$s","Через %n месяцев, %1$s, затем %2$s","Через %n месяцев, %1$s, затем %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Через год, %1$s, затем %2$s","Через %n года, %1$s, затем %2$s","Через %n лет, %1$s, затем %2$s","Через %n лет, %1$s, затем %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "В прошлом, %1$s, затем %2$s и %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Через минуту, %1$s, затем %2$s и %3$s","Через %n минуты, %1$s, затем %2$s и %3$s","Через %n минут, %1$s, затем %2$s и %3$s","Через %n минут, %1$s, затем %2$s и %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Через час, %1$s, затем %2$s и %3$s","Через %n часа, %1$s, затем %2$s и %3$s","Через %n часов, %1$s, затем %2$s и %3$s","Через %n часов, %1$s, затем %2$s и %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Через день, %1$s, затем %2$s и %3$s","Через %n дня, %1$s, затем %2$s и %3$s","Через %n дней, %1$s, затем %2$s и %3$s","Через %n дней, %1$s, затем %2$s и %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Через неделю, %1$s, затем %2$s и %3$s","Через %n недели, %1$s, затем %2$s и %3$s","Через %n недель, %1$s, затем %2$s и %3$s","Через %n недель, %1$s, затем %2$s и %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Через месяц, %1$s, затем %2$s и %3$s","Через %n месяца, %1$s, затем %2$s и %3$s","Через %n месяцев, %1$s, затем %2$s и %3$s","Через %n месяцев, %1$s, затем %2$s и %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Через год, %1$s, затем %2$s и %3$s","Через %n года, %1$s, затем %2$s и %3$s","Через %n лет, %1$s, затем %2$s и %3$s","Через %n лет, %1$s, затем %2$s и %3$s"],
    "Could not generate next recurrence statement" : "Не удалось создать правило следующего повторения",
    "Cancelled: %1$s" : "Событие отменено: %1$s",
    "\"%1$s\" has been canceled" : "Событие «%1$s» отменено",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s принял(а) ваше приглашение",
    "%1$s has tentatively accepted your invitation" : "%1$s предварительно принял(а) ваше приглашение",
    "%1$s has declined your invitation" : "%1$s отклонил(а) ваше приглашение",
    "%1$s has responded to your invitation" : "%1$s ответил(а) на ваше приглашение",
    "Invitation updated: %1$s" : "Изменение приглашения: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s изменил(а) событие «%2$s»",
    "Invitation: %1$s" : "Приглашение: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s приглашает вас принять участие в событии «%2$s»",
    "Organizer:" : "Организатор:",
    "Attendees:" : "Участники:",
    "Title:" : "Название:",
    "When:" : "Когда:",
    "Location:" : "Местонахождение:",
    "Link:" : "Ссылка:",
    "Occurring:" : "Происходит:",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "More options …" : "Дополнительные параметры…",
    "More options at %s" : "Дополнительные параметры на %s",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sunday" : "Воскресенье",
    "January" : "Январь",
    "February" : "Февраль",
    "March" : "Март",
    "April" : "Апрель",
    "May" : "Май",
    "June" : "Июнь",
    "July" : "Июль",
    "August" : "Август",
    "September" : "Сентябрь",
    "October" : "Октябрь",
    "November" : "Ноябрь",
    "December" : "Декабрь",
    "First" : "Первый",
    "Second" : "Второй",
    "Third" : "Третий",
    "Fourth" : "Четвертый",
    "Fifth" : "Пятый",
    "Last" : "Последний",
    "Second Last" : "Предпоследний",
    "Third Last" : "Третий с конца",
    "Fourth Last" : "Четвёртый с конца",
    "Fifth Last" : "Пятый с конца",
    "Contacts" : "Контакты",
    "{actor} created address book {addressbook}" : "{actor} создал(а) адресную книгу «{addressbook}»",
    "You created address book {addressbook}" : "Вы создали адресную книгу «{addressbook}»",
    "{actor} deleted address book {addressbook}" : "{actor} удалил(а) адресную книгу «{addressbook}»",
    "You deleted address book {addressbook}" : "Вы удалили адресную книгу «{addressbook}»",
    "{actor} updated address book {addressbook}" : "{actor} изменил(а) адресную книгу {addressbook}",
    "You updated address book {addressbook}" : "Вы изменили адресную книгу {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} предоставил(а) вам доступ к адресной книге {addressbook}",
    "You shared address book {addressbook} with {user}" : "Вы предоставили доступ пользователю {user} к адресной книге {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} предоставил(а) пользователю {user} доступ к адресной книге {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} закрыла(а) вам доступ к адресной книге {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Вы закрыли пользователю {user} доступ к адресной книге {addressbook} ",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} закрыл(а) пользователю {user} доступ к адресной книге {addressbook}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} закрыла(а) себе доступ к адресной книге {addressbook}",
    "You shared address book {addressbook} with group {group}" : "Вы предоставили группе  {group} доступ к адресной книге {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} предоставил(а) группе {group} доступ к адресной книге {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "Вы закрыли группе {group} доступ к адресной книге {addressbook} ",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} закрыл(а) группе {group} доступ к адресной книге {addressbook}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} создал(а) запись {card} в адресной книге {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Вы создали запись {card} в адресной книге {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} удалил(а) запись {card} в адресной книге {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Вы удалил запись {card} в адресной книге {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} изменил(а) запись {card} в адресной книге {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Вы изменили запись {card} в адресной книге {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Изменение  <strong>контакта</strong> или <strong>адресной книги</strong>",
    "System address book disabled" : "Системная адресная книга отключена",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Системная адресная книга была автоматически отключена во время обновления. Это означает, что она больше не будет доступна пользователям в приложении «Контакты» и других клиентах. Системная адресная книга была отключена, поскольку количество контактов в ней превысило максимальное рекомендуемое значение. Это ограничение установлено для предотвращения проблем с производительностью. Вы можете повторно включить системную адресную книгу с помощью следующей команды: {command}",
    "Accounts" : "Учётные записи",
    "System address book which holds all accounts" : "Системная адресная книга, в которой хранятся все учетные записи",
    "File is not updatable: %1$s" : "Файл не подлежит обновлению: %1$s",
    "Failed to get storage for file" : "Не удалось получить хранилище для файла",
    "Could not write to final file, canceled by hook" : "Не удалось записать результирующий файл, запись отменена вызовом обработчика",
    "Could not write file contents" : "Не удалось записать содержимое файла",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байта"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Ошибка при копировании в целевое расположение, скопировано: %1$s, ожидаемый размер файла: %2$s",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Ожидаемый размер файла составляет %1$s, но из клиента приложения Nextcloud было прочитано и записано в хранилище %2$s. К этому могла привести ошибка при передаче данных на стороне отправителя либо проблема в подсистеме хранения данных на стороне сервера.",
    "Could not rename part file to final file, canceled by hook" : "Не удалось переименовать временный файл в результирующий, операция отменена вызовом обработчика",
    "Could not rename part file to final file" : "Не удалось переименовать временный файл в результирующий",
    "Failed to check file size: %1$s" : "Не удалось проверить размер файла: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Не удалось открыть файл: %1$s (%2$d), файл, похоже, существует",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Не удалось открыть файл: %1$s (%2$d), файл, похоже, не существует",
    "Encryption not ready: %1$s" : "Подсистема шифрования не готова: %1$s",
    "Failed to open file: %1$s" : "Не удалось открыть файл: %1$s",
    "Failed to unlink: %1$s" : "Не удалось разорвать связь: %1$s",
    "Failed to write file contents: %1$s" : "Не удалось записать содержимое файла: %1$s",
    "File not found: %1$s" : "Файл не найден: %1$s",
    "Invalid target path" : "Неверный целевой путь",
    "System is in maintenance mode." : "Сервер находится в режиме обслуживания.",
    "Upgrade needed" : "Требуется обновление",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ваш %s должен быть настроен на использование протокола HTTPS, чтобы можно было использовать CalDAV и CardDAV на iOS/macOS.",
    "Configures a CalDAV account" : "Настройка аккаунта CalDAV",
    "Configures a CardDAV account" : "Настройка аккаунта CardDAV",
    "Events" : "События",
    "Untitled task" : "Задача без названия",
    "Completed on %s" : "Завершено %s",
    "Due on %s by %s" : "До %s %s",
    "Due on %s" : "До %s",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Добро пожаловать в Календарь Nextcloud!\n\nЭто пример события — исследуйте возможности планирования с Календарём Nextcloud, внося любые изменения по своему усмотрению!\n\nС помощью Календаря Nextcloud вы можете:\n- Легко создавать, редактировать и управлять событиями.\n- Создавать несколько календарей и делиться ими с коллегами, друзьями или семьёй.\n- Проверять доступность и показывать другим своё занятое время.\n- Беспрепятственно подключать приложения и устройства через CalDAV.\n- Настроить календарь под себя: повторяющиеся события, уведомления и многое другое.",
    "Example event - open me!" : "Пример события — отройте меня!",
    "System Address Book" : "Системная адресная книга",
    "The system address book contains contact information for all users in your instance." : "Системная адресная книга содержит контактную информацию всех пользователей в вашем инстансе.",
    "Enable System Address Book" : "Включить системную адресную книгу",
    "DAV system address book" : "Системная адресная книга DAV",
    "No outstanding DAV system address book sync." : "Синхронизация системной адресной книги DAV выполнена.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Синхронизация системной адресной книги DAV ещё не запущена, поскольку в этом экземпляре более 1000 пользователей или произошла ошибка. Перезапустите синхронизацию вручную используя команду «occ dav:sync-system-addressbook».",
    "DAV system address book size" : "Размер системной адресной книги DAV",
    "The system address book is disabled" : "Системная адресная книга отключена",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Системная адресная книга включена, но содержит больше установленного лимита в %d контактов",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Системная адресная книга включена и содержит меньше установленного лимита в %d контактов",
    "WebDAV endpoint" : "точка подключения WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Не удалось проверить, правильно ли настроен ваш веб-сервер, чтобы разрешить синхронизацию файлов через WebDAV. Пожалуйста, проверьте вручную.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Веб-сервер ещё не настроен должным образом для синхронизации файлов: похоже, что не работоспособен интерфейс WebDAV.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Ваш веб-сервер настроен должным образом, чтобы обеспечить синхронизацию файлов через WebDAV.",
    "Calendars including events, details and attendees" : "Календари, в том числе события, подробные сведения и участники",
    "Migrated calendar (%1$s)" : "Перенос календаря (%1$s)",
    "Contacts and groups" : "Контакты и группы",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Состояние отсутствия сохранено",
    "Failed to save your absence settings" : "Не удалось сохранить параметры отсутствия",
    "Absence cleared" : "Состояние отсутствия удалено",
    "Failed to clear your absence settings" : "Не удалось удалить параметры отсутствия",
    "First day" : "Первый день",
    "Last day (inclusive)" : "Последний день (включительно)",
    "Out of office replacement (optional)" : "Замена вне офиса (по желанию)",
    "Name of the replacement" : "Название заменяющего устройства",
    "Short absence status" : "Краткий статус отсутствия",
    "Long absence Message" : "Длинное сообщение об отсутствии",
    "Save" : "Сохранить",
    "Disable absence" : "Отключить отсутствие",
    "Failed to load availability" : "Не удалось получить сведения о доступности",
    "Saved availability" : "Сведения о доступности сохранены",
    "Failed to save availability" : "Не удалось сохранить сведения о доступности",
    "to" : "по",
    "Delete slot" : "Удалить интервал",
    "No working hours set" : "Рабочие часы не указаны",
    "Add slot" : "Добавить интервал",
    "Weekdays" : "Дни недели",
    "Pick a start time for {dayName}" : "Выберите время начала в {dayName}",
    "Pick a end time for {dayName}" : "Выберите время окончания в {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматически изменять статус на «Не беспокоить» вне интервала доступности для отключения уведомлений.",
    "Cancel" : "Отмена",
    "Import" : "Импортировать",
    "Error while saving settings" : "Ошибка при сохранении параметров",
    "Contact reset successfully" : "Контакт успешно сброшен",
    "Error while resetting contact" : "Ошибка при сбросе контакта",
    "Contact imported successfully" : " Контакт успешно импортирован",
    "Error while importing contact" : " Ошибка при импорте контакта",
    "Import contact" : "Импортировать контакт",
    "Reset to default" : "Сбросить изменения",
    "Import contacts" : "Импортировать контакты",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Импорт нового файла .vcf удалит существующий контакт по умолчанию и заменит его новым. Продолжить?",
    "Failed to save example event creation setting" : "Не удалось сохранить настройки создания примера события",
    "Failed to upload the example event" : "Не удалось загрузить пример события",
    "Custom example event was saved successfully" : "Настраиваемый пример события успешно сохранён",
    "Failed to delete the custom example event" : "Не удалось удалить настраиваемый пример события",
    "Custom example event was deleted successfully" : "Настраиваемый пример события успешно удалён",
    "Import calendar event" : "Импортировать событие календаря",
    "Uploading a new event will overwrite the existing one." : " Загрузка нового события перезапишет существующее.",
    "Upload event" : "Загрузить событие",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Также установите {calendarappstoreopen}приложение Calendar{linkclose}, или {calendardocopen}подключите ваш ПК и мобильное устройство для синхронизации ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Проверьте правильность настройки {emailopen}почтового сервера{linkclose}.",
    "Calendar server" : "Сервер календаря",
    "Send invitations to attendees" : "Отправить приглашения",
    "Automatically generate a birthday calendar" : "Создавать календарь дней рождения автоматически",
    "Birthday calendars will be generated by a background job." : "Календари дней рождения будут создаваться фоновым процессом.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "И поэтому они станут доступны не моментально, а через некоторое время.",
    "Send notifications for events" : "Отправлять уведомления о событиях",
    "Notifications are sent via background jobs, so these must occur often enough." : "Уведомления будут отправляться через фоновые задания, поэтому они должны выполняться достаточно часто.",
    "Send reminder notifications to calendar sharees as well" : "Отправлять напоминания всем пользователям, имеющим доступ к календарю",
    "Reminders are always sent to organizers and attendees." : "Организаторам и участникам уведомления отправляются во всех случаях.",
    "Enable notifications for events via push" : "Включить уведомления о событиях с помощью push",
    "Example content" : "Пример содержимого",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Пример содержимого демонстрирует возможности Nextcloud. По умолчанию поставляется стандартное содержимое, которое можно заменить настраиваемым.",
    "Availability" : "Рабочее время",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Если вы настроите свой расписание работы, другие пользователи при планировании встреч смогут видеть, когда вас нет в офисе.",
    "Absence" : "Отсутствие",
    "Configure your next absence period." : "Укажите интервал вашего следующего отсутствия.",
    "There was an error updating your attendance status." : "Ошибка обновления статуса участия.",
    "Please contact the organizer directly." : "Обратитесь к организатору напрямую.",
    "Are you accepting the invitation?" : "Принять приглашение?",
    "Tentative" : "Под вопросом",
    "Your attendance was updated successfully." : "Статус участия обновлён.",
    "No results." : "Неверный целевой путь.",
    "Start typing." : "Начать печатать."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
