OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Persönlicher Aktivitäten-Feed für %s",
    "Your feed URL is invalid" : "Ihre Feed-URL ist ungültig",
    "Activity feed for %1$s" : "Aktivitätsfeed für %1$s",
    "Activity feed" : "Feed der Aktivitäten",
    "Your settings have been updated." : "Ihre Einstellungen wurden aktualisiert.",
    "Settings have been updated." : "Die Einstellungen wurden aktualisiert.",
    "remote user" : "Externer Benutzer",
    "Recent activity" : "Neueste Aktivitäten",
    "No activities" : "Keine Aktivitäten",
    "More activities" : "Weitere Aktivitäten",
    "Daily activity summary for %s" : "Tägliche Aktivitätsübersicht für %s",
    "_and %n more…_::_and %n more…_" : ["und %n weitere","und %n weitere…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "In den <a href=\"%s\">Einstellungen</a> können die täglichen Zusammenfassungs-E-Mails deaktiviert werden.",
    "You can disable daily digest emails in the settings: %s" : "Die täglichen Zusammenfassungs-E-Mails können in den Einstellungen deaktiviert werden: %s",
    "All activities" : "Alle Aktivitäten",
    "By others" : "Von anderen",
    "By you" : "Von Ihnen",
    "Activity at %s" : "Aktivität bei %s",
    "Hello %s" : "Hallo %s",
    "Hello %s," : "Hallo %s,",
    "There was some activity at %s" : "Es gab Aktivität bei %s",
    "_and %n more _::_and %n more _" : ["und %n weiterer","und %n weitere"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "In den <a href=\"%s\">Einstellungen</a> können diese E-Mails deaktiviert oder ihre Häufigkeit geändert werden.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "In den Einstellungen können diese E-Mails deaktiviert oder ihre Häufigkeit geändert werden: %s",
    "Mail" : "E-Mail",
    "Push" : "Push",
    "Activity" : "Aktivität",
    "Notifications" : "Benachrichtigungen",
    "This application enables people to view a log of activities about them, their files or other data." : "Diese Anwendung ermöglicht es Personen, ein Protokoll ihrer Aktivitäten, ihrer Dateien oder anderer Daten anzuzeigen.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Mit dieser App können Benutzer Aktionen im Zusammenhang mit ihren Dateien und Daten in Nextcloud sehen.\n\t\tJede Person kann ihre individuellen Aktivitätseinstellungen in den persönlichen Einstellungen konfigurieren,\n\t\tum auszuwählen, welche Aktivität auf Mobiltelefone übertragen werden soll, senden Sie sie per E-Mail\n\t\toder ob jeden Morgen eine tägliche Zusammenfassung gesendet wird.\n\t\tWeitere Informationen finden Sie in der Aktivitätsdokumentation.",
    "Send email" : "E-Mail senden",
    "Send push notification" : "Push-Benachrichtigung senden",
    "Activity notification configuration" : "Konfiguration der Aktivitätsbenachrichtigung",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "_Downloaded %n time (%s in the last 30 days)_::_Downloaded %n times (%s in the last 30 days)_" : ["%n mal heruntergeladen (%s mal in den letzten 30 Tagen)","%n mal heruntergeladen (%s mal in den letzten 30 Tagen)"],
    "_Downloaded %n time_::_Downloaded %n times_" : ["%n mal heruntergeladen","%n mal heruntergeladen"],
    "You need to set up your email address before you can receive notification emails." : "Bevor Sie E-Mail-Benachrichtigungen empfangen können, müssen Sie Ihre E-Mail-Adresse einrichten.",
    "Send activity emails" : "E-Mails zu Aktivitäten senden",
    "As soon as possible" : "So bald wie möglich",
    "Hourly" : "Stündlich",
    "Daily" : "täglich",
    "Weekly" : "wöchentlich",
    "You commented" : "Sie haben kommentiert",
    "Message deleted by author" : "Nachricht vom Autor gelöscht",
    "Open {filename}" : "{filename} öffnen",
    "in {path}" : "in {path}",
    "Home" : "Startseite",
    "Could not load activities" : "Aktivitäten konnten nicht geladen werden",
    "Loading activities" : "Lade Aktivitäten",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzufügungen, Änderungen und Freigaben an",
    "No activity yet" : "Bislang keine Aktivitäten",
    "New activities" : "Neue Aktivitäten",
    "Loading more activities" : "Lade weitere Aktivitäten",
    "No more activities." : "Keine weiteren Aktivitäten",
    "Could not enable RSS link" : "RSS-Link konnte nicht aktiviert werden",
    "RSS link copied to clipboard" : "RSS-Link in die Zwischenablage kopiert",
    "Could not copy the RSS link, please copy manually:" : "Der RSS-Link konnte nicht kopiert werden, bitte kopieren sie ihn manuell:",
    "Activity settings" : "Aktivitätseinstellungen",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "RSS feed" : "RSS-Feed",
    "Copy RSS feed link" : "RSS-Feed-Link kopieren",
    "Personal notification settings" : "Persönliche Benachrichtigungseinstellungen",
    "Unable to load the activity list" : "Aktivitätenliste kann nicht geladen werden",
    "Choose for which activities you want to get an email or push notification." : "Wählen Sie aus, für welche Aktivitäten Sie eine E-Mail oder eine Push-Benachrichtigung erhalten möchten.",
    "Choose for which activities you want to get a push notification." : "Wählen Sie aus, für welche Aktivitäten Sie eine Push-Benachrichtigung erhalten möchten.",
    "Notification" : "Benachrichtigung",
    "Enable notification emails" : "Benachrichtigungs-E-Mails einschalten",
    "Daily activity summary" : "Tägliche Aktivitätsübersicht",
    "Send daily activity summary in the morning" : "Morgens eine tägliche Aktivitätsübersicht senden",
    "Default settings" : "Standardeinstellungen",
    "Configure the default notification settings for new accounts." : "Standardbenachrichtigungseinstellungen für neue Konten konfigurieren.",
    "Unable to save the settings" : "Einstellungen konnten nicht gespeichert werden",
    "No more events to load" : "Keine weiteren Ereignisse zu laden"
},
"nplurals=2; plural=(n != 1);");
