const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.OC.filePath('firstrunwizard', '', 'js/main-Csyvloc9.chunk.mjs'),window.OC.filePath('firstrunwizard', '', 'js/NcModal-DHryP_87-CfIGJ5TI.chunk.mjs'),window.OC.filePath('firstrunwizard', '', 'js/index-EKlYWjzp.chunk.mjs')])))=>i.map(i=>d[i]);
import{_ as t}from"./modulepreload-polyfill-CBWYtosv.chunk.mjs";document.addEventListener("DOMContentLoaded",async function(){(await t(()=>import("./main-Csyvloc9.chunk.mjs"),__vite__mapDeps([0,1,2]),import.meta.url)).open()});
//# sourceMappingURL=firstrunwizard-activate.mjs.map
