import{g as i}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as c}from"./autoit-TaGBUO9K.chunk.mjs";function s(r,a){for(var o=0;o<a.length;o++){const t=a[o];if(typeof t!="string"&&!Array.isArray(t)){for(const e in t)if(e!=="default"&&!(e in r)){const n=Object.getOwnPropertyDescriptor(t,e);n&&Object.defineProperty(r,e,n.get?n:{enumerable:!0,get:()=>t[e]})}}}return Object.freeze(Object.defineProperty(r,Symbol.toStringTag,{value:"Module"}))}var f=c();const l=i(f),u=s({__proto__:null,default:l},[f]);export{u as a};
//# sourceMappingURL=autoit-Bzx2qU2M.chunk.mjs.map
