OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s نىڭ شەخسىي پائالىيەت يىمىكى",
    "Your feed URL is invalid" : "سىزنىڭ URL ئادرېسىڭىز ئىناۋەتسىز",
    "Activity feed for %1$s" : "%1$s نىڭ پائالىيەت يىمىكى",
    "Activity feed" : "پائالىيەت يەملىرى",
    "Your settings have been updated." : "تەڭشەكلىرىڭىز يېڭىلاندى.",
    "Settings have been updated." : "تەڭشەكلەر يېڭىلاندى.",
    "remote user" : "يىراقتىكى ئىشلەتكۈچى",
    "Recent activity" : "يېقىنقى پائالىيەت",
    "No activities" : "پائالىيەت يوق",
    "More activities" : "تېخىمۇ كۆپ پائالىيەتلەر",
    "Daily activity summary for %s" : "%s نىڭ كۈندىلىك پائالىيەت خۇلاسىسى",
    "_and %n more…_::_and %n more…_" : ["يەنە %n تال...","يەنە %n تال..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "سىز كۈندىلىك ھەزىم قىلىش ئېلىخېتىنى <a href=\"%s\">تەڭشەك</a> دە ئېتىۋېتەلەيسىز.",
    "You can disable daily digest emails in the settings: %s" : "سىز كۈندىلىك ھەزىم قىلىش ئېلىخېتىنى تەڭشەكتە ئېتىۋېتەلەيسىز: %s",
    "All activities" : "بارلىق پائالىيەتلەر",
    "By others" : "باشقىلار تەرىپىدىن",
    "By you" : "سىز بىلەن",
    "Activity at %s" : "%s دىكى پائالىيەت",
    "Hello %s" : "ياخشىمۇسىز %s",
    "Hello %s," : "ياخشىمۇسىز %s.",
    "There was some activity at %s" : "%s دە بەزى پائالىيەتلەر بولغان",
    "_and %n more _::_and %n more _" : ["يەنە %n دانە","يەنە %n دانە"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "بۇ ئېلېكترونلۇق خەتلەرنىڭ چاستوتىنى ئۆزگەرتەلەيسىز ياكى <a href=\"%s\"> تەڭشەك </a> دە چەكلىيەلەيسىز.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "بۇ ئېلېكترونلۇق خەتلەرنىڭ چاستوتىنى ئۆزگەرتەلەيسىز ياكى تەڭشەكلەردە چەكلىيەلەيسىز:%s",
    "Mail" : "خەت",
    "Push" : "ئىتتىرىش",
    "Activity" : "پائالىيەت",
    "Notifications" : "ئۇقتۇرۇش",
    "This application enables people to view a log of activities about them, their files or other data." : "بۇ پروگرامما كىشىلەرگە مۇناسىۋەتلىك ھۆججەتلەرنى ، ھۆججەتلىرىنى ياكى باشقا سانلىق مەلۇماتلارنى كۆرەلەيدۇ.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "بۇ ئەپ كىشىلەرنىڭ Nextcloud دىكى ھۆججەتلىرى ۋە سانلىق مەلۇماتلىرىغا مۇناسىۋەتلىك ھەرىكەتلەرنى كۆرەلەيدۇ.\n\t\tھەر بىر ئادەم شەخسىي تەڭشەكلەردە شەخسىي پائالىيەت تەڭشەكلىرىنى تەڭشىيەلەيدۇ ،\n\t\tئېلېكترونلۇق خەت ئارقىلىق قايسى پائالىيەتنى يان تېلېفونغا ئىتتىرىش كېرەكلىكىنى تاللاش\n\t\tياكى ھەر كۈنى ئەتىگەندە كۈندىلىك خۇلاسە ئەۋەتىلەمدۇ يوق.\n\t\tپائالىيەت ھۆججىتىدە تېخىمۇ كۆپ ئۇچۇرلار بار.",
    "Send email" : "ئېلېكترونلۇق خەت ئەۋەتىڭ",
    "Send push notification" : "ئىتتىرىش ئۇقتۇرۇشى ئەۋەتىڭ",
    "Activity notification configuration" : "پائالىيەت ئۇقتۇرۇشى",
    "Today" : "بۈگۈن",
    "Yesterday" : "تۈنۈگۈن",
    "You need to set up your email address before you can receive notification emails." : "ئۇقتۇرۇش ئېلېكترونلۇق خەتلىرىنى تاپشۇرۇۋېلىشتىن بۇرۇن ئېلېكترونلۇق خەت ئادرېسىڭىزنى تەڭشىشىڭىز كېرەك.",
    "Send activity emails" : "پائالىيەت ئېلېكترونلۇق خەت ئەۋەتىڭ",
    "As soon as possible" : "ئىمكانقەدەر تېز",
    "Hourly" : "سائەتلىك",
    "Daily" : "كۈندىلىك",
    "Weekly" : "ھەپتىلىك",
    "You commented" : "باھا بەردىڭىز",
    "Message deleted by author" : "ئاپتور تەرىپىدىن ئۆچۈرۈلگەن ئۇچۇر",
    "Open {filename}" : "{filename} نى ئېچىڭ",
    "in {path}" : "{path} دە",
    "Home" : "ئۆي",
    "Could not load activities" : "پائالىيەتلەرنى يۈكلىيەلمىدى",
    "Loading activities" : "يۈكلەش پائالىيىتى",
    "This stream will show events like additions, changes & shares" : "بۇ ئېقىن قوشۇش ، ئۆزگەرتىش ۋە ئورتاقلىشىش قاتارلىق ۋەقەلەرنى كۆرسىتىدۇ",
    "No activity yet" : "تېخى پائالىيەت يوق",
    "Loading more activities" : "تېخىمۇ كۆپ پائالىيەتلەرنى يۈكلەۋاتىدۇ",
    "No more activities." : "ئەمدى پائالىيەت يوق.",
    "Could not enable RSS link" : "RSS ئۇلىنىشىنى قوزغىتالمىدى",
    "RSS link copied to clipboard" : "RSS ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى",
    "Could not copy the RSS link, please copy manually:" : "RSS ئۇلانمىسىنى كۆچۈرەلمىدىڭىز ، قولدا كۆچۈرۈڭ:",
    "Activity settings" : "پائالىيەت تەڭشەكلىرى",
    "Enable RSS feed" : "RSS تەمىناتىنى قوزغىتىڭ",
    "RSS feed" : "RSS يىمىكى",
    "Copy RSS feed link" : "RSS يەم ئۇلانمىسىنى كۆچۈرۈڭ",
    "Personal notification settings" : "شەخسىي ئۇقتۇرۇش تەڭشىكى",
    "Unable to load the activity list" : "پائالىيەت تىزىملىكىنى يۈكلىيەلمىدى",
    "Choose for which activities you want to get an email or push notification." : "قايسى پائالىيەتلەرگە ئېلېكترونلۇق خەت ئالماقچى ياكى ئىتتىرىش ئۇقتۇرۇشىنى تاللاڭ.",
    "Choose for which activities you want to get a push notification." : "ئىتتىرىش ئۇقتۇرۇشىغا ئېرىشمەكچى بولغان پائالىيەتلەرنى تاللاڭ.",
    "Notification" : "ئۇقتۇرۇش",
    "Enable notification emails" : "ئۇقتۇرۇش ئېلېكترونلۇق خەتلىرىنى قوزغىتىڭ",
    "Daily activity summary" : "كۈندىلىك پائالىيەت خۇلاسىسى",
    "Send daily activity summary in the morning" : "ئەتىگەندە كۈندىلىك پائالىيەت خۇلاسىسىنى ئەۋەتىڭ",
    "Default settings" : "كۆڭۈلدىكى تەڭشەكلەر",
    "Configure the default notification settings for new accounts." : "يېڭى ھېساباتلارنىڭ سۈكۈتتىكى ئۇقتۇرۇش تەڭشىكىنى سەپلەڭ.",
    "Unable to save the settings" : "تەڭشەكلەرنى ساقلىيالمىدى",
    "No more events to load" : "يۈكلەيدىغان ئىشلار يوق"
},
"nplurals=2; plural=(n != 1);");
