OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Pārlases (brute-force) iestatījumi",
    "Whitelist IPs" : "Baltā saraksta IP adreses",
    "Comment" : "Piebilde",
    "Add" : "Pievienot",
    "Save" : "Saglabāt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
