OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Файл татах хязгаар",
    "File link share download limit" : "Файлын холбоос хуваалцалт татах хязгаар",
    "This app allows limiting the number of downloads for external link shares." : "Энэ програм нь гадаад холбоосоор хуваалцсан файлуудын татан авалтын тоог хязгаарлах боломжийг олгоно.",
    "The minimum limit is 1" : "Хамгийн бага хязгаар нь 1",
    "Failed to set download limit" : "Татах хязгаар тохируулж чадсангүй",
    "Failed to remove download limit" : "Татах хязгаар устгаж чадсангүй",
    "Limit downloads" : "Татах хязгаарлах",
    "Set download limit" : "Татах хязгаар тохируулах",
    "Setting a new limit will reset the download count" : "Шинэ хязгаар тохируулах нь татах тоог шинэчилнэ",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 татах боломж үлдсэн","{count} татах боломж үлдсэн"],
    "Download limit" : "Татах хязгаар",
    "Configure the default download limit for external shares." : "Гадны хуваалцалтуудын өгөгдмөл татах хязгаарыг тохируулах.",
    "Default download limit for external shares" : "Гадны хуваалцалтуудын өгөгдмөл татах хязгаар",
    "Set default download limit" : "Өгөгдмөл татах хязгаар тохируулах",
    "You have reached the maximum amount of downloads allowed" : "Та зөвшөөрөгдсөн татаж авах дээд хэмжээнд хүрсэн",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Энэ хуваалцсан файл нь хязгаарлагдсан тооны татаж авалттай. Та шинэ татаж авалт эхлүүлэхдээ итгэлтэй байна уу?",
    "Failed to set default download limit" : "Өгөгдмөл татах хязгаар тохируулж чадсангүй",
    "Failed to remove default download limit" : "Өгөгдмөл татах хязгаар устгаж чадсангүй"
},
"nplurals=2; plural=(n != 1);");
