"use strict";(self.webpackChunkrecommendations=self.webpackChunkrecommendations||[]).push([["node_modules_nextcloud_vue_dist_Components_NcSelect_mjs"],{7607:(e,s,n)=>{n.r(s),n.d(s,{default:()=>o.N});var o=n(118)}}]);