OC.L10N.register(
    "logreader",
    {
    "Logging" : "רישום",
    "Log Reader" : "קורא רישומים",
    "A log reader for Nextcloud" : "קורא רישומים ל־Nextcloud",
    "Log reader for Nextcloud" : "קורא רישומים ל־Nextcloud",
    "Level" : "רמה",
    "App" : "יישומון",
    "Time" : "זמן",
    "Download logs" : "הורדת רישומים",
    "Relative" : "יחסי",
    "Message" : "הודעה",
    "Show details" : "הצגת פרטים",
    "Info" : "פרטים",
    "Warning" : "אזהרה",
    "Error" : "שגיאה"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
