OC.L10N.register(
    "photos",
    {
    "Public link" : "公开链接",
    "Photos" : "照片",
    "On This Day" : "在这一天",
    "Your memories under your control" : "您的回忆在您的掌控之下",
    "All media" : "所有媒体",
    "Videos" : "视频",
    "Albums" : "相册",
    "Collaborative albums" : "协作相册",
    "People" : "人物",
    "Folders" : "文件夹",
    "Favorites" : "收藏",
    "On this day" : "当年今日",
    "Shared with you" : "与你共享",
    "Tags" : "标签",
    "Places" : "地点",
    "Map" : "地图",
    "Photos settings" : "照片设置",
    "Mark selection as favorite" : "将已选项标记为最爱",
    "Add selection to favorites" : "添加已选项至最爱",
    "Remove selection from favorites" : "从最爱中移除所选项",
    "This name is already in use." : "此名称已被使用。",
    "\"{char}\" is not allowed inside a filename." : "文件名中不允许出现 “{char}”",
    "Invalid filename." : "无效文件名称。",
    "Name of the album" : "相册名称",
    "Location of the album" : "相册位置",
    "Back" : "返回",
    "Add collaborators" : "添加协作者",
    "Save" : "保存",
    "Create album" : "创建相册",
    "Add to Album" : "添加至相册",
    "Add selection to album {albumName}" : "将所选项加入相册 {ablumName}",
    "Shared by" : "共享人",
    "Create a new album." : "创建新相册。",
    "Create new album" : "创建新相册",
    "New album" : "新相册",
    "_%n item_::_%n photos and videos_" : ["%n 张照片与视频"],
    "Failed to fetch collaborators list." : "无法获取协作者列表。",
    "Failed to update album." : "无法更新相册。",
    "Add people or groups who can edit your album" : "添加可以编辑您相册的用户与群组",
    "Search people or groups" : "搜索用户或群组",
    "No recommendations. Start typing." : "无建议。开始输入。",
    "Copy the public link" : "复制公开链接",
    "Public link copied!" : "已复制公开链接！",
    "Copy public link" : "复制公开链接",
    "Delete the public link" : "删除公开链接",
    "Create public link share" : "创建公开链接分享",
    "Share via public link" : "通过公开链接分享",
    "This collection does not exist" : "此收藏不存在",
    "An error occurred" : "发生错误",
    "No picture for this day" : "这一天没有照片",
    "Picture taken on this day will show up here." : "在这一天拍摄的照片将显示在这。",
    "More photos from this day" : "这一天更多的照片",
    "_%n photos_::_%n photos_" : ["%n张照片"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n张尚未指派的照片"],
    "Favorite" : "收藏",
    "Favorite image, open the full size \"{name}\" image" : "收藏图像，打开 “{name}” 原图。",
    "Open the full size \"{name}\" image" : "打开图片 “{name}” 的完整尺寸",
    "Select image {imageName}" : "选择图像 {imageName}",
    "Open the \"{name}\" folder" : "打开 “{name}” 文件夹",
    "Go back" : "返回",
    "Select a custom date range" : "选择自定义日期范围",
    "Select a date range" : "选择日期范围",
    "Date range" : "日期范围",
    "Select filters" : "选择筛选器",
    "Dates" : "日期",
    "Jump to specific date in list" : "跳转至列表中指定时间",
    "Jump to {date}" : "跳转至 {date}",
    "Add to {destination}" : "添加到 {destination}",
    "The destination folder is owned by {owner}" : "目标文件夹所有者为 {owner}",
    "There are no photos or videos yet!" : "还没有照片或视频！",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Squared photos view" : "方形照片视图",
    "Delete source directory" : "删除源目录",
    "Pick folder" : "选择文件夹",
    "Select a source folder for your media" : "为你的媒体文件选择一个源文件夹",
    "Media folders" : "多媒体文件夹",
    "Choose the folders from where photos and videos are shown." : "选择显示照片和视频的文件夹。",
    "All folders" : "所有文件夹",
    "Add a Photos source for the timelines" : "为时间轴添加一个照片源",
    "Add folder" : "添加文件夹",
    "Home" : "首页",
    "Select the default upload location for your media" : "选择你的媒体文件默认上传位置",
    "Upload folder" : "上传文件夹",
    "General" : "常规",
    "_%n photo_::_%n photos_" : ["%n张照片"],
    "Unselect all" : "取消全选",
    "Add photos to this album" : "添加照片至此相册",
    "Manage collaborators for this album" : "管理此相册的协作者。",
    "Open actions menu" : "打开操作菜单",
    "Edit album details" : "编辑相册详情",
    "Download all files in album" : "下载相册中的所有文件",
    "Delete album" : "删除相册",
    "Download selected files" : "下载选择的文件",
    "Remove selection from album" : "从相册中移除所选项",
    "This album does not have any photos or videos yet!" : "这个相册中还没有任何照片或视频！",
    "Add photos to {albumName}" : "添加照片至相簿 {albumName}",
    "Manage collaborators" : "管理协作者",
    "Save collaborators for this album." : "保存此相册的协作者。",
    "Cover photo for album {albumName}" : "相册 {albumName} 的封面照片",
    "There is no album yet!" : "还没有相册！",
    "This person could not be found" : "找不到这个人",
    "Rename person" : "修改此人姓名",
    "Merge with different person" : "与另一个人合并为同一人",
    "Download selected photos" : "下载所选照片",
    "Remove from favorites" : "从收藏中移除",
    "Remove person" : "移除这个人",
    "Name of this person" : "这个人的名字",
    "Save." : "保存。",
    "Merge person" : "合并人物",
    "Move to different person" : "移动到其他人",
    "_Move photo to a different person_::_Move photos to a different person_" : ["将照片移动给其他人"],
    "_Remove photo from person_::_Remove photos from person_" : ["从关联人移除照片"],
    "This might take some time depending on the size of your photo library." : "取决于您的相册库大小，这可能会花上一些时间。",
    "Recognized people will show up here" : "被识别出的人会显示在此处",
    "This folder does not exist" : "此文件夹不存在",
    "Loading folders…" : "正在加载文件夹…",
    "No photos in here" : "此处没有照片",
    "Taken on {date} at {time}" : "拍摄于 {date} {time}",
    "This place does not have any photos or videos yet!" : "这个地点还没有任何照片和视频！",
    "Add photos to this place" : "添加照片至此地点",
    "Cover photo for place {placeName}" : "地点{placeName}的封面照片",
    "There is no place yet!" : "还没有地点！",
    "Cover photo for shared album {albumName}" : "共享相册的封面照片 {albumName}",
    "Back to tags overview" : "回到标签一览",
    "No photos with this tag yet" : "还没有照片拥有该标签",
    "No tags yet" : "尚无标签",
    "Photos with tags will show up here" : "带标签的照片将显示在此处",
    "Popular tags" : "常用标签",
    "All tags" : "所有标签",
    "Create new album from filters" : "从筛选器创建新相册",
    "One of the source folders does not exist" : "其中一个源文件夹不存在",
    "Add to album" : "添加至相册",
    "Delete selection" : "删除选择项",
    "No photos or videos in here" : "此处没有图片或视频",
    "Unassigned faces" : "未指派的人脸",
    "Failed to fetch collection." : "无法获取收藏。",
    "Failed to fetch collections list." : "无法获取收藏列表。",
    "Failed to fetch faces list." : "无法获取人脸列表。",
    "Error fetching files" : "获取文件时出错",
    "All your media" : "所有媒体",
    "Album {title}" : "相册{title}",
    "Shared Albums" : "共享的相册",
    "Shared album {title}" : "共享的相册{title}",
    "Public album {title}" : "公共相册{title}",
    "Tagged photos" : "标记的照片",
    "Tagged photo {title}" : "标记的相册{title}",
    "{title}'s face" : "{title}的脸",
    "Last week" : "上周",
    "Last Month" : "上个月",
    "Custom…" : "自定义…",
    "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
    "Details" : "详情",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "无法将 {fileBaseName} 添加到收藏 {collectionFileName}",
    "Failed to delete {fileBaseName}" : "无法删除 {fileBaseName}",
    "Failed to create {collectionFileName}" : "无法创建 {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "无法将 {currentCollectionFileName} 重命名为 {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "无法使用 {properties} 更新 {collectionFileName} 的属性",
    "Delete collection" : "删除收藏",
    "Leave shared album" : "离开共享相册",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "是否确定要删除 {collectionName}？此操作无法撤销。",
    "Failed to delete {collectionFileName}" : "无法删除 {collectionFileName}",
    "Cancel" : "取消",
    "Confirm" : "确认",
    "Failed to move {fileBaseName} to person {faceName}" : "无法将 {fileBaseName} 移至人物 {faceName}",
    "Failed to remove {fileBaseName}" : "无法移除 {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "无法将 {oldName} 重命名为 {faceName}",
    "Failed to delete {faceName}" : "无法删除 {faceName}",
    "Failed to delete {fileId}" : "无法删除 {fileId}",
    "Failed to delete {fileName}" : "无法删除 {fileName}",
    "Failed to set favorite state for {fileId}" : "无法为 {fileId} 设置收藏状态",
    "Failed to set favorite state for {fileName}" : "无法为 {fileName} 设置收藏状态",
    "Could not load photos folder" : "无法加载照片文件夹",
    "Group" : "群组",
    "Remove {collaboratorLabel} from the collaborators list" : "将 {collaboratorLabel} 移除协作者列表",
    "Enable squared photos view" : "启用方形照片视图",
    "Choose default Photos upload and Albums location" : "选择预设照片上传与相册位置",
    "Choose a different folder" : "选择一个不同的文件夹",
    "View" : "查看",
    "Choose the folder where photos and albums are uploaded to." : "选择照片和相册上传的文件夹。",
    "Loading folders …" : "正在加载文件夹 …"
},
"nplurals=1; plural=0;");
