OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Lagt til i listen over klarerte servere",
    "No server found with ID: %s" : "Kunne ikke finne tjener med ID: %s",
    "Could not remove server" : "Kunne ikke fjerne tjener",
    "Server is already in the list of trusted servers." : "Serveren er allerede i listen av klarerte servere.",
    "No server to federate with found" : "Ingen server å sammenknytte med ble funnet",
    "Could not add server" : "Kunne ikke legge til server",
    "Trusted servers" : "Klarerte servere",
    "Federation" : "Sammenknytting",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Sammenknytting lar deg koble til andre klarerte servere for å utveksle kontokatalogen.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Sammenknytting lar deg koble til andre klarerte servere for å utveksle kontokatalogen. Dette brukes for eksempel til å automatisk fullføre eksterne kontoer for deling i organisasjonsnettverk.",
    "Add" : "Legg til",
    "Delete" : "Slett",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Sammenknytting lar deg koble til andre klarerte servere for å utveksle kontokatalogen. Dette brukes for eksempel til å automatisk fullføre eksterne kontoer for deling i organisasjonsnettverk. Det er ikke nødvendig å legge til en server som klarert server for å opprette en delt delt ressurs i forbund.",
    "+ Add trusted server" : "+ Legg til klarert server",
    "Trusted server" : "Klarert server"
},
"nplurals=2; plural=(n != 1);");
