<?php
// This file is auto-generated. Do not edit!
return array('Avst'=>'авестийская','Adlm'=>'адлам','Moon'=>'азбука муна','Shaw'=>'алфавит Шоу','Arab'=>array(''=>'арабица','variant'=>array('персидско-арабская')),'Armi'=>'арамейская','Armn'=>'армянская','Afak'=>'афака','Bali'=>'балийская','Bamu'=>'бамум','Bass'=>'басса (вах)','Batk'=>'батакская','Beng'=>'бенгальская','Blis'=>'блиссимволика','Bopo'=>'бопомофо','Brah'=>'брахми','Bugi'=>'бугинизийская','Buhd'=>'бухид','Vaii'=>'вайская','Wara'=>'варанг-кшити','Visp'=>'видимая речь','Wole'=>'волеаи','Syrn'=>'восточно-сирийская','Glag'=>'глаголица','Goth'=>'готская','Gran'=>'грантха','Grek'=>'греческая','Geor'=>'грузинская','Geok'=>'грузинская хуцури','Gujr'=>'гуджарати','Guru'=>'гурмукхи','Latg'=>'гэльская латинская','Deva'=>'деванагари','Dsrt'=>'дезерет','Jamo'=>'джамо','Tfng'=>'древнеливийская','Perm'=>'древнепермская','Dupl'=>'дуплоянская скоропись','Hebr'=>'еврейская','Egyd'=>'египетская демотическая','Egyh'=>'египетская иератическая','Egyp'=>'египетская иероглифическая','Syrj'=>'западносирийская','Qaag'=>'зоджи','Yiii'=>'и','Kali'=>'кайа','Kthi'=>'кайтхи','Cans'=>'канадское слоговое письмо','Knda'=>'каннада','Cari'=>'карийская','Kana'=>'катакана','Hrkt'=>'катакана и хирагана','Cprt'=>'кипрская','Cyrl'=>'кириллица','Cirt'=>'кирт','Hani'=>'китайская','Copt'=>'коптская','Kore'=>'корейская','Kpel'=>'кпелле','Khar'=>'кхароштхи','Khmr'=>'кхмерская','Sind'=>'кхудавади','Lana'=>'ланна','Laoo'=>'лаосская','Latn'=>'латиница','Latf'=>'латинская фрактура','Lepc'=>'лепха','Lydi'=>'лидийская','Limb'=>'лимбу','Lina'=>'линейное письмо А','Linb'=>'линейное письмо Б','Lisu'=>'лису','Lyci'=>'лициан','Loma'=>'лома','Hluw'=>'лувийские иероглифы','Maya'=>'майя','Mlym'=>'малаялам','Mand'=>'мандейская','Mtei'=>'манипури','Mani'=>'манихейская','Zmth'=>'математические обозначения','Mend'=>'менде','Mero'=>'мероитская','Merc'=>'мероитская курсивная','Mong'=>'монгольская','Mroo'=>'мро','Mymr'=>'мьянманская','Nbat'=>'набатейская','Nkgb'=>'наси геба','Aran'=>'насталик','Zzzz'=>'неизвестная письменность','Zxxx'=>'нет письменности','Nkoo'=>'нко','Talu'=>'новый тайский ле','Nshu'=>'нюй-шу','Zyyy'=>'общепринятая','Ogam'=>'огамическая','Olck'=>'ол чики','Orya'=>'ория','Orkh'=>'орхоно-енисейская','Osma'=>'османская','Phag'=>'пагспа','Palm'=>'пальмиры','Prti'=>'парфянская','Hmng'=>'пахау хмонг','Phlv'=>'пахлави книжная','Phlp'=>'пахлави псалтирная','Phli'=>'пехлевийская','Plrd'=>'поллардовская фонетика','Rjng'=>'реджангская','Roro'=>'ронго-ронго','Runr'=>'руническая','Samr'=>'самаритянская','Sara'=>'сарати','Saur'=>'саураштра','Narb'=>'северноаравийское','Sylo'=>'силоти нагри','Zsym'=>'символы','Sinh'=>'сингальская','Syrc'=>'сирийская','Syre'=>'сирийская эстрангело','Sora'=>'сора-сонпенг','Hung'=>'старовенгерская','Ital'=>'староитальянская','Xpeo'=>'староперсидская','Cyrs'=>'старославянская','Sarb'=>'староюжноарабская','Sund'=>'сунданская','Tglg'=>'тагалог','Tagb'=>'тагбанва','Tavt'=>'тай-вьет','Thai'=>'тайская','Tale'=>'тайский ле','Takr'=>'такри','Taml'=>'тамильская','Thaa'=>'тана','Tang'=>'тангутское меня','Telu'=>'телугу','Teng'=>'тенгварская','Tibt'=>'тибетская','Tirh'=>'тирхута','Hant'=>array(''=>'традиционная','stand-alone'=>array('традиционная китайская')),'Ugar'=>'угаритская','Zinh'=>'унаследованная','Hans'=>array(''=>'упрощенная','stand-alone'=>array('упрощенная китайская')),'Phnx'=>'финикийская','Hang'=>'хангыль','Rohg'=>'ханифи','Hano'=>'хануну','Hanb'=>'ханьб','Inds'=>'хараппская (письменность долины Инда)','Hira'=>'хирагана','Khoj'=>'ходжики','Cakm'=>'чакмийская','Cham'=>'чамская','Cher'=>'чероки','Jurc'=>'чжурчжэньская','Shrd'=>'шарада','Brai'=>'шрифт Брайля','Xsux'=>'шумеро-аккадская клинопись','Zsye'=>'эмодзи','Ethi'=>'эфиопская','Java'=>'яванская','Sgnw'=>'язык знаков','Jpan'=>'японская','Aghb'=>'Aghb','Ahom'=>'Ahom','Bhks'=>'Bhks','Chrs'=>'Chrs','Cpmn'=>'Cpmn','Diak'=>'Diak','Dogr'=>'Dogr','Elba'=>'Elba','Elym'=>'Elym','Gong'=>'Gong','Gonm'=>'Gonm','Hatr'=>'Hatr','Hmnp'=>'Hmnp','Kawi'=>'Kawi','Kits'=>'Kits','Mahj'=>'Mahj','Maka'=>'Maka','Marc'=>'Marc','Medf'=>'Medf','Modi'=>'Modi','Mult'=>'Mult','Nagm'=>'Nagm','Nand'=>'Nand','Newa'=>'Newa','Osge'=>'Osge','Ougr'=>'Ougr','Pauc'=>'Pauc','Sidd'=>'Sidd','Sogd'=>'Sogd','Sogo'=>'Sogo','Soyo'=>'Soyo','Tnsa'=>'Tnsa','Toto'=>'Toto','Vith'=>'Vith','Wcho'=>'Wcho','Yezi'=>'Yezi','Zanb'=>'Zanb');
