OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Verziók",
    "This application automatically maintains older versions of files that are changed." : "Ez az alkalmazás automatikusan karbantartja a változtatott fájlok régebbi verzióit.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Ez az alkalmazás automatikusan karbantartja a változtatott fájlok régebbi verzióit. Amikor be van kapcsolva, egy rejtett verziómappa jön létre sz összes felhasználó tárhelyén, amelyet a korábbi verziók tárolására használ a rendszer. A felhasználó bármikor visszatérhet egy korábbi verzióhoz a webes felületen keresztül, és a lecserélt fájl maga is előzménnyé válik. Az alkalmazás automatikusan kezeli a verziómappát, biztosítva, hogy a fiók ne fusson ki a kvótájából az előzmények miatt.\n\t\tA fájlelőzmények lejárati dátumán kívül az alkalmazás sose használ az elérhető szabad terület 50%-ánál többet. Ha a tárolt előzmények túllépik ezt a korlátot, az alkalmazás addig törli a legrégebbi verziókat, amíg meg nem felel a korlátozásnak. További információ érhető el a Verziók dokumentációjában.",
    "Current version" : "Jelenlegi verzió",
    "Initial version" : "Kezdeti verzió",
    "You" : "Ön",
    "Actions for version from {versionHumanExplicitDate}" : "A verzióra vonatkozó műveletek: {versionHumanExplicitDate}",
    "Name this version" : "Verzió elnevezése",
    "Edit version name" : "Verziónév szerkesztése",
    "Compare to current version" : "Összehasonlítás a jelenlegi verzióval",
    "Restore version" : "Verzió helyreállítása",
    "Download version" : "Verzió letöltése",
    "Delete version" : "Verzió törlése",
    "Cancel" : "Mégse",
    "Remove version name" : "Verziónév eltávolítása",
    "Save version name" : "Verziónév mentése",
    "Version name" : "Verziónév",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "A nevesített verziók meg lesznek őrizve, és ki lesznek zárva az automatikus takarítás alól, ha a tárkvóta betelik.",
    "Initial version restored" : "Kezdeti verzió helyreállítva",
    "Version restored" : "Verzió helyreállítva",
    "Could not restore version" : "Nem sikerült helyreállítani a verziót",
    "Could not set version label" : "Nem sikerült beállítani a verziócímkét",
    "Could not delete version" : "Nem sikerült törölni a verziót",
    "File versions" : "Fájlverziók"
},
"nplurals=2; plural=(n != 1);");
