OC.L10N.register(
    "support",
    {
    "Link:" : "ბმული:",
    "Forum" : "ფორუმი",
    "News" : "სიახლეები",
    "Like our Facebook page" : "მოიწონეთ ჩვენი Facebook გვერდი",
    "Follow us on Twitter" : "გამოგვყევით Twitter-ზე",
    "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
    "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები"
},
"nplurals=2; plural=(n!=1);");
