.favorite-marker-icon[data-v-38da3233]{color:#a08b00;min-width:unset!important;min-height:unset!important}.favorite-marker-icon[data-v-38da3233] svg{width:32px!important;height:32px!important;max-width:unset!important;max-height:unset!important}.favorite-marker-icon[data-v-38da3233] svg path{stroke:var(--color-main-background);stroke-width:10px;stroke-linejoin:round;paint-order:stroke}.file-container[data-v-84e14464]{contain:strict;background:var(--color-primary-element-light);position:relative;height:100%;width:100%;border:2px solid var(--color-main-background);box-sizing:border-box}.file-container.selected[data-v-84e14464]:after,.file-container[data-v-84e14464]:focus-within:after,.file-container[data-v-84e14464]:has(:focus):after{position:absolute;top:0;inset-inline-start:0;z-index:2;width:100%;height:100%;content:"";outline:var(--color-primary-element) solid 4px;outline-offset:-4px;pointer-events:none}.file-container.selected .selection-checkbox[data-v-84e14464],.file-container:focus-within .selection-checkbox[data-v-84e14464],.file-container:has(:focus) .selection-checkbox[data-v-84e14464]{opacity:1}.file-container .file[data-v-84e14464]{width:100%;height:100%;box-sizing:border-box;outline:none;display:flex}.file-container .file__blurhash[data-v-84e14464]{position:absolute;top:0;height:100%;width:100%;object-fit:cover}.file-container .file__images[data-v-84e14464]{width:100%;height:100%}.file-container .file__images .icon-overlay[data-v-84e14464]{position:absolute;top:0;inset-inline-end:0px;width:100%;height:100%;z-index:1;opacity:.8}.file-container .file__images .icon-overlay[data-v-84e14464] .material-design-icon__svg{fill:var(--color-main-background)}.file-container .file__images img[data-v-84e14464]{width:100%;height:100%;object-fit:cover;position:absolute;color:transparent}.file-container:hover .selection-checkbox[data-v-84e14464],.file-container.selected .selection-checkbox[data-v-84e14464],.file-container:focus-within .selection-checkbox[data-v-84e14464]{opacity:1}.file-container:hover .favorite-state[data-v-84e14464],.file-container.selected .favorite-state[data-v-84e14464],.file-container:focus-within .favorite-state[data-v-84e14464]{display:none}.file-container .selection-checkbox[data-v-84e14464]{opacity:0;position:absolute;top:8px;inset-inline-end:min(22px,50% - 7px);z-index:1;width:fit-content}.file-container .selection-checkbox[data-v-84e14464] .checkbox-radio-switch__input:focus-visible+.checkbox-radio-switch__content,.file-container .selection-checkbox .checkbox-radio-switch__input[data-v-84e14464]:focus-visible{outline:2px solid var(--color-main-text);box-shadow:0 0 0 3px var(--color-main-background);outline-offset:0px}.file-container .selection-checkbox[data-v-84e14464] .checkbox-radio-switch__content{padding:10px;box-sizing:border-box;background:var(--color-main-background)}.file-container .selection-checkbox[data-v-84e14464] .checkbox-radio-switch__content:after{content:"";width:16px;height:16px;position:absolute;inset-inline-start:14px;z-index:-1}.file-container .selection-checkbox[data-v-84e14464] .checkbox-radio-switch__content .checkbox-radio-switch__icon{margin:0}.file-container .selection-checkbox .input-label[data-v-84e14464]{position:fixed;z-index:-1;top:-5000px;inset-inline-start:-5000px}.file-container .favorite-state[data-v-84e14464]{position:absolute;top:2px;inset-inline-end:min(2px,50% - 7px)}
