OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Bertsioak",
    "This application automatically maintains older versions of files that are changed." : "Aplikazio honek aldatzen diren fitxategien bertsio zaharrak mantentzen ditu automatikoki.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Aplikazio honek automatikoki mantentzen ditu aldatzen diren fitxategien bertsio zaharragoak. Gaituta dagoenean, ezkutuko bertsioen karpeta batez hornitzen da erabiltzaile bakoitzaren direktorioa, fitxategien bertsio zaharrak gordetzeko. Erabiltzaileak edozein unetan bertsio zaharrago batera leheneratu dezake web interfazearen bidez, ordeztutako fitxategia bertsio bihurtuz. Aplikazioak automatikoki kudeatzen du bertsioen karpeta, erabiltzailea bertsioak direla eta kuotarik gabe geratuko ez dela ziurtatzeko.\n\t\tBertsioak iraungitzeaz gain, bertsioen aplikazioak ziurtatzen du ez dela inoiz erabiliko kontuaren uneko espazio librearen %50 baino gehiago. Biltegiratutako bertsioek muga hori gainditzen badute, aplikazioak bertsio zaharrenak ezabatuko ditu, mugara jaitsi arte. Informazio gehiago dago eskuragarri bertsioen dokumentazioan.",
    "Current version" : "Uneko bertsioa",
    "Initial version" : "Hasierako bertsioa",
    "You" : "Zu ",
    "Actions for version from {versionHumanExplicitDate}" : "Bertsiorako ekintzak {versionHumanExplicitDate}(e)tik",
    "Name this version" : "Eman izena bertsio honi",
    "Edit version name" : "Editatu bertsioaren izena",
    "Compare to current version" : "Konparatu uneko bertsioarekin",
    "Restore version" : "Leheneratu bertsioa",
    "Download version" : "Deskargatu bertsioa",
    "Delete version" : "Ezabatu bertsioa",
    "Cancel" : "Utzi",
    "Remove version name" : "Kendu bertsioaren izena",
    "Save version name" : "Gorde bertsioaren izena",
    "Version name" : "Bertsioaren izena",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Izendatutako bertsioak mantentzen dira eta garbiketa automatikoetatik kanpo geratzen dira biltegiratze-kuota beteta dagoenean.",
    "Initial version restored" : "Hasierako bertsioa ondo leheneratu da",
    "Version restored" : "Bertsioa leheneratu da",
    "Could not restore version" : "Ezin izan da bertsioa leheneratu",
    "Could not set version label" : "Ezin izan da bertsio etiketa ezarri",
    "Could not delete version" : "Ezin izan da bertsioa ezabatu",
    "File versions" : "Fitxategien bertsioak"
},
"nplurals=2; plural=(n != 1);");
