OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Ο συνδεδεμένος λογαριασμός πρέπει να είναι διαχειριστής ή να έχει εξουσιοδότηση για επεξεργασία αυτής της ρύθμισης.",
    "Could not create non-existing user ID" : "Δεν ήταν δυνατή η δημιουργία μη υπάρχοντος ID χρήστη",
    "User already exists" : "Ο χρήστης υπάρχει ήδη",
    "Group %1$s does not exist" : "Η ομάδα %1$s δεν υπάρχει",
    "Insufficient privileges for group %1$s" : "Ανεπαρκή δικαιώματα για την ομάδα %1$s",
    "No group specified (required for sub-admins)" : "Δεν καθορίστηκε ομάδα (απαιτείται για υποδιαχειριστές)",
    "Sub-admin group does not exist" : "Η ομάδα υποδιαχειριστών δεν υπάρχει",
    "Cannot create sub-admins for admin group" : "Δεν μπορούν να δημιουργηθούν υποδιαχειριστές για ομάδα διαχειριστών",
    "No permissions to promote sub-admins" : "Καθόλου δικαιώματα για προαγωγή υποδιαχειριστών",
    "Invalid password value" : "Μη έγκυρη τιμή κωδικού πρόσβασης",
    "An email address is required, to send a password link to the user." : "Απαιτείται διεύθυνση email, για αποστολή συνδέσμου κωδικού πρόσβασης στον χρήστη.",
    "Required email address was not provided" : "Δεν παρέχεται η απαιτούμενη διεύθυνση email",
    "User creation failed" : "Η δημιουργία χρήστη απέτυχε",
    "Invalid quota value: %1$s" : "Μη έγκυρη τιμή ορίου: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Μη έγκυρη τιμή ορίου. Το %1$s υπερβαίνει το μέγιστο όριο",
    "Unlimited quota is forbidden on this instance" : "Το απεριόριστο όριο απαγορεύεται σε αυτή την εγκατάσταση",
    "Setting the password is not supported by the users backend" : "Ο ορισμός του κωδικού πρόσβασης δεν υποστηρίζεται από το σύστημα χρηστών",
    "Invalid language" : "Μη έγκυρη γλώσσα",
    "Invalid locale" : "Μη έγκυρη τοποθεσία",
    "Invalid timezone" : "Μη έγκυρη ζώνη ώρας",
    "Invalid first day of week" : "Μη έγκυρη πρώτη ημέρα εβδομάδας",
    "Cannot remove yourself from the admin group" : "Δεν μπορείτε να αφαιρέσετε τον εαυτό σας από την ομάδα διαχειριστών",
    "Cannot remove yourself from this group as you are a sub-admin" : "Δεν μπορείτε να αφαιρέσετε τον εαυτό σας από αυτήν την ομάδα καθώς είστε υποδιαχειριστής",
    "Not viable to remove user from the last group you are sub-admin of" : "Δεν είναι εφικτό να αφαιρέσετε τον χρήστη από την τελευταία ομάδα που είστε υποδιαχειριστής",
    "User does not exist" : "Ο χρήστης δεν υπάρχει",
    "Group does not exist" : "Η ομάδα δεν υπάρχει",
    "User is not a sub-admin of this group" : "Ο χρήστης δεν είναι υποδιαχειριστής αυτής της ομάδας",
    "Email address not available" : "Η διεύθυνση email δεν είναι διαθέσιμη",
    "Sending email failed" : "Η αποστολή email απέτυχε",
    "Logged in account is not mail address owner" : "Ο συνδεδεμένος λογαριασμός δεν είναι κάτοχος της διεύθυνσης email",
    "Email confirmation" : "Επιβεβαίωση ηλεκτρονικού ταχυδρομείου",
    "To enable the email address %s please click the button below." : "Για να ενεργοποιήσετε τη διεύθυνση ηλεκτρονικού ταχυδρομείου %s κάντε κλικ στο παρακάτω κουμπί.",
    "Confirm" : "Επιβεβαίωση",
    "Email was already removed from account and cannot be confirmed anymore." : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου έχει ήδη αφαιρεθεί από τον λογαριασμό και δεν μπορεί πλέον να επιβεβαιωθεί.",
    "Could not verify mail because the token is expired." : "Δεν ήταν δυνατή η επαλήθευση της αλληλογραφίας επειδή το διακριτικό έχει λήξει.",
    "Could not verify mail because the token is invalid." : "Αδυναμία επαλήθευσης ηλεκτρονικής αλληλογραφίας επειδή το διακριτικό δεν είναι έγκυρο.",
    "An unexpected error occurred. Please contact your admin." : "Προέκυψε ένα μη αναμενόμενο σφάλμα. Παρακαλώ επικοινωνήστε με τον διαχειριστή σας.",
    "Email confirmation successful" : "Η επιβεβαίωση μέσω ηλεκτρονικού ταχυδρομείου ήταν επιτυχής",
    "Provisioning API" : "API παροχής",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Αυτή η εφαρμογή ενεργοποιεί ένα σύνολο APIs που εξωτερικά συστήματα μπορούν να χρησιμοποιήσουν για τη διαχείριση λογαριασμών, ομάδων και εφαρμογών.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Αυτή η εφαρμογή ενεργοποιεί ένα σύνολο APIs που εξωτερικά συστήματα μπορούν να χρησιμοποιήσουν για δημιουργία, επεξεργασία, διαγραφή και ερώτηση χαρακτηριστικών\n\t\tλογαριασμών, ερώτηση, ορισμό και αφαίρεση ομάδων, ορισμό ορίου και ερώτηση συνολικού χώρου αποθήκευσης που χρησιμοποιείται στο Nextcloud. Οι λογαριασμοί διαχειριστών ομάδων\n\t\tμπορούν επίσης να κάνουν ερωτήματα στο Nextcloud και να εκτελούν τις ίδιες λειτουργίες όπως ένας διαχειριστής για τις ομάδες που διαχειρίζονται. Το API επίσης επιτρέπει\n\t\tσε έναν διαχειριστή να κάνει ερωτήματα για ενεργές εφαρμογές Nextcloud, πληροφορίες εφαρμογών και να ενεργοποιεί ή απενεργοποιεί μια εφαρμογή από απόσταση.\n\t\tΜόλις ενεργοποιηθεί η εφαρμογή, οι αιτήματα HTTP μπορούν να χρησιμοποιηθούν μέσω μιας κεφαλίδας Basic Auth για την εκτέλεση οποιασδήποτε από τις λειτουργίες\n\t\tπου αναφέρονται παραπάνω. Περισσότερες πληροφορίες είναι διαθέσιμες στην τεκμηρίωση του API Παροχής, συμπεριλαμβανομένων παραδειγμάτων κλήσεων\n\t\tκαι απαντήσεων διακομιστή."
},
"nplurals=2; plural=(n != 1);");
