OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Aan favorieten toegevoegd",
    "Removed from favorites" : "Uit favorieten verwijderd",
    "You added {file} to your favorites" : "Je voegde {file} toe aan je favorieten",
    "You removed {file} from your favorites" : "Je verwijderde {file} uit je favorieten",
    "Favorites" : "Favorieten",
    "File changes" : "Bestandswijzigingen",
    "Created by {user}" : "Gecreëerd door {user}",
    "Changed by {user}" : "Gewijzigd door {user}",
    "Deleted by {user}" : "Verwijderd door {user}",
    "Restored by {user}" : "Hersteld door {user}",
    "Renamed by {user}" : "Hernoemd door {user}",
    "Moved by {user}" : "Verplaatst door {user}",
    "\"remote account\"" : "\"extern account\"",
    "You created {file}" : "Je creëerde {file}",
    "You created an encrypted file in {file}" : "Je creëerde een versleuteld bestand in {file}",
    "{user} created {file}" : "{user} creëerde {file}",
    "{user} created an encrypted file in {file}" : "{user} creëerde een versleuteld bestand in {file}",
    "{file} was created in a public folder" : "{file} werd gecreëerd in een openbare map",
    "You changed {file}" : "Je wijzigde {file}",
    "You changed an encrypted file in {file}" : "Je wijzigde een versleuteld bestand in {file}",
    "{user} changed {file}" : "{user} wijzigde {file}",
    "{user} changed an encrypted file in {file}" : "{user} heeft een versleuteteld bestand veranderd in {file}",
    "You deleted {file}" : "Je verwijderde {file}",
    "You deleted an encrypted file in {file}" : "Je hebt een versleuteld bestand gewist in {file}",
    "{user} deleted {file}" : "{user} verwijderde {file}",
    "{user} deleted an encrypted file in {file}" : "{user} heeft een versleuteld bestand gewist in {file}",
    "You restored {file}" : "Je herstelde {file}",
    "{user} restored {file}" : "{user} herstelde {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Je hernoemde {oldfile} (verborgen) naar {newfile}(verborgen)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Je hernoemde {oldfile} (verborgen) naar {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Je hernoemde {oldfile} naar {newfile} (verborgen)",
    "You renamed {oldfile} to {newfile}" : "Je hernoemde {oldfile} naar {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} hernoemde {oldfile} (verborgen) naar {newfile} (verborgen)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} hernoemde {oldfile} (verborgen) naar {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} hernoemde {oldfile} naar {newfile} (verborgen)",
    "{user} renamed {oldfile} to {newfile}" : "{user} hernoemde {oldfile} naar {newfile}",
    "You moved {oldfile} to {newfile}" : "Je verplaatste {oldfile} naar {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} verplaatste {oldfile} naar {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Een bestand werd toegevoegd of verwijderd van je <strong>favorieten</strong>",
    "Files" : "Bestanden",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Een favoriet bestand of map is <strong>gewijzigd</strong>",
    "Failed to authorize" : "Kon niet autoriseren",
    "Invalid folder path" : "Ongeldig pad",
    "Folder not found" : "Map niet gevonden",
    "The file cannot be found" : "Het bestand kan niet worden gevonden",
    "The destination path does not exist: %1$s" : "Het bestemmingspad bestaat niet: %1$s",
    "You do not have permission to create a file at the specified location" : "Je hebt geen toestemming om een bestand aan te maken op de opgegeven locatie",
    "The file could not be converted." : "Het bestand kon niet worden geconverteerd.",
    "Could not get relative path to converted file" : "Kon geen relatief pad naar geconverteerd bestand achterhalen",
    "Limit must be a positive integer." : "Limiet moet een positief integer getal zijn.",
    "The replacement character may only be a single character." : "Het vervangende teken kan alleen maar een enkel teken zijn",
    "Filename sanitization already started." : "Opschonen bestandsnaam is al actief",
    "No filename sanitization in progress." : "Opschonen bestandsnaam niet actief",
    "Favorite files" : "Favoriete bestanden",
    "No favorites" : "Geen favorieten",
    "More favorites" : "Meer favorieten",
    "Accept" : "Accepteren",
    "Reject" : "Afwijzen",
    "Incoming ownership transfer from {user}" : "Inkomend verzoek voor eigendomsoverdracht van {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Wil je {path} aanvaarden? \n\nOpmerking: het overdrachtsproces kan na acceptatie tot 1 uur duren.",
    "Ownership transfer denied" : "Eigendomsoverdracht geweigerd",
    "Your ownership transfer of {path} was denied by {user}." : "Eigendomsoverdracht van {path} is geweigerd door {user}.",
    "Ownership transfer failed" : "Eigendomsoverdracht mislukt",
    "Your ownership transfer of {path} to {user} failed." : "Eigendomsoverdracht van {path} naar {user} is mislukt.",
    "The ownership transfer of {path} from {user} failed." : "Eigendomsoverdracht van {path} van {user} is mislukt.",
    "Ownership transfer done" : "Eigendomsoverdracht geslaagd",
    "Your ownership transfer of {path} to {user} has completed." : "Eigendomsoverdracht van {path} naar {user} is gereed.",
    "The ownership transfer of {path} from {user} has completed." : "Eigendomsoverdracht van {path} van {user} is gereed.",
    "in %s" : "in %s",
    "Transferred from %1$s on %2$s" : "Overgezet van %1$s naar %2$s",
    "File Management" : "Bestandsbeheer",
    "Home" : "Thuis",
    "Target folder does not exist any more" : "Doelmap bestaat niet meer",
    "Reload current directory" : "Huidige map opnieuw laden",
    "Go to the \"{dir}\" directory" : "Ga naar de \"{dir}\" map",
    "Current directory path" : "Huidig directory pad",
    "Share" : "Delen",
    "Reload content" : "Laad inhoud opnieuw",
    "Your have used your space quota and cannot upload files anymore" : "Je hebt je ruimtequotum gebruikt en kan geen bestanden meer uploaden",
    "You do not have permission to upload or create files here." : "Je hebt geen toestemming om hier bestanden te uploaden of aan te maken.",
    "Drag and drop files here to upload" : "Drag en drop bestanden hier om te uploaden",
    "Favorite" : "Favoriet",
    "Back" : "Terug",
    "Toggle selection for file \"{displayName}\"" : "Wijzig selectie voor bestand \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Wijzig selectie voor map \"{displayName}\"",
    "File is loading" : "Bestand is aan het laden",
    "Folder is loading" : "Map is aan het laden",
    "Filename" : "Bestandsnaam",
    "Folder name" : "Mapnaam",
    "This node is unavailable" : "Deze node is niet beschikbaar",
    "Another entry with the same name already exists." : "Er bestaat al een ander item met dezelfde naam",
    "Invalid filename." : "Ongeldige bestandsnaam",
    "Rename file" : "Bestand hernoemen",
    "Recently created" : "Recentelijk gemaakt",
    "Folder" : "Map",
    "Unknown file type" : "Onbekend bestandstype",
    "{ext} image" : "{ext} afbeelding",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} audio",
    "{ext} text" : "{ext} tekst",
    "Pending" : "In behandeling",
    "Unknown date" : "Onbekende datum",
    "Active filters" : "Actieve filters",
    "Remove filter" : "Verwijder filter",
    "Today" : "Vandaag",
    "Last 7 days" : "Laatste 7 dagen",
    "Last 30 days" : "Laatste 30 dagen",
    "This year ({year})" : "Dit jaar ({year})",
    "Last year ({year})" : "Afgelopen jaar ({year})",
    "Custom range" : "Aangepast bereik",
    "Custom date range" : "Aangepast datumbereik",
    "Search everywhere" : "Zoek in alles",
    "Documents" : "Documenten",
    "Spreadsheets" : "Spreadsheets",
    "Presentations" : "Presentaties",
    "PDFs" : "PDFs",
    "Folders" : "Mappen",
    "Audio" : "Geluid",
    "Images" : "Afbeeldingen",
    "Videos" : "Video's",
    "Filters" : "Filters",
    "Back to filters" : "Terug naar filters",
    "Appearance" : "Uiterlijk",
    "Show hidden files" : "Toon verborgen bestanden",
    "Show file type column" : "Toon bestandstypekolom",
    "Show file extensions" : "Laat bestand extensies zien",
    "Crop image previews" : "Snij afbeeldingvoorbeelden bij",
    "General" : "Algemeen",
    "Sort favorites first" : "Sorteer eerst favorieten",
    "Sort folders before files" : "Sorteer mappen voor bestanden",
    "Enable folder tree view" : "Schakel mappenboom weergave in",
    "Default view" : "Standaardweergave",
    "All files" : "Alle bestanden",
    "Personal files" : "Persoonlijke bestanden",
    "Additional settings" : "Aanvullende instellingen",
    "Actions" : "Acties",
    "File actions" : "Bestandsacties",
    "Selection" : "Selectie",
    "Select all files" : "Selecteer alle bestanden",
    "Deselect all" : "Deselecteer alles",
    "Select or deselect" : "Selecteren of deselecteren",
    "Select a range" : "Selecteer een bereik",
    "Navigation" : "Navigatie",
    "Go to parent folder" : "Ga naar bovenliggende map",
    "Go to file above" : "Ga naar bovenliggend bestand",
    "Go to file below" : "Ga naar onderliggend bestand",
    "Go left in grid" : "Ga naar links in raster",
    "Go right in grid" : "Ga naar rechts in raster",
    "View" : "Bekijken",
    "Toggle grid view" : "Omschakelen roosterweergave",
    "Show those shortcuts" : "Toon die snelkoppelingen",
    "Warnings" : "Waarschuwingen",
    "Warn before changing a file extension" : "Waarschuw voordat een bestand extensie wordt gewijzigd",
    "Warn before deleting a file" : "Waarschuwen voor verwijderen bestand",
    "WebDAV URL" : "WebDAV URL",
    "Create an app password" : "Maak een app wachtwoord",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Verplicht voor WebDAV authenticatie omdat Twee-Factor Authenticatie is ingeschakeld voor dit account.",
    "How to access files using WebDAV" : "Hoe bestanden te benaderen met WebDAV",
    "Total rows summary" : "Aantal rijen samenvatting",
    "Toggle selection for all files and folders" : "Wijzig selectie voor alle bestanden en mappen",
    "Name" : "Naam",
    "File type" : "Bestandstype",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "{displayName}: failed on some elements" : "{displayName}: sommige onderdelen zijn mislukt",
    "{displayName}: done" : "{displayName}: compleet",
    "{displayName}: failed" : "{displayName}: mislukt",
    "(selected)" : "(geselecteerd)",
    "List of files and folders." : "Lijst van bestanden en mappen.",
    "You have used your space quota and cannot upload files anymore." : "Je hebt je ruimtequotum gebruikt en kan geen bestanden meer uploaden",
    "Column headers with buttons are sortable." : "Kolomkoppen met knoppen zijn sorteerbaar",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "De lijst is niet volledig verwerkt om de prestatie niet te beperken. De bestanden worden verder verwerkt als je door de lijst navigeert.",
    "File not found" : "Bestand niet gevonden",
    "_{count} selected_::_{count} selected_" : ["{count} geselecteerd","{count} geselecteerd"],
    "Views" : "Bekeken",
    "Search everywhere …" : "Zoek in alles …",
    "Search here …" : "Zoek hier …",
    "Search scope options" : "Zoek bereikopties",
    "Search here" : "Zoek hier",
    "Owner" : "Eigenaar",
    "{usedQuotaByte} used" : "{usedQuotaByte} gebruikt",
    "{used} of {quota} used" : "{used} van {quota} gebruikt",
    "{relative}% used" : "{relative}% gebruikt",
    "Could not refresh storage stats" : "Kan opslagstatistieken niet vernieuwen",
    "Your storage is full, files can not be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage information" : "Opslaginformatie",
    "Storage quota" : "Opslagquota",
    "New folder" : "Nieuwe map",
    "Create new folder" : "Nieuwe map aanmaken",
    "This name is already in use." : "De naam is al in gebruik.",
    "Create" : "Aanmaken",
    "Files starting with a dot are hidden by default" : "Bestanden die met een punt beginnen, worden standaard verborgen",
    "Failed to start filename sanitization." : "Opschonen bestandsnaam is mislukt.",
    "Failed to refresh filename sanitization status." : "Update van opschonen bestandsnaam status mislukt",
    "Filename sanitization in progress." : "Opschonen bestandsnaam wordt uitgevoerd.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "{processedUsers} van {totalUsers} accounts zijn al verwerkt.",
    "Preparing …" : "Voorbereiden …",
    "Refresh" : "Verversen",
    "All files have been santized for Windows filename support." : "Alle bestanden zijn opgeschoond voor ondersteuning van Windows bestandsnamen.",
    "Some files could not be sanitized, please check your logs." : "Enkele bestanden kunnen niet opgeschoond worden, controleer je logs.",
    "Sanitization errors" : "Opschoon fouten",
    "Not sanitized filenames" : "Niet opgeschoonde bestanden",
    "Windows filename support has been enabled." : "Ondersteuning voor Windows bestanden is ingeschakeld",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Ondanks dat dit gebruikers stopt om niet niet ondersteunde bestanden aan te maken, zijn bestaande bestanden nog niet hernoemd en kunnen dus de sync met Windows afbreken.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Je kan het hernoemen van ongeldige bestandsnamen starten, dit wordt gedaan in de achtergrond en duurt mogelijk even.",
    "Please note that this may cause high workload on the sync clients." : "Wees gewaarschuwd dat dit een hoge werklast voor het syncen van clients kan opleveren.",
    "Limit" : "Limiet",
    "This allows to configure how many users should be processed in one background job run." : "Met dit kan je configureren hoeveel gebruikers verwerkt worden tijdens een achtergrond taak. ",
    "Sanitize filenames" : "Opschonen bestanden",
    "(starting)" : "(begonnen)",
    "Fill template fields" : "Vul de velden van het sjabloon in",
    "Submitting fields …" : "Toevoegen velden …",
    "Submit" : "Verwerken",
    "Choose a file or folder to transfer" : "Kies een bestand of map om over te dragen",
    "Transfer" : "Overdragen",
    "Transfer {path} to {userid}" : "Draag {path} over aan {userid}",
    "Error while searching for users" : "Fout bij zoeken naar gebruikers",
    "Ownership transfer request sent" : "Aanvraag eigendomsoverdracht verstuurd",
    "Cannot transfer ownership of a file or folder you do not own" : "Kan de eigendom van een bestand of map waarvan u niet de eigenaar bent, niet overdragen",
    "Transfer ownership of a file or folder" : "Overdragen eigendom bestand of map ",
    "New owner" : "Nieuwe eigenaar",
    "Keep {old}" : "Bewaar {old}",
    "Keep without extension" : "Bewaren zonder extensie",
    "Use {new}" : "Gebruik {new}",
    "Remove extension" : "Verwijder extensie",
    "Change file extension" : "Wijzig bestandsextensie",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Wijzigen van de bestandsextensie {old} naar {new} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Verwijderen van de extensie {old} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Toevoegen van de extensie {new} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
    "Do not show this dialog again." : "Laat dit dialoogvenster niet meer zien.",
    "Rename file to hidden" : "Hernoem bestand naar verborgen",
    "Prefixing a filename with a dot may render the file hidden." : "Een bestand laten starten met een punt kan het bestand verbergen.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Weet je zeker dat je het bestand wil hernoemen naar \"{filename}\"?",
    "Cancel" : "Annuleren",
    "Rename" : "Naam wijzigen",
    "Select file or folder to link to" : "Selecteer een bestand of map om naar te linken",
    "Choose {file}" : "Kies {file}",
    "Files settings" : "Instellingen voor bestanden",
    "Switch to list view" : "Omschakelen naar lijstoverzicht",
    "Switch to grid view" : "Omschakelen naar roosterweergave",
    "The file could not be found" : "Het bestand kon niet worden gevonden",
    "Upload was cancelled by user" : "Upload was geannuleerd door de gebruiker",
    "Not enough free space" : "Onvoldoende vrije ruimte",
    "Operation is blocked by access control" : "De operatie werd tegengehouden door toegangscontrole",
    "Error during upload: {message}" : "Fout tijdens upload: {message}",
    "Error during upload, status code {status}" : "Fout tijdens upload, status code {status}",
    "Unknown error during upload" : "Onbekende fout tijdens upload",
    "File list is reloading" : "Bestanden lijst wordt opnieuw geladen",
    "Loading current folder" : "Laden huidige map",
    "Retry" : "Opnieuw",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
    "Go back" : "Ga terug",
    "Loading …" : "Aan het laden...",
    "Your files" : "Jouw bestanden",
    "Open in files" : "Open in bestanden",
    "File cannot be accessed" : "Bestand kan niet worden benaderd",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dit bestand is niet gevonden of je hebt geen machtigingen om het te bekijken. Vraag de verzender om het met je te delen.",
    "No search results for “{query}”" : "No search results for “{query}”",
    "Search for files" : "Zoeken naar bestanden",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Toestaan om bestandsnamen te beperken om te borgen dat bestanden met alle cliënts gesynchroniseerd kunnen worden. Standaard zijn alle bestandsnamen valide die zijn toegestaan op POSIX (zoals Linux en macOS.)",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Na inschakeling van Windows-compatibele bestandsnamen, kunnen bestaande bestanden niet meer worden gewijzigd, maar kunnen ze door de eigenaar worden hernoemd naar geldige nieuwe namen.",
    "Failed to toggle Windows filename support" : "Omschakelen naar Windows bestand ondersteuning mislukt",
    "Files compatibility" : "Bestandscompatibiliteit",
    "Enforce Windows compatibility" : "Dwing Windows-compatibiliteit af",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dit zal bestandsnamen blokkeren die niet toegestaan zijn op Windows-systemen, zoals gereserveerde namen of speciale tekens. Dit dwingt niet tot compatibiliteit voor hoofd- en kleine letters.",
    "Blank" : "Blanco",
    "Unable to create new file from template" : "Kan geen nieuw bestand maken vanuit het sjabloon",
    "Pick a template for {name}" : "Kies een sjabloon voor {name}",
    "Create a new file with the selected template" : "Maak een nieuw bestand met het geselecteerde sjabloon",
    "Creating file" : "Maken bestand",
    "Save as {displayName}" : "Opslaan als {displayName}",
    "Save as …" : "Bewaar als …",
    "Converting files …" : "Bestanden converteren …",
    "Failed to convert files: {message}" : "Conversie van bestanden mislukt: {message} ",
    "All files failed to be converted" : "De conversie van alle bestanden is mislukt",
    "One file could not be converted: {message}" : "Een bestand kon niet worden geconverteerd: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n bestand kon niet worden geconverteerd","%n bestanden konden niet worden geconverteerd"],
    "_%n file converted_::_%n files converted_" : ["%n bestand geconverteerd","%n bestanden geconverteerd"],
    "Files converted" : "Bestanden geconverteerd",
    "Failed to convert files" : "Conversie van bestanden mislukt",
    "Converting file …" : "Bestand converteren …",
    "File successfully converted" : "Bestand succesvol geconverteerd",
    "Failed to convert file: {message}" : "Conversie van bestand mislukt: {message} ",
    "Failed to convert file" : "Conversie van bestand mislukt",
    "Delete" : "Verwijderen",
    "Leave this share" : "Verlaat deze share",
    "Leave these shares" : "Verlaat deze shares",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Disconnect storages" : "Opslaglocaties ontkoppelen",
    "Delete permanently" : "Permanent verwijderen",
    "Delete and unshare" : "Verwijder en stop delen",
    "Delete file" : "Verwijder bestand",
    "Delete files" : "Verwijder bestanden",
    "Delete folder" : "Map verwijderen",
    "Delete folders" : "Verwijder mappen",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Je staat op het punt om {count} item permanent te verwijderen","Je staat op het punt om {count} items permanent te verwijderen"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Je staat op het punt om {count} item te verwijderen","Je staat op het punt om {count}items te verwijderen"],
    "Confirm deletion" : "Bevestig verwijderen",
    "Download" : "Downloaden",
    "The requested file is not available." : "Het gevraagde bestand is niet beschikbaar.",
    "The requested files are not available." : "De gevraagde bestanden zijn niet beschikbaar.",
    "Add to favorites" : "Aan favorieten toevoegen",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add or remove favorite" : "Verwijder of voeg een favoriet toe",
    "Move" : "Verplaatsen",
    "Copy" : "Kopiëren",
    "Move or copy" : "Verplaats of kopieer",
    "Destination is not a folder" : "Bestemming is geen map",
    "This file/folder is already in that directory" : "Dit bestand/deze map staat al in die map",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Je kan een bestand/map niet verplaatsen naar zichzelf of naar een subfolder van zichzelf.",
    "A file or folder with that name already exists in this folder" : "Een bestand of map met dezelfde naam is al aanwezig in deze map",
    "The files are locked" : "De bestanden zijn vergrendeld",
    "The file does not exist anymore" : "Dit bestand bestaat niet meer",
    "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
    "Moving {count} files to \"{destination}\" …" : "{count} bestanden aan het verplaatsen naar \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopieren \"{source}\" naar \"{destination}\" …",
    "Copying {count} files to \"{destination}\" …" : "{count}bestanden aan het kopiëren naar \"{destination}\" …",
    "Choose destination" : "Kies bestemming",
    "Copy to {target}" : "Kopieer naar {target}",
    "Move to {target}" : "Verplaats naar {target}",
    "Move or copy operation failed" : "Verplaatsen of kopiëren mislukt",
    "Open folder" : "Open map",
    "Open folder {displayName}" : "Open map {displayName}",
    "Open in Files" : "Open in Bestanden",
    "Open locally" : "Lokaal openen",
    "Failed to redirect to client" : "Omleiden naar cliënt mislukt",
    "Open file locally" : "Bestand lokaal openen",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Het bestand zou nu moeten openen op je apparaat. Als dat niet het geval is, controleer dan of je de desktop app geïnstalleerd hebt.",
    "Retry and close" : "Probeer opnieuw en sluiten",
    "Open online" : "Open online",
    "Details" : "Details",
    "Open the details sidebar" : "Open de details zijbalk",
    "Unfavorite" : "Favoriet weghalen",
    "View in folder" : "Bekijken in map",
    "Type" : "Type",
    "Created new folder \"{name}\"" : "Nieuwe map \"¨{name}\" gemaakt.",
    "Unable to initialize the templates directory" : "Kon de sjablonenmap niet instellen",
    "Create templates folder" : "Nieuwe sjablonenmap",
    "Templates" : "Sjablonen",
    "New template folder" : "Nieuwe sjablonenmap",
    "In folder" : "In map",
    "Pick folder to search in" : "Kies map om in te zoeken",
    "Search in all files" : "Zoeken in alle bestanden",
    "Search in folder: {folder}" : "Zoeken in map: {folder}",
    "One of the dropped files could not be processed" : "Een van de bestanden kon niet verwerkt worden.",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Je browser ondersteund de Filesystem API niet. Mappen worden niet geüpload",
    "No files to upload" : "Geen bestanden om te uploaden",
    "Unable to create the directory {directory}" : "Kan map {directory} niet maken",
    "Some files could not be uploaded" : "Sommige bestanden konden niet worden geüpload",
    "Files uploaded successfully" : "Bestand succesvol geüpload.",
    "No files to process" : "Geen bestanden te verwerken",
    "Files copied successfully" : "Bestanden succesvol gekopieerd",
    "Files moved successfully" : "Bestanden succesvol verplaatst",
    "Some files could not be copied" : "Sommige bestanden konden niet gekopieerd worden",
    "Some files could not be moved" : "Een paar bestanden konden niet worden verplaatst",
    "Conflicts resolution skipped" : "Conflictoplossing overgeslagen",
    "Upload cancelled" : "Uploaden geannuleerd",
    "Could not rename \"{oldName}\", it does not exist any more" : "Kon \"{oldName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{newName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{oldName}\"" : "Kon \"{oldName}\" niet hernoemen",
    "This operation is forbidden" : "Deze taak is verboden",
    "This folder is unavailable, please try again later or contact the administration" : "Deze map is niet beschikbaar, probeer het later nog eens of neem contact op met de beheerder",
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Unexpected error: {error}" : "Onverwachte fout: {error}",
    "Unknown error" : "Onbekende fout",
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
    "_%n hidden_::_%n hidden_" : ["%n onzichtbaar","%n onzichtbaar"],
    "Filename must not be empty." : "Bestandsnaam mag niet leeg zijn",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\"is niet toegestaan in een bestandsnaam",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" is een greserveerde naam en niet toegestaan voor bestandsnamen",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" is geen toegestaan bestandstype",
    "Filenames must not end with \"{extension}\"." : "Bestandsnamen mogen niet eindigen met \"{extension}\".",
    "List of favorite files and folders." : "Lijst van favoriete bestanden en mappen.",
    "No favorites yet" : "Nog geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
    "List of your files and folders." : "Lijst van je bestanden en mappen.",
    "Folder tree" : "Mapboom",
    "List of your files and folders that are not shared." : "Lijst van je bestanden en mappen die niet gedeeld zijn.",
    "No personal files found" : "Geen persoonlijke bestanden gevonden",
    "Files that are not shared will show up here." : "Niet-gedeelde bestanden worden hier getoond.",
    "Recent" : "Recent",
    "List of recently modified files and folders." : "Lijst van recent gewijzigde bestanden en mappen.",
    "No recently modified files" : "Geen recent gewijzigde bestanden",
    "Files and folders you recently modified will show up here." : "Bestanden en mappen die je recent gewijzigd hebt, worden hier getoond.",
    "Search" : "Zoeken",
    "Search results within your files." : "Zoekresultaten binnen jouw bestanden.",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" hernoemd naar \"{newName}\"",
    "Clear filter" : "Filter leegmaken",
    "Open file sidebar" : "Open bestands zijbalk",
    "Search everywhere …" : "Zoek in alles...",
    "Search here …" : "Zoek hier ...",
    "Preparing …" : "Voorbereiden ...",
    "Submitting fields …" : "Velden verwerken ...",
    "Invalid path selected" : "Ongeldig pad geselecteerd",
    "Choose file or folder to transfer" : "Kies over te dragen bestand of map",
    "Change" : "Pas aan",
    "Shared by link" : "Gedeeld via link",
    "Shared" : "Gedeeld",
    "You" : "Jij",
    "Shared multiple times with different people" : "Meerdere keren gedeeld met verschillende mensen",
    "Unable to change the favorite state of the file" : "Kan de favoriete status van het bestand niet wijzigen",
    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
    "Tags" : "Tags",
    "Save as …" : "Opslaan als...",
    "Converting files …" : "Bestanden converteren ...",
    "Converting file …" : "Bestand converteren ..."
},
"nplurals=2; plural=(n != 1);");
