OC.L10N.register(
    "photos",
    {
    "Photos" : "ඡායාරූප",
    "Favorites" : "ප්‍රියතම",
    "Back" : "ආපසු",
    "Save" : "සුරකින්න",
    "Favorite" : "ප්‍රියතම",
    "Go back" : "ආපසු යන්න",
    "Home" : "මුල් පිටුව",
    "General" : "සමාන්‍යය",
    "Cancel" : "Cancel",
    "Confirm" : "තහවුරු කරන්න"
},
"nplurals=2; plural=(n != 1);");
