OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Ieteiktās datnes",
    "Recommendations" : "Ieteikumi",
    "Shows recommended files" : "Parāda ieteiktās datnes",
    "Shows recommended files for quick access of files and folders with recent activity" : "Parāda ieteiktās datnes ātrai piekļuvei datnēm un mapēm ar nesenām darbībām",
    "No recommendations yet" : "Vēl nav ieteikumu",
    "Show recommendations" : "Rādīt ieteikumus"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
