var t,r;function u(){if(r)return t;r=1;function i(c){const n="[ \\t\\f]*",g="[ \\t\\f]+",s=n+"[:=]"+n,a=g,l="("+s+"|"+a+")",e="([^\\\\:= \\t\\f\\n]|\\\\.)+",o={end:l,relevance:0,starts:{className:"string",end:/$/,relevance:0,contains:[{begin:"\\\\\\\\"},{begin:"\\\\\\n"}]}};return{name:".properties",disableAutodetect:!0,case_insensitive:!0,illegal:/\S/,contains:[c.COMMENT("^\\s*[!#]","$"),{returnBegin:!0,variants:[{begin:e+s},{begin:e+a}],contains:[{className:"attr",begin:e,endsParent:!0}],starts:o},{className:"attr",begin:e+n+"$"}]}}return t=i,t}export{u as r};
//# sourceMappingURL=properties-q8asBERA.chunk.mjs.map
