OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Системска ознака %1$s е додадена во системот",
    "Added system tag {systemtag}" : "Додадена системска ознака {systemtag}",
    "Added system tag %1$s" : "Додадена системска ознака %1$s",
    "%1$s added system tag %2$s" : "%1$s додаде системска ознака %2$s",
    "{actor} added system tag {systemtag}" : "{actor} додаде системска ознака {systemtag}",
    "System tag %1$s removed by the system" : "Системска ознака %1$s е отстранета од системот",
    "Removed system tag {systemtag}" : "Отстранета системска ознака {systemtag}",
    "Removed system tag %1$s" : "Отстранета системска ознака %1$s",
    "%1$s removed system tag %2$s" : "%1$s отстрани системска ознака %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} отстрани системска ознака {systemtag}",
    "You created system tag %1$s" : "Креиравте системска ознака %1$s",
    "You created system tag {systemtag}" : "Креиравте системска ознака {systemtag}",
    "%1$s created system tag %2$s" : "%1$s креираше системска ознака %2$s",
    "{actor} created system tag {systemtag}" : "{actor} креираше системска ознака {systemtag}",
    "You deleted system tag %1$s" : "Избришавте системска ознака %1$s",
    "You deleted system tag {systemtag}" : "Избришавте системска ознака {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s избриша системска ознака %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} избриша системска ознака {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ја ажуриравте системската ознака %2$s во %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ја ажуриравте системската ознака {oldsystemtag} во {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ажурираше системска ознака %3$s во %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ажурираше системска ознака {oldsystemtag} во {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системска ознака %2$s е додадена на %1$s од системот",
    "System tag {systemtag} was added to {file} by the system" : "Системска ознака {systemtag} е додадена на {file} од системот",
    "You added system tag %2$s to %1$s" : "Додадовте системска ознака %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Додадовте системска ознака {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додаде системска ознака %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додаде системска ознака {systemtag} на {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системска ознака %2$s е отстранета од %1$s од системот",
    "System tag {systemtag} was removed from {file} by the system" : "Системска ознака {systemtag} е отстранета од {file} од системот",
    "You removed system tag %2$s from %1$s" : "Отстранивте системска ознака %2$s од %1$s",
    "You removed system tag {systemtag} from {file}" : "Отстранивте системска ознака {systemtag} од {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s отстрани системска ознака %3$s од %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} отстрани системска ознака {systemtag} од {file}",
    "%s (restricted)" : "%s (ограничена)",
    "%s (invisible)" : "%s (невидливо)",
    "<strong>System tags</strong> for a file have been modified" : "Изменета е <strong>Системска ознака</strong> за датотека",
    "Files" : "Датотеки",
    "Tags" : "Ознаки",
    "All tagged %s …" : "Сите означени %s …",
    "tagged %s" : "означени %s",
    "Collaborative tags" : "Колаборативна ознака",
    "Collaborative tagging functionality which shares tags among people." : "Колаборативна ознака е можност да се споделуваат ознаките со корисниците.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Колаборативна ознака е можност да се споделуваат ознаките со корисниците. Одлично за тимско работење.\n\t(Доколку користите провајдер со инсталирани повеќе инстанци, се препорачува да се оневозможи оваа апликацика бидејќи ознаките ќе бидат споделени.)",
    "Public" : "Јавна",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидливо",
    "Created tag" : "Создадена ознака",
    "Failed to create tag" : "Неуспешно креирање на ознака",
    "Updated tag" : "Ажурирана ознака",
    "Failed to update tag" : "Неуспешно ажурирање ознака",
    "Deleted tag" : "Избришана ознака",
    "Failed to delete tag" : "Неуспешно бришење на ознака",
    "Create or edit tags" : "Креирај или измени ознака",
    "Search for a tag to edit" : "Барај ознака за ажурирање",
    "Collaborative tags …" : "Колаборативни ознаки …",
    "No tags to select" : "Нема ознаки за обележување",
    "Tag name" : "Име на ознака",
    "Tag level" : "Ниво на ознака",
    "Create" : "Креирај",
    "Update" : "Ажурирај",
    "Delete" : "Избриши",
    "Reset" : "Поништи",
    "Loading …" : "Се вчитува …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} ќе се постави а {tag2} ќе се острани од една датотека.","{tag1} ќе се постави а {tag2} ќе се отстрани од {count} датотеки."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} ќе се постави на една датотека.","{tag} ќе се постави на {count} датотеки."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} ќе се острани од една датотека.","{tag} ќе се отстрани од {count} датотеки."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} и {lastTag} ќе се постават на една датотека.","{tags} и {lastTag} ќе се постават на {count} датотеки."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} и {lastTag} ќе се остранат од една датотека.","{tags} и {lastTag} ќе се остранат од {count} датотеки."],
    "{displayName} (hidden)" : "{displayName} (невидлив)",
    "{displayName} (restricted)" : "{displayName} (ограничен)",
    "Only admins can create new tags" : "Само администраторите можат да креираат ознаки",
    "Failed to apply tags changes" : "Неуспешно применување на промените на ознаките",
    "Manage tags" : "Уреди ги ознаките",
    "Applying tags changes…" : "Применување на промени во ознаките…",
    "Search or create tag" : "Барај или креирај ознака",
    "Search tag" : "Барај ознака",
    "Change tag color" : "Измени ја бојата на ознаката",
    "Create new tag" : "Креирај нова ознака",
    "Choose tags for the selected files" : "Избери ознаки за означените датотеки",
    "Cancel" : "Откажи",
    "Apply" : "Примени",
    "Failed to load selected tags" : "Неуспешно вчитување на избраната ознака",
    "Failed to load tags" : "Неуспешно вчитување на ознаки",
    "Failed to select tag" : "Неуспешно избирање на ознака",
    "System admin disabled tag creation. You can only use existing ones." : "Администраторот ги има оневозможено креирање на нови ознали. Може да користите некои од постоечките.",
    "Loading collaborative tags …" : "Вчитување на колаборативни ознаки …",
    "Search or create collaborative tags" : "Барај или креирај колаборативна ознака ",
    "No tags to select, type to create a new tag" : "Нема избрано ознака, напиши за да креираш нова ознака",
    "Unable to update setting" : "Неможе да се ажурира подесувањето",
    "System tag creation is now restricted to administrators" : "Креирањето на системски ознаки сега е ограничено на администратори",
    "System tag creation is now allowed for everybody" : "Креирањето на системски ознаки сега е дозволено за сите",
    "System tag management" : "Управување со системски ознаки",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Доколку е овозможено, само администраторите можат да креираат и уредуваат ознаки. Сметките сè уште можат да ги доделуваат и отстрануваат од датотеки.",
    "Restrict tag creation and editing to administrators" : "Ограничете го креирањето и уредувањето на ознаки само за администратори",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Колаборативните ознаки се достапни за сите корисници. Ограничените ознаки се видливи за корисниците но неможат да ги додаваат. Невидливите ознаки се за внатрешна употреба, тоа значи дека корисниците неможат да ги видат или да ги додаваат.",
    "Add tags" : "Додади ознаки",
    "Assigned collaborative tags" : "Доделени колаборативни ознаки",
    "Open in Files" : "Отвори во датотеките",
    "List of tags and their associated files and folders." : "Список на ознаки и нивните поврзани датотеки и папки.",
    "No tags found" : "Не се пронајдени ознаки",
    "Tags you have created will show up here." : "Ознаките што ги имате креирано ќе се појават овде",
    "Failed to load tag" : "Неуспешно вчитување на ознака",
    "Failed to load last used tags" : "Неуспешно вчитување на последно користените ознаки",
    "Missing \"Content-Location\" header" : "Недостасува \"Content-Location\" заглавие",
    "A tag with the same name already exists" : "Веќе постои ознака со истото име",
    "Failed to load tags for file" : "Неуспешно вчитување на ознаки за датотека",
    "Failed to set tag for file" : "Неуспешно поставување на ознака за датотека",
    "Failed to delete tag for file" : "Неуспешно бришење ознака за датотека",
    "Collaborative tags …" : "Колаборативни ознаки ...",
    "Loading …" : "Се вчитува…",
    "Loading collaborative tags …" : "Вчитување на колаборативни ознаки"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
