OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta del sistema %1$s agregada por el sistema",
    "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
    "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
    "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} agregó la etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta del sistema %1$s eliminada por el sistema",
    "Removed system tag {systemtag}" : "Eliminó la etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "Etiqueta del sistema %1$s eliminada",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Creaste la etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Creaste la etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creo la etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Borraste la etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Borraste la etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s borró la etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} borró la etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Actualizaste la etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Actualizaste la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta del sistema %2$s agregada a %1$s por el sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta del sistema {systemtag} agregada a {file} por el sistema",
    "You added system tag %2$s to %1$s" : "Agregaste la etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Agregaste la etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta del sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta del sistema %2$s eliminada de %1$s por el sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta del sistema {systemtag} eliminada de {file} por el sistema",
    "You removed system tag %2$s from %1$s" : "Eliminaste la etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Eliminaste la etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eliminó la etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eliminó la etiqueta del sistema  {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible) ",
    "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
    "Files" : "Archivo",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos los etiquetados %s …",
    "tagged %s" : "etiquetado %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidad de etiquetado colaborativo que comparte etiquetas entre personas.",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "No se pudo crear la etiqueta",
    "Updated tag" : "Etiqueta actualizada",
    "Failed to update tag" : "No se pudo actualizar la etiqueta",
    "Deleted tag" : "Etiqueta eliminada",
    "Failed to delete tag" : "No se pudo eliminar la etiqueta",
    "Create or edit tags" : "Crear o editar etiquetas",
    "Search for a tag to edit" : "Buscar la etiqueta a editar",
    "No tags to select" : "No hay etiquetas para seleccionar",
    "Tag name" : "Nombre de la etiqueta",
    "Tag level" : "Nivel de la etiqueta",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Borrar",
    "Reset" : "Restaurar",
    "Manage tags" : "Administrar etiquetas",
    "Cancel" : "Cancelar",
    "Apply" : "Aplicar",
    "Failed to load selected tags" : "No se pudieron cargar las etiquetas seleccionadas",
    "Failed to load tags" : "No se pudieron cargar las etiquetas",
    "Failed to select tag" : "No se pudieron seleccionar las etiquetas",
    "Search or create collaborative tags" : "Buscar o crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "No hay etiquetas para seleccionar, escriba para crear una nueva etiqueta",
    "Assigned collaborative tags" : "Etiquetas colaborativas asignadas",
    "Open in Files" : "Abrir en Archivos",
    "List of tags and their associated files and folders." : "Lista de etiquetas y sus archivos y carpetas asociados.",
    "No tags found" : "No se encontraron etiquetas",
    "Tags you have created will show up here." : "Las etiquetas que haya creado aparecerán aquí.",
    "Failed to load last used tags" : "No se pudieron cargar las últimas etiquetas utilizadas",
    "Missing \"Content-Location\" header" : "Falta el encabezado \"Contenido-Ubicación\"",
    "Failed to load tags for file" : "No se pudieron cargar las etiquetas del archivo",
    "Failed to set tag for file" : "No se pudo establecer la etiqueta del archivo",
    "Failed to delete tag for file" : "No se pudo eliminar la etiqueta del archivo",
    "Collaborative tags …" : "Etiquetas colaborativas ...",
    "Loading …" : "Cargando …",
    "Loading collaborative tags …" : "Cargando las etiquetas colaborativas …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
