import{g as a}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as c}from"./prolog-CXI90EJ8.chunk.mjs";function s(t,f){for(var o=0;o<f.length;o++){const e=f[o];if(typeof e!="string"&&!Array.isArray(e)){for(const r in e)if(r!=="default"&&!(r in t)){const n=Object.getOwnPropertyDescriptor(e,r);n&&Object.defineProperty(t,r,n.get?n:{enumerable:!0,get:()=>e[r]})}}}return Object.freeze(Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}))}var i=c();const p=a(i),u=s({__proto__:null,default:p},[i]);export{u as p};
//# sourceMappingURL=prolog-PlIk_cMj.chunk.mjs.map
