OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "найдвартай серверийн жагсаалтанд нэмэх",
    "No server found with ID: %s" : "%s ID-тай сервер олдсонгүй",
    "Could not remove server" : "Серверийг хасаж чадсангүй",
    "Server is already in the list of trusted servers." : "сервер нь аль хэдийн найдвартай серверийн жагсаалтанд  байна",
    "No server to federate with found" : "Ямар ч холбооны сервер олдсонгүй ",
    "Could not add server" : " сервер нэмж чадаагүй ",
    "Trusted servers" : "найдвартай сервер",
    "Federation" : "холбоо",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federation нь бүртгэлийн лавлагааг солилцохын тулд бусад итгэмжлэгдсэн серверүүдтэй холбогдох боломж олгодог.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federation нь бүртгэлийн лавлагааг солилцохын тулд бусад итгэмжлэгдсэн серверүүдтэй холбогдох боломж олгодог. Жишээлбэл, federated хуваалцалтад зориулж гадаад бүртгэлүүдийг автоматаар дуусгахад ашиглагдана.",
    "Could not add trusted server. Please try again later." : "Найдвартай сервер нэмэх боломжгүй байна. Дараа дахин оролдоно уу.",
    "Add trusted server" : "Найдвартай сервер нэмэх",
    "Server url" : "Серверийн URL",
    "Add" : "нэмэх",
    "Server ok" : "Сервер ажиллаж байна",
    "User list was exchanged at least once successfully with the remote server." : "Хэрэглэгчдийн жагсаалтыг алсын сервертэй хамгийн багадаа нэг удаа амжилттай солилцсон.",
    "Server pending" : "Сервер хүлээгдэж байна",
    "Waiting for shared secret or initial user list exchange." : "Нийтлэг нууц эсвэл анхны хэрэглэгчдийн жагсаалт солилцохыг хүлээж байна.",
    "Server access revoked" : "Серверийн хандалт цуцлагдсан",
    "Server failure" : "Серверийн алдаа",
    "Connection to the remote server failed or the remote server is misconfigured." : "Алслагдсан сервертэй холбогдоход алдаа гарсан эсвэл алслагдсан сервер буруу тохируулагдсан байна.",
    "Failed to delete trusted server. Please try again later." : "Найдвартай сервер устгах боломжгүй байна. Дараа дахин оролдоно уу.",
    "Delete" : "Устгах",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federation нь бүртгэлийн лавлагааг солилцохын тулд бусад итгэмжлэгдсэн серверүүдтэй холбогдох боломж олгодог. Жишээлбэл, federated хуваалцалтад зориулж гадаад бүртгэлүүдийг автоматаар дуусгахад ашиглагдана. Federated хуваалцалт үүсгэхийн тулд серверийг итгэмжлэгдсэн сервер болгон нэмэх шаардлагагүй.",
    "Each server must validate the other. This process may require a few cron cycles." : "Сервер бүр нөгөөгийнхөө хүчинтэй байдлыг баталгаажуулах ёстой. Энэ процесс хэдэн cron мөчлөг шаардаж болно.",
    "External documentation for Federated Cloud Sharing" : "Холбогдсон үүлэн хуваалцалтын гадаад баримт бичиг",
    "+ Add trusted server" : "+ найдвартай сервер нэмэх",
    "Trusted server" : "найдвартай сервер"
},
"nplurals=2; plural=(n != 1);");
