var u,m;function S(){if(m)return u;m=1;function N(e){const n="[a-z'][a-zA-Z0-9_']*",f="("+n+":"+n+"|"+n+")",c={keyword:"after and andalso|10 band begin bnot bor bsl bzr bxor case catch cond div end fun if let not of orelse|10 query receive rem try when xor maybe else",literal:"false true"},d=e.COMMENT("%","$"),o={className:"number",begin:"\\b(\\d+(_\\d+)*#[a-fA-F0-9]+(_[a-fA-F0-9]+)*|\\d+(_\\d+)*(\\.\\d+(_\\d+)*)?([eE][-+]?\\d+)?)",relevance:0},v={begin:"fun\\s+"+n+"/\\d+"},b={begin:f+"\\(",end:"\\)",returnBegin:!0,relevance:0,contains:[{begin:f,relevance:0},{begin:"\\(",end:"\\)",endsWithParent:!0,returnEnd:!0,relevance:0}]},a={begin:/\{/,end:/\}/,relevance:0},l={begin:"\\b_([A-Z][A-Za-z0-9_]*)?",relevance:0},g={begin:"[A-Z][a-zA-Z0-9_]*",relevance:0},r={begin:"#"+e.UNDERSCORE_IDENT_RE,relevance:0,returnBegin:!0,contains:[{begin:"#"+e.UNDERSCORE_IDENT_RE,relevance:0},{begin:/\{/,end:/\}/,relevance:0}]},E={scope:"string",match:/\$(\\([^0-9]|[0-9]{1,3}|)|.)/},s={scope:"string",match:/"""("*)(?!")[\s\S]*?"""\1/},t={scope:"string",contains:[e.BACKSLASH_ESCAPE],variants:[{match:/~\w?"""("*)(?!")[\s\S]*?"""\1/},{begin:/~\w?\(/,end:/\)/},{begin:/~\w?\[/,end:/\]/},{begin:/~\w?{/,end:/}/},{begin:/~\w?</,end:/>/},{begin:/~\w?\//,end:/\//},{begin:/~\w?\|/,end:/\|/},{begin:/~\w?'/,end:/'/},{begin:/~\w?"/,end:/"/},{begin:/~\w?`/,end:/`/},{begin:/~\w?#/,end:/#/}]},_={beginKeywords:"fun receive if try case maybe",end:"end",keywords:c};_.contains=[d,v,e.inherit(e.APOS_STRING_MODE,{className:""}),_,b,t,s,e.QUOTE_STRING_MODE,o,a,l,g,r,E];const i=[d,v,_,b,t,s,e.QUOTE_STRING_MODE,o,a,l,g,r,E];b.contains[1].contains=i,a.contains=i,r.contains[1].contains=i;const T=["-module","-record","-undef","-export","-ifdef","-ifndef","-author","-copyright","-doc","-moduledoc","-vsn","-import","-include","-include_lib","-compile","-define","-else","-endif","-file","-behaviour","-behavior","-spec","-on_load","-nifs"],w={className:"params",begin:"\\(",end:"\\)",contains:i};return{name:"Erlang",aliases:["erl"],keywords:c,illegal:"(</|\\*=|\\+=|-=|/\\*|\\*/|\\(\\*|\\*\\))",contains:[{className:"function",begin:"^"+n+"\\s*\\(",end:"->",returnBegin:!0,illegal:"\\(|#|//|/\\*|\\\\|:|;",contains:[w,e.inherit(e.TITLE_MODE,{begin:n})],starts:{end:";|\\.",keywords:c,contains:i}},d,{begin:"^-",end:"\\.",relevance:0,excludeEnd:!0,returnBegin:!0,keywords:{$pattern:"-"+e.IDENT_RE,keyword:T.map(O=>`${O}|1.5`).join(" ")},contains:[w,t,s,e.QUOTE_STRING_MODE]},o,t,s,e.QUOTE_STRING_MODE,r,l,g,a,E,{begin:/\.$/}]}}return u=N,u}export{S as r};
//# sourceMappingURL=erlang-CTgWIaMO.chunk.mjs.map
