var n,i;function g(){if(i)return n;i=1;function c(a){const r=a.regex,e="HTTP/([32]|1\\.[01])",l=/[A-Za-z][A-Za-z0-9-]*/,s={className:"attribute",begin:r.concat("^",l,"(?=\\:\\s)"),starts:{contains:[{className:"punctuation",begin:/: /,relevance:0,starts:{end:"$",relevance:0}}]}},t=[s,{begin:"\\n\\n",starts:{subLanguage:[],endsWithParent:!0}}];return{name:"HTTP",aliases:["https"],illegal:/\S/,contains:[{begin:"^(?="+e+" \\d{3})",end:/$/,contains:[{className:"meta",begin:e},{className:"number",begin:"\\b\\d{3}\\b"}],starts:{end:/\b\B/,illegal:/\S/,contains:t}},{begin:"(?=^[A-Z]+ (.*?) "+e+"$)",end:/$/,contains:[{className:"string",begin:" ",end:" ",excludeBegin:!0,excludeEnd:!0},{className:"meta",begin:e},{className:"keyword",begin:"[A-Z]+"}],starts:{end:/\b\B/,illegal:/\S/,contains:t}},a.inherit(s,{relevance:0})]}}return n=c,n}export{g as r};
//# sourceMappingURL=http-BF-Ug6Y1.chunk.mjs.map
