OC.L10N.register(
    "photos",
    {
    "Public link" : "Viešoji nuoroda",
    "Photos" : "Nuotraukos",
    "On This Day" : "Šią dieną",
    "Your memories under your control" : "Jūsų prisiminimai jūsų rankose",
    "All media" : "Visa medija",
    "Videos" : "Vaizdo įrašai",
    "Albums" : "Albumai",
    "Collaborative albums" : "Bendradarbiavimo albumai",
    "People" : "Žmonės",
    "Folders" : "Aplankai",
    "Favorites" : "Mėgstamos",
    "On this day" : "Šią dieną",
    "Shared with you" : "Bendrinama su jumis",
    "Tags" : "Žymos",
    "Places" : "Vietos",
    "Map" : "Žemėlapis",
    "Photos settings" : "Nuotraukų nustatymai",
    "Mark selection as favorite" : "Pažymėti pasirinkimą kaip mėgstamiausią",
    "Add selection to favorites" : "Pridėkite pasirinkimą prie mėgstamiausių",
    "Remove selection from favorites" : "Pašalinti pasirinkimą iš mėgstamiausių",
    "This name is already in use." : "Šis pavadinimas jau yra naudojamas.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" simbolis failo pavadinime neleidžiamas",
    "Invalid filename." : "Neteisingas failo pavadinimas.",
    "Name of the album" : "Albumo pavadinimas",
    "Location of the album" : "Albumo vieta",
    "Back" : "Atgal",
    "Add collaborators" : "Pridėti bendradarbiautojus",
    "Save" : "Įrašyti",
    "Create album" : "Sukurti albumą",
    "Add to Album" : "Pridėti į albumą",
    "Add selection to album {albumName}" : "Pridėti pasirinkimą į {albumName} albumą",
    "Shared by" : "Bendrina",
    "Create a new album." : "Sukurti naują albumą.",
    "Create new album" : "Sukurti naują albumą",
    "New album" : "Naujas albumas",
    "_%n item_::_%n photos and videos_" : ["%n elementas","%n nuotraukos ir vaizdo įrašai","%n nuotraukų ir vaizdo įrašų","%n nuotraukų ir vaizdo įrašų"],
    "Failed to fetch collaborators list." : "Nepavyko gauti bendradarbiautojų sąrašo.",
    "Failed to update album." : "Nepavyko atnaujinti albumo.",
    "Add people or groups who can edit your album" : "Pridėti žmonių ar grupių, kurie galėtų taisyti jūsų albumą",
    "Search people or groups" : "Ieškoti žmonių ar grupių",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "Copy the public link" : "Kopijuoti viešąją nuorodą",
    "Public link copied!" : "Viešoji nuoroda nukopijuota!",
    "Copy public link" : "Kopijuoti viešąją nuorodą",
    "Delete the public link" : "Ištrinti viešąją nuorodą",
    "Create public link share" : "Sukurti viešą nuorodos bendrinimą",
    "Share via public link" : "Bendrinti per viešąją nuorodą",
    "This collection does not exist" : "Šios kolekcijos nėra",
    "An error occurred" : "Įvyko klaida",
    "No picture for this day" : "Šios dienos nuotraukos nėra",
    "Picture taken on this day will show up here." : "Šią dieną padaryta nuotrauka bus rodoma čia.",
    "More photos from this day" : "Daugiau nuotraukų iš šios dienos",
    "_%n photos_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nepriskirta nuotrauka","%n nepriskirtos nuotraukos","%n nepriskirtų nuotraukų","%n nepriskirtų nuotraukų"],
    "Favorite" : "Mėgstamas",
    "Favorite image, open the full size \"{name}\" image" : "Mėgstamiausias paveikslėlis, atidarykite viso dydžio \"{name}\"",
    "Open the full size \"{name}\" image" : "Atverti viso dydžio „{name}“ paveikslą",
    "Select image {imageName}" : "Pasirinkti {imageName} paveikslėlį ",
    "Open the \"{name}\" folder" : "Atidaryti \"{name}\" aplanką",
    "Go back" : "Grįžti",
    "Select a custom date range" : "Pasirinkti norimą datų intervalą",
    "Select a date range" : "Pasirinkti datų intervalą",
    "Date range" : "Laikotarpis",
    "Select filters" : "Pasirinkti filtrus",
    "Dates" : "Datos",
    "Jump to specific date in list" : "Pereiti prie konkrečios datos sąraše",
    "Jump to {date}" : "Pereiti prie {date}",
    "Add to {destination}" : "Pridėti į {destination}",
    "The destination folder is owned by {owner}" : "Paskirties aplanko savininkas yra {owner}",
    "There are no photos or videos yet!" : "Kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "_{years} year ago_::_{years} years ago_" : ["Prieš {years} metus","Prieš {years} metus","Prieš {years} metų","Prieš {years} metus"],
    "Squared photos view" : "Kvadrato nuotraukų rodinys",
    "Delete source directory" : "Ištrinti šaltinio katalogą",
    "Pick folder" : "Pasirinkite aplanką",
    "Select a source folder for your media" : "Pasirinkite medijos šaltinio aplanką",
    "Media folders" : "Medijos aplankai",
    "Choose the folders from where photos and videos are shown." : "Pasirinkite aplankus, kuriuose rodomos nuotraukos ir vaizdo įrašai.",
    "All folders" : "Visi aplankai",
    "Add a Photos source for the timelines" : "Pridėkite laiko juostų nuotraukų šaltinį",
    "Add folder" : "Pridėti aplanką",
    "Home" : "Namai",
    "Select the default upload location for your media" : "Pasirinkite numatytąją medijos įkėlimo vietą",
    "Upload folder" : "Įkelti aplanką",
    "General" : "Bendra",
    "_%n photo_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "Unselect all" : "Atšaukti visų pasirinkimą",
    "Add photos to this album" : "Pridėti į šį albumą nuotraukų",
    "Manage collaborators for this album" : "Tvarkyti šio albumo bendradarbiautojus",
    "Open actions menu" : "Atverti veiksmų meniu",
    "Edit album details" : "Taisyti išsamesnę albumo informaciją",
    "Download all files in album" : "Atsisiųsti visus failus šiame albume",
    "Delete album" : "Ištrinti albumą",
    "Download selected files" : "Atsisiųsti pažymėtus failus",
    "Remove selection from album" : "Šalinti žymėjimą iš albumo",
    "This album does not have any photos or videos yet!" : "Šiame albume kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "Add photos to {albumName}" : "Pridėkite nuotraukų į {albumName}",
    "Manage collaborators" : "Tvarkyti bendradarbiautojus",
    "Save collaborators for this album." : "Išsaugoti šio albumo bendradarbiautojus",
    "Cover photo for album {albumName}" : "{albumName} albumo viršelio nuotrauka",
    "There is no album yet!" : "Kol kas nėra jokių albumų!",
    "This person could not be found" : "Nepavyko rasti šio žmogaus",
    "Rename person" : "Pervadinti žmogų",
    "Merge with different person" : "Sulieti su kitu žmogumi",
    "Download selected photos" : "Atsisiųsti pažymėtas nuotraukas",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Remove person" : "Šalinti žmogų",
    "Name of this person" : "Šio žmogaus vardas",
    "Save." : "Įrašyti.",
    "Merge person" : "Sujungti asmenį",
    "Move to different person" : "Perkelti kitam asmeniui",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Perkelti nuotrauką kitam asmeniui","Perkelti nuotraukas kitam asmeniui","Perkelti nuotraukų kitam asmeniui","Perkelti nuotraukų kitam asmeniui"],
    "_Remove photo from person_::_Remove photos from person_" : ["Pašalinti nuotrauką iš asmens","Pašalinti nuotraukas iš asmens","Pašalinti nuotraukų iš asmens","Pašalinti nuotraukų iš asmens"],
    "This might take some time depending on the size of your photo library." : "Tai, priklausomai nuo jūsų nuotraukų bibliotekos dydžio, gali šiek tiek užtrukti.",
    "Recognized people will show up here" : "Čia bus rodomi atpažinti žmonės",
    "This folder does not exist" : "Šio aplanko nėra",
    "Loading folders…" : "Įkeliami aplankai…",
    "No photos in here" : "Čia nuotraukų nėra",
    "Taken on {date} at {time}" : "Padaryta {date} {time}",
    "This place does not have any photos or videos yet!" : "Šioje vietoje dar nėra jokių nuotraukų ar vaizdo įrašų!",
    "Add photos to this place" : "Pridėti nuotraukų prie šios vietos",
    "Cover photo for place {placeName}" : "{placeName} vietos viršelio nuotrauka",
    "There is no place yet!" : "Vietos dar nėra!",
    "Cover photo for shared album {albumName}" : "Bendrinamo {albumName} albumo viršelio nuotrauka",
    "Back to tags overview" : "Atgal į žymų apžvalgą",
    "No photos with this tag yet" : "Kol kas nėra nuotraukų, turinčių šią žymą",
    "No tags yet" : "Kol kas žymų nėra",
    "Photos with tags will show up here" : "Čia bus rodomos nuotraukos, turinčios žymas",
    "Popular tags" : "Populiarios žymos",
    "All tags" : "Visos žymos",
    "Create new album from filters" : "Sukurti naują albumą naudojant filtrus",
    "One of the source folders does not exist" : "Vienas iš šaltinio aplankų neegzistuoja",
    "Add to album" : "Pridėti į albumą",
    "Delete selection" : "Ištrinti žymėjimą",
    "No photos or videos in here" : "Čia nėra jokių nuotraukų ar vaizdo įrašų",
    "Unassigned faces" : "Nepriskirti veidai",
    "Failed to fetch collection." : "Nepavyko atsisiųsti kolekcijos.",
    "Failed to fetch collections list." : "Nepavyko atsisiųsti kolekcijų sąrašo.",
    "Failed to fetch faces list." : "Nepavyko gauti veidų sąrašo.",
    "Error fetching files" : "Klaida atsisiunčiant failus",
    "All your media" : "Visa jūsų medija",
    "Album {title}" : "{title} albumas",
    "Shared Albums" : "Bendrinami albumai",
    "Shared album {title}" : "Bendrintas {title} albumas",
    "Public album {title}" : "Viešas {title} albumas",
    "Tagged photos" : "Nuotraukos, turinčios žymas",
    "Tagged photo {title}" : " Žymėta {title} nuotrauka",
    "{title}'s face" : "{title} veidas",
    "Last week" : "Praeitą savaitę",
    "Last Month" : "Praėjusį mėnesį",
    "Custom…" : "Pasirinktinis…",
    "{startDate} to {endDate}" : "Nuo {startDate} iki {endDate}",
    "Details" : "Išsamiau",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Nepavyko pridėti {fileBaseName} prie {collectionFileName} kolekcijos ",
    "Failed to delete {fileBaseName}" : "Nepavyko ištrinti {fileBaseName}",
    "Failed to create {collectionFileName}" : "Nepavyko sukurti {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Nepavyko pervadinti {currentCollectionFileName} į {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Nepavyko atnaujinti {collectionFileName} savybių pagal {properties}",
    "Delete collection" : "Ištrinti kolekciją",
    "Leave shared album" : "Išeiti iš bendro albumo",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Ar tikrai norite ištrinti {collectionName}? Šio veiksmo negalima atšaukti.",
    "Failed to delete {collectionFileName}" : "Nepavyko ištrinti {collectionFileName}",
    "Cancel" : "Atsisakyti",
    "Confirm" : "Patvirtinti",
    "Failed to move {fileBaseName} to person {faceName}" : "Nepavyko {fileBaseName} perkelti asmeniui vardu {faceName}",
    "Failed to remove {fileBaseName}" : "Nepavyko pašalinti {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Nepavyko pervadinti {oldName} į {faceName}",
    "Failed to delete {faceName}" : "Nepavyko ištrinti {faceName}",
    "Failed to delete {fileId}" : "Nepavyko ištrinti {fileId}",
    "Failed to delete {fileName}" : "Nepavyko ištrinti {fileName}",
    "Failed to set favorite state for {fileId}" : "Nepavyko nustatyti mėgstamiausios {fileId} būsenos",
    "Failed to set favorite state for {fileName}" : "Nepavyko nustatyti mėgstamiausios {fileName} būsenos",
    "Could not load photos folder" : "Nepavyko įkelti nuotraukų aplanko",
    "Group" : "Grupė",
    "Remove {collaboratorLabel} from the collaborators list" : "Pašalinti {collaboratorLabel} iš bendradarbiautojų sąrašo",
    "Enable squared photos view" : "Įjungti kvadratinį nuotraukų rodinį",
    "Choose default Photos upload and Albums location" : "Pasirinkite numatytąją nuotraukų įkėlimo ir albumų vietą",
    "Choose a different folder" : "Pasirinkti kitą aplanką",
    "View" : "Rodyti",
    "Choose the folder where photos and albums are uploaded to." : "Pasirinkti aplanką, į kurį įkeliamos nuotraukos ir albumai.",
    "Loading folders …" : "Įkeliami aplankai  …"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
