OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "偵測到新的帳號登入位置",
    "More info about the suspicious IP address available on %s" : "關於可疑 IP 地址的更多資訊，請見 %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious by an AI model. If this was you, you can ignore this message, as the AI model did not take any automated actions. Otherwise, you should change your password." : "偵測到您帳號有新的帳戶登入活動。IP 位址 %s 被人工智慧模型歸類為可疑。如果是您本人的登入活動，您可以忽略此訊息，因為 AI 模型並未採取任何自動操作。否則您應變更密碼。",
    "Open %s ↗" : "開啟 %s ↗",
    "Suspicious Login" : "可疑的帳號登入活動",
    "New login detected" : "偵測到新的帳號登入活動",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "偵測並警告登入 Nextcloud 的可疑 IP\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "偵測到您帳號有新的帳戶登入活動。IP 位址 %s 被歸類為可疑。如果是您本人的登入活動，您可以忽略此訊息。否則您應變更密碼。"
},
"nplurals=1; plural=0;");
