OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Inloggat konto måste vara en administratör eller ha behörighet att ändra denna inställning.",
    "Could not create non-existing user ID" : "Kunde inte skapa ej existerande användar-ID",
    "User already exists" : "Användaren finns redan",
    "Group %1$s does not exist" : "Grupp %1$s finns inte",
    "Insufficient privileges for group %1$s" : "Otillräckliga privilegier för grupp %1$s",
    "No group specified (required for sub-admins)" : "Ingen grupp specificerad (krävs för underadministratörer)",
    "Invalid password value" : "Ogiltigt lösenords-värde",
    "Unlimited quota is forbidden on this instance" : "Obegränsad kvot är inte tillåtet på denna instans",
    "Invalid language" : "Ogiltigt språk",
    "Invalid locale" : "Ogiltigt språkområde",
    "User does not exist" : "Användare finns inte",
    "Group does not exist" : "Grupp finns inte",
    "Email address not available" : "E-postadress är inte tillgänglig",
    "Sending email failed" : "Utskick av e-postmeddelande misslyckades",
    "Email confirmation" : "E-postverifikation",
    "To enable the email address %s please click the button below." : "För att aktivera e-postadressen %s vänligen klicka på knappen nedanför.",
    "Confirm" : "Bekräfta",
    "Email was already removed from account and cannot be confirmed anymore." : "E-postadress har redan tagits bort från konto och kan inte längre verifieras.",
    "Could not verify mail because the token is expired." : "Kunde inte verifiera e-postadressen eftersom giltighetstiden för verifikationskoden har gått ut.",
    "Could not verify mail because the token is invalid." : "Kunde inte verifiera e-postadressen eftersom verifikationskoden är inkorrekt.",
    "An unexpected error occurred. Please contact your admin." : "Ett oväntat fel har uppkommit. Kontakta din administratör.",
    "Email confirmation successful" : "E-postbekräftelsen lyckades",
    "Provisioning API" : "Distribuerings API"
},
"nplurals=2; plural=(n != 1);");
