OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etykieta systemowa %1$s dodana przez system",
    "Added system tag {systemtag}" : "Dodano etykietę systemową  {systemtag}",
    "Added system tag %1$s" : "Dodano etykietę systemową %1$s",
    "%1$s added system tag %2$s" : "%1$s dodał etykietę systemową %2$s",
    "{actor} added system tag {systemtag}" : "{actor} dodał etykietę systemową {systemtag}",
    "System tag %1$s removed by the system" : "Znacznik systemowy %1$s usunięty przez system",
    "Removed system tag {systemtag}" : "Usunięto etykietą systemową {systemtag}",
    "Removed system tag %1$s" : "Usunięto etykietę systemową %1$s",
    "%1$s removed system tag %2$s" : "%1$s usunął etykietę systemową %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} usunął etykietę systemową {systemtag}",
    "You created system tag %1$s" : "Utworzyłeś etykietę systemową %1$s",
    "You created system tag {systemtag}" : "Utworzyłeś etykietę systemową {systemtag}",
    "%1$s created system tag %2$s" : "%1$s utworzył etykietę systemową %2$s",
    "{actor} created system tag {systemtag}" : "{actor} utworzył etykietę systemową {systemtag}",
    "You deleted system tag %1$s" : "Skasowałeś etykietę systemową %1$s",
    "You deleted system tag {systemtag}" : "Usunąłeś etykietę systemową {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s usunął etykietę systemową %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} usunął etykietę systemową {systemtag}",
    "You updated system tag %2$s to %1$s" : "Zaktualizowałeś etykietę systemową %2$s do %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Zaktualizowałeś etykietę systemową {oldsystemtag} do {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s zaktualizował etykietę systemową %3$s do %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} zaktualizował etykietę systemową {oldsystemtag} do {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etykieta systemowy %2$s została dodana do %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Etykieta systemowa {systemtag} została dodana do {file}",
    "You added system tag %2$s to %1$s" : "Dodałeś etykietę systemową %2$s do %1$s",
    "You added system tag {systemtag} to {file}" : "Dodałeś etykietę systemową {systemtag} do {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s dodał etykiete systemową %3$s do %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} dodał etykietę systemową {systemtag} do {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etykieta systemowa %2$s została usunięta z %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Etykieta systemowa {systemtag} została usunięta z {file}",
    "You removed system tag %2$s from %1$s" : "Usunąłeś etykietę systemową %2$s z %1$s",
    "You removed system tag {systemtag} from {file}" : "Usunąłeś etykietę systemową {systemtag} z {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s usunął etykietę systemową %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} usunął etykietę systemową {systemtag} z {file}",
    "%s (restricted)" : "%s (ograniczony)",
    "%s (invisible)" : "%s (niewidoczny)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Etykieta systemowa</strong> dla pliku została zmieniona",
    "Files" : "Pliki",
    "Tags" : "Etykiety",
    "All tagged %s …" : "Wszystkie oznaczone %s…",
    "tagged %s" : "oznaczone %s",
    "Collaborative tags" : "Wspólne etykiety",
    "Collaborative tagging functionality which shares tags among people." : "Funkcja wspólnego przypisywania etykiet, która udostępnia etykiety między osobami.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Wspólna funkcja przypisywania etykiet, która udostępnia etykiety innym ludziom. Idealne dla zespołów.\n\t(Jeśli jesteś dostawcą instalacji dla wielu odbiorców, zaleca się dezaktywację tej aplikacji, ponieważ etykiety są udostępniane.)",
    "Public" : "Publiczne",
    "Restricted" : "Ograniczone",
    "Invisible" : "Niewidoczne",
    "Created tag" : "Utworzona etykieta",
    "Failed to create tag" : "Błąd tworzenia etykiety",
    "Updated tag" : "Zaktualizowana etykieta",
    "Failed to update tag" : "Błąd aktualizacji etykiety",
    "Deleted tag" : "Usunięta etykieta",
    "Failed to delete tag" : "Błąd usuwania etykiety",
    "Create or edit tags" : "Utwórz lub edytuj etykietę:",
    "Search for a tag to edit" : "Wyszukaj etykietę do edycji",
    "Collaborative tags …" : "Tagi współdzielone …",
    "No tags to select" : "Brak etykiet do zaznaczenia",
    "Tag name" : "Nazwa etykiety",
    "Tag level" : "Poziom etykiety",
    "Create" : "Utwórz",
    "Update" : "Uaktualnij",
    "Delete" : "Usuń",
    "Reset" : "Reset",
    "Loading …" : "Ładowanie ...",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} zostanie ustawiony, a {tag2} zostanie usunięty z jednego pliku","{tag1} zostanie ustawiony, a {tag2} zostanie usunięty z {count} plików ","{tag1} zostanie ustawiony, a {tag2} zostanie usunięty z {count} plików ","{tag1} zostanie ustawiony, a {tag2} zostanie usunięty z {count} plików "],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag}  zostanie ustawiony dla 1 pliku.","{tag} zostanie ustawiony dla {count} plików.","{tag} zostanie ustawiony dla {count} plików.","{tag} zostanie ustawiony dla {count} plików."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} zostanie usunięty z 1 pliku.","{tag} zostanie usunięty z {count} plików."," {tag} zostanie usunięty z {count} plików.","{tag} zostanie usunięty z {count} plików."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} i {lastTag} zostaną ustawione dla 1 pliku.","{tags} i {lastTag} zostaną ustawione dla {count} plików.","{tags} i {lastTag} zostaną ustawione dla {count} plików.","{tags} i {lastTag} zostaną ustawione dla {count} plików."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} i {lastTag} zostaną usunięte z 1 pliku.","{tags} i {lastTag} zostaną usunięte z {count} plików.","{tags} i {lastTag} zostaną usunięte z {count} plików.","{tags} i {lastTag} zostaną usunięte z {count} plików."],
    "{displayName} (hidden)" : "{displayName} (ukryty)",
    "{displayName} (restricted)" : "{displayName} (ograniczony)",
    "Only admins can create new tags" : "Tylko administratorzy mogą tworzyć nowe tagi",
    "Failed to apply tags changes" : "Nie udało się zastosować zmian tagów",
    "Manage tags" : "Zarządzaj etykietami",
    "Applying tags changes…" : "Zastosowywanie zmian etykiet…",
    "Search or create tag" : "Wyszukaj lub utwórz etykietę",
    "Search tag" : "Wyszukaj tag",
    "Change tag color" : "Zmień kolor etykiety",
    "Create new tag" : "Utwórz nową etykietę",
    "Choose tags for the selected files" : "Wybierz tagi dla oznaczonych plików",
    "Cancel" : "Anuluj",
    "Apply" : "Zastosuj",
    "Failed to load selected tags" : "Nie udało się załadować wybranych tagów",
    "Failed to load tags" : "Nie udało się załadować etykiet",
    "Failed to select tag" : "Nie udało się wybrać tagu",
    "System admin disabled tag creation. You can only use existing ones." : "Administrator systemu wyłączył tworzenie tagów. Można używać tylko istniejących tagów.",
    "Loading collaborative tags …" : "Wczytywanie tagów współdzielonych …",
    "Search or create collaborative tags" : "Wyszukaj lub utwórz wspólne tagi",
    "No tags to select, type to create a new tag" : "Brak tagów do wyboru, wpisz, aby utworzyć nowy tag",
    "Unable to update setting" : "Nie udało się zaktualizować ustawienia",
    "System tag creation is now restricted to administrators" : "Tworzenie tagów systemowych jest teraz ograniczone do administratorów",
    "System tag creation is now allowed for everybody" : "Tworzenie tagów systemowych jest teraz dozwolone dla wszystkich",
    "System tag management" : "Zarządzanie tagami systemowymi",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Jeśli włączone, tylko administratorzy mogą tworzyć i edytować tagi. Konta nadal mogą przypisywać i usuwać je z plików.",
    "Restrict tag creation and editing to administrators" : "Ogranicz tworzenie i edytowanie tagów do administratorów",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Wspólne etykietowanie jest dostępne dla wszystkich użytkowników. Ograniczone etykiety są widoczne dla użytkowników, ale nie mogą być przez nich przypisane. Etykiety niewidoczne są natomiast przeznaczone do użytku wewnętrznego, ponieważ użytkownicy nie mogą ich zobaczyć ani przypisać.",
    "Add tags" : "Dodaj etykiety",
    "Assigned collaborative tags" : "Przypisane wspólne etykiety",
    "Open in Files" : "Otwórz w Plikach",
    "List of tags and their associated files and folders." : "Lista etykiet i związanych z nimi plików i katalogów.",
    "No tags found" : "Nie znaleziono etykiet",
    "Tags you have created will show up here." : "Utworzone przez Ciebie tagi pojawią się tutaj.",
    "Failed to load tag" : "Nie udało się pobrać etykiety",
    "Failed to load last used tags" : "Nie udało się załadować ostatnio używanych tagów",
    "Missing \"Content-Location\" header" : "Brakuje nagłówka „Content-Location”",
    "A tag with the same name already exists" : "Tag o tej samej nazwie już istnieje",
    "Failed to load tags for file" : "Nie udało się załadować tagów dla pliku",
    "Failed to set tag for file" : "Nie udało się ustawić tagu dla pliku",
    "Failed to delete tag for file" : "Nie udało się usunąć tagu z pliku",
    "Collaborative tags …" : "Etykiety wspólne…",
    "Loading …" : "Wczytywanie…",
    "Loading collaborative tags …" : "Wczytywanie wspólnych etykiet…"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
