OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Daemon-konfigurasjon ikke funnet",
    "Error starting install of ExApp" : "Feil ved start av installasjon av ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp-registrering feilet, sjekk NC-loggene",
    "ExApp not found, failed to get status" : "ExApp ikke funnet, henting av status feilet",
    "Could not perform installation of ExApp" : "Kunne ikke utføre installasjon av ExApp",
    "Failed to enable ExApp" : "Aktivering av ExApp feilet",
    "Failed to disable ExApp" : "Deaktivering av ExApp feilet",
    "Could not update ExApp" : "Kunne ikke oppdatere ExApp",
    "Error starting update of ExApp" : "Feil ved start av oppdatering av ExApp",
    "Could not perform update of ExApp" : "Kunne ikke utføre oppdatering av ExApp",
    "ExApp not found, failed to get logs" : "ExApp ikke funnet, henting av logger feilet",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Henting av konteinerlogger feilet. Merk: Nedlasting av Docker-konteiner fungerer bare for konteinere med json-fil eller journalført loggdriver. Feil: %s",
    "AppAPI authentication failed" : "AppAPI-autentisering feilet",
    "AppAPI ExApp notifier" : "AppAPI ExApp-varsler",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "AI-integrasjonsteam",
    "ExApps Settings" : "Innstillinger for ExApps",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "External Apps management" : "Administrasjon av eksterne apper",
    "Admin options saved" : "Administrasjonsalternativer lagret",
    "Failed to save admin options" : "Lagring av administrasjonsalternativer feilet",
    "ExApp init timeout (minutes)" : "ExApp init tidsavbrudd (minutter)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Tidsavbrudd for ExApp-initialiseringsprosessen, hvoretter AppAPI vil merke den som feilet",
    "ExApp init timeout" : "ExApp init tidsavbrudd",
    "ExApp container restart policy" : "Retningslinjer for omstart av ExApp-beholder",
    "Cancel" : "Avbryt",
    "Delete" : "Slett",
    "Password confirmation failed" : "Passordbekreftelse feilet",
    "Default" : "Forvalg",
    "Set as default" : "Angi som standard",
    "Test deploy" : "Test distribuering",
    "Edit" : "Rediger",
    "Daemon connection successful" : "Vellykket daemon-forbindelse",
    "Unlimited" : "Ubegrenset",
    "Default daemon. ExApps will be installed on it" : "Standard daemon. ExApps blir installert på den.",
    "ExApps installed" : "ExApps installert",
    "Name" : "Navn",
    "Protocol" : "Protokoll",
    "Host" : "Server",
    "Docker network" : "Docker-nettverk",
    "Nextcloud URL" : "Nextcloud URL",
    "HaProxy password" : "HaProxy-passord",
    "Memory limit" : "Minnegrense",
    "Additional options" : "Ytterligere alternativer",
    "Check connection" : "Sjekk forbindelsen",
    "Registered Deploy daemons list" : "Registrert liste over distribuerings-daemoner",
    "Register ExApp in Nextcloud" : "Registrer ExApp i Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Sjekk om ExApp er registrert i Nextcloud før distribusjon",
    "Image pull" : "Bildetrekk",
    "Check if the image is successfully pulled" : "Sjekk om bildet er vellykket trukket",
    "Container started" : "Konteiner startet",
    "Check if the image successfully pulled and container is created and started" : "Sjekk om bildet ble trukket og konteineren er opprettet og startet",
    "Heartbeat" : "Hjerteslag",
    "Check for the heartbeat is finished and healthy" : "Sjekk om hjerterytmen er ferdig og sunn",
    "Init step" : "Initialiseringstrinn",
    "Wait for initialization step to finish" : "Vent til initialiseringstrinnet er ferdig",
    "Enabled" : "Aktivert",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Sjekk om ExApp håndterte den aktiverte hendelsen og registrerte alle ting riktig",
    "Only if ExApp container is preset" : "Bare hvis ExApp-konteineren er forhåndsinnstilt",
    "Deploy test passed successfully!" : "Distribusjonstesten bestått vellykket!",
    "Deploy test failed at step \"{step}\"" : "Distribusjonstesten feilet på trinn \"{step}\"",
    "More information" : "Mer informasjon",
    "Download ExApp logs" : "Last ned ExApp logger",
    "Remove" : "Fjern",
    "From" : "Fra",
    "To" : "Til",
    "Add" : "Legg til",
    "AppAPI Docker Socket Proxy authentication password" : "AppAPI Docker Socket Proxy autentiseringspassord",
    "DaemonConfig successfully registered" : "DaemonKonfigurasjon registrert",
    "Failed to register DaemonConfig. Check the logs" : "Registrering av DaemonKonfigurasjon feilet. Sjekk loggene.",
    "DaemonConfig successfully updated" : "DaemonKonfigurasjon oppdatert",
    "Failed to update DaemonConfig. Check the logs" : "Oppdatering av DaemonKonfigurasjon feilet. Sjekk loggene.",
    "Failed to connect to Daemon. Check the logs" : "Kobling til daemonen feilet. Sjekk loggene.",
    "Failed to check connection to Daemon. Check the logs" : "Sjekking av forbindelsen til daemonen feilet. Sjekk loggene.",
    "Daemon configuration template" : "Mal for konfigurasjon av daemon",
    "Daemon registration form" : "Registreringsskjema for daemon",
    "Display name" : "Visningsnavn",
    "Deployment method" : "Distribueringsmetode",
    "Daemon host" : "Daemon-vert",
    "Compute device" : "Beregningsenhet",
    "Add additional option" : "Legg til ytterligere alternativ",
    "Option key (unique)" : "Alternativnøkkel (unik)",
    "Option key (unique, e.g. my_key)" : "Alternativnøkkel (unik, f.eks. min_nøkkel)",
    "Option key is required" : "Alternativnøkkel kreves",
    "Option value" : "Alternativverdi",
    "Option value is required" : "Alternativverdi kreves",
    "Confirm" : "Bekreft",
    "Save" : "Lagre",
    "Register" : "Registrer",
    "External Apps" : "Eksterne apper",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "AppAPI-prosjektet er et spennende initiativ som har som mål å revolusjonere måten applikasjoner utvikles for Nextcloud.",
    "Deploy Daemons" : "Distribuer daemons",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Distribuerings-daemon (DaemonConfig) er en ExApps orkestreringsdaemon.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Distribuerings-daemons. Distribuerings-daemon (DaemonConfig) er en ExApps orkestreringsdemon.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Standard distribuerings-daemon er ikke tilgjengelig. Vennligst verifiser dens konfigurasjon.",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Spesifiser retningslinjer for omstart av beholder, f.eks. 'alltid' for å sikre at ExApp kjører etter omstart av daemonserveren.",
    "This settings changes are reflected only for newly created containers" : "Disse endringene i innstillingene gjenspeiles bare for nyopprettede beholdere.",
    "{license}-licensed" : "{license}-lisensiert",
    "Update to {version}" : "Oppdater til {version}",
    "Delete data on remove" : "Slett data ved fjerning",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen minimumversjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen høyeste versjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denne appen kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt:",
    "View in store" : "Vis i butikk",
    "Visit website" : "Besøk nettsiden",
    "Report a bug" : "Rapporter en feil",
    "User documentation" : "Brukerdokumentasjon",
    "Admin documentation" : "Administratordokumentasjon",
    "Developer documentation" : "Utviklerdokumentasjon",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Denne appen er ikke registrert i AppStore. Ingen ekstra informasjon tilgjengelig. Bare aktivere-/deaktivere- og fjerne handlinger er tillatt.",
    "This app is supported via your current Nextcloud subscription." : "Denne appen er støttet av ditt nåværende Nextcloud abonnement.",
    "Supported" : "Støttet",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Anbefalte apper er utviklet av og innenfor fellesskapet. De tilbyr sentral funksjonalitet og er klare for bruk i produksjon.",
    "Featured" : "Anbefalt",
    "Update to {update}" : "Oppdater til {update}",
    "All ExApps are up-to-date." : "Alle ExApps er oppdatert.",
    "Default Deploy daemon is not accessible" : "Standard distribuerings-daemon er ikke tilgjengelig.",
    "Icon" : "Ikon",
    "Version" : "Versjon",
    "Daemon" : "Nisse",
    "Level" : "Nivå",
    "Actions" : "Handlinger",
    "Results from other categories" : "Resultater fra andre kategorier",
    "No apps found" : "Ingen apper funnet",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp har en oppdatering tilgjengelig","%n apper har en oppdatering tilgjengelig"],
    "_Update_::_Update all_" : ["Oppdater","Oppdater alle"],
    "Deploy Daemon" : "Distribuerings-daemon",
    "Type" : "Type",
    "Display Name" : "Visningsnavn",
    "GPUs support" : "Støtte for GPUer",
    "Are you sure you want delete Deploy Daemon" : "Er du sikker på at du vil slette distribuerings-daemon?",
    "All ExApps on this daemon will be removed" : "Alle ExApps på denne daemonen blir fjernet",
    "All ExApps installed on this daemon will be removed" : "Alle ExApps installert på denne daemonen blir fjernet",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "\"manuell-installasjon\" distribuerings-daemon kan ikke settes som standard",
    "Failed to save admin options. Check the logs" : "Lagring av administrasjonsalternativer feilet. Se loggene.",
    "Deploy daemon config details" : "Konfigurasjonsdetaljer for distribuerings-daemon",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Manuell installasjon-daemon vanligvis brukt for utvikling. Den kan ikke angis som standard daemon.",
    "Deploy config" : "Konfigurasjon for distribuering",
    "Verify connection" : "Verifiser forbindelse",
    "No Deploy daemons configured" : "Ingen distribuerings-daemoner konfigurert",
    "Register a custom one or setup from available templates" : "Registrer en tilpasset en eller sett opp fra tilgjengelige maler",
    "Register Daemon" : "Registrer daemon",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI vil prøve å installere det lille skjelettet ExApp for å verifisere Daemon konfigurert riktig og distribusjonstrinnene passerer.",
    "The following Deploy test checks must be passed to succeed:" : "Følgende distribusjonstestsjekker må bestås for å lykkes:",
    "More info" : "Mer info",
    "Remove test ExApp" : "Fjern test ExApp",
    "Start Deploy test" : "Start distribusjonstest",
    "Stop Deploy test" : "Stopp distribusjonstest",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp er uregistrert og konteineren fjernes på \"Stopp distribusjonstest\"",
    "Hostname to access ExApps" : "Vertsnavn for å få tilgang til ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Vertsnavn eller bane for å få tilgang til Docker-bakgrunnsprosessen (f.eks. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "En daemon med dette navnet finnes allerede",
    "Password must be at least 12 characters long" : "Passordet må bestå av minst 12 tegn",
    "With https enabled network is set to host" : "Med https aktivert er nettverk satt til å være vert",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Endringer vil bare bli brukt for nylig installerte ExApps. For eksisterende ExApps bør Docker-konteinere opprettes på nytt.",
    "URL should start with http:// or https://" : "URL-adressen skal starte med http:// eller https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "For HTTPS-daemon bør Nextcloud URL være HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Alle tilgjengelige GPU-enheter på daemon-verten vil bli bedt om å bli aktivert i ExApp-beholdere av Docker.",
    "Edit Deploy Daemon" : "Rediger distribuerings-daemon",
    "Register Deploy Daemon" : "Registrer distribuerings-daemon",
    "Select daemon configuration template" : "Velg mal for konfigurasjon av daemon",
    "Unique Deploy Daemon Name" : "Unikt navn på distribuerings-daemon",
    "Select daemon deploy method" : "Velg metode for daemon-distribuering",
    "Set daemon as default" : "Angi daemon som standard",
    "Set as default daemon" : "Angi som standard daemon",
    "Enable https" : "Aktiver https",
    "Show deploy config" : "Vis konfigurasjon for distribuering",
    "Hide deploy config" : "Skjul konfigurasjon for distribuering",
    "Network" : "Nettverk",
    "Docker network name" : "Docker-nettverksnavn",
    "Additional option" : "Ytterligere alternativ",
    "by {author}\n{license}" : "av {author}\n{license}",
    "Your apps" : "Dine apper",
    "Documentation" : "Dokumentasjo",
    "Details" : "Detaljer",
    "Changelog" : "Endringslogg",
    "Active apps" : "Aktive apper",
    "Disabled apps" : "Deaktiverte apper",
    "Updates" : "Oppdateringer",
    "Featured apps" : "Fremhevede apper",
    "Supported apps" : "Støttede apper",
    "manual-install apps cannot be updated" : "Apper som installeres manuelt, kan ikke oppdateres",
    "{progress}% Deploying" : "{progress}% utplasserer",
    "{progress}% Initializing" : "{progress}% Initialiserer",
    "Healthchecking" : "Helsekontroll",
    "Deploy and Enable" : "Distribuer og aktiver",
    "Enable" : "Aktiver",
    "Disable" : "Deaktiver",
    "Allow untested app" : "Tillatt utestet app",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Standard distribuerings-daemon er ikke tilgjengelig. Verifiser konfigurasjonen.",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Appen lastes ned fra App Store og distribueres på standard distribuerings-daemon.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Denne appen er ikke merket som kompatibel med Nextcloud-versjonen. Hvis du fortsetter, vil du fortsatt kunne installere appen. Vær oppmerksom på at appen kanskje ikke fungerer som forventet.",
    "Your ExApps" : "Dine ExApps",
    "An error occurred during the request. Unable to proceed." : "En feil oppsto under forespørselen. Kan ikke fortsette.",
    "The app has been enabled but needs to be updated." : "Appen er aktivert, men må oppdateres.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Feil: denne appen kan ikke aktiveres fordi det gjør serveren ustabil",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Forsterk din Nextcloud med AppAPI og dens spesialdesignede applikasjoner.\n\n\nAppAPI er et prosjekt innenfor Nextcloud-økosystemet designet for å strømlinjeforme og forbedre prosessen med\napplikasjonsutvikling, distribusjon og administrasjon.\n\nDen introduserer en ny metodikk som lar utviklere lage\napplikasjoner som bruker en rekke programmeringsspråk, ikke begrenset til PHP, som tradisjonelt ble brukt i Nextcloud-utvikling.\n\n\n### Liste over programmer som krever AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Hvis du ønsker å utvikle en applikasjon, hjelper og assisterer vi deg gjerne._\n\n### Støtte\n\nVi setter pris på all støtte til dette prosjektet:\n\n- ⭐ Stjernemerk vårt arbeid på GitHub\n- ❗ Opprett en problemstilling eller en funksjonsforespørsel\n- 💁 Løs et problem og opprett en pull-forespørsel\n- 🧑‍💻 Utvikle ditt eget program ved hjelp av AppAPI\n\nVi er virkelig begeistret for fremtiden til AppAPI-prosjektet og dets potensial til å transformere\nmåten applikasjoner utvikles og oppleves på i Nextcloud.\n\nNår vi legger ut på denne reisen, inviterer vi deg hjertelig - utviklere, tenkere, skapere og visjonære -\ntil å bli med oss i å forme et mer allsidig, stabilt og sikkert applandskap.\n\n*Dine innsikter, forslag og bidrag er uvurderlige for oss.*"
},
"nplurals=2; plural=(n != 1);");
