OC.L10N.register(
    "comments",
    {
    "Comments" : "תגובות",
    "You commented" : "הערות שלך",
    "{author} commented" : "התקבלה תגובה מאת {author}",
    "You commented on %1$s" : "הגבת על %1$s",
    "You commented on {file}" : "הגבת על {file}",
    "%1$s commented on %2$s" : "התקבלו תגובות %1$s ב- %2$s ",
    "{author} commented on {file}" : "נוספה תגובה על {file} מאת {author}",
    "<strong>Comments</strong> for files" : "<strong>תגובות</strong> על קבצים",
    "Files" : "קבצים",
    "{user} mentioned you in a comment on \"{file}\"" : "אוזכרת על ידי {user} בהערה בתוך „{file}”",
    "Files app plugin to add comments to files" : "תוסף ליישומון הקבצים כדי להוסיף הערות על קבצים",
    "Edit comment" : "עריכת תגובה",
    "Delete comment" : "מחיקת תגובה",
    "Cancel edit" : "בטל עריכה",
    "Post comment" : "פרסם תגובה",
    "Unable to load the comments list" : "לא ניתן לטעון את רשימת התגובות",
    "No comments yet, start the conversation!" : "אין תגובות עדיין, בואו נתחיל לקשקש!",
    "No more messages" : "אין יותר הודעות",
    "Retry" : "ניסיון חוזר",
    "_1 new comment_::_{unread} new comments_" : ["הערה חדשה אחת","{unread} הערות חדשות","{unread} הערות חדשות"],
    "Comment" : "תגובה",
    "An error occurred while trying to edit the comment" : "אירעה שגיאה בניסיון לערוך את התגובה",
    "Comment deleted" : "נמחקה הערה",
    "An error occurred while trying to delete the comment" : "אירעה שגיאה בניסיון למחוק את התגובה",
    "An error occurred while trying to create the comment" : "אירעה שגיאה בניסיון ליצור את התגובה"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
