OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "خېرىدارىڭىزنىڭ ئۇلىنىش ھوقۇقى يوق. خېرىدارىڭىزنىڭ باشقۇرغۇچىغا خەۋەر قىلىڭ.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "قايتا نىشانلانغان URL ئادرېسىڭىز تولۇق URL بولۇشى كېرەك: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "باشقا تور پروگراممىلىرىدىن OAuth2 ماسلاشتۇرۇلغان دەلىللەشكە يول قويىدۇ.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 دېتالى باشقۇرغۇچىنىڭ ئىچىگە دەلىللەش خىزمەت ئېقىمىنى سەپلەپ ، باشقا تور قوللىنىشچان پروگراممىلىرىنىڭ OAuth2 ماسلاشتۇرۇلغان دەلىللىشىگە يول قويىدۇ.",
    "Secret key" : "مەخپىي ئاچقۇچ",
    "Delete" : "ئۆچۈر",
    "An unknown error occurred." : "نامەلۇم خاتالىق يۈز بەردى.",
    "OAuth 2.0 clients" : "OAuth 2.0 خېرىدارى",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 سىرتقى مۇلازىمەتلەرنىڭ {instanceName} نى زىيارەت قىلىشىنى تەلەپ قىلىدۇ.",
    "Name" : "ئاتى",
    "Redirection URI" : "قايتا نىشانلاش URI",
    "Client identifier" : "خېرىدار تونۇغۇچ",
    "Delete client" : "خېرىدارنى ئۆچۈرۈڭ",
    "Make sure you store the secret key, it cannot be recovered." : "مەخپىي ئاچقۇچنى ساقلىغانلىقىڭىزنى جەزملەشتۈرۈڭ ، ئەسلىگە كەلتۈرگىلى بولمايدۇ.",
    "Add client" : "خېرىدار قوشۇڭ",
    "Add" : "قوش",
    "Client Identifier" : "خېرىدار تونۇغۇچ",
    "Show client secret" : "خېرىدارلارنىڭ مەخپىيىتىنى كۆرسىتىڭ",
    "Hide client secret" : "خېرىدارلارنىڭ مەخپىيىتىنى يوشۇرۇش"
},
"nplurals=2; plural=(n != 1);");
