OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Imeshirikishwa na {email}",
    "Shared with {email} by {actor}" : "Imeshirikiwa na {email} kwa {actor}",
    "Unshared from {email}" : "Haijashirikiwa kutoka kwa {email}",
    "Unshared from {email} by {actor}" : "Haijashirikiwa kutoka kwa {email} na {actor}",
    "Password for mail share sent to {email}" : "Nenosiri la kushiriki barua pepe limetumwa kwa {email}",
    "Password for mail share sent to you" : "Nenosiri la kushiriki barua limetumwa kwako",
    "You shared {file} with {email} by mail" : "Umeshiriki {file} na {email} kupitia barua pepe",
    "{actor} shared {file} with {email} by mail" : "{actor} alishiriki {file} na {email} kwa barua",
    "You unshared {file} from {email} by mail" : "Ulighairi kushiriki {file} kutoka kwa {email} kupitia barua pepe",
    "{actor} unshared {file} from {email} by mail" : "{actor} hajashiriki {file} kutoka kwa {email} kwa barua",
    "Password to access {file} was sent to {email}" : "Nenosiri la kufikia {file} lilitumwa kwa {email}",
    "Password to access {file} was sent to you" : "Nenosiri la kufikia {file} lilitumwa kwako",
    "Share by mail" : "Shiriki kwa barua",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Kushiriki %1$s kumeshindwa, kwa sababu kipengee hiki tayari kimeshirikiwa na akaunti %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Hatuwezi kukutumia nenosiri linalozalishwa kiotomatiki. Tafadhali weka barua pepe halali katika mipangilio yako ya kibinafsi na ujaribu tena.",
    "Failed to send share by email. Got an invalid email address" : "Imeshindwa kutuma kushiriki kwa barua pepe. Nimepata barua pepe batili",
    "Failed to send share by email" : "Imeshindwa kutuma kushiriki kwa barua pepe",
    "%1$s shared %2$s with you" : "%1$s ameshirikisha %2$s na wewe",
    "Note:" : "Kumbuka:",
    "This share is valid until %s at midnight" : "Ushiriki huu ni halali hadi %s saa sita usiku",
    "Expiration:" : "Muda wake wa kuisha:",
    "%1$s via %2$s" : "%1$s kupitia %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s ameshiriki %2$s na wewe. Unapaswa kuwa tayari umepokea barua tofauti iliyo na kiungo ili kuifikia.",
    "Password to access %1$s shared to you by %2$s" : "Nenosiri la kufikia %1$s lililoshirikiwa kwako na %2$s",
    "Password to access %s" : "Nenosiri la kufikia %s",
    "It is protected with the following password:" : "Inalindwa na nenosiri lifuatalo:",
    "This password will expire at %s" : "Nenosiri hili litaisha muda kwa %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s alishiriki %2$s nawe na anataka kuongeza:",
    "%1$s shared %2$s with you and wants to add" : "%1$s ameshiriki %2$s na wewe na anataka kuongeza",
    "%s added a note to a file shared with you" : "%s aliongeza dokezo kwenye faili iliyoshirikiwa nawe",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Umeshiriki %1$s na %2$s. Mgao tayari umetumwa kwa mpokeaji. Kutokana na sera za usalama zilizofafanuliwa na msimamizi wa %3$s kila hisa inahitaji kulindwa na nenosiri na hairuhusiwi kutuma nenosiri moja kwa moja kwa mpokeaji. Kwa hivyo unahitaji kusambaza nenosiri kwa mikono kwa mpokeaji.",
    "Password to access %1$s shared by you with %2$s" : "Nenosiri la kufikia %1$s iliyoshirikiwa nawe na %2$s",
    "This is the password:" : "Hili ndilo neno la siri:",
    "You can choose a different password at any time in the share dialog." : "Unaweza kuchagua nenosiri tofauti wakati wowote kwenye kidirisha cha kushiriki.",
    "Could not find share" : "Haikuweza kupata kushiriki",
    "Share provider which allows you to share files by mail" : "Shiriki mtoa huduma anayekuruhusu kushiriki faili kupitia barua",
    "Unable to update share by mail config" : "Imeshindwa kusasisha usanidi wa kushiriki kwa barua",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Inaruhusu watu kushiriki kiungo kilichobinafsishwa kwa faili au folda kwa kuweka barua pepe.",
    "Send password by mail" : "Tuma nenosiri kwa barua",
    "Reply to initiator" : "Jibu kwa mwanzilishi"
},
"nplurals=2; plural=(n != 1);");
