OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Panou",
    "Dashboard app" : "Panou de bord aplicație",
    "Weather" : "Vreme",
    "Status" : "Stare",
    "Good morning" : "Bună dimineața",
    "Good morning, {name}" : "Bună dimineața, {name}",
    "Good afternoon" : "Bună ziua",
    "Good afternoon, {name}" : "Bună ziua, {name}",
    "Good evening" : "Bună seara",
    "Good evening, {name}" : "Bună seara, {name}",
    "Hello" : "Bună",
    "Hello, {name}" : "Bună, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "La mulți ani 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "La mulți ani, {name} 🥳🤩🎂🎉",
    "Customize" : "Personalizează",
    "Edit widgets" : "Editează widget",
    "Get more widgets from the App Store" : "Obține mai multe widget-uri din App Store",
    "Weather service" : "Serviciu de vreme",
    "Weather data from Met.no" : "Date despre vreme de la Met.no",
    "geocoding with Nominatim" : "geocoding cu Nominatim",
    "elevation data from OpenTopoData" : "date despre elevație de la OpenTopoData"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
