OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Anuncios de Nextcloud",
    "Nextcloud announcement" : "Anuncio de Nextcloud"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
