OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "Favorites" : "Ulubione",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote account\"" : "\"zdalne konto\"",
    "You created {file}" : "Utworzyłeś {file}",
    "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
    "{user} created {file}" : "{user} utworzył {file}",
    "{user} created an encrypted file in {file}" : "{user} utworzył zaszyfrowany plik w {file}",
    "{file} was created in a public folder" : "{file} został utworzony w katalogu publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "You changed an encrypted file in {file}" : "Zmieniłeś zaszyfrowany plik w {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmienił zaszyfrowany plik w {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "You deleted an encrypted file in {file}" : "Usunąłeś zaszyfrowany plik w {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "{user} deleted an encrypted file in {file}" : "{user} usunął zaszyfrowany plik w {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Zmieniłeś {oldfile} (hidden) na {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Zmieniłeś {oldfile} (hidden) na {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Zmieniłeś {oldfile} na {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} zmienił {oldfile} (hidden) na {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} zmienił {oldfile} (hidden) na {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} zmienił {oldfile} na {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z <strong>ulubionych</strong>",
    "Files" : "Pliki",
    "A file or folder has been <strong>changed</strong>" : "Plik lub katalog został <strong>zmieniony</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Ulubiony plik lub katalog został <strong>zmieniony</strong>",
    "Failed to authorize" : "Błąd autoryzacji",
    "Invalid folder path" : "Nieprawidłowa ścieżka katalogu",
    "Folder not found" : "Nie znaleziono katalogu",
    "The file cannot be found" : "Nie można znaleźć pliku",
    "The destination path does not exist: %1$s" : "Ścieżka docelowa nie istnieje: %1$s",
    "You do not have permission to create a file at the specified location" : "Nie masz uprawnień do utworzenia pliku w określonej lokalizacji",
    "The file could not be converted." : "Nie udało się przekonwertować pliku.",
    "Could not get relative path to converted file" : "Nie można uzyskać ścieżki względnej do przekonwertowanego pliku",
    "Limit must be a positive integer." : "Limit musi być dodatnią liczbą całkowitą.",
    "The replacement character may only be a single character." : "Znak zastępczy może być tylko pojedynczym znakiem.",
    "Filename sanitization already started." : "Rozpoczęto już oczyszczanie nazw plików.",
    "No filename sanitization in progress." : "Brak trwającego procesu oczyszczania nazw plików.",
    "Favorite files" : "Ulubione pliki",
    "No favorites" : "Brak ulubionych",
    "More favorites" : "Więcej ulubionych",
    "Accept" : "Akceptuj",
    "Reject" : "Odrzuć",
    "Incoming ownership transfer from {user}" : "Przychodzące przeniesienie własności od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Czy chcesz zaakceptować {path}\n\nUwaga: Proces transferu po zaakceptowaniu może potrwać do 1 godziny.",
    "Ownership transfer denied" : "Odmowa przeniesienia własności",
    "Your ownership transfer of {path} was denied by {user}." : "Twoje przeniesienie własności {path} zostało odrzucone przez {user}.",
    "Ownership transfer failed" : "Przeniesienie własności nie powiodło się",
    "Your ownership transfer of {path} to {user} failed." : "Twoje przeniesienie własności {path} na {user} nie powiodło się.",
    "The ownership transfer of {path} from {user} failed." : "Przeniesienie własności {path} z {user} nie powiodło się.",
    "Ownership transfer done" : "Dokonano przeniesienia własności",
    "Your ownership transfer of {path} to {user} has completed." : "Twoje przeniesienie własności {path} na {user} zostało zakończone.",
    "The ownership transfer of {path} from {user} has completed." : "Przeniesienie własności {path} z {user} zostało zakończone.",
    "in %s" : "w %s",
    "Transferred from %1$s on %2$s" : "Przeniesiono z %1$s dnia %2$s",
    "File Management" : "Zarządzanie plikami",
    "Home" : "Strona główna",
    "Target folder does not exist any more" : "Katalog docelowy już nie istnieje",
    "Reload current directory" : "Przeładuj bieżący katalog",
    "Go to the \"{dir}\" directory" : "Przejdź do katalogu \"{dir}\"",
    "Current directory path" : "Obecna ścieżka katalogu",
    "Share" : "Udostępnij",
    "Reload content" : "Odśwież zawartość",
    "Your have used your space quota and cannot upload files anymore" : "Wykorzystałeś limit miejsca i nie możesz już wysyłać plików.",
    "You do not have permission to upload or create files here." : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "Drag and drop files here to upload" : "Przeciągnij i upuść pliki tutaj, aby je przesłać",
    "Favorite" : "Ulubiony",
    "Back" : "Poprzednia",
    "Toggle selection for file \"{displayName}\"" : "Przełącz zaznaczenie dla pliku \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Przełącz zaznaczenie dla katalogu \"{displayName}\"",
    "File is loading" : "Plik jest wczytywany",
    "Folder is loading" : "Katalog jest wczytywany",
    "Filename" : "Nazwa pliku",
    "Folder name" : "Nazwa katalogu",
    "This node is unavailable" : "Ten węzeł jest niedostępny",
    "Another entry with the same name already exists." : "Inny wpis o tej samej nazwie już istnieje.",
    "Invalid filename." : "Nieprawidłowa nazwa pliku.",
    "Rename file" : "Zmień nazwę pliku",
    "Recently created" : "Ostatnio utworzone",
    "Folder" : "Katalog",
    "Unknown file type" : "Nieznany typ pliku",
    "{ext} image" : "{ext} zdjęcie",
    "{ext} video" : "{ext} wideo",
    "{ext} audio" : "{ext} dźwiękowy",
    "{ext} text" : "{ext} tekstowy",
    "Pending" : "Oczekujące",
    "Unknown date" : "Nieznana data",
    "Active filters" : "Aktywne filtry",
    "Remove filter" : "Usuń filtr",
    "Today" : "Dzisiaj",
    "Last 7 days" : "Ostatnie 7 dni",
    "Last 30 days" : "Ostatnie 30 dni",
    "This year ({year})" : "W tym roku ({year})",
    "Last year ({year})" : "Ostatni rok ({year})",
    "Custom range" : "Zakres niestandardowy",
    "Custom date range" : "Własny zakres dat",
    "Search everywhere" : "Szukaj wszędzie",
    "Documents" : "Dokumenty",
    "Spreadsheets" : "Arkusze kalkulacyjne",
    "Presentations" : "Prezentacje",
    "PDFs" : "PDFy",
    "Folders" : "Katalogi",
    "Audio" : "Dźwięk",
    "Images" : "Obrazy",
    "Videos" : "Filmy",
    "Filters" : "Filtry",
    "Back to filters" : "Powrót do filtrów",
    "Appearance" : "Wygląd",
    "Show hidden files" : "Pokaż ukryte pliki",
    "Show file type column" : "Pokaż kolumnę typu pliku",
    "Show file extensions" : "Pokaż rozszerzenia plików",
    "Crop image previews" : "Przytnij podglądy obrazów",
    "General" : "Ogólne",
    "Sort favorites first" : "Najpierw sortuj ulubione",
    "Sort folders before files" : "Sortuj katalogi przed plikami",
    "Enable folder tree view" : "Włącz widok drzewa folderów",
    "Default view" : "Widok domyślny",
    "All files" : "Wszystkie pliki",
    "Personal files" : "Pliki osobiste",
    "Additional settings" : "Ustawienia dodatkowe",
    "Actions" : "Akcje",
    "File actions" : "Akcje na plikach",
    "Selection" : "Wybór",
    "Select all files" : "Wybierz wszystkie pliki",
    "Deselect all" : "Odznacz wszystkie",
    "Select or deselect" : "Zaznacz lub odznacz",
    "Select a range" : "Wybierz zakres",
    "Navigation" : "Nawigacja",
    "Go to parent folder" : "Przejdź do folderu nadrzędnego",
    "Go to file above" : "Przejdź do pliku powyżej",
    "Go to file below" : "Przejdź do pliku poniżej",
    "Go left in grid" : "Przejdź w lewo w siatce",
    "Go right in grid" : "Przejdź w prawo w siatce",
    "View" : "Podgląd",
    "Toggle grid view" : "Przełącz widok siatki",
    "Show those shortcuts" : "Pokaż te skróty",
    "Warnings" : "Ostrzeżenie",
    "Warn before changing a file extension" : "Ostrzegaj przed zmianą rozszerzenia pliku",
    "Warn before deleting a file" : "Ostrzegaj przed usunięciem pliku",
    "WebDAV URL" : "URL WebDAV",
    "Create an app password" : "Utwórz hasło aplikacji",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Wymagane do uwierzytelniania WebDAV, ponieważ dla tego konta włączono uwierzytelnianie dwuskładnikowe.",
    "How to access files using WebDAV" : "Jak uzyskać dostęp do plików przez WebDAV",
    "Total rows summary" : "Podsumowanie wszystkich wierszy",
    "Toggle selection for all files and folders" : "Przełącz zaznaczenie dla wszystkich plików i katalogów",
    "Name" : "Nazwa",
    "File type" : "Typ pliku",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowany",
    "{displayName}: failed on some elements" : "{displayName}: niepowodzenie w przypadku niektórych elementów",
    "{displayName}: done" : "{displayName}: zakończono",
    "{displayName}: failed" : "{displayName}: niepowodzenie",
    "(selected)" : "(wybrany)",
    "List of files and folders." : "Lista plików i katalogów.",
    "You have used your space quota and cannot upload files anymore." : "Wykorzystałeś limit miejsca i nie możesz już wysyłać plików.",
    "Column headers with buttons are sortable." : "Nagłówki kolumn z przyciskami są sortowalne.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
    "File not found" : "Nie odnaleziono pliku",
    "_{count} selected_::_{count} selected_" : ["wybrano {count}","wybrano {count}","wybrano {count}","wybrano {count}"],
    "Views" : "Widoki",
    "Search everywhere …" : "Szukaj wszędzie …",
    "Search here …" : "Szukaj tutaj …",
    "Search scope options" : "Opcje zakresu wyszukiwania",
    "Search here" : "Szukaj tutaj",
    "Owner" : "Właściciel",
    "{usedQuotaByte} used" : "Wykorzystano {usedQuotaByte}",
    "{used} of {quota} used" : "Wykorzystane {used} z {quota}",
    "{relative}% used" : "Wykorzystano {relative}%",
    "Could not refresh storage stats" : "Nie można odświeżyć statystyk przechowywania",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Nie można już zaktualizować ani zsynchronizować plików!",
    "Storage information" : "Informacje o przechowywaniu",
    "Storage quota" : "Limit przechowywania",
    "New folder" : "Nowy katalog",
    "Create new folder" : "Utwórz nowy katalog",
    "This name is already in use." : "Ta nazwa jest już używana.",
    "Create" : "Utwórz",
    "Files starting with a dot are hidden by default" : "Pliki zaczynające się od kropki są domyślnie ukryte",
    "Failed to start filename sanitization." : "Nie udało się rozpocząć oczyszczania nazw plików.",
    "Failed to refresh filename sanitization status." : "Nie udało się odświeżyć statusu oczyszczania nazw plików.",
    "Filename sanitization in progress." : "Oczyszczanie nazw plików w toku.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Aktualnie przetworzono {processedUsers} z {totalUsers} kont.",
    "Preparing …" : "Przygotowywanie ...",
    "Refresh" : "Odśwież",
    "All files have been santized for Windows filename support." : "Wszystkie pliki zostały oczyszczone dla obsługi nazw plików Windows.",
    "Some files could not be sanitized, please check your logs." : "Niektórych plików nie udało się oczyścić, sprawdź logi.",
    "Sanitization errors" : "Błędy oczyszczania.",
    "Not sanitized filenames" : "Nieoczyszczone nazwy plików.",
    "Windows filename support has been enabled." : "Obsługa nazw plików Windows została włączona.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Podczas gdy to blokuje użytkowników przed tworzeniem nowych plików z nieobsługiwanymi nazwami, istniejące pliki nie zostały jeszcze przemianowane i mogą wciąż powodować problemy z synchronizacją w Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Możesz wywołać proces zmiany nazw plików z nieprawidłowymi nazwami – zostanie to wykonane w tle i może potrwać pewien czas.",
    "Please note that this may cause high workload on the sync clients." : "Pamiętaj, że może to spowodować duże obciążenie klientów synchronizacji.",
    "Limit" : "Limit",
    "This allows to configure how many users should be processed in one background job run." : "To pozwala skonfigurować, ilu użytkowników powinno być przetwarzanych w jednym zadaniu w tle.",
    "Sanitize filenames" : "Oczyść nazwy plików",
    "(starting)" : "(rozpoczynanie)",
    "Fill template fields" : "Wypełnij pola szablonu",
    "Submitting fields …" : "Przesyłanie pól …",
    "Submit" : "Wyślij",
    "Choose a file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
    "Transfer \"{path}\"" : "Przenieś \"{path}\"",
    "Select file or folder" : "Wybierz plik lub folder",
    "Transfer" : "Przenieś",
    "Transfer {path} to {userid}" : "Przenieś {path} do {userid}",
    "Error while opening file picker for transfer ownership" : "Błąd podczas otwierania wyboru pliku do przeniesienia własności",
    "Error while searching for users" : "Błąd podczas wyszukiwania użytkowników",
    "Ownership transfer request sent" : "Wysłano żądanie przeniesienia własności",
    "Cannot transfer ownership of a file or folder you do not own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
    "Error while sending ownership transfer request" : "Błąd podczas wysyłania żądania przeniesienia własności",
    "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
    "File or folder to transfer" : "Plik lub folder do przeniesienia",
    "No file or folder selected" : "Nie wybrano pliku ani folderu",
    "New owner" : "Nowy właściciel",
    "You need to select a file or folder to transfer ownership." : "Musisz wybrać plik lub folder, aby przenieść własność.",
    "You need to select a new owner for the file or folder." : "Musisz wybrać nowego właściciela dla pliku lub folderu.",
    "Keep {old}" : "Zachowaj {old}",
    "Keep without extension" : "Przechowaj bez przedłużania",
    "Use {new}" : "Użyj {new}",
    "Remove extension" : "Usuń rozszerzenie",
    "Change file extension" : "Zmień rozszerzenie pliku",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Zmienienie rozszerzenia pliku z „{old}”  na „{new}” może spowodować, że plik będzie nieczytelny.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Usunięcie rozszerzenia pliku „{old}” może spowodować, że plik będzie nieczytelny.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Dodanie rozszerzenia pliku „{new}” może spowodować, że plik będzie nieczytelny.",
    "Do not show this dialog again." : "Nie pokazuj więcej tego okna dialogowego.",
    "Rename file to hidden" : "Zmień nazwę pliku na ukrytą",
    "Prefixing a filename with a dot may render the file hidden." : "Poprzedzenie nazwy pliku kropką może spowodować jego ukrycie.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Czy na pewno chcesz zmienić nazwę pliku na \"{filename}\"?",
    "Cancel" : "Anuluj",
    "Rename" : "Zmień nazwę",
    "Select file or folder to link to" : "Wybierz plik lub katalog do linku",
    "Choose {file}" : "Wybierz {file}",
    "Files settings" : "Ustawienia Plików",
    "Switch to list view" : "Przełącz na widok listy",
    "Switch to grid view" : "Przełącz na widok siatki",
    "The file could not be found" : "Nie można znaleźć pliku",
    "Upload was cancelled by user" : "Przesyłanie zostało anulowane przez użytkownika",
    "Not enough free space" : "Za mało wolnego miejsca",
    "Operation is blocked by access control" : "Operacja jest zablokowana przez kontrolę dostępu",
    "Error during upload: {message}" : "Błąd podczas wysyłania: {message}",
    "Error during upload, status code {status}" : "Błąd podczas wysyłania, kod statusu {status}",
    "Unknown error during upload" : "Nieznany błąd podczas wysyłania",
    "File list is reloading" : "Lista plików jest odświeżana",
    "Loading current folder" : "Wczytywanie bieżącego katalogu",
    "Retry" : "Powtórz",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wyślij lub zsynchronizuj pliki z urządzeniami.",
    "Go back" : "Wstecz",
    "Loading …" : "Ładowanie ...",
    "Your files" : "Twoje pliki",
    "Open in files" : "Otwórz w Plikach",
    "File cannot be accessed" : "Nie można uzyskać dostępu do pliku",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nie znaleziono pliku lub nie masz uprawnień, aby go wyświetlić. Poproś nadawcę o udostępnienie.",
    "No search results for “{query}”" : "Brak wyników wyszukiwania dla \"{query}\"",
    "Search for files" : "Szukaj plików",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Zezwalaj na ograniczenie nazw plików, aby zapewnić synchronizację plików ze wszystkimi klientami. Domyślnie dozwolone są wszystkie nazwy plików obowiązujące w systemie POSIX (np. Linux lub macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po włączeniu nazw plików zgodnych z systemem Windows, istniejące pliki nie można już modyfikować, ale ich właściciel może zmienić ich nazwy na nowe, prawidłowe.",
    "Failed to toggle Windows filename support" : "Nie udało się przełączyć obsługi nazw plików Windows",
    "Files compatibility" : "Zgodność plików",
    "Enforce Windows compatibility" : "Wymuszaj zgodność z systemem Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Spowoduje to zablokowanie nazw plików nieprawidłowych w systemach Windows, na przykład nazw zastrzeżonych lub znaków specjalnych. Nie wymusi to jednak zgodności z rozróżnianiem wielkości liter.",
    "Blank" : "Pusty",
    "Unable to create new file from template" : "Nie można utworzyć nowego pliku z szablonu",
    "Pick a template for {name}" : "Wybierz szablon dla {name}",
    "Create a new file with the selected template" : "Utwórz nowy plik z wybranym szablonem",
    "Creating file" : "Tworzenie pliku",
    "Save as {displayName}" : "Zapisz jako {displayName}",
    "Save as …" : "Zapisz jako …",
    "Converting files …" : "Konwertowanie plików …",
    "Failed to convert files: {message}" : "Nie udało się przekonwertować plików: {message}",
    "All files failed to be converted" : "Nie udało się przekonwertować żadnego pliku",
    "One file could not be converted: {message}" : "Jednego pliku nie można przekonwertować: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n plik nie mógł zostać przekonwertowany","%n pliki nie mogły zostać przekonwertowane","%n plików nie mogło zostać przekonwertowanych","%n plików nie mogło zostać przekonwertowanych"],
    "_%n file converted_::_%n files converted_" : ["%n plik przekonwertowany","%n pliki przekonwertowane","%n plików przekonwertowanych","%n plików przekonwertowanych"],
    "Files converted" : "Pliki przekonwertowane",
    "Failed to convert files" : "Nie udało się przekonwertować plików",
    "Converting file …" : "Konwertowanie pliku …",
    "File successfully converted" : "Plik pomyślnie przekonwertowany",
    "Failed to convert file: {message}" : "Nie udało się przekonwertować pliku: {message}",
    "Failed to convert file" : "Nie udało się przekonwertować pliku",
    "Delete" : "Usuń",
    "Leave this share" : "Opuść te udostępnienie",
    "Leave these shares" : "Opuść udostępnienia",
    "Disconnect storage" : "Odłącz magazyn",
    "Disconnect storages" : "Odłącz magazyny",
    "Delete permanently" : "Usuń bezpowrotnie",
    "Delete and unshare" : "Usuń i przestań udostępniać",
    "Delete file" : "Usuń plik",
    "Delete files" : "Usuń pliki",
    "Delete folder" : "Usuń katalog",
    "Delete folders" : "Usuń katalogi",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Zamierzasz trwale usunąć {count} element","Zamierzasz trwale usunąć {count} elementy","Zamierzasz trwale usunąć {count} elementów","Zamierzasz trwale usunąć {count} elementów"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Zamierzasz usunąć {count} element","Zamierzasz usunąć {count} elementy","Zamierzasz usunąć {count} elementów","Zamierzasz usunąć {count} elementów"],
    "Confirm deletion" : "Potwierdź usunięcie",
    "Download" : "Pobierz",
    "The requested file is not available." : "Żądany plik jest niedostępny.",
    "The requested files are not available." : "Żądane pliki są niedostępne.",
    "Add to favorites" : "Dodaj do ulubionych",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add or remove favorite" : "Dodaj lub usuń z ulubionych",
    "Move" : "Przenieś",
    "Copy" : "Kopiuj",
    "Move or copy" : "Przenieś lub kopiuj",
    "Destination is not a folder" : "Miejsce docelowe nie jest katalogiem",
    "This file/folder is already in that directory" : "Ten plik/katalog znajduje się już w tym katalogu",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nie można przenieść pliku/katalogu do tego samego katalogu lub do własnego podkatalogu",
    "A file or folder with that name already exists in this folder" : "Plik lub katalog o tej nazwie już istnieje w tym katalogu",
    "The files are locked" : "Pliki są zablokowane",
    "The file does not exist anymore" : "Plik już nie istnieje",
    "Moving \"{source}\" to \"{destination}\" …" : "Przenoszenie „{source}” do „{destination}” …",
    "Moving {count} files to \"{destination}\" …" : "Przenoszenie {count} plików do \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopiowanie „{source}” do „{destination}” …",
    "Copying {count} files to \"{destination}\" …" : "Kopiowanie {count} plików \"{destination}\" …",
    "Choose destination" : "Wybierz miejsce docelowe",
    "Copy to {target}" : "Skopiuj do {target}",
    "Move to {target}" : "Przenieś do {target}",
    "Move or copy operation failed" : "Operacja przenoszenia lub kopiowania nie powiodła się",
    "Open folder" : "Otwórz katalog",
    "Open folder {displayName}" : "Otwórz katalog {displayName}",
    "Open in Files" : "Otwórz w Plikach",
    "Open locally" : "Otwórz lokalnie",
    "Failed to redirect to client" : "Nie udało się przekierować do klienta",
    "Open file locally" : "Otwórz plik lokalnie",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Plik powinien teraz otworzyć się na Twoim urządzeniu. Jeśli tak się nie stanie, sprawdź, czy masz zainstalowaną aplikację komputerową.",
    "Retry and close" : "Spróbuj ponownie i zamknij",
    "Open online" : "Otwórz online",
    "Details" : "Szczegóły",
    "Open the details sidebar" : "Otwórz panel szczegółów",
    "Unfavorite" : "Usuń z ulubionych",
    "View in folder" : "Zobacz w katalogu",
    "Type" : "Rodzaj",
    "Created new folder \"{name}\"" : "Utworzono nowy katalog \"{name}\"",
    "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
    "Create templates folder" : "Utwórz katalog szablonów",
    "Templates" : "Szablony",
    "New template folder" : "Nowy katalog szablonów",
    "In folder" : "W katalogu",
    "Pick folder to search in" : "Wybierz folder do przeszukiwania",
    "Search in all files" : "Szukaj we wszystkich plikach",
    "Search in folder: {folder}" : "Szukaj w katalogu: {folder}",
    "One of the dropped files could not be processed" : "Jeden z upuszczonych plików nie mógł być przetworzony",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Twoja przeglądarka nie obsługuje interfejsu API systemu plików. Katalogi nie zostaną przesłane",
    "No files to upload" : "Brak plików do przesłania",
    "Unable to create the directory {directory}" : "Nie można utworzyć katalogu {directory}",
    "Some files could not be uploaded" : "Nie udało się wysłać niektórych plików",
    "Files uploaded successfully" : "Pliki przesłane pomyślnie",
    "No files to process" : "Brak plików do przetworzenia",
    "Files copied successfully" : "Pliki skopiowane pomyślnie",
    "Files moved successfully" : "Pliki zostały przeniesione pomyślnie",
    "Some files could not be copied" : "Nie udało się skopiować niektórych plików",
    "Some files could not be moved" : "Niektóre pliki nie mogły zostać przeniesione",
    "Conflicts resolution skipped" : "Pominięto rozwiązywanie konfliktów",
    "Upload cancelled" : "Anulowano przesyłanie",
    "Could not rename \"{oldName}\", it does not exist any more" : "Nie można zmienić nazwy \"{oldName}\", już nie istnieje",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{newName}\" jest już używana w katalogu \"{dir}\". Wybierz inną nazwę.",
    "Could not rename \"{oldName}\"" : "Nie można zmienić nazwy \"{oldName}\"",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This folder is unavailable, please try again later or contact the administration" : "Ten folder jest niedostępny, spróbuj ponownie później lub skontaktuj się z administracją",
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Unexpected error: {error}" : "Nieoczekiwany błąd: {error}",
    "Unknown error" : "Nieznany błąd",
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n hidden_::_%n hidden_" : ["%n ukryty","%n ukryte","%n ukrytych","%n ukrytych"],
    "Filename must not be empty." : "Nazwa pliku nie może być pusta.",
    "\"{char}\" is not allowed inside a filename." : "„{char}” nie jest dozwolone w nazwie pliku.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "„{segment}” jest nazwą zastrzeżoną i nie jest dozwolona w przypadku nazw plików.",
    "\"{extension}\" is not an allowed filetype." : "„{extension}” nie jest dozwolonym typem pliku.",
    "Filenames must not end with \"{extension}\"." : "Nazwy plików nie mogą kończyć się na „{extension}”.",
    "List of favorite files and folders." : "Lista ulubionych plików i katalogów.",
    "No favorites yet" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "List of your files and folders." : "Lista Twoich plików i katalogów.",
    "Folder tree" : "Drzewo folderów",
    "List of your files and folders that are not shared." : "Lista twoich plików i katalogów, które nie są udostępniane",
    "No personal files found" : "Nie znaleziono plików osobistych",
    "Files that are not shared will show up here." : "Tutaj pojawią się pliki, które nie są udostępniane.",
    "Recent" : "Ostatnie",
    "List of recently modified files and folders." : "Lista ostatnio zmodyfikowanych plików i katalogów.",
    "No recently modified files" : "Brak ostatnio zmodyfikowanych plików",
    "Files and folders you recently modified will show up here." : "Tutaj pojawią się pliki i katalogi, które ostatnio zmodyfikowałeś.",
    "Search" : "Szukaj",
    "Search results within your files." : "Wyniki wyszukiwania w Twoich plikach.",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Wysyłany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz wysłać, przekraczają maksymalną dopuszczalną wielkość.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Zmieniono nazwę \"{oldName}\" na \"{newName}\"",
    "Clear filter" : "Wyczyść filtr",
    "Open file sidebar" : "Otwórz panel boczny pliku",
    "Search everywhere …" : "Szukaj wszędzie…",
    "Search here …" : "Szukaj tutaj…",
    "Preparing …" : "Przygotowywanie...",
    "Submitting fields …" : "Wysyłanie pól…",
    "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
    "Choose file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
    "Change" : "Zmień",
    "Shared by link" : "Udostępnione linkiem",
    "Shared" : "Udostępnione",
    "You" : "Ty",
    "Shared multiple times with different people" : "Udostępniony wiele razy różnym osobom",
    "Unable to change the favorite state of the file" : "Nie można zmienić ulubionego stanu pliku",
    "Error while loading the file data" : "Błąd podczas wczytywania danych pliku",
    "Tags" : "Etykiety",
    "Save as …" : "Zapisz jako…",
    "Converting files …" : "Konwertowanie plików…",
    "Converting file …" : "Konwertowanie plików…"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
