OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Compartir ficheiros",
    "Downloaded via public link" : "Descargado mediante unha ligazón pública",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante unha ligazón pública",
    "{email} downloaded {file}" : "{email} descargou {file}",
    "Shared with group {group}" : "Compartido co grupo {group}",
    "Removed share for group {group}" : "Retirar a compartición para o grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartiu co grupo {group}",
    "{actor} removed share for group {group}" : "{actor} retirou a compartición para o grupo {group}",
    "Share for group {group} expired" : "Caducou a compartición polo grupo {group}",
    "You shared {file} with group {group}" : "Vde. compartiu {file} co grupo {group}",
    "You removed group {group} from {file}" : "Vde. retirou o grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartiu {file} co grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} retirou o grupo {group} de {file}",
    "Share for file {file} with group {group} expired" : "Caducou a compartición do ficheiro {file} co grupo {group} ",
    "Shared as public link" : "Compartido como ligazón pública",
    "Removed public link" : "Retirada a ligazón pública",
    "Public link expired" : "A ligazón pública caducou",
    "{actor} shared as public link" : "{actor} compartiu como ligazón pública",
    "{actor} removed public link" : "{actor} retirou a ligazón pública",
    "Public link of {actor} expired" : "A ligazón pública de {actor} caducou",
    "You shared {file} as public link" : "Vde. compartiu {file} como ligazón pública",
    "You removed public link for {file}" : "Vde. retirou a ligazón pública de {file}",
    "Public link expired for {file}" : "A ligazón pública para {file} caducou",
    "{actor} shared {file} as public link" : "{actor} compartiu {file} como ligazón pública",
    "{actor} removed public link for {file}" : "{actor} retirou a ligazón pública para {file}",
    "Public link of {actor} for {file} expired" : "A ligazón pública de {actor} para {file} caducou",
    "{user} accepted the remote share" : "{user} aceptou a compartición remota",
    "{user} declined the remote share" : "{user} declinou a compartición remota",
    "You received a new remote share {file} from {user}" : "Recibiu unha nova compartición remota {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptou a compartición remotade {file}",
    "{user} declined the remote share of {file}" : "{user} declinou a compartición remota de {file}",
    "{user} unshared {file} from you" : "{user} deixou de compartir {file} con Vde.",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Retirar o compartido para {user}",
    "You removed yourself" : "Vde. retirouse a si mesmo",
    "{actor} removed themselves" : "{actor} foi retirado",
    "{actor} shared with {user}" : "{actor} compartiu con {user}",
    "{actor} removed share for {user}" : "{actor} retirou o compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} retirou o compartido",
    "Share for {user} expired" : "Caducou a compartición por {user}",
    "Share expired" : "Caducou a compartición",
    "You shared {file} with {user}" : "Vde. compartiu {file} con  {user}",
    "You removed {user} from {file}" : "Vde. retirou a {user} de {file}",
    "You removed yourself from {file}" : "Vde. retirouse a si mesmo de {file}",
    "{actor} removed themselves from {file}" : "{actor} foi retirado de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartiu {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} retirou a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} compartiu {file} con Vde.",
    "{actor} removed you from the share named {file}" : "{actor} retirouno a Vde. da compartición nomeada {file}",
    "Share for file {file} with {user} expired" : "Caducou a compartición do ficheiro {file} co usuario {user} ",
    "Share for file {file} expired" : "Caducou a compartición do ficheiro {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Foi <strong>descargado</strong> un ficheiro ou cartafol compartido por correo ou ligazón pública",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Os ficheiros foron <strong>enviados</strong> a un cartafol compartido por correo mediante ligazón pública",
    "A file or folder was shared from <strong>another server</strong>" : "Compartiuse un ficheiro ou cartafol desde <strong>outro servidor</strong>",
    "Sharing" : "Compartindo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
    "Shared link" : "Ligazón para compartir",
    "Wrong share ID, share does not exist" : "O ID da compartición é erróneo, a compartición non existe",
    "Could not delete share" : "Non foi posíbel eliminar a compartición",
    "Please specify a file or folder path" : "Especifique a ruta dun ficheiro ou cartafol",
    "Wrong path, file/folder does not exist" : "Ruta errónea, o ficheiro/cartafol non existe",
    "Could not create share" : "Non foi posíbel crear a compartición",
    "Please specify a valid account to share with" : "Especifique unha conta válida coa que compartir",
    "Group sharing is disabled by the administrator" : "A opción de compartir en grupo foi desactivada pola administración desta instancia.",
    "Please specify a valid group" : "Especifique un grupo correcto",
    "Public link sharing is disabled by the administrator" : "Compartir por ligazón pública foi desactivado pola administración desta instancia.",
    "Please specify a valid email address" : "Especifique un enderezo de correo-e válido",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Compartir %s enviando o contrasinal mediante Parladoiro de Nextcloud fallou porque Parladoiro de Nextcloud non está activado",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Fallou a compartición de %1$s, xa que a infraestrutura non permite accións do tipo %2$s",
    "Please specify a valid federated account ID" : "Especifique un ID de conta federado válido",
    "Please specify a valid federated group ID" : "Especifique un ID de grupo federado válido",
    "You cannot share to a Team if the app is not enabled" : "Vde. non pode compartir cun equipo se a aplicación non está activada",
    "Please specify a valid team" : "Especifique un equipo correcto",
    "Sharing %s failed because the back end does not support room shares" : "Fallou a compartición de %s, xa que a infraestrutura non admite salas compartidas",
    "Unknown share type" : "Tipo descoñecido de compartición",
    "Not a directory" : "Non é un directorio",
    "Could not lock node" : "Non foi posíbel bloquear o nodo",
    "Public upload is only possible for publicly shared folders" : "O envío público só é posíbel para aos cartafoles públicos compartidos",
    "Share must at least have READ or CREATE permissions" : "Compartir debe ter polo menos permisos de LER ou CREAR",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "A compartición debe ter permiso de LECTURA se está estabelecido o permiso ACTUALIZAR ou ELIMINAR",
    "Public upload disabled by the administrator" : "O envío público foi desactivado pola administración desta instancia.",
    "Could not lock path" : "Non foi posíbel bloquear a ruta",
    "no sharing rights on this item" : "non hai dereitos de uso compartido deste elemento",
    "You are not allowed to edit incoming shares" : "Vde. non ten permiso para editar os recursos compartidos entrantes",
    "Wrong or no update parameter given" : "Parámetro erróneo ou non actualizado",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Produciuse un erro ao «enviar o contrasinal mediante Parladoiro de Nextcloud» para compartir un ficheiro ou cartafol porque Parladoiro de Nextcloud non está activado.",
    "Custom share link tokens have been disabled by the administrator" : "A administración do seu sitio desactivou os testemuños personalizados de ligazóns de uso compartido",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Os testemuños deben conter polo menos 1 carácter e só poden conter letras, números ou un guión",
    "Invalid date. Format must be YYYY-MM-DD" : "Data incorrecta. O formato debe ser AAAA-MM-DD",
    "No sharing rights on this item" : "Non hai dereitos de uso compartido deste elemento",
    "Invalid share attributes provided: \"%s\"" : "Forneceronse atributos non válidos de compartición . «%s»",
    "You are not allowed to send mail notifications" : "Vde. non ten permiso para enviar notificacións por correo",
    "No mail notification configured for this share type" : "Non foi configurada ningunha notificación de correo para este tipo de recurso compartido",
    "Wrong password" : "Contrasinal erróneo",
    "Error while sending mail notification" : "Produciuse un erro ao enviar a notificación por correo",
    "Failed to generate a unique token" : "Produciuse un fallo ao xerar un testemuño único",
    "This share does not exist or is no longer available" : "Este recurso compartido non existe ou xa non está dispoñíbel",
    "shared by %s" : "compartido por %s",
    "Download" : "Descargar",
    "Add to your %s" : "Engadir ao seu %s",
    "Direct link" : "Ligazón directa",
    "Share API is disabled" : "A API de compartición foi desactivada",
    "File sharing" : "Compartir ficheiros",
    "Share will expire tomorrow" : "A compartición caduca mañá",
    "Your share of {node} will expire tomorrow" : "A súa compartición de {node} caduca mañá",
    "You received {share} as a share by {user}" : "Vde. recibiu {share} como un elemento compartido de {user}",
    "You received {share} to group {group} as a share by {user}" : "Vde. recibiu {share} no grupo {group} como un elemento compartido de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Remember to upload the files to %s" : "Lembre enviar os ficheiros a %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Queremos lembrarlle que aínda non enviou ningún ficheiro ao cartafol compartido.",
    "Open \"%s\"" : "Abrir «%s»",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Esta aplicación permítelle á xente compartir ficheiros dentro de Nextcloud. Se o activa, a administración do sitio pode escoller que grupos poden compartir ficheiros. As persoas implicadas poderán compartir ficheiros e cartafoles con outras contas e grupos dentro de Nextcloud. Ademais, se a administración activa a característica de ligazón compartida, pode empregarse unha ligazón externa para compartir ficheiros con outras persoas fora de Nextcloud. A administración pode facer obrigatorio o uso de contrasinais ou datas de caducidade  e activar a compartición de servidor a servidor mediante ligazóns compartidas, así como compartir desde dispositivos móbiles.\nDesactivar esta característica retira os ficheiros compartidos e os cartafoles do servidor, para todos os receptores, e tamén dos clientes de sincronización e móbiles. Atopará máis información na documentación de Nextcloud.",
    "Filter accounts" : "Filtrar contas",
    "you" : "Vde.",
    "The request will expire on {date} at midnight and will be password protected." : "A solicitude caducará na media noite do {date} e estará protexida por contrasinal.",
    "The request will expire on {date} at midnight." : "A solicitude caducará na media noite do {date}.",
    "The request will be password protected." : "A solicitude estará protexida por contrasinal.",
    "When should the request expire?" : "Cando debe caducar a solicitude?",
    "Set a submission expiration date" : "Definir unha data de caducidade de entrega",
    "Expiration date" : "Data de caducidade",
    "Select a date" : "Seleccione unha data",
    "Your administrator has enforced a {count} days expiration policy." : "A administración do sitio impuxo unha directiva de caducidade de {count} días.",
    "What password should be used for the request?" : "Que contrasinal debe empregarse para a solicitude?",
    "Set a password" : "Definir un contrasinal",
    "Password" : "Contrasinal",
    "Enter a valid password" : "Introduza un contrasinal válido",
    "Generate a new password" : "Xerar un novo contrasinal",
    "Your administrator has enforced a password protection." : "A administración do sitio impuxo unha protección por contrasinal.",
    "Automatically copying failed, please copy the share link manually" : "Produciuse un erro ao copiar automaticamente, copie a ligazón para compartir manualmente",
    "Link copied" : "Ligazón copiada",
    "Email already added" : "O correo xa foi engadido",
    "Invalid email address" : "Enderezo de correo incorrecto",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["O seguinte enderezo de correo non é válido: {emails}","Os seguintes enderezos de correo non son válidos: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["Xa foi engadido {count} enderezo de correo","Xa foron engadidos {count} enderezos de correo"],
    "_{count} email address added_::_{count} email addresses added_" : ["Foi engadido {count} enderezo de correo","Foron engadidos {count} enderezos de correo"],
    "You can now share the link below to allow people to upload files to your directory." : "Agora pode compartir a seguinte ligazón para permitir que as persoas envíen ficheiros ao seu directorio.",
    "Share link" : "Ligazón para compartir",
    "Copy" : "Copiar",
    "Send link via email" : "Enviar a ligazón por correo",
    "Enter an email address or paste a list" : "Introduza un enderezo de correo ou pegue unha lista",
    "Remove email" : "Retirar o correo",
    "Select a destination" : "Seleccione un destino",
    "Select" : "Seleccionar",
    "What are you requesting?" : "Que é o que está a solicitar?",
    "Request subject" : "Asunto da solicitude",
    "Birthday party photos, History assignment…" : "Fotos da festa de aniversario, asignación de historia…",
    "Where should these files go?" : "Onde deben ir estes ficheiros?",
    "Upload destination" : "Destino do envío",
    "Revert to default" : "Reverter ao predeterminado",
    "The uploaded files are visible only to you unless you choose to share them." : "Os ficheiros enviados só son visíbeis para Vde. a non ser que decida compartilos.",
    "Add a note" : "Engadir unha nota",
    "Note for recipient" : "Nota para o destinatario",
    "Add a note to help people understand what you are requesting." : "Engada unha nota para que a xente comprenda o que está a solicitar.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Pode engadir ligazóns, datas ou calquera outra información que axude ao destinatario a comprender o que está a solicitar.",
    "Close" : "Pechar",
    "_Send email and close_::_Send {count} emails and close_" : ["Enviar o correo e pechar","Enviar {count} correos e pechar"],
    "Please select a folder, you cannot share the root directory." : "Seleccione un cartafol, Vde. non pode compartir o directorio raíz.",
    "File request created" : "Creouse a solicitude de ficheiro",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Creouse a solicitude de ficheiro e enviouse o correo","Creouse a solicitude de ficheiros e enviáronse {count} correos"],
    "Error creating the share: {errorMessage}" : "Produciuse un erro ao crear a compartición: {errorMessage}",
    "Error creating the share" : "Produciuse un erro ao crear a compartición",
    "Error sending emails: {errorMessage}" : "Produciuse un erro ao enviar os correos: {errorMessage}",
    "Error sending emails" : "Produciuse un erro ao enviar os correos",
    "Create a file request" : "Crear unha solicitude de ficheiro",
    "Collect files from others even if they do not have an account." : "Recoller os ficheiros doutros aínda que non teñan unha conta.",
    "To ensure you can receive files, verify you have enough storage available." : "Para asegurarse de que pode recibir ficheiros, verifique que ten dispoñíbel espazo de almacenamento abondo.",
    "File request" : "Solicitude de ficheiro",
    "Previous step" : "Paso anterior",
    "Cancel" : "Cancelar",
    "Cancel the file request creation" : "Cancelar a creación da solicitude de ficheiro",
    "Close without sending emails" : "Pechar sen enviar o correo",
    "Continue" : "Continuar",
    "Error while toggling options" : "Produciuse un erro ao alternar as opcións",
    "Accept shares from other accounts and groups by default" : "Aceptar comparticións doutras contas e grupos de xeito predeterminado",
    "Choose a default folder for accepted shares" : "Escolla un cartafol predeterminado para as comparticións aceptadas",
    "Invalid path selected" : "Seleccionou unha ruta incorrecta.",
    "Unknown error" : "Produciuse un erro descoñecido",
    "Set default folder for accepted shares" : "Definir o cartafol predeterminado para as comparticións aceptadas",
    "Reset" : "Restabelecer",
    "Reset folder to system default" : "Restabelecer o cartafol ao predeterminado do sistema",
    "Share expiration: {date}" : "Caducidade da compartición: {date}",
    "Share Expiration" : "Caducidade da compartición",
    "group" : "grupo",
    "conversation" : "conversa",
    "remote" : "remoto",
    "remote group" : "grupo remoto",
    "guest" : "convidado",
    "by {initiator}" : "por {initiator}",
    "Shared with the group {user} by {owner}" : "Compartido co grupo {user} por {owner}",
    "Shared with the conversation {user} by {owner}" : "Compartido coa conversa {user} por {owner}",
    "Shared with {user} by {owner}" : "Compartido con {user} por {owner}",
    "Open Sharing Details" : "Abrir os detalles da compartición",
    "Added by {initiator}" : "Engadido por {initiator}",
    "Via “{folder}”" : "A través de «{folder}»",
    "Unshare" : "Deixar de compartir",
    "Cannot copy, please copy the link manually" : "Non foi posíbel copiala. Copie a ligazón manualmente",
    "Copy internal link" : "Copiar a ligazón interna",
    "For people who already have access" : "Para persoas que xa teñen acceso",
    "Internal link" : "Ligazón interna",
    "{shareWith} by {initiator}" : "{shareWith} por {initiator}",
    "Shared via link by {initiator}" : "Compartido mediante ligazón por {initiator}",
    "File request ({label})" : "Solicitude de ficheiro ({label})",
    "Mail share ({label})" : "Compartir por correo ({label})",
    "Share link ({label})" : "Ligazón para compartir ({label})",
    "Mail share" : "Compartir por correo",
    "Share link ({index})" : "Ligazón para compartir ({index})",
    "Create public link" : "Crear ligazón pública",
    "Actions for \"{title}\"" : "Accións para «{title}»",
    "Copy public link of \"{title}\"" : "Copiar a ligazón pública de «{title}»",
    "Error, please enter proper password and/or expiration date" : "Erro, introduza un contrasinal ou unha data de caducidade correctos",
    "Link share created" : "Creouse a ligazón para compartir",
    "Error while creating the share" : "Produciuse un erro ao crear a compartición",
    "Your browser does not support copying, please copy the link manually:" : "O seu navegador non admite a copia, copie a ligazón manualmente:",
    "Successfully copied public link" : "A ligazón pública foi copiada satisfactoriamente",
    "Please enter the following required information before creating the share" : "Introduza a seguinte información necesaria antes de crear a compartición",
    "Password protection (enforced)" : "Protección con contrasinal (obrigatoria)",
    "Password protection" : "Protección por contrasinal",
    "Enter a password" : "Introduza un contrasinal",
    "Enable link expiration (enforced)" : "Activar a caducidade da ligazón (obrigatoria)",
    "Enable link expiration" : "Activa a caducidade da ligazón",
    "Enter expiration date (enforced)" : "Introducir a data de caducidade (obrigatoria)",
    "Enter expiration date" : "Introducir a data de caducidade",
    "Create share" : "Crear elemento compartido",
    "Customize link" : "Personalizar a ligazón",
    "Generate QR code" : "Xerar un código QR",
    "Add another link" : "Engadir outra ligazón",
    "Create a new share link" : "Crear unha nova ligazón para compartir",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Opcións de compartir de xeito rápido, a selección actual é \"{selectedOption}\"",
    "View only" : "Só ver",
    "Can edit" : "Pode editar",
    "Custom permissions" : "Permisos personalizados",
    "Resharing is not allowed" : "Non se permite volver compartir",
    "Name or email …" : "Nome ou correo…",
    "Name, email, or Federated Cloud ID …" : "Nome, correo ou ID de nube federada…",
    "Searching …" : "Buscando…",
    "No elements found." : "Non se atopou ningún elemento.",
    "Search everywhere" : "Buscar en todos os sitios",
    "Guest" : "Convidado",
    "Group" : "Grupo",
    "Email" : "Correo-e",
    "Team" : "Equipo",
    "Talk conversation" : "Conversa no Parladoiro",
    "Deck board" : "Taboleiro da Gabeta",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "en {server}",
    "Enter external recipients" : "Introduza os destinatarios externos",
    "Search for internal recipients" : "Busca de destinatarios internos",
    "Note from" : "Nota de",
    "Note:" : "Nota:",
    "File drop" : "Soltar o ficheiro",
    "Upload files to {foldername}." : "Enviar ficheiros a {foldername}.",
    "By uploading files, you agree to the terms of service." : "Ao enviar ficheiros acepta as condicións de servizo.",
    "Successfully uploaded files" : "Os ficheiros foron actualizados satisfactoriamente",
    "View terms of service" : "Ver as condicións de servizo",
    "Terms of service" : "Condicións de servizo",
    "Share with {user}" : "Compartir con {user}",
    "Share with email {email}" : "Compartir co correo {email}",
    "Share with group" : "Compartir co grupo",
    "Share in conversation" : "Compartir na conversa",
    "Share with {user} on remote server {server}" : "Compartir con {user} no servidor remoto {server}",
    "Share with remote group" : "Compartir co grupo remoto",
    "Share with guest" : "Compartir co convidado",
    "Update share" : "Actualizar a compartición",
    "Save share" : "Gardar a compartición",
    "Read" : "Ler",
    "Create" : "Crear",
    "Edit" : "Editar",
    "Share" : "Compartir",
    "Delete" : "Eliminar",
    "Password field cannot be empty" : "O campo de contrasinal non pode estar baleiro",
    "Replace current password" : "Substituír o contrasinal actual",
    "Failed to generate a new token" : "Produciuse un fallo ao xerar un novo testemuño",
    "Allow upload and editing" : "Permitir o envío e a edición",
    "Allow editing" : "Permitir a edición",
    "Upload only" : "Só enviar",
    "Advanced settings" : "Axustes avanzados",
    "Share label" : "Compartir a etiqueta",
    "Share link token" : "Compartir o testemuño da ligazón",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Defina o testemuño de ligazón de compartición pública como algo doado de lembrar ou xere un novo testemuño. Non se recomenda empregar un testemuño doado de adiviñar para as comparticións que conteñan información confidencial.",
    "Generating…" : "Xerando…",
    "Generate new token" : "Xerar un novo testemuño",
    "Set password" : "Definir o contrasinal",
    "Password expires {passwordExpirationTime}" : "O contrasinal caduca o {passwordExpirationTime}",
    "Password expired" : "O contrasinal caducou",
    "Video verification" : "Verificación de vídeo",
    "Expiration date (enforced)" : "Data de caducidade (obrigatoria)",
    "Set expiration date" : "Definir a data de caducidade",
    "Hide download" : "Agochar a descarga",
    "Allow download and sync" : "Permitir a descarga e a sincronización",
    "Note to recipient" : "Nota para o destinatario",
    "Enter a note for the share recipient" : "Introduza unha nota para o destinatario da compartición",
    "Show files in grid view" : "Amosar os ficheiros en vista de grade",
    "Delete share" : "Eliminar o recurso compartido",
    "Others with access" : "Outros con acceso",
    "No other accounts with access found" : "Non se atoparon outras contas con acceso",
    "Toggle list of others with access to this directory" : "Alternar a lista doutros con acceso a este directorio",
    "Toggle list of others with access to this file" : "Alternar a lista doutros con acceso a este ficheiro",
    "Unable to fetch inherited shares" : "Non é posíbel recuperar as comparticións herdadas",
    "Link shares" : "Ligazóns para compartir",
    "Shares" : "Comparticións",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Comparta ficheiros dentro da súa organización. Os destinatarios que xa poden ver o ficheiro tamén poden usar esta ligazón para un acceso doado.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Comparta ficheiros con outras persoas fóra da súa organización a través de ligazóns públicas e enderezos de correo-e. Tamén pode compartir con contas de {productName} noutras instancias usando o seu ID federado na nube.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Comparticións de aplicacións ou outras orixes que non estean incluídas en comparticións internas ou externas.",
    "Type names, teams, federated cloud IDs" : "Escriba nomes, equipos ou ID de nubes federadas.",
    "Type names or teams" : "Escriba nomes ou equipos.",
    "Type a federated cloud ID" : "Escriba un ID de nube federada.",
    "Type an email" : "Escriba un correo",
    "Type an email or federated cloud ID" : "Escriba un correo ou un ID de nube federada.",
    "Unable to load the shares list" : "Non é posíbel cargar a lista de comparticións",
    "Expires {relativetime}" : "Caduca ás {relativetime}",
    "this share just expired." : "vén de caducar esta compartición",
    "Shared with you by {owner}" : "Compartido con Vde. por {owner}",
    "Internal shares" : "Comparticións internas",
    "Internal shares explanation" : "Explicación das comparticións internas",
    "External shares" : "Comparticións externas",
    "External shares explanation" : "Explicación das comparticións externas",
    "Additional shares" : "Comparticións adicionais",
    "Additional shares explanation" : "Explicación das comparticións adicionais",
    "Link to a file" : "Ligazón a un ficheiro",
    "_Accept share_::_Accept shares_" : ["Aceptar a compartición","Aceptar as comparticións"],
    "Open in Files" : "Abrir en Ficheiros",
    "_Reject share_::_Reject shares_" : ["Rexeitar a compartición","Rexeitar as comparticións"],
    "_Restore share_::_Restore shares_" : ["Restaurar a compartición","Restaurar as comparticións"],
    "Shared" : "Compartido",
    "Shared by {ownerDisplayName}" : "Compartido por {ownerDisplayName}",
    "Shared multiple times with different people" : "Compartido varias veces con diferentes persoas",
    "Sharing options" : "Opcións de compartir",
    "Shared with others" : "Compartido con outros",
    "You do not have enough permissions to share this file." : "Non ten permisos abondo para compartir este ficheiro.",
    "People" : "Persoas",
    "Create file request" : "Crear unha solicitude de ficheiro",
    "Upload files to {foldername}" : "Enviar ficheiros a {foldername}",
    "Public file share" : "Compartir ficheiro de xeito público",
    "Publicly shared file." : "Ficheiro compartido publicamente.",
    "No file" : "Non hai ningún ficheiro",
    "The file shared with you will show up here" : "O ficheiro compartido con Vde. aparecerá aquí",
    "Public share" : "Compartición pública",
    "Publicly shared files." : "Ficheiros compartidos publicamente.",
    "No files" : "Non hai ningún ficheiro",
    "Files and folders shared with you will show up here" : "Os ficheiros e cartafoles compartidos con Vde. aparecerán aquí",
    "Overview of shared files." : "Vista xeral dos ficheiros compartidos.",
    "No shares" : "Ningunha compartición",
    "Files and folders you shared or have been shared with you will show up here" : "Os ficheiros e cartafoles que Vde. compartiu ou que foron compartidos con Vde. amosaranse aquí",
    "Shared with you" : "Compartido con Vde.",
    "List of files that are shared with you." : "Lista de ficheiros que se comparten con Vde.",
    "Nothing shared with you yet" : "Aínda non hai ren compartido con Vde.",
    "Files and folders others shared with you will show up here" : "Os ficheiros e cartafoles que outros compartiron con Vde. amosaranse aquí",
    "List of files that you shared with others." : "Lista de ficheiros que compartiu Vde. con outros.",
    "Nothing shared yet" : "Aínda non hai ren compartido",
    "Files and folders you shared will show up here" : "Os ficheiros e cartafoles que compartiu amosaranse aquí",
    "Shared by link" : "Compartido por ligazón",
    "List of files that are shared by link." : "Lista de ficheiros que se comparten mediante ligazón.",
    "No shared links" : "Non hai ligazóns para compartir",
    "Files and folders you shared by link will show up here" : "Os ficheiros e cartafoles que compariu por ligazón amosaranse aquí",
    "File requests" : "Solicitudes de ficheiros",
    "List of file requests." : "Lista de solicitudes de ficheiros.",
    "No file requests" : "Non hai solicitudes de ficheiros",
    "File requests you have created will show up here" : "As solicitudes de ficheiros que creou amosaranse aquí",
    "Deleted shares" : "Comparticións eliminadas",
    "List of shares you left." : "Lista de comparticións que deixou",
    "No deleted shares" : "Non hai comparticións eliminadas",
    "Shares you have left will show up here" : "As comparticións que aínda mantén amosaranse aquí",
    "Pending shares" : "Comparticións pendentes",
    "List of unapproved shares." : "Lista de comparticións non aprobadas.",
    "No pending shares" : "Non hai comparticións pendentes",
    "Shares you have received but not approved will show up here" : "As comparticións que recibiu mais non aprobou amosaranse aquí",
    "Error deleting the share" : "Produciuse un erro ao eliminar a compartición",
    "Error updating the share" : "Produciuse un erro ao actualizar a compartición",
    "File \"{path}\" has been unshared" : "Foi retirado o ficheiro compartido «{path}».",
    "Folder \"{path}\" has been unshared" : "Foi retirado o cartafol compartido «{path}».",
    "Could not update share" : "Non foi posíbel actualizar a compartición",
    "Share saved" : "Gardouse a compartición",
    "Share expiry date saved" : "Gardouse a data de caducidade da compartición",
    "Share hide-download state saved" : "Gardouse o estado de agochado e descarga da compartición",
    "Share label saved" : "Gardouse a etiqueta de compartición",
    "Share note for recipient saved" : "Gardouse a nota de compartición para o destinatario",
    "Share password saved" : "Gardouse o contrasinal para compartir",
    "Share permissions saved" : "Gardáronse os permisos para compartir",
    "To upload files to {folder}, you need to provide your name first." : "Para enviar ficheiros a {folder}, primeiro debe fornecer o seu nome.",
    "Upload files to {folder}" : "Enviar ficheiros a {folder}",
    "Please confirm your name to upload files to {folder}" : "Confirme o seu nome para enviar ficheiros a {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} compartiu un cartafol con Vde.",
    "Names must not be empty." : "Os nomes non deben estar baleiros.",
    "Names must not start with a dot." : "Os nomes non deben comezar cun punto.",
    "\"{char}\" is not allowed inside a name." : "«{char}» non está permitido nun nome.",
    "\"{segment}\" is a reserved name and not allowed." : "«{segment}» é un nome reservado e non está permitido.",
    "\"{extension}\" is not an allowed name." : "«{extension}» non é un nome permitido.",
    "Names must not end with \"{extension}\"." : "Os nomes non deben rematar con «{extension}».",
    "Invalid name." : "Nome incorrecto.",
    "Password created successfully" : "O contrasinal foi creado correctamente",
    "Error generating password from password policy" : "Produciuse un erro ao xerar o contrasinal a partir da directiva de contrasinais",
    "Shared with you and the group {group} by {owner}" : "Compartido con Vde. e co grupo {group} por {owner}",
    "Shared with you and {circle} by {owner}" : "Compartido con Vde. e {circle} por {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Compartido con Vde. e a conversa {conversation} por {owner}",
    "Shared with you in a conversation by {owner}" : "Compartido con Vde. nunha conversa por {owner}",
    "Share not found" : "Non se atopou a compartición",
    "Back to %s" : "Volver a %s",
    "Add to your Nextcloud" : "Engadir ao seu Nextcloud",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Produciuse un erro ao compartir %s porque a infraestrutura non admite comparticións de ScienceMesh",
    "Name or email …" : "Nome ou correo…",
    "Name, email, or Federated Cloud ID …" : "Nome, correo ou ID de nube federada…",
    "Searching …" : "Buscando…"
},
"nplurals=2; plural=(n != 1);");
