OC.L10N.register(
    "logreader",
    {
    "Logging" : "იწერება ლოგი",
    "Log Reader" : "ლოგის მკითხველი",
    "Level" : "დონე",
    "App" : "აპლიკაცია",
    "Time" : "დრო",
    "Download logs" : "ლოგების გადმოწერა",
    "Relative" : "ფარდობითი",
    "Message" : "წერილი",
    "Info" : "ინფორმაცია",
    "Warning" : "გაფრთხილება",
    "Error" : "შეცდომა"
},
"nplurals=2; plural=(n!=1);");
