<?php
// This file is auto-generated. Do not edit!
return array('Lisu'=>'абетка Фрейзера','Avst'=>'авестійський','Adlm'=>'адлам','Arab'=>array(''=>'арабиця','variant'=>array('персько-арабська')),'Armi'=>'армі','Afak'=>'афака','Ahom'=>'ахом','Bali'=>'балійський','Bamu'=>'бамум','Bass'=>'басса','Batk'=>'батак','Zxxx'=>'безписемна','Beng'=>'бенгальська','Bopo'=>'бопомофо','Brah'=>'брахмі','Bugi'=>'бугійський','Buhd'=>'бухід','Vaii'=>'ваї','Visp'=>'видиме мовлення','Armn'=>'вірменська','Glag'=>'глаголичний','Goth'=>'готичний','Grek'=>'грецька','Geor'=>'грузинська','Gujr'=>'гуджараті','Guru'=>'гурмухі','Ital'=>'давньоіталійський','Perm'=>'давньопермський','Xpeo'=>'давньоперський','Syre'=>'давньосирійський естрангело','Syrj'=>'давньосирійський західний','Syrn'=>'давньосирійський східний','Hung'=>'давньоугорський','Cyrs'=>'давньоцерковнословʼянський','Deva'=>'деванагарі','Dsrt'=>'дезерет','Zsye'=>'емодзі','Ethi'=>'ефіопська','Egyd'=>'єгипетський демотичний','Egyh'=>'єгипетський ієратичний','Egyp'=>'єгипетський ієрогліфічний','Zyyy'=>'звичайна','Sgnw'=>'знаковий','Qaag'=>'зоджі','Hebr'=>'іврит','Yiii'=>'йї','Aghb'=>'кавказька албанська','Kthi'=>'каїті','Knda'=>'каннада','Cari'=>'каріанський','Kana'=>'катакана','Kali'=>'кая лі','Cyrl'=>'кирилиця','Cirt'=>'кирт','Hani'=>'китайська','Cprt'=>'кіпрський','Copt'=>'коптський','Kore'=>'корейська','Khar'=>'кхароштхі','Khmr'=>'кхмерська','Geok'=>'кхутсурі','Lana'=>'ланна','Laoo'=>'лаоська','Latn'=>'латиниця','Latg'=>'латинський гельський','Latf'=>'латинський фрактурний','Lepc'=>'лепча','Lydi'=>'лідійський','Lyci'=>'лікійський','Limb'=>'лімбу','Lina'=>'лінійний А','Linb'=>'лінійний В','Loma'=>'лома','Maya'=>'майя ієрогліфічний','Mlym'=>'малаяламська','Mand'=>'мандейський','Mani'=>'маніхейський','Zmth'=>'математична','Mtei'=>'мейтей майєк','Mero'=>'мероїтський','Mong'=>'монгольська','Moon'=>'мун','Mymr'=>'мʼянмська','Aran'=>'насталік','Newa'=>'нева','Zzzz'=>'невідома система письма','Nkoo'=>'нко','Talu'=>'новий тайський луе','Ogam'=>'огамічний','Olck'=>array(''=>'ол-чикі','variant'=>array('сантальська')),'Orya'=>'орія','Orkh'=>'орхонський','Osge'=>'осейджиська','Osma'=>'османський','Prti'=>'парфянський','Hmng'=>'пахау хмонг','Phlv'=>'пехлеві літературний','Phli'=>'пехлеві написів','Phlp'=>'пехлеві релігійний','Plrd'=>'писемність Полларда','Phag'=>'пхагс-па','Rjng'=>'реджанг','Roro'=>'ронго-ронго','Runr'=>'рунічний','Samr'=>'самаритянський','Sara'=>'сараті','Saur'=>'саураштра','Blis'=>'символи Блісса','Zsym'=>'символьна','Sinh'=>'сингальська','Syrc'=>'сирійська','Sylo'=>'сілоті нагрі','Hans'=>array(''=>'спрощена','stand-alone'=>array('китайська спрощена')),'Sund'=>'сунданська','Thaa'=>'таана','Tglg'=>'тагальський','Tagb'=>'тагбанва','Tavt'=>'тай-вʼєт','Tale'=>'тай-лі','Thai'=>'тайська','Taml'=>'тамільська','Tang'=>'тангут','Telu'=>'телугу','Teng'=>'тенгвар','Tibt'=>'тибетська','Tfng'=>'тифінаг','Hant'=>array(''=>'традиційна','stand-alone'=>array('китайська традиційна')),'Ugar'=>'угаритський','Cans'=>'уніфіковані символи канадських тубільців','Zinh'=>'успадкована','Phnx'=>'фінікійський','Cham'=>'хамітський','Hang'=>'хангиль','Rohg'=>'ханіфі','Hano'=>'хануну','Hanb'=>'хань','Inds'=>'харапський','Hira'=>'хірагана','Cakm'=>'чакма','Jamo'=>'чамо','Cher'=>'черокі','Shaw'=>'шоу','Brai'=>'шрифт Брайля','Xsux'=>'шумеро-аккадський клінопис','Java'=>'яванський','Jpan'=>'японська','Hrkt'=>'японські силабарії','Bhks'=>'Bhks','Chrs'=>'Chrs','Cpmn'=>'Cpmn','Diak'=>'Diak','Dogr'=>'Dogr','Dupl'=>'Dupl','Elba'=>'Elba','Elym'=>'Elym','Gong'=>'Gong','Gonm'=>'Gonm','Gran'=>'Gran','Hatr'=>'Hatr','Hluw'=>'Hluw','Hmnp'=>'Hmnp','Kawi'=>'Kawi','Khoj'=>'Khoj','Kits'=>'Kits','Mahj'=>'Mahj','Maka'=>'Maka','Marc'=>'Marc','Medf'=>'Medf','Mend'=>'Mend','Merc'=>'Merc','Modi'=>'Modi','Mroo'=>'Mroo','Mult'=>'Mult','Nagm'=>'Nagm','Nand'=>'Nand','Narb'=>'Narb','Nbat'=>'Nbat','Nshu'=>'Nshu','Ougr'=>'Ougr','Palm'=>'Palm','Pauc'=>'Pauc','Sarb'=>'Sarb','Shrd'=>'Shrd','Sidd'=>'Sidd','Sind'=>'Sind','Sogd'=>'Sogd','Sogo'=>'Sogo','Sora'=>'Sora','Soyo'=>'Soyo','Takr'=>'Takr','Tirh'=>'Tirh','Tnsa'=>'Tnsa','Toto'=>'Toto','Vith'=>'Vith','Wara'=>'Wara','Wcho'=>'Wcho','Yezi'=>'Yezi','Zanb'=>'Zanb');
