"use strict";(self.webpackChunkprivacy=self.webpackChunkprivacy||[]).push([["node_modules_nextcloud_dialogs_dist_chunks_index-Kg2hZgGF_mjs"],{8066:(e,_,s)=>{s.d(_,{FilePickerVue:()=>i});const i=(0,s(5471).$V)((()=>Promise.all([s.e("vendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-ajWx2Snh_mjs"),s.e("data_image_svg_xml_3c_21--_20-_20SPDX-FileCopyrightText_202020_20Google_20Inc_20-_20SPDX-Lice-cc29b1")]).then(s.bind(s,2131))))}}]);
//# sourceMappingURL=privacy-node_modules_nextcloud_dialogs_dist_chunks_index-Kg2hZgGF_mjs.js.map?v=439699108336bff0cafc