import{g}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as l}from"./nsis-Cl3qveJ-.chunk.mjs";function c(e,s){for(var t=0;t<s.length;t++){const n=s[t];if(typeof n!="string"&&!Array.isArray(n)){for(const r in n)if(r!=="default"&&!(r in e)){const i=Object.getOwnPropertyDescriptor(n,r);i&&Object.defineProperty(e,r,i.get?i:{enumerable:!0,get:()=>n[r]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,a;function u(){if(a)return o;a=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/nsis" instead of "highlight.js/lib/languages/nsis.js"'))}return e(),o=l(),o}var f=u();const p=g(f),j=c({__proto__:null,default:p},[f]);export{j as n};
//# sourceMappingURL=nsis.js-BvY8pvJU.chunk.mjs.map
