OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "لقد قُمت بإنشاء الفريق {circle}",
    "{author} created the team {circle}" : "{author} قام بإنشاء الفريق {circle}",
    "You deleted {circle}" : "أنت حذفت الدائرة {circle}",
    "{author} deleted {circle}" : "{author} حذف الدائرة {circle}",
    "You made {member} join {circle}" : "أنت قمت بتمكين انضمام {member} إلى {circle}",
    "{author} made {member} join {circle}" : "قام {author} بتمكين انضمام {member} إلى {circle}",
    "You added team {member} as member to {circle}" : "لقد قمت بإضافة الفريق {member} كعضو في {circle}",
    "{author} added team {member} as member to {circle}" : "قام {author} بإضافة عضو الفريق  {member} كعضوٍ في دائرة الاتصال {circle}",
    "You made {member} leave {circle}" : "أنت جعلت {member} يغادر الحلقة {circle}",
    "{author} made {member} leave {circle}" : "{author} قام بجعل {member} يغادر الحلقة {circle}",
    "You removed {member} from {circle}" : "أنت أزلت عضوية {member} في {circle}",
    "{author} removed {member} from {circle}" : "قام {author} بسحب عضوية {member} في دائرة الاتصال {circle}",
    "You joined {circle}" : "أنت انضممت إلى  {circle}",
    "{member} joined {circle}" : "{member} إنضمّ إلى {circle}",
    "You accepted the invitation to join {circle}" : "إنت قبلت الدعوة للانضمام إلى {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} قبل الدعوة للانضمام إلى {circle}",
    "You added {member} as member to {circle}" : "أنت أضفت {member} كعضوٍ في {circle}",
    "You have been added as member to {circle} by {author}" : "تمّت إضافتك كعضوٍ في {circle} من قِبَل {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} تمّت إضافته كعضوٍ في {circle} من قِبَل {author}",
    "You added {external} to {circle}" : "أنت أضفت {external} إلى {circle}",
    "{external} has been added to {circle} by {author}" : "{external} تمًت إضافته إلى {circle} من قِبَل {author}",
    "You accepted {member}'s request to join {circle}" : "أنت قبلت طلب {member} بالانضمام إلى {circle}",
    "Your request to join {circle} has been accepted by {author}" : "طلبك الانضمام إلى {circle} تمّ قبوله من {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "طلب {member} بالانضام إلى {circle} تمّ قبوله من {author}",
    "You left {circle}" : "أنت غادرتَ {circle}",
    "{member} left {circle}" : "{member} غادر {circle}",
    "You declined the invitation to join {circle}" : "أنت رفضت الدعوة بالانضمام إلى {circle}",
    "{member} declined an invitation to join {circle}" : "{member} رفض الدعوة بالانضمام إلى {circle}",
    "You cancelled your request to join {circle}" : "أنت ألغيت طلبك بالانضمام إلى {circle}",
    "{member} cancelled a request to join {circle}" : "{member} قام بإلغاء طلب الانضمام إلى الحلقة {circle}",
    "You have been removed from {circle} by {author}" : "تمّت إزالة عضويتك من {circle} من قِبَل {author}",
    "{member} has been removed from {circle} by {author}" : "{member} تمّت إزالة عضويته من {circle} من قِبَل {author}",
    "You removed {external} from {circle}" : "أنت أزلت عضوية {external} من {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} تمّت إزالة عضويته من {circle} من قِبَل {author}",
    "You cancelled {member}'s invitation to join {circle}" : "أنت ألغيت دعوة {member} للانضمام إلى  {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "دعوتك للانضمام إلى {circle} تمّ إلغاؤها من قِبَل {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} قام بإلغاء دعوة {member} للانضمام إلى  {circle}",
    "You dismissed {member}'s request to join {circle}" : "أنت لم توافق على طلب {member} بالانضام إلى {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "طلبك بالانضمام إلى {circle} تمّ رفضه من {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "طلب {member} بالانضمام إلى {circle} تمّ رفضه من {author}",
    "You invited {member} to join {circle}" : "أنت دعوت {member} للانضمام إلى {circle}",
    "You have been invited to join {circle} by {author}" : "تمّت دعوتك للانضمام إلى {circle} من قِبَل {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} تمّت دعوته للانضمام إلى {circle} من قِبَل {author}",
    "You changed {member}'s level in {circle} to %1$s" : "أنت قمت بتغيير مستوى {member} في {circle} إلى %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} قام بتغيير مستواك في {circle} إلى %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} قام بتغيير مستوى {member} في {circle} إلى %1$s",
    "You sent a request to join {circle}" : "أنت أرسلت طلباً للانضمام إلى {circle}",
    "{member} sent a request to join {circle}" : "{member} أرسل طلباً للانضمام إلى {circle}",
    "You are the new owner of {circle}" : "أنت المالك الجديد للدائرة {circle}",
    "{member} is the new owner of {circle}" : "{member} هو المالك الجديد للدائرة {circle}",
    "Teams" : "الفرق",
    "On events happening in a <strong>team</strong> of which you are a member" : "تبعاً للأحداث التي تحدث في الفريق <strong></strong> الذي أنت عضو فيه",
    "Any important event in a <strong>team</strong> you are moderating" : "حدث هام في الفريق <strong></strong> الذي تتولى أنت التنسيق له",
    "On global events happening in any <strong>team</strong>" : "الأحداث العامة التي تحدث في أي فريق <strong></strong>",
    "Single" : "مُنفرِدٌ single",
    "Personal" : "شخصي",
    "System" : "النظام",
    "Visible" : "مرئيّ",
    "Open" : "افتح",
    "Invite" : "يدعو",
    "Join request" : "طلب انضمام",
    "Friends" : "الأصدقاء",
    "Password protected" : "محمي بكلمة مرور",
    "No Owner" : "لا يوجد مالك",
    "Hidden" : "مخفي",
    "Backend" : "جهة الخادم",
    "Local" : "المحلي",
    "Root" : "الجذر",
    "Team invite" : "دعوة الفريق",
    "Federated" : "المتحدة",
    "Mount point" : "نقطة حمل Mount point",
    "Nextcloud Account" : "حساب نكست كلاود",
    "Nextcloud Group" : "مجموعة نكست كلاود",
    "Email address" : "عنوان البريد الإلكتروني",
    "Contact" : "التواصل",
    "Team" : "الفريق",
    "Nextcloud App" : "تطبيق نكست كلاود",
    "Member" : "عضو",
    "Moderator" : "مشرف",
    "Admin" : "مدير",
    "Owner" : "مالك",
    "%s shared »%s« with you." : "%s مُشتركة »%s« معك.",
    "%s shared »%s« with \"%s\"." : "%s مُشتركةٌ »%s« مع \"%s\".",
    "%s on %s" : "%s على %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s شارك »%2$s« معك.\nيُفترض أن إيميلاً قد وصلك يحوي رابطاً للوصول إلى المُشاركة.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s شارك »%2$s« معك. يُفترض أن إيميلاً قد وصلك يحوي رابطاً للوصول إلى المُشاركة.",
    "Password to access »%1$s« shared to you by %2$s" : "كلمة مرور للوصول إلى »%1$s« تمّت مُشاركتها معك من قِبَل %2$s",
    "Password to access »%s«" : "كلمة مرور للوصول إلى »%s«",
    "It is protected with the following password:" : "إنها محميّة بكلمة المرور التالية:",
    "%1$s via %2$s" : "%1$s عبر %2$s",
    "Click the button below to open it." : "أنقر على الزر أدناه لفتحه.",
    "Open »%s«" : "فتح »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s شارك عدة ملفاتٍ معك.\nيُفترض أن إيميلاً قد وصلك يحوي رابطاً للوصول إلى المُشاركة.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s شارك عدة ملفاتٍ معك. يُفترض أن إيميلاً قد وصلك يحوي رابطاً للوصول إلى المُشاركة.",
    "Password to access files shared to you by %1$s" : "كلمة مرورٍ للوصول إلى ملفاتٍ تمّت مُشاركتها معك من قِبَل %1$s",
    "Password to access files" : "كلمة مرورٍ للوصول إلى ملفاتٍ",
    "%s shared multiple files with \"%s\"." : "%s شارك عدّة ملفّاتٍ معك \"%s\".",
    "%s shared multiple files with you." : "%s شارك عدّة ملفّاتٍ معك.",
    "Boot up" : "بدء التشغيل",
    "Nextcloud Initialization" : "بدء تشغيل نكست كلاود",
    "Circles App Initialization" : "بدء تشغيل تطبيق الدوائر Circles App",
    "Fresh installation status" : "حالة التنصيب الجديدة",
    "Building Local Database" : "بناء قاعدة بياناتٍ محلّيّةٍ",
    "Adding local users and moderators" : "إضافة مستخدمين محليين ومشرفين",
    "Show all teams" : "عرض كل الفرق",
    "Create a new team" : "إنشاء فريق جديد",
    "Files" : "الملفّات",
    "The team is not federated" : "الفريق ليس فريق من السحابة الموحدة",
    "You cannot join this team" : "لا يمكنك الانضمام إلى هذا الفريق",
    "This member is not a moderator" : "هذا العضو ليس مشرف",
    "Insufficient privileges" : "الصلاحيات لا تكفي",
    "This member does not exist" : "هذا العضو غير موجود",
    "This member is the owner of the team" : "هذا العضو هو مالك الفريق",
    "Level cannot be changed for this type of member" : "لا يمكن تغيير المستوى لعضو من هذا النوع",
    "%s (Team owned by %s)" : "%s (فريق يملكه %s)",
    "You are now a member of the Team \"%2$s\"" : "أنت الآن عضو في الفريق \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "أنت مدعوٌ من قِبَل %1$s لعضوية الفريق \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s أرسل طلباً لعضوية الفريق \"%2$s\"",
    "Accept" : "قبول",
    "Refuse" : "رفض",
    "Leave the team" : "مغادرة الفريق",
    "%s" : "%s",
    "Personal team" : "فريق شخصي",
    "%s owned by %s" : "%s يملكها %s",
    "You have no permission to create a new team" : "ليس عندك الصلاحية لإنشاء فريق جديد",
    "%s shared a file with \"%s\"." : "%s شارك ملفّاً مع \"%s\".",
    "%s shared a file with you." : "%s شارك ملفّاً معك.",
    "Open %s" : "إفتَح %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s شارك بعض المحتوى معك.\nيٌفترض أن إيميلاً قد وصلك يحوي رابطاً للوصول إلى هذا المحتوى.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s شارك بعض المحتوى معك.يٌفترض أن إيميلاً قد وصلك يحوي رابطاً للوصول إلى هذا المحتوى..",
    "Password to access content shared with you by %1$s" : "تمّت مُشاركة كلمة مرورٍ معك للوصول إلى المحتوى %1$s",
    "Password to access content" : "كلمة مرورٍ للوصول إلى المحتوى",
    "This item is already shared with this team" : "هذا العنصر سبقت مشاركته سلفاً مع هذا الفريق",
    "Bring cloud-users closer together." : "تقريب مستخدمي السحابة من بعضهم البعض.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "تسمح الفرق للأشخاص بإنشاء مجموعاتهم الخاصة من الأشخاص/الزملاء/الأصدقاء. يمكن بعد ذلك استخدام هذه المجموعات من الأشخاص بواسطة أي تطبيق آخر لغرض المشاركة.",
    "https://…" : "https://…",
    "Try again" : "عاود المحاولة",
    "No teams found" : "لا يوجد أي فريق",
    "Loading…" : "التحميل جارٍ ...",
    "No files in here" : "لا توجد ملفات هنا",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Name" : "الاسم",
    "Size" : "الحجم",
    "Modified" : "آخر تعديل"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
