import{g as f}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as g}from"./lasso-CXJApZlN.chunk.mjs";function c(e,s){for(var n=0;n<s.length;n++){const r=s[n];if(typeof r!="string"&&!Array.isArray(r)){for(const t in r)if(t!=="default"&&!(t in e)){const o=Object.getOwnPropertyDescriptor(r,t);o&&Object.defineProperty(e,t,o.get?o:{enumerable:!0,get:()=>r[t]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var i,a;function u(){if(a)return i;a=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/lasso" instead of "highlight.js/lib/languages/lasso.js"'))}return e(),i=g(),i}var l=u();const p=f(l),j=c({__proto__:null,default:p},[l]);export{j as l};
//# sourceMappingURL=lasso.js-BaweEwO4.chunk.mjs.map
