OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "បានចម្លង",
    "Press ⌘-C to copy." : " ចុច ⌘-C ដើម្បីចម្លង",
    "Press Ctrl-C to copy." : "ចុច Ctrl-C ដើម្បីចម្លង",
    "Size:" : "ទំហំ៖",
    "Shares" : "ចែក​រំលែក",
    "Type:" : "ប្រភេទ៖"
},
"nplurals=1; plural=0;");
