OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "找不到幕後程式設定",
    "Error starting install of ExApp" : "開始安裝 ExApp 時發生錯誤",
    "ExApp failed to register, check the NC logs" : "ExApp 註冊失敗，請檢查 Nextcloud 紀錄檔",
    "ExApp not found, failed to get status" : "找不到 ExApp，無法取得狀態",
    "Error adding Docker registry" : "新增 Docker registry 時發生錯誤",
    "Error removing Docker registry" : "移除 Docker registry 時發生錯誤",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "此應用程式未從 AppStore 安裝。未提供額外資訊。僅允許啟用/停用與移除動作。",
    "Could not perform installation of ExApp" : "無法執行 ExApp 的安裝",
    "Failed to enable ExApp" : "啟用 ExApp 失敗",
    "Failed to disable ExApp" : "停用 ExApp 失敗",
    "Could not update ExApp" : "無法更新 ExApp",
    "Error starting update of ExApp" : "開始更新 ExApp 時發生錯誤",
    "Could not perform update of ExApp" : "無法執行 ExApp 的更新",
    "ExApp not found, failed to get logs" : "找不到 ExApp，無法取得紀錄檔",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "無法取得容器紀錄檔。注意：下載 Docker 容器僅適用於有 json 檔案或 journald 紀錄檔驅動程式的容器。錯誤：%s",
    "ExApp not found, failed to get deploy options" : "找不到 ExApp，無法取得部署選項",
    "AppAPI authentication failed" : "AppAPI 驗證失敗",
    "AppAPI ExApp notifier" : "AppAPI ExApp 通知",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "整合團隊",
    "ExApps Settings" : "ExApp 設定",
    "AppAPI deploy daemon" : "AppAPI 部署幕後程式",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "未設定 AppAPI 部署幕後程式。請在設定中註冊預設部署幕後程式以安裝外部應用程式 (Ex-Apps)。",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "AppAPI 預設部署幕後程式「%s」無法使用。請檢查幕後程式組態。",
    "The AppAPI default deploy daemon is not using HaRP. Please consider switching to HaRP for better performance." : "AppAPI 預設部署幕後程式未使用 HaRP。請考慮切換至 HaRP 以獲得更好的效能。",
    "AppAPI HaRP version check" : "AppAPI HaRP 版本檢查",
    "Could not retrieve HaRP version from daemon \"%s\"" : "無法從「%s」幕後程式擷取 HaRP 版本",
    "HaRP version for daemon \"%s\" is \"%s\", which is too old. The minimum required version is \"%s\". Please update the daemon to the latest version." : "幕後程式「%s」的 HaRP 版本為「%s」，太舊了。需要的最低版本為「%s」。請更新幕後程式至最新版本。",
    "Failed to check HaRP version for daemon \"%s\": %s" : "檢視幕後程式「%s」的 HaRP 版本失敗：%s",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "### What is AppAPI?\n\nAppAPI is the Nextcloud component that enables **External Apps (ExApps)**.\nExApps are apps whose backend runs **outside** the Nextcloud PHP process (usually as a Docker container), while still integrating with your Nextcloud users, permissions and web UI.\n\n### Do I need it?\n\nNo. If you do not plan to install External Apps, you can disable AppAPI.\n\nIf AppAPI is enabled without a configured Deploy Daemon, Nextcloud will show the info message:\n\n> \"AppAPI default deploy daemon is not set …\"\n\nThat warning means: \"External Apps are not configured yet\".\n\nYou can either disable AppAPI, or configure a Deploy Daemon (see below).\n\n### How do External Apps get deployed?\n\nA **Deploy Daemon** is the service Nextcloud talks to in order to install, start, stop and reach ExApps.\n\nTwo options are available:\n\n- **HaRP** (recommended for Nextcloud 32+) — a high-performance reverse proxy with FRP tunneling\n- **Docker Socket Proxy** (legacy) — scheduled for removal in Nextcloud 35\n\nSee the [admin documentation](https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html) for setup instructions." : "### AppAPI 是什麼？\n\nAppAPI 是用來啟用**外部應用程式 (ExApps)** 的 Nextcloud 元件。\nExApps 是指其後端在 Nextcloud PHP 處理程序**之外**運作（通常是 Docker 容器）的應用程式，同時仍能與您的 Nextcloud 使用者、權限及網頁介面整合。\n\n### 我需要它嗎？\n\n如果您並未規劃安裝外部應用程式的話，您可以停用 AppAPI。\n\n若啟用了 AppAPI 但沒有設定好的部署幕後程式，Nextcloud 將會顯示資訊訊息：\n\n> 「未設定 AppAPI 預設部署幕後程式……」\n\n此警告代表了：「外部應用程式尚未設定完成」。\n\n您可以停用 AppAPI 或設定部署幕後程式（見下）。\n\n### 如何部署外部應用程式？\n\n**部署幕後程式**是 Nextcloud 用來安裝、啟動、停止及存取 ExApps 的通訊服務。\n\n有兩種選項可供選擇：\n\n- **HaRP**（建議用於 Nextcloud 32 或更新版本）：有 FRP 隧道的高效能的反向代理伺服器\n- **Docker Socket Proxy**（舊版）：計畫於 Nextcloud 35 移除\n\n檢視[管理員文件](https://docs.nextcloud.com/server/latest/admin_manual/exapps_management/DeployConfigurations.html)以取得設定資訊。",
    "External Apps management" : "外部應用程式管理",
    "Admin options saved" : "已儲存管理選項",
    "Failed to save admin options" : "儲存管理選項失敗",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "AppAPI 計畫是一項令人振奮的計畫，旨在透過使用 docker 容器，徹底改變 Nextcloud 應用程式的開發方式。允許更多的程式語言選擇，並允許將運算密集型的任務移轉到不同的伺服器。",
    "Deploy daemons" : "部署幕後程式",
    "A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署幕後程式 (DaemonConfig) 是 ExApps 的協作幕後程式。",
    "Deploy daemons. A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署幕後程式。部署幕後程式 (DaemonConfig) 是 ExApps 的協作幕後程式。",
    "Default deploy daemon is not accessible. Please check its configuration" : "預設部署幕後程式無法使用。請檢查設定",
    "ExApp init timeout (minutes)" : "ExApp 初始化逾時（分鐘）",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "ExApp 初始化流程逾時，在此之後 AppAPI 將會標記其為失敗",
    "ExApp init timeout" : "ExApp 初始化逾時",
    "ExApp container restart policy" : "ExApp 容器重新啟動政策",
    "Choose the container restart policy, e.g. 'always' to ensure ExApps will be running after a daemon server reboot" : "選擇容器重新啟動政策，例如「一律」確保 ExApps 將會在幕後程式伺服器重新啟動後執行",
    "This settings changes are effective only for newly created containers" : "此設定變更僅反映在新建立的容器中",
    "Deploy daemon deletion confirmation" : "部署幕後程式刪除確認",
    "Are you sure you want delete the \"{name}\" deploy daemon?" : "您確定您想要刪除「{name}」部署幕後程式嗎？",
    "Remove all ExApps installed on this daemon" : "移除所有安裝在此幕後程式上的 ExApps",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "A \"manual-install\" deploy daemon cannot be set as default" : "「手動安裝」部署幕後程式無法設定為預設值",
    "Failed to save admin settings. Check the logs" : "儲存管理設定失敗。請檢查紀錄檔",
    "Password confirmation failed" : "密碼確認失敗",
    "Default" : "預設",
    "Set as default" : "設定為預設值",
    "Test deploy" : "測試部署",
    "Docker registries" : "Docker registry",
    "Edit" : "編輯",
    "Daemon connection successful" : "幕後程式連線成功",
    "Failed to connect to the daemon. Check the logs" : "連線至幕後程式失敗。請檢查紀錄檔",
    "Failed to check connection to the daemon. Check the logs" : "檢查至幕後程式的連線失敗。請檢查紀錄檔",
    "Unlimited" : "無限制",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} 個 CPU"],
    "Deploy daemon configuration" : "部署幕後程式設定",
    "Deploy daemon configuration details" : "部署幕後程式設定詳細資訊",
    "Deploy daemon" : "部署幕後程式",
    "Default daemon. ExApps will be installed on it" : "預設幕後程式。ExApp 將會安裝在其之上",
    "The \"Manual install\" daemon is usually used for development. It cannot be set as the default daemon." : "「手動安裝」幕後程式通常用於開發。其不能被設定為預設幕後程式。",
    "ExApps installed" : "已安裝 ExApp",
    "Name" : "名稱",
    "Protocol" : "協定",
    "Host" : "主機",
    "ExApp direct communication (FRP disabled)" : "ExApp 直接通訊（已停用 FRP）",
    "Deploy options" : "部署選項",
    "Docker network" : "Docker 網路",
    "Nextcloud URL" : "Nextcloud URL",
    "HaProxy password" : "HaProxy 密碼",
    "GPU support" : "GPU 支援",
    "Computation device" : "計算裝置",
    "Memory limit" : "記憶體限制",
    "CPU limit" : "CPU 限制",
    "Additional options" : "額外選項",
    "Check connection" : "檢查連線",
    "Registered Deploy daemons list" : "已註冊的部署幕後程式清單",
    "No Deploy daemons are registered" : "未註冊部署幕後程式",
    "Register a custom one or configure one from the available templates" : "從可用範本註冊自訂範本或設定",
    "Register daemon" : "註冊幕後程式",
    "Register ExApp in Nextcloud" : "在 Nextcloud 註冊 ExApp",
    "Check if the ExApp is registered in Nextcloud before deployment" : "部署前檢查 ExApp 是否已在 Nextcloud 中註冊",
    "Image pull" : "拉取映像檔",
    "Check if the image is successfully pulled" : "檢查是否成功拉取映像檔",
    "Container started" : "容器已啟動",
    "Check if the image successfully pulled and container is created and started" : "檢查是否成功拉取映像檔，以及容器是否已建立並啟動",
    "Heartbeat" : "心跳",
    "Check for the heartbeat is finished and healthy" : "檢查心跳是否完成且健康",
    "Init step" : "初始化步驟",
    "Wait for initialization step to finish" : "等待初始化步驟完成",
    "Enabled" : "已啟用",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "檢查 ExApp 是否成功處理啟用的事件並正確註冊所有內容",
    "Only if ExApp container is preset" : "僅當 ExApp 容器已預設設定時",
    "Deploy test passed successfully!" : "部署測試成功通過！",
    "Deploy test failed at step \"{step}\"" : "部署測試於「{step}」步驟失敗",
    "AppAPI will try to install small skeleton ExApp to check that the daemon is configured correctly and the deployment steps are successful." : "AppAPI 將嘗試安裝小型 ExApps 骨架來檢查幕後程式是否正確設定以及部署步驟是否成功。",
    "The following deploy test checks must succeed:" : "以下部署測試檢查必須成功：",
    "More information" : "更多資訊",
    "Download ExApp logs" : "下載 ExApp 紀錄檔",
    "Remove the test ExApp" : "移除測試 ExApp",
    "Start the deploy test" : "開始部署測試",
    "Stop the deploy test" : "停止部署測試",
    "The test ExApp is unregistered and its container is removed on \"Stop the deploy test\"" : "測試 ExApp 已被取消註冊，其容器已在「停止部署測試」中移除",
    "Please enter a registry domain" : "請輸入 registry 網域",
    "\"From\" cannot be \"local\"" : "「From」不能是「local」",
    "This registry mapping already exists" : "已存在此 registry 對映",
    "\"From\" and \"To\" cannot be the same" : "「From」與「To」不能相同",
    "Docker registry mapping added" : "已新增 Docker registry 對映",
    "Error adding Docker registry mapping" : "新增 Docker registry 對映時發生錯誤",
    "Docker registry mapping removed" : "已移除 Docker registry 對映",
    "Error removing Docker registry mapping" : "移除 Docker registry 對映時發生錯誤",
    "Override Docker registries" : "覆寫 Docker registry",
    "Configure Docker registry override mappings for the selected daemon." : "為選取的幕後程式設定 Docker registry 覆寫對映。",
    "The matching source registry in ExApp info.xml will be overwritten during deployment (image pull step)." : "ExApp info.xml 中相符的來源 registry 將會在部署時覆寫（映像檔拉取步驟）。",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "如果您想使用自訂的 Docker registry，例如使用私人 Docker registry，或使用不同的 Docker registry 進行測試，這將非常有用。",
    "Image pull will be skipped" : "將會略過映像檔拉取",
    "Remove" : "移除",
    "No custom Docker registries are registered" : "未設定自訂的 Docker registry",
    "Add registry override mapping" : "新增 registry 覆寫對映",
    "From" : "從",
    "registry URL (e.g. ghcr.io)" : "registry URL（例如 ghcr.io）",
    "To" : "至",
    "registry URL (e.g. docker.io)" : "registry URL（例如 docker.io）",
    "Add" : "新增",
    "Hostname used by Nextcloud to access the ExApps" : "Nextcloud 用來存取 ExApps 的主機名稱",
    "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}." : "{name} 可用的主機名稱（與連接埠）。這不需要是公開主機，只要是 Nextcloud 伺服器可以存取的主機即可，例如：{host}。",
    "The hostname (and port) or path at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server. It can also be the path to the Docker socket. (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "{name} 可用的主機名稱（與連接埠）或路徑。這不需要是公開主機，只要是 Nextcloud 伺服器可以存取的主機即可。也可以是 Docker socket 的路徑（例如 nextcloud-appapi-dsp:2375、/var/run/docker.sock）",
    "A daemon with this name already exists" : "同名幕後程式已存在",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "HaRP 容器通訊的祕密金鑰 (HP_SHARED_KEY)。",
    "AppAPI Docker Socket Proxy authentication password" : "AppAPI Docker Socket Proxy 驗證密碼",
    "Changes are only effective for newly installed ExApps. For existing ExApps, the Docker containers should be recreated to apply the new settings values." : "變更僅對新安裝的 ExApps 有效。對於現有的 ExApps，應重新建立 Docker 容器以套用新的設定值。",
    "The Docker network that the deployed ExApps will use." : "部署的 ExApps 將要使用的 Docker 網路。",
    "The URL should start with http:// or https://" : "URL 應以 http:// 或 https:// 開頭",
    "For a HTTPS daemon, the Nextcloud URL should be HTTPS" : "對於 HTTPS 幕後程式，Nextcloud URL 應該為 HTTPS",
    "All available GPU devices on the daemon host need to be enabled in ExApp containers by Docker." : "所有位於幕後程式主機上的可用 GPU 裝置，皆需透過 Docker 在 ExApp 容器中啟用。",
    "DaemonConfig successfully registered" : "DaemonConfig 成功註冊",
    "Failed to register DaemonConfig. Check the logs" : "註冊 DaemonConfig 失敗。請檢查紀錄檔",
    "DaemonConfig successfully updated" : "DaemonConfig 成功更新",
    "Failed to update DaemonConfig. Check the logs" : "更新 DaemonConfig 失敗。請檢查紀錄檔",
    "Failed to connect to Daemon. Check the logs" : "連線至幕後程式失敗。請檢查紀錄檔",
    "Failed to check connection to Daemon. Check the logs" : "檢查至幕後程式的連線失敗。請檢查紀錄檔",
    "Edit the deploy daemon" : "編輯部署幕後程式",
    "Register a new deploy daemon" : "註冊新的部署幕後程式",
    "Daemon configuration template" : "幕後程式設定範本",
    "Select a daemon configuration template" : "選取幕後程式設定範本",
    "Daemon registration form" : "幕後程式註冊表單",
    "Unique deploy daemon name" : "獨一無二的部署幕後程式名稱",
    "Unique deploy Daemon name" : "獨一無二的部署幕後程式名稱",
    "Display name" : "顯示名稱",
    "Deployment method" : "部署方法",
    "Select the daemon deploy method" : "選取幕後程式部署方法",
    "HaRP host" : "HaRP 主機",
    "Daemon host" : "幕後程式主機",
    "HaRP shared key" : "HaRP 共用金鑰",
    "The password must be at least 12 characters long" : "密碼必須至少 12 個字元長",
    "Set this daemon as the default one" : "將此幕後程式設定為預設",
    "Set as the default daemon" : "設定為預設幕後程式",
    "Enable HTTPS" : "啟用 HTTPS",
    "Show deploy options" : "顯示部署選項",
    "Hide deploy options" : "隱藏部署選項",
    "Enable HaRP" : "啟用 HaRP",
    "FRP server address" : "FRP 伺服器位址",
    "The address (host:port) of the FRP server that should be reachable by the ExApp in the network defined in the 'Docker network' section." : "在「Docker network」區塊中定義的網路裡，ExApp 應該可以連線到的 FRP 伺服器位址（主機:連接埠）。",
    "Docker socket proxy port" : "Docker socket 代理伺服器連接埠",
    "The port in HaRP which the Docker socket proxy connects to. This should be exposed but for the in-built one, it is not required to be exposed or changed." : "Docker socket 代理伺服器連線到的 HaRP 連接埠。這應該是公開的，但對於內建的版本，則不需要公開或變更。",
    "Disable FRP" : "停用 FRP",
    "Flag for advanced setups only. Disables the FRP tunnel between ExApps and HaRP." : "僅適用於進階設定的旗標。停用 ExApps 與 HaRP 間的 FRP 通道。",
    "Docker network for ex-app deployment must be defined" : "必須定義用於外部應用程式部署的 docker 網路",
    "Compute device" : "計算裝置",
    "Memory limit (in MiB)" : "記憶體限制（以 MiB 計）",
    "Must be a positive integer" : "必須為正整數",
    "Maximum amount of memory that the ExApp container can use in mebibytes" : "ExApp 容器可以使用的最大記憶體量（以 MiB 計）",
    "CPU limit as decimal value" : "CPU 限制（十進位值）",
    "Must be a positive number" : "必須為正數",
    "Maximum number of CPU cores that the ExApp container can use (e.g. 0.5 for half a core, 2 for two cores)" : "ExApp 容器可以使用的最大 CPU 核心數（舉例來說，半個核心為 0.5，兩個核心為 2）",
    "Add additional option" : "新增其他選項",
    "Option key (unique)" : "選項鍵（唯一）",
    "Option key (unique, e.g. my_key)" : "選項鍵（唯一，例如 my_key）",
    "Option key is required" : "選項鍵必填",
    "Option value" : "選項值",
    "Option value is required" : "選項值必填",
    "Confirm" : "確認",
    "Save" : "儲存",
    "Register" : "註冊",
    "External Apps" : "外部應用程式",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### 使用 AppAPI 與其專門設計的應用程式強化您的 Nextcloud\n\n\nAppAPI 是 Nextcloud 生態系中的一個專案，旨在簡化並強化\n應用程式開發、部署及管理。\n\n其引入了一種新的方法，讓開發者可以製作\n使用多種程式語言的應用程式，不僅限於 PHP，後者傳統上用於 Nextcloud 開發。\n\n\n### 內建應用程式\n\n**從 Nextcloud 30.0.1 開始，此應用程式已包含在預設的 Nextcloud 軟體包中。**\n\n### 支援\n\n我們感謝對此專案的任何支援：\n\n- ⭐ 在 GitHub 上給我們的作品星星\n- ❗ 建立問題或功能請求\n- 💁 解決問題並建立拉取請求\n- 🧑‍💻 使用 AppAPI 開發您自己的應用程式\n\n我們對 AppAPI 專案的未來及其改變 Nextcloud 中應用程式開發與\n體驗方式的潛力感到由衷的興奮。\n\n當我們踏上這趟旅程時，我們熱烈邀請您（開發者、思想家、創造者和夢想家）\n與我們一起塑造更通用、穩定和安全的應用程式格局。\n\n*您的見解、建議和貢獻對我們來說非常寶貴。*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "AppAPI 專案是一項令人興奮的舉措，旨在徹底改變 Nextcloud 的應用程式開發方式。",
    "Deploy Daemons" : "部署幕後程式",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署幕後程式 (DaemonConfig) 是 ExApp 的協作幕後程式。",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署幕後程式。部署幕後程式 (DaemonConfig) 是 ExApp 的協作幕後程式。",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "預設部署幕後程式無法使用。請驗證其設定",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "指定容器重新啟動政策，例如「一律」確保 ExApp 在幕後程式伺服器重新啟動後執行",
    "This settings changes are reflected only for newly created containers" : "此設定變更僅反映在新建立的容器中",
    "{license}-licensed" : "以 {license} 授權",
    "Update to {version}" : "更新到 {version}",
    "Delete data on remove" : "移除時刪除資料",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未指定最低的 Nextcloud 版本。未來可能會出現錯誤。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未指定最高的 Nextcloud 版本。未來可能會出現錯誤。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "無法安裝此應用程式，因為無法滿足下列的依賴關係：",
    "View in store" : "在商店中檢視",
    "Visit website" : "造訪網站",
    "Report a bug" : "回報問題",
    "User documentation" : "使用者說明文件",
    "Admin documentation" : "管理員說明文件",
    "Developer documentation" : "開發者說明文件",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "此應用程式未在 AppStore 註冊。無可用的額外資訊。僅允許啟用/停用與移除動作。",
    "This app is supported via your current Nextcloud subscription." : "您目前的 Nextcloud 訂閱支援此應用程式。",
    "Supported" : "支援",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "精選應用程式是由社群開發的。它們提供了相當重要的功能，並已準備好在正式環境使用。",
    "Featured" : "精選",
    "Update to {update}" : "更新到 {update}",
    "All ExApps are up-to-date." : "所有 ExApp 均已最新。",
    "Default Deploy daemon is not accessible" : "預設部署幕後程式無法使用",
    "Icon" : "圖示",
    "Version" : "版本",
    "Daemon" : "守護程式",
    "Level" : "層級",
    "Actions" : "動作",
    "Results from other categories" : "其他分類的結果",
    "No apps found" : "找不到應用程式",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n 個應用程式有可用的更新"],
    "_Update_::_Update all_" : ["更新全部"],
    "Deploy Daemon" : "部署幕後程式",
    "Type" : "類型",
    "Display Name" : "顯示名稱",
    "GPUs support" : "GPU 支援",
    "Are you sure you want delete Deploy Daemon" : "您確定您想要刪除部署幕後程式嗎",
    "All ExApps on this daemon will be removed" : "所有在此幕後程式上的 ExApp 都將會被移除",
    "All ExApps installed on this daemon will be removed" : "所有安裝在此幕後程式上的 ExApp 都將會被移除",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "「手動安裝」部署幕後程式無法設定為預設值",
    "Failed to save admin options. Check the logs" : "儲存管理選項失敗。請檢查紀錄檔",
    "Deploy daemon config details" : "部署幕後程式設定詳細資訊",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "手動安裝幕後程式通常用於開發。其不能被設定為預設幕後程式。",
    "Deploy config" : "部署設定",
    "Verify connection" : "驗證連線",
    "No Deploy daemons configured" : "未設定部署幕後程式",
    "Register a custom one or setup from available templates" : "從可用範本註冊自訂範本或設定",
    "Register Daemon" : "註冊幕後程式",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI 將嘗試安裝小型 ExApp 骨架來驗證幕後程式是否正確設定以及部署步驟是否通過。",
    "The following Deploy test checks must be passed to succeed:" : "必須通過以下部署測試檢查才能成功：",
    "More info" : "更多資訊",
    "Remove test ExApp" : "移除測試 ExApp",
    "Start Deploy test" : "開始部署測試",
    "Stop Deploy test" : "停止部署測試",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp 已被取消註冊，其容器已在「停止部署測試」中移除",
    "Hostname to access ExApps" : "用來存取 ExApps 的主機名稱",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "存取 Docker 幕後程式的主機名稱或路徑（例如 nextcloud-appapi-dsp:2375, /var/run/docker.sock）",
    "Daemon with this name already exists" : "同名幕後程式已存在",
    "Password must be at least 12 characters long" : "密碼必須至少 12 個字元長",
    "With https enabled network is set to host" : "啟用 https 後，網路設定為主機",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "變更僅適用於新安裝的 ExApps。對於現有的 ExApps，應重新建立 Docker 容器。",
    "URL should start with http:// or https://" : "URL 應以 http:// 或 https:// 開頭",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "對於 HTTPS 幕後程式，Nextcloud URL 應該為 HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Docker 將要求在 ExApp 容器中啟用幕後程式主機上的所有可用 GPU 裝置。",
    "Edit Deploy Daemon" : "編輯部署幕後程式",
    "Register Deploy Daemon" : "註冊部署幕後程式",
    "Select daemon configuration template" : "選取幕後程式設定範本",
    "Unique Deploy Daemon Name" : "獨一無二的部署幕後程式名稱",
    "Select daemon deploy method" : "選取幕後程式部署方法",
    "Set daemon as default" : "設定幕後程式為預設值",
    "Set as default daemon" : "設定為預設幕後程式",
    "Enable https" : "啟用 https",
    "Show deploy config" : "顯示部署設定",
    "Hide deploy config" : "隱藏部署設定",
    "Network" : "網路",
    "Docker network name" : "Docker 網路名稱",
    "Additional option" : "其他選項",
    "by {author}\n{license}" : "作者為 {author}\n{license}",
    "Your apps" : "您的應用程式",
    "Documentation" : "文件",
    "Details" : "詳細資訊",
    "Changelog" : "變更紀錄",
    "Active apps" : "已啟用應用程式",
    "Disabled apps" : "已停用應用程式",
    "Updates" : "更新",
    "Featured apps" : "精選應用程式",
    "Supported apps" : "支援的應用程式",
    "manual-install apps cannot be updated" : "無法更新手動安裝應用程式",
    "{progress}% Deploying" : "{progress}% 部署中",
    "{progress}% Initializing" : "初始化 {progress}%",
    "Healthchecking" : "健康檢查",
    "Deploy and Enable" : "部署與啟用",
    "Enable" : "啟用",
    "Disable" : "停用",
    "Allow untested app" : "允許未經測試的應用程式",
    "Default Deploy daemon is not accessible. Please verify configuration" : "預設部署幕後程式無法使用。請驗證設定",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "該應用程式將從 App Store 下載並部署在預設的部署幕後程式上",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此應用程式未被標記為與您的 Nextcloud 版本相容。如果繼續，您仍可安裝應用程式。但請注意應用程式可能無法正常運作。",
    "Your ExApps" : "您的 ExApp",
    "An error occurred during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
    "The app has been enabled but needs to be updated." : "應用程式已啟用，但需要更新。",
    "Error: This app cannot be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### 使用 AppAPI 與其專門設計的應用程式強化您的 Nextcloud\n\n\nAppAPI 是 Nextcloud 生態系中的一個專案，旨在簡化並強化\n應用程式開發、部署及管理。\n\n其引入了一種新的方法，讓開發者可以製作\n使用多種程式語言的應用程式，不僅限於 PHP，後者傳統上用於 Nextcloud 開發。\n\n\n### 需要 AppAPI 的應用程式清單：\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_若您希望開發應用程式，我們將很樂意為您提供協助。_\n\n### 支援\n\n我們感謝對此專案的任何支援：\n\n- ⭐ 在 GitHub 上給我們的作品星星\n- ❗ 建立問題或功能請求\n- 💁 解決問題並建立拉取請求\n- 🧑‍💻 使用 AppAPI 開發您自己的應用程式\n\n我們對 AppAPI 專案的未來及其改變 Nextcloud 中應用程式開發與\n體驗方式的潛力感到由衷的興奮。\n\n當我們踏上這趟旅程時，我們熱烈邀請您（開發者、思想家、創造者和夢想家）\n與我們一起塑造更通用、穩定和安全的應用程式格局。\n\n*您的見解、建議和貢獻對我們來說非常寶貴。*"
},
"nplurals=1; plural=0;");
