import{g as l}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as f}from"./gradle-DjA8oGha.chunk.mjs";function c(e,s){for(var n=0;n<s.length;n++){const r=s[n];if(typeof r!="string"&&!Array.isArray(r)){for(const t in r)if(t!=="default"&&!(t in e)){const i=Object.getOwnPropertyDescriptor(r,t);i&&Object.defineProperty(e,t,i.get?i:{enumerable:!0,get:()=>r[t]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,a;function u(){if(a)return o;a=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/gradle" instead of "highlight.js/lib/languages/gradle.js"'))}return e(),o=f(),o}var g=u();const d=l(g),j=c({__proto__:null,default:d},[g]);export{j as g};
//# sourceMappingURL=gradle.js-bsESWIZW.chunk.mjs.map
