OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Ficheiros recomendados",
    "Recommendations" : "Recomendacións",
    "Shows recommended files" : "Amosa os ficheiros recomendados",
    "Shows recommended files for quick access of files and folders with recent activity" : "Amosa os ficheiros recomendados para acceder rapidamente a ficheiros e cartafoles con actividade recente",
    "No recommendations yet" : "Aínda non hai recomendacións",
    "Last updated {timeAgo}" : "Última actualización: {timeAgo}",
    "Shared with you {timeAgo}" : "Compartido con Vde. hai {timeAgo}",
    "Last commented on {timeAgo}" : "Último comentario hai {timeAgo}",
    "Path name {path}" : "Nome da ruta {path}",
    "Show recommendations" : "Amosar as recomendacións"
},
"nplurals=2; plural=(n != 1);");
