OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Надано доступ через {email} ",
    "Shared with {email} by {actor}" : "Опубліковано {actor} з {email}",
    "Unshared from {email}" : "Скасовано доступ з {email}",
    "Unshared from {email} by {actor}" : "{actor} скасував доступ до {email}",
    "Password for mail share sent to {email}" : "Пароль для обміну поштою надіслано на адресу {email}",
    "Password for mail share sent to you" : "Вам надіслано пароль для обміну поштою",
    "You shared {file} with {email} by mail" : "Ви поділилися поштою {file} з {email}",
    "{actor} shared {file} with {email} by mail" : "{actor} надав(-ла) доступ до файлу {file} через ел.пошту {email}",
    "You unshared {file} from {email} by mail" : "Ви скасували доступ до {file} з {email} поштою",
    "{actor} unshared {file} from {email} by mail" : "{actor} скасував доступ до {file} з {email} поштою",
    "Password to access {file} was sent to {email}" : "Пароль для доступу до {file} надіслано на адресу {email}",
    "Password to access {file} was sent to you" : "Вам надіслано пароль для доступу до {file}",
    "Share by mail" : "Поділитися за допомогою ел. пошти",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не вдалося надати %1$s у спільний доступ, оскільки цей ресурс вже у спільному доступі з користувачем %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Ми не можемо надіслати вам автоматично згенерований пароль. Укажіть дійсну адресу електронної пошти в особистих налаштуваннях і повторіть спробу.",
    "Failed to send share by email. Got an invalid email address" : "Не вдалося надіслати спільний доступ електронною поштою. Отримав недійсну електронну адресу",
    "Failed to send share by email" : "Не вдалося надіслати спільний доступ електронною поштою",
    "%1$s shared %2$s with you" : "%1$s поділив(ла)ся%2$s з вами",
    "Note:" : "Примітка:",
    "This share is valid until %s at midnight" : "Доступ до спільного ресурсу є чинний до опівночі %s",
    "Expiration:" : "Термін завершення:",
    "Open shared item" : "Відкрити спільний ресурс",
    "%1$s via %2$s" : "%1$s через %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s поділився %2$s з вами. Ви мали отримати окремий лист з посиланням на доступ до цього ресурсу.",
    "Password to access %1$s shared to you by %2$s" : "%2$s надіслав вам пароль для доступу до %1$s",
    "Password to access %s" : "Пароль для доступу до %s",
    "It is protected with the following password:" : "Він захищений таким паролем:",
    "This password will expire at %s" : "Цей пароль закінчиться о %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s поділив(ла)ся %2$s з вами та бажає додати:",
    "%1$s shared %2$s with you and wants to add" : "%1$s поділив(ла)ся %2$s з вами та бажає додати",
    "%s added a note to a file shared with you" : "%s додав(-ла) примітку до файлу, яким поділилися з вами",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Ви щойно надали доступ %2$s до %1$s. Цей спільний ресурс було надіслано отримувачеві. Через безпекові політики, які було визначено адміністратором %3$s кожний спільний ресурс має бути захищено паролем, також не дозволено напряму надсилати пароль отримувачеві. Таким чином ви маєте вручну надіслати пароль отримувачеві.",
    "Password to access %1$s shared by you with %2$s" : "%2$s надіслав вам пароль для доступу до %1$s",
    "This is the password:" : "Це пароль:",
    "You can choose a different password at any time in the share dialog." : "Ви можете будь-коли вибрати інший пароль у діалоговому вікні спільного доступу.",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Share provider which allows you to share files by mail" : "Провайдер спільного доступу, який дозволяє обмінюватися файлами поштою",
    "Unable to update share by mail config" : "Не вдається оновити конфігурацію спільного доступу за допомогою пошти",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Дозволяє користувачам надавати персоналізоване посилання на файл або каталог шляхом додавання адреси ел. пошти.",
    "Send password by mail" : "Надіслати пароль поштою",
    "Reply to initiator" : "Відповісти ініціатору"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
