import{g as a}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as c}from"./actionscript-CgCtblwr.chunk.mjs";function s(r,f){for(var o=0;o<f.length;o++){const t=f[o];if(typeof t!="string"&&!Array.isArray(t)){for(const e in t)if(e!=="default"&&!(e in r)){const n=Object.getOwnPropertyDescriptor(t,e);n&&Object.defineProperty(r,e,n.get?n:{enumerable:!0,get:()=>t[e]})}}}return Object.freeze(Object.defineProperty(r,Symbol.toStringTag,{value:"Module"}))}var i=c();const l=a(i),u=s({__proto__:null,default:l},[i]);export{u as a};
//# sourceMappingURL=actionscript-CxympPq_.chunk.mjs.map
