OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Ongeldige gefedereerde Cloud-ID",
    "Server to server sharing is not enabled on this server" : "Server met server delen is op deze server niet ingeschakeld",
    "Couldn't establish a federated share." : "Kon geen gefedereerde share tot stand brengen",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kon geen gefedereerde share tot stand brengen, misschien was het wachtwoord onjuist.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "De gefedereerde share aanvraag is verzonden, je ontvangt een uitnodiging. Controleer je meldingen.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kon geen gefedereerde share tot stand brengen, waarschijnlijk was de federatieserver te oud (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "Het is niet toegestaan om gefedereerde groepsshares vanaf deze server te versturen.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Het delen van%1$s is mislukt, omdat dit item al gedeeld wordt met het account %2$s",
    "Federated shares require read permissions" : "Gefedereerde shares vereisen leesmachtiging",
    "File is already shared with %s" : "Bestand is al gedeeld met %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Delen van %1$s mislukt, kon %2$s niet vinden, misschien is de server niet bereikbaar of je gebruikt een zelf-ondertekend certificaat.",
    "Could not find share" : "Kon share niet vinden",
    "Federated sharing" : "Gefedereerd delens",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Je ontving {share} als een extern deel verzoek van {user} (namens {behalf})",
    "You received {share} as a remote share from {user}" : "Je ontving {share} als een extern share verzoek van {user}",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Sharing" : "Delen",
    "Federated file sharing" : "Gefedereerd delen",
    "Provide federated file sharing across servers" : "Voorzien in gefedereerd delen van bestanden over verschillende servers",
    "Enable data upload" : "Schakel data upload in",
    "Disable upload" : "Schakel upload uit",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Dit wordt gebruikt om de federatieve cloud-ID op te halen om federatief delen gemakkelijker te maken.",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Deel met mij via mijn #Nextcloud Federated Cloud-ID, zie {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Deel met mij via mijn #Nextcloud gefedereerde Cloud-ID",
    "Share with me via Nextcloud" : "Deel met mij via Nextcloud",
    "Cloud ID copied" : "Cloud ID gekopieerd",
    "Copy" : "Kopiëren",
    "Clipboard not available. Please copy the cloud ID manually." : "Klembord niet beschikbaar. Kopieer de cloud-ID handmatig.",
    "Copied!" : "Gekopieerd!",
    "Federated Cloud" : "Gefedereerde Cloud",
    "Your Federated Cloud ID" : "Jouw Federated Cloud-ID",
    "Share it so your friends can share files with you:" : "Deel het, zodat anderen bestanden met jou kunnen delen:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Toevoegen aan je website",
    "HTML Code:" : "HTML Code:",
    "Cancel" : "Annuleren",
    "Add remote share" : "Toevoegen externe share",
    "Remote share" : "Externe share",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Wil je de externe share {name} van {owner}@{remote} toevoegen?",
    "Remote share password" : "Wachtwoord externe share",
    "X (formerly Twitter)" : "X (voorheen Twitter)"
},
"nplurals=2; plural=(n != 1);");
