const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.OC.filePath('photos', '', 'js/PhotosTab-D-NwEPMj.chunk.mjs'),window.OC.filePath('photos', '', 'js/index-BCevi9E9.chunk.mjs'),window.OC.filePath('photos', '', 'js/preload-helper-DadE4qT2.chunk.mjs'),window.OC.filePath('photos', '', 'js/icons-CFZwNZD8.chunk.mjs'),window.OC.filePath('photos', '', 'css/PhotosTab-DGphhlff.chunk.css')])))=>i.map(i=>d[i]);
import{t as s,V as n,f as u,h as o,_ as d}from"./preload-helper-DadE4qT2.chunk.mjs";const w='<svg xmlns="http://www.w3.org/2000/svg" id="mdi-information-outline" viewBox="0 0 24 24"><path d="M11,9H13V7H11M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M11,17H13V11H11V17Z" /></svg>';n.prototype.t=s,n.prototype.n=u,o("nc:metadata-photos-exif"),o("nc:metadata-photos-ifd0"),o("nc:metadata-photos-gps"),o("nc:metadata-photos-place");let a=null,t=null;const c=new OCA.Files.Sidebar.Tab({id:"photos",name:s("photos","Details"),iconSvg:w,async mount(e,i,r){if(a===null){const{default:l}=await d(async()=>{const{default:p}=await import("./PhotosTab-D-NwEPMj.chunk.mjs");return{default:p}},__vite__mapDeps([0,1,2,3,4]),import.meta.url);a=a??n.extend(l)}t&&t.$destroy(),t=new a({parent:r}),t.update(i),t.$mount(e)},update(e){t.update(e)},destroy(){t.$destroy(),t=null}});window.addEventListener("DOMContentLoaded",async function(){if(window.OCA.Files&&window.OCA.Files.Sidebar){window.OCA.Files.Sidebar.registerTab(c);const{default:e}=await d(async()=>{const{default:i}=await import("./PhotosTab-D-NwEPMj.chunk.mjs");return{default:i}},__vite__mapDeps([0,1,2,3,4]),import.meta.url);a=a??n.extend(e)}});
//# sourceMappingURL=photos-sidebar.mjs.map
