OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "System-Schlagwort %1$s vom System hinzugefügt",
    "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
    "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat den System-Tag %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} hinzugefügt",
    "System tag %1$s removed by the system" : "System-Schlagwort %1$s wurde vom System entfernt",
    "Removed system tag {systemtag}" : "System-Tag {systemtag} entfernt",
    "Removed system tag %1$s" : "System-Tag %1$s entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat den System-Tag %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat das System-Tag {systemtag} entfernt",
    "You created system tag %1$s" : "Du hast das System-Tag %1$s erstellt",
    "You created system tag {systemtag}" : "Du hast den System-Tag {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat den System-Tag %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} erstellt",
    "You deleted system tag %1$s" : "Du hast den System-Tag %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Du hast den System-Tag {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat den System-Tag %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Du hast den System-Tag %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du hast den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat den System-Tag von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hat den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "System tag %2$s was added to %1$s by the system" : "System-Schlagwort %2$s wurde %1$s vom System hinzugefügt",
    "System tag {systemtag} was added to {file} by the system" : "System-Tag {systemtag} wurde {file} vom System hinzugefügt",
    "You added system tag %2$s to %1$s" : "Du hast den System-Tag %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Du hast den System-Tag {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat den System-Tag %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat den System-Tag {systemtag} zu {file} hinzugefügt",
    "System tag %2$s was removed from %1$s by the system" : "System-Schlagwort %2$s wurde vom System aus %1$s entfernt",
    "System tag {systemtag} was removed from {file} by the system" : "System-Schlagwort {systemtag} wurde vom System von {file} entfernt",
    "You removed system tag %2$s from %1$s" : "Du hast den System-Tag %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Du hast den System-Tag {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat das den System-Tag %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat den System-Tag {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei wurden geändert",
    "Files" : "Dateien",
    "Tags" : "Tags",
    "All tagged %s …" : "Alle Schlagworte %s hinzugefügt …",
    "tagged %s" : "Schlagwort %s hinzugefügt",
    "Collaborative tags" : "Kollaborative Schlagworte",
    "Collaborative tagging functionality which shares tags among people." : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Schlagwort-Funktionalität für die Zusammenarbeit, die das Teilen von Schlagworten unter Benutzern ermöglicht. Sehr gut für Gruppen geeignet.\n\t(In eine Mehrkundeninstallation sollte diese App deaktiviert werden, da sonst die Schlagworte mit allen Kunden geteilt werden.)",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Created tag" : "Schlagwort erstellt",
    "Failed to create tag" : "Schlagwort konnte nicht erstellt werden",
    "Updated tag" : "Schlagwort aktualisiert",
    "Failed to update tag" : "Schlagwort konnte nicht aktualisiert werden",
    "Deleted tag" : "Schlagwort gelöscht",
    "Failed to delete tag" : "Schlagwort konnte nicht gelöscht werden",
    "Create or edit tags" : "Schlagworte erstellen oder bearbeiten",
    "Search for a tag to edit" : "Nach einem Schlagwort zum Bearbeiten suchen",
    "Collaborative tags …" : "Kollaborative Schlagworte  …",
    "No tags to select" : "Kein Schlagworte zur Auswahl",
    "Tag name" : "Schlagwortname",
    "Tag level" : "Schlagwort-Level",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Delete" : "Löschen",
    "Reset" : "Zurücksetzen",
    "Loading …" : "Lade …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} wird gesetzt und {tag2} von einer Datei entfernt.","{tag1} wird gesetzt und {tag2} von {count} Dateien entfernt."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} wird bei einer Datei gesetzt.","{tag} wird bei {count} Dateien gesetzt."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} wird von einer Datei entfernt.","{tag} wird von {count} Dateien entfernt."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} und {lastTag} werden auf eine Datei gesetzt.","{tags} und {lastTag} werden auf {count} Dateien gesetzt."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} und {lastTag} werden von einer Datei entfernt.","{tags} und {lastTag} werden von {count} Dateien entfernt."],
    "{displayName} (hidden)" : "{displayName} (versteckt)",
    "{displayName} (restricted)" : "{displayName} (eingeschränkt)",
    "Only admins can create new tags" : "Nur die Administration kann neue Schlagworte erstellen",
    "Failed to apply tags changes" : "Schlagwort-Änderungen konnten nicht angewendet werden",
    "Manage tags" : "Schlagworte verwalten",
    "Applying tags changes…" : "Schlagwort-Änderungen werden angewendet …",
    "Search or create tag" : "Schlagwort suchen oder erstellen",
    "Search tag" : "Schlagworte suchen",
    "Change tag color" : "Schlagwortfarbe ändern",
    "Create new tag" : "Neues Schlagwort erstellen",
    "Choose tags for the selected files" : "Schlagworte für die gewählten Dateien wählen",
    "Cancel" : "Abbrechen",
    "Apply" : "Anwenden",
    "Failed to load selected tags" : "Ausgewählte Schlagworte konnten nicht geladen werden",
    "Failed to load tags" : "Schlagworte konnten nicht geladen werden",
    "Failed to select tag" : "Schlagwort konnte nicht ausgewählt werden",
    "System admin disabled tag creation. You can only use existing ones." : "Die Systemadministration hat die Erstellung von Schlagworten deaktiviert. Es können nur vorhandene Schlagworte verwendet werden.",
    "Loading collaborative tags …" : "Kollaborative Schlagworte laden …",
    "Search or create collaborative tags" : "Suchen oder erstellen von kollaborativen Schlagworten",
    "No tags to select, type to create a new tag" : "Keine Schlagworte zur Auswahl, Eingabe beginnen, um ein neues Schlagwort zu erstellen",
    "Unable to update setting" : "Einstellung konnte nicht aktualisiert werden",
    "System tag creation is now restricted to administrators" : "Die Erstellung von System-Schlagworten ist jetzt auf die Administration beschränkt",
    "System tag creation is now allowed for everybody" : "Die Erstellung von System-Schlagworten ist jetzt für alle erlaubt",
    "System tag management" : "Verwaltung von System-Schlagworten",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Wenn diese Option aktiviert ist, kann nur die Administration Schlagworte erstellen und bearbeiten. Konten können sie weiterhin zuweisen und von Dateien entfernen.",
    "Restrict tag creation and editing to administrators" : "Die Erstellung und Bearbeitung von System-Schlagworten auf die Administration beschränken",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Öffentliche Schlagworte sind für alle Benutzer verfügbar. Eingeschränkte Schlagworte sind für alle Benutzer sichtbar, können jedoch nicht zugewiesen werden. Nicht sichtbare Schlagworte sind für interne Verwendung und können vom Benutzer nicht eingesehen und nicht zugewiesen werden.",
    "Add tags" : "Schlagworte hinzufügen",
    "Assigned collaborative tags" : "Zugewiesene kollaborative Schlagworte",
    "Open in Files" : "In App \"Dateien\" öffnen",
    "List of tags and their associated files and folders." : "Liste der Schlagworte und der zugehörigen Dateien und Ordner.",
    "No tags found" : "Keine Tags gefunden",
    "Tags you have created will show up here." : "Die von Ihnen erstellten Schlagworte werden hier angezeigt.",
    "Failed to load tag" : "Schlagwort konnte nicht geladen werden",
    "Failed to load last used tags" : "Zuletzt verwendete Schlagworte konnten nicht geladen werden",
    "Missing \"Content-Location\" header" : "Fehlender \"Content-Location\"-Header",
    "A tag with the same name already exists" : "Ein Schlagwort mit demselben Namen existiert bereits",
    "Failed to load tags for file" : "Schlagworte für Datei konnten nicht geladen werden",
    "Failed to set tag for file" : "Schlagwort für Datei konnte nicht gesetzt werden",
    "Failed to delete tag for file" : "Schlagwort für Datei konnte nicht gelöscht werden",
    "Collaborative tags …" : "Kollaborative Schlagworte …",
    "Loading …" : "Lade …",
    "Loading collaborative tags …" : "Kollaborative Schlagworte laden …"
},
"nplurals=2; plural=(n != 1);");
