OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "بازیابی شد",
    "Deleted files" : "فایل های حذف شده",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)",
    "This application enables people to restore files that were deleted from the system." : "این برنامه به کاربران این امکان را می‌دهد که فایل‌های حذف شده از سیستم خود را بازیابی کنند.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "این برنامه به افراد امکان می‌دهد فایل‌هایی را که از سیستم حذف شده‌اند، بازیابی کنند. این برنامه لیستی از فایل‌های حذف شده را در رابط وب نمایش می‌دهد و گزینه‌هایی برای بازیابی آن فایل‌های حذف شده به دایرکتوری‌های فایل‌های افراد یا حذف دائمی آنها از سیستم دارد. بازیابی یک فایل، در صورت فعال بودن نسخه‌های برنامه، نسخه‌های مرتبط فایل را نیز بازیابی می‌کند. هنگامی که یک فایل از یک اشتراک حذف می‌شود، می‌توان آن را به همان روش بازیابی کرد، اگرچه دیگر به اشتراک گذاشته نمی‌شود. به طور پیش‌فرض، این فایل‌ها به مدت 30 روز در سطل زباله باقی می‌مانند. برای جلوگیری از اتمام فضای دیسک یک حساب، برنامه فایل‌های حذف شده بیش از 50٪ از سهمیه رایگان موجود برای فایل‌های حذف شده را استفاده نمی‌کند. اگر فایل‌های حذف شده از این حد تجاوز کنند، برنامه قدیمی‌ترین فایل‌ها را تا زمانی که به کمتر از این حد برسد، حذف می‌کند. اطلاعات بیشتر در مستندات فایل‌های حذف شده موجود است.",
    "Restore" : "بازیابی",
    "Not enough free space to restore the file/folder" : "فضای خالی کافی برای بازیابی فایل/پوشه نیست",
    "Empty deleted files" : "خالی کردن فایل‌ های حذف شده",
    "Confirm permanent deletion" : "حذف دائمی را تأیید کنید",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "آیا مطمئن هستید که می‌خواهید تمام فایل‌ ها و پوشه‌ های موجود در سطل زباله را برای همیشه حذف کنید؟ این کار قابل بازگشت نیست.",
    "Cancel" : "منصرف شدن",
    "Original location" : "مکان اصلی",
    "Deleted by" : "حذف شده توسط",
    "Deleted" : "حذف شده",
    "few seconds ago" : "چند ثانیه پیش",
    "A long time ago" : "مدت ها پیش",
    "Unknown" : "ناشناخته",
    "All files" : "تمامی فایل‌ها",
    "You" : "You",
    "List of files that have been deleted." : "List of files that have been deleted.",
    "No deleted files" : "هیچ فایل حذف شده وجود ندارد",
    "Files and folders you have deleted will show up here" : "Files and folders you have deleted will show up here",
    "All files have been permanently deleted" : "همه فایل‌ ها به طور دائم حذف شده‌ اند",
    "Failed to empty deleted files" : "خالی کردن فایل‌ های حذف شده ناموفق بود"
},
"nplurals=2; plural=(n > 1);");
