OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Rilevata nuova posizione di accesso",
    "More info about the suspicious IP address available on %s" : "Maggiori informazioni sull'indirizzo IP sospetto sono disponibili su %s",
    "Open %s ↗" : "Apri %s ↗",
    "Suspicious Login" : "Accesso sospetto",
    "New login detected" : "Rilevato un nuovo accesso",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Rileva e avvisa gli IP sospetti che accedono a Nextcloud\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "È stato rilevato un nuovo accesso al tuo account. L'indirizzo IP 1 %s è stato classificato come sospetto. Se sei stato tu, puoi ignorare questo messaggio. Altrimenti dovresti cambiare la password."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
