OC.L10N.register(
    "profile",
    {
    "Profile" : "Профил",
    "This application provides the profile" : "Ова апликација обезбеђује профил",
    "Provides a customisable user profile interface." : "Обезбеђује интерфејс корисничког профила који може да се прилагоди.",
    "Searching …" : "Тражи се …",
    "Not found" : "Није нађено",
    "Insert" : "Уметни",
    "You have not added any info yet" : "Још увек нисте додали никакве информације",
    "{user} has not added any info yet" : "{user} још увек није унео никакве информације",
    "Error opening the user status modal, try hard refreshing the page" : "Грешка приликом отварања модалног прозора за статус корисника, покушајте да освежите страну уз брисање кеша",
    "Edit Profile" : "Уреди профил",
    "The headline and about sections will show up here" : "Овде ће се појавити насловна линија и одељак „о”",
    "Profile not found" : "Није пронађен профил",
    "The profile does not exist." : "Профил не постоји.",
    "Back to %s" : "Назад на %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
