OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Fitxategiaren gogorarazpenak",
    "View file" : "Ikusi fitxategia",
    "View folder" : "Ikusi karpeta",
    "Failed to clear reminder" : "Gogorarazpena garbitzeak huts egin du",
    "Cancel" : "Utzi",
    "Clear reminder" : "Garbitu gogorarazpena",
    "Set reminder" : "Ezarri gogorarazpena",
    "Reminder set" : "Gogorarazpena ezarrita",
    "Later today" : "Beranduago gaur",
    "Set reminder for later today" : "Ezarri gogorarazpena gaur beranduagorako",
    "Tomorrow" : "Bihar",
    "Set reminder for tomorrow" : "Ezarri gogorarazpena biharko",
    "This weekend" : "Asteburu hau",
    "Set reminder for this weekend" : "Ezarri gogorarazpena asteburu honetarako",
    "Next week" : "Hurrengo astea",
    "Set reminder for next week" : "Ezarri gogorarazpena hurrengo asterako"
},
"nplurals=2; plural=(n != 1);");
