OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "Prohlížeč PDF",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Zobrazte si PDF dokumenty přímo v Nextcloud. \nKrom toho tato aplikace také může zobrazovat soubory Adobe Illustrator (.ai). \nZaloženo na [pdf.js](https://mozilla.github.io/pdf.js/)",
    "Failed to load settings" : "Nepodařilo se načíst nastavení",
    "Failed to save settings" : "Nastavení se nepodařilo uložit",
    "PDF Viewer" : "Prohlížeč PDF",
    "File upload failed." : "Nahrání souboru se nezdařilo.",
    "To view a shared PDF file, the download needs to be allowed for this file share" : "Pro zobrazení sdíleného PDF souboru je zapotřebí, aby pro toto sdílení byla povolena stahování"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
