OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Բարև %s",
    "Hello %s," : "Բարև %s,",
    "Notifications" : "Ծանուցում",
    "in {path}" : "դեպի {ուղի}",
    "Never" : "Երբեք",
    "Your settings have been updated." : "Ձեր կարգավորումներն թարմացվել են։",
    "You need to set up your email address before you can receive notification emails." : "Փոստի վրա ծանուցումն ստանալու համար անհրաժեշտ է կարգավորել էլ․հասցեն։"
},
"nplurals=2; plural=(n != 1);");
