OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privatësia",
    "Cancel" : "Anuloje",
    "Add" : "Shto ",
    "Encryption" : "Enkriptimi",
    "Edit" : "Përpuno",
    "Region" : "Rajon",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratet e Bashkuara Arabe",
    "Afghanistan" : "Afganistani",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Shqipëria",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktiku",
    "Argentina" : "Argjentina",
    "American Samoa" : "Samoa Amerikane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ishujt Oland",
    "Azerbaijan" : "Azerbajxhani",
    "Bosnia and Herzegovina" : "Bosnja and Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgjika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bullgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butani",
    "Botswana" : "Botsvana",
    "Belarus" : "Bjellorusi",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Congo" : "Kongo",
    "Switzerland" : "Zvicër",
    "Chile" : "Kili",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbi",
    "Cuba" : "Kubë",
    "Cabo Verde" : "Kepi i Gjelbër",
    "Cyprus" : "Qipro",
    "Germany" : "Gjermani",
    "Denmark" : "Danimarkë",
    "Algeria" : "Algjeria",
    "Ecuador" : "Ekuadori",
    "Estonia" : "Estonia",
    "Egypt" : "Egjipt",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlanda",
    "Fiji" : "Fixhi",
    "France" : "Franca",
    "Gabon" : "Gabon",
    "Georgia" : "Gjeorgji",
    "Ghana" : "Gana",
    "Gibraltar" : "Gjibraltar",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Greece" : "Greqi",
    "Guatemala" : "Guatemala",
    "Honduras" : "Honduras",
    "Croatia" : "Kroaci",
    "Haiti" : "Haiti",
    "Hungary" : "Hungari",
    "Indonesia" : "Indonezia",
    "Ireland" : "Irlanda",
    "Israel" : "Izraeli",
    "India" : "India",
    "Iraq" : "Irak",
    "Iceland" : "Islanda",
    "Italy" : "Itali",
    "Jamaica" : "Xhamaika",
    "Jordan" : "Jordani",
    "Japan" : "Japoni",
    "Kenya" : "Kenia",
    "Cambodia" : "Kamboxhia",
    "Kiribati" : "Kiribati",
    "Kuwait" : "Kuvajti",
    "Kazakhstan" : "Kazakistani",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luksemburgu",
    "Libya" : "Libia",
    "Morocco" : "Maroku",
    "Montenegro" : "Mali i Zi",
    "Mali" : "Mali",
    "Mongolia" : "Mongolia",
    "Malta" : "Malta",
    "Mexico" : "Meksikë",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollandë",
    "Norway" : "Norvegji",
    "Nepal" : "Nepal",
    "New Zealand" : "Zelanda e Re",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Poloni",
    "Puerto Rico" : "Puerto Riko",
    "Portugal" : "Portugali",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Qatar",
    "Romania" : "Rumania",
    "Serbia" : "Serbi",
    "Saudi Arabia" : "Arabia Saudite",
    "Sudan" : "Sudan",
    "Sweden" : "Suedi",
    "Singapore" : "Singapori",
    "Slovenia" : "Sllovenia",
    "Slovakia" : "Sllovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegali",
    "Somalia" : "Somalia",
    "Chad" : "Çad",
    "Togo" : "Togo",
    "Thailand" : "Tajlanda",
    "Tajikistan" : "Taxhikistan",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizia",
    "Tonga" : "Tonga",
    "Turkey" : "Turqi",
    "Taiwan" : "Tajvan",
    "Ukraine" : "Ukrainë",
    "Uganda" : "Uganda",
    "Uruguay" : "Uruguaj",
    "Zambia" : "Zambia"
},
"nplurals=2; plural=(n != 1);");
