OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Le mot de passe a expiré, veuillez utiliser la fonction mot de passe perdu pour le ré-initialiser",
    "Password must not have been used recently before." : "Le mot de passe ne doit pas avoir été utilisé récemment.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Le mot de passe se trouve parmi les 1 000 000 de mots de passe les plus courants. Merci de le rendre unique.",
    "Password is present in compromised password list. Please choose a different password." : "Le mot de passe est présent dans la liste des mots de passe compromis. Merci d'en choisir un autre.",
    "Password needs to be at least %s characters long." : "Le mot de passe doit comporter au moins %s caractères.",
    "Password needs to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password needs to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password needs to contain at least one lower and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password policy" : "Politique de mots de passe",
    "Allows admins to configure a password policy" : "Permet aux administrateurs de configurer une politique de mot de passe.",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permettre à l'administrateur de définir certaines conditions préalables pour le mot de passe, par exemple, imposer une longueur minimale.",
    "General password policies" : "Politiques générales de mots de passe",
    "Add policy set" : "Ajouter un ensemble de politiques",
    "Login policies" : "Politiques de connexion",
    "Password history size" : "Taille de l'historique des mots de passe",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Nombre de mots de passe à conserver (empreintes sécurisées) pour empêcher les utilisateurs de réutiliser d'anciens mots de passe.",
    "Maximum login attempts" : "Tentatives de connexion maximum",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Nombre de tentatives de connexion avant que le compte utilisateur soit désactivé jusqu’à ce qu’une action manuelle soit faite. (0 pour indiquer aucune limite)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Veuillez noter que cette option est destinée à protéger les comptes attaqués. Les comptes désactivés doivent être réactivés manuellement par l'administrateur. Les attaquants qui tentent de deviner les mots de passe des comptes verront leur adresse IP bloquée par la protection contre les attaques par force brute, indépendamment de ce paramètre.",
    "Number of days until user password expires" : "Nombre de jours avant expiration du mot de passe",
    "Password expiration" : "Expiration du mot de passe",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Attention: activer l'expiration du mot de passe est aujourd'hui considéré comme un risque de sécurité par plusieurs agences de sécurité.",
    "Remove policy" : "Supprimer la politique",
    "Minimum password length" : "Longueur minimale du mot de passe",
    "Forbid common passwords" : "Interdire les mots de passe courants",
    "Enforce upper and lower case characters" : "Imposer des caractères en majuscules et en minuscules",
    "Enforce numeric characters" : "Imposer des chiffres",
    "Enforce special characters" : "Imposer des caractères spéciaux",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Vérifier le mot de passe par rapport à la liste des mots de passe compromis sur haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Cette vérification crée un hachage du mot de passe et envoie les 5 premiers caractères de ce hachage à l'API haveibeenpwned.com pour récupérer une liste de tous les hachages qui commencent par ceux-là. Ensuite, il vérifie sur l'instance Nextcloud si le mot de passe est dans le jeu de résultats.",
    "Account password policies" : "Politiques de mots de passe de compte",
    "Share password policies" : "Politiques de mots de passe de partage"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
