OC.L10N.register(
    "logreader",
    {
    "Logging" : "記錄",
    "Errors in the log" : "紀錄檔中的錯誤",
    "Failed to get an iterator for log entries: %s" : "無法取得日誌條目的迭代器：%s",
    "No errors in the logs since %s" : "從 %s 開始，紀錄檔中沒有錯誤",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["從 %s 開始，紀錄檔中有 %n 個錯誤"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["從 %s 開始，紀錄檔中有 %n 個警告"],
    "Log Reader" : "記錄日誌閱讀程式",
    "A log reader for Nextcloud" : "Nextcloud 的記錄日誌閱讀程式",
    "Log reader for Nextcloud" : "Nextcloud 的記錄日誌閱讀程式",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "如果您認為這是一個錯誤，請驗證您的 {config} 中的 {setting} 設置，並查閱 Nextcloud 管理手冊。",
    "Log reader" : "記錄日誌閱讀程式",
    "Open log reader settings" : "開啟記錄閱讀程式設定",
    "Log reader settings" : "記錄閱讀程式設定",
    "Currently the log file {file} is shown" : "目前顯示記錄檔案 {file}",
    "Show server log" : "顯示伺服器記錄",
    "Live view is disabled" : "實時檢視已停用",
    "No log file" : "沒有記錄檔案",
    "File-based logging must be enabled to access logs from the Web UI." : "啟用基於檔案的記錄才能從 Web UI 存取記錄。",
    "Log entry successfully copied" : "已成功複製記錄條目",
    "Level" : "級別",
    "App" : "應用程式",
    "No app in context" : "上下文中沒有應用程式",
    "Time" : "時間",
    "Copy raw entry" : "複製原始的條目",
    "Copy formatted entry" : "複製格式化條目",
    "Hide exception details" : "隱藏例外細節",
    "View exception details" : "檢視例外細節",
    "Raw log entry" : "原始的記錄條目",
    "Search log entries" : "搜尋記錄條目",
    "Caused by {exception}" : "由 {exception} 造成",
    "Line {line}" : "行 {line}",
    "Filter log levels" : "過濾記錄層級",
    "Set log level" : "設定紀錄層級",
    "Time format" : "時間格式",
    "Live view" : "實時檢視",
    "Download/Upload logs" : "下載 / 上傳記錄",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "無法剖析近端記錄檔案",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "您也可以使用以下命令將從剪貼簿複製的紀錄條目貼上到紀錄檢視中來顯示它們：{keyboardShortcut}",
    "Download logs" : "下載記錄檔",
    "Show local log file" : "顯示近端記錄檔案",
    "Upload local log file to be displayed" : "上傳近端記錄檔案進行顯示",
    "Time format used for displaying the timestamp" : "用於顯示時間戳的時間格式",
    "(Local log files only support the \"raw\" time format)" : "（近端記錄檔案僅支持「原始」時間格式）",
    "Could not change date time format." : "無法更改日期時間格式。",
    "Raw data" : "原始數據",
    "Local time" : "本地時間",
    "UTC time" : "UTC 時間",
    "Relative" : "相對",
    "Could not change live view setting." : "無法更改即時檢視設定。",
    "Polling is disabled because server is not configured to log to file" : "因為伺服器未配置為記錄到檔案，所以民意調查已被停用。",
    "Polling (live view)" : "民意調查（實時查看）",
    "Could not set logging levels to show" : "無法設置記錄級別為「顯示」。",
    "Filter logging levels" : "過濾記錄層級",
    "Could not set logging level" : "無法設定紀錄層級",
    "Set backend loglevel" : "設定後端紀錄層級",
    "Application" : "應用程式",
    "Message" : "訊息",
    "Log entry actions" : "記錄條目操作",
    "Loading older log entries" : "舊記錄條目加載中",
    "No older log entries available" : "沒有較早的記錄條目可用。",
    "Collapse row" : "摺疊列",
    "Expand row" : "展開列",
    "Show details" : "顯示細節",
    "Debug" : "除錯",
    "Info" : "資訊",
    "Warning" : "警告",
    "Error" : "錯誤",
    "Fatal" : "致命",
    "Could not load log entries" : "無法載入紀錄檔條目",
    "Clipboard" : "剪貼板",
    "Could not parse clipboard content" : "無法解析剪貼簿內容",
    "Could not fetch new log entries (server unavailable)" : "無法獲取新的記錄條目（伺服器不可用）",
    "Could not fetch new entries" : "無法擷取新條目",
    "Could not copy to clipboard, please copy manually:" : "無法複製到剪貼板，請手動複製：",
    "\tfrom {address} by {user} at {time}\n" : "\t{user} 在 {time} 來自 {address}\n"
},
"nplurals=1; plural=0;");
