OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Cancel",
    "Delete" : "Eliminar",
    "Edit" : "Editar",
    "Unlimited" : "Ilimitado",
    "Name" : "Nombre",
    "Host" : "Servidor",
    "Enabled" : "Habilitado",
    "More information" : "Más información",
    "Remove" : "Eliminar",
    "Add" : "Agregar",
    "Confirm" : "Confirmar",
    "Save" : "Guardar",
    "Register" : "Registrar",
    "Update to {version}" : "Actualizar a {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visite el sitio web",
    "Report a bug" : "Reporte un tema",
    "User documentation" : "Documentación del usuario",
    "Admin documentation" : "Documentación del administrador",
    "Developer documentation" : "Documentación del desarrollador",
    "Supported" : "Soportado",
    "Featured" : "Destacado",
    "Icon" : "Ícono",
    "Version" : "Versión",
    "Level" : "Nivel",
    "Actions" : "Acciones",
    "Type" : "Escribir",
    "Display Name" : "Nombre a desplegar",
    "Your apps" : "Sus aplicaciones",
    "Documentation" : "Documentación",
    "Details" : "Detalles",
    "Changelog" : "Bitácora de cambios",
    "Active apps" : "Aplicaciones activas",
    "Disabled apps" : "Aplicaciones deshabilitadas",
    "Updates" : "Actualizaciones",
    "Featured apps" : "Aplicaciones destacadas",
    "Supported apps" : "Aplicaciones soportadas",
    "Deploy and Enable" : "Desplegar y habilitar",
    "Enable" : "Activar",
    "Disable" : "Deshabilitar",
    "Allow untested app" : "Permitir aplicación no probada",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continuás podrás instalar la aplicación, pero tené en cuenta que podría no funcionar según lo esperado.",
    "An error occurred during the request. Unable to proceed." : "Ocurrió un error durante la solicitud. No se puede continuar.",
    "The app has been enabled but needs to be updated." : "La aplicación ha sido habilitada pero necesita actualizarse.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: Esta aplicación no se puede habilitar porque genera inestabilidad en el servidor"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
