OC.L10N.register(
    "circles",
    {
    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
    "Open" : "ತೆರೆಯಿರಿ",
    "Password protected" : "ಗುಪ್ತಪದದಿಂದ ರಕ್ಷಿಸಲಾಗಿದೆ",
    "Local" : "ಸ್ಥಳೀಯ",
    "Federated" : "Federated",
    "Admin" : "﻿ನಿರ್ವಹಕ",
    "Owner" : "Owner",
    "Files" : "﻿ಕಡತಗಳು",
    "Name" : "﻿ಹೆಸರು",
    "Size" : "﻿ ಗಾತ್ರ",
    "Modified" : "﻿ಬದಲಾಯಿಸಿದ"
},
"nplurals=2; plural=(n > 1);");
