var b,v;function y(){if(v)return b;v=1;function f(i){const A=i.regex.either(...["(?:NeedsTeXFormat|RequirePackage|GetIdInfo)","Provides(?:Expl)?(?:Package|Class|File)","(?:DeclareOption|ProcessOptions)","(?:documentclass|usepackage|input|include)","makeat(?:letter|other)","ExplSyntax(?:On|Off)","(?:new|renew|provide)?command","(?:re)newenvironment","(?:New|Renew|Provide|Declare)(?:Expandable)?DocumentCommand","(?:New|Renew|Provide|Declare)DocumentEnvironment","(?:(?:e|g|x)?def|let)","(?:begin|end)","(?:part|chapter|(?:sub){0,2}section|(?:sub)?paragraph)","caption","(?:label|(?:eq|page|name)?ref|(?:paren|foot|super)?cite)","(?:alpha|beta|[Gg]amma|[Dd]elta|(?:var)?epsilon|zeta|eta|[Tt]heta|vartheta)","(?:iota|(?:var)?kappa|[Ll]ambda|mu|nu|[Xx]i|[Pp]i|varpi|(?:var)rho)","(?:[Ss]igma|varsigma|tau|[Uu]psilon|[Pp]hi|varphi|chi|[Pp]si|[Oo]mega)","(?:frac|sum|prod|lim|infty|times|sqrt|leq|geq|left|right|middle|[bB]igg?)","(?:[lr]angle|q?quad|[lcvdi]?dots|d?dot|hat|tilde|bar)"].map(e=>e+"(?![a-zA-Z@:_])")),_=new RegExp(["(?:__)?[a-zA-Z]{2,}_[a-zA-Z](?:_?[a-zA-Z])+:[a-zA-Z]*","[lgc]__?[a-zA-Z](?:_?[a-zA-Z])*_[a-zA-Z]{2,}","[qs]__?[a-zA-Z](?:_?[a-zA-Z])+","use(?:_i)?:[a-zA-Z]*","(?:else|fi|or):","(?:if|cs|exp):w","(?:hbox|vbox):n","::[a-zA-Z]_unbraced","::[a-zA-Z:]"].map(e=>e+"(?![a-zA-Z:_])").join("|")),z=[{begin:/[a-zA-Z@]+/},{begin:/[^a-zA-Z@]?/}],p=[{begin:/\^{6}[0-9a-f]{6}/},{begin:/\^{5}[0-9a-f]{5}/},{begin:/\^{4}[0-9a-f]{4}/},{begin:/\^{3}[0-9a-f]{3}/},{begin:/\^{2}[0-9a-f]{2}/},{begin:/\^{2}[\u0000-\u007f]/}],P={className:"keyword",begin:/\\/,relevance:0,contains:[{endsParent:!0,begin:A},{endsParent:!0,begin:_},{endsParent:!0,variants:p},{endsParent:!0,relevance:0,variants:z}]},Z={className:"params",relevance:0,begin:/#+\d?/},h={variants:p},x={className:"built_in",relevance:0,begin:/[$&^_]/},k={className:"meta",begin:/% ?!(T[eE]X|tex|BIB|bib)/,end:"$",relevance:10},w=i.COMMENT("%","$",{relevance:0}),c=[P,Z,h,x,k,w],d={begin:/\{/,end:/\}/,relevance:0,contains:["self",...c]},N=i.inherit(d,{relevance:0,endsParent:!0,contains:[d,...c]}),E={begin:/\[/,end:/\]/,endsParent:!0,relevance:0,contains:[d,...c]},u={begin:/\s+/,relevance:0},r=[N],g=[E],n=function(e,a){return{contains:[u],starts:{relevance:0,contains:e,starts:a}}},t=function(e,a){return{begin:"\\\\"+e+"(?![a-zA-Z@:_])",keywords:{$pattern:/\\[a-zA-Z]+/,keyword:"\\"+e},relevance:0,contains:[u],starts:a}},l=function(e,a){return i.inherit({begin:"\\\\begin(?=[ 	]*(\\r?\\n[ 	]*)?\\{"+e+"\\})",keywords:{$pattern:/\\[a-zA-Z]+/,keyword:"\\begin"},relevance:0},n(r,a))},m=(e="string")=>i.END_SAME_AS_BEGIN({className:e,begin:/(.|\r?\n)/,end:/(.|\r?\n)/,excludeBegin:!0,excludeEnd:!0,endsParent:!0}),o=function(e){return{className:"string",end:"(?=\\\\end\\{"+e+"\\})"}},s=(e="string")=>({relevance:0,begin:/\{/,starts:{endsParent:!0,contains:[{className:e,end:/(?=\})/,endsParent:!0,contains:[{begin:/\{/,end:/\}/,relevance:0,contains:["self"]}]}]}}),q=[...["verb","lstinline"].map(e=>t(e,{contains:[m()]})),t("mint",n(r,{contains:[m()]})),t("mintinline",n(r,{contains:[s(),m()]})),t("url",{contains:[s("link"),s("link")]}),t("hyperref",{contains:[s("link")]}),t("href",n(g,{contains:[s("link")]})),...[].concat(...["","\\*"].map(e=>[l("verbatim"+e,o("verbatim"+e)),l("filecontents"+e,n(r,o("filecontents"+e))),...["","B","L"].map(a=>l(a+"Verbatim"+e,n(g,o(a+"Verbatim"+e))))])),l("minted",n(g,n(r,o("minted"))))];return{name:"LaTeX",aliases:["tex"],contains:[...q,...c]}}return b=f,b}export{y as r};
//# sourceMappingURL=latex-CieJSPgB.chunk.mjs.map
