OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systemmerkelappen %1$s ble lagt til av systemet",
    "Added system tag {systemtag}" : "La til system-merkelapp {systemtag}",
    "Added system tag %1$s" : "La til system-merkelapp %1$s",
    "%1$s added system tag %2$s" : "%1$s  la til system-merkelapp %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la til system-merkelapp {systemtag}",
    "System tag %1$s removed by the system" : "Systemmerkelappen %1$s ble fjernet av systemet",
    "Removed system tag {systemtag}" : "Fjernet system-merkelapp {systemtag}",
    "Removed system tag %1$s" : "Fjernet system-merkelapp %1$s",
    "%1$s removed system tag %2$s" : "%1$s fjernet system-merkelapp %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjernet system-merkelapp {systemtag}",
    "You created system tag %1$s" : "Du opprettet system-merkelapp %1$s",
    "You created system tag {systemtag}" : "Du opprettet system-merkelapp {systemtag}",
    "%1$s created system tag %2$s" : "%1$s opprettet system-merkelapp %2$s",
    "{actor} created system tag {systemtag}" : "{actor} opprettet system-merkelapp {systemtag}",
    "You deleted system tag %1$s" : "Du slettet system-merkelapp %1$s",
    "You deleted system tag {systemtag}" : "Du slettet system-merkelapp {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s slettet system-merkelapp %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} slettet system-merkelapp {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du oppdaterte system-merkelapp %2$s til %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du oppdaterte system-merkelapp {oldsystemtag} til {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s oppdaterte system-merkelapp %3$s til %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} oppdaterte system-merkelapp {oldsystemtag} til {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systemmerkelappen %2$s ble lagt til %1$s av systemet",
    "System tag {systemtag} was added to {file} by the system" : "Systemmerkelappen {systemtag} ble lagt til {file} av systemet",
    "You added system tag %2$s to %1$s" : "Du la til system-merkelapp %2$s til %1$s",
    "You added system tag {systemtag} to {file}" : "Du la til system merkelapp {systemtag} til {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la til system-merkelapp %3$s til %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la til system-merkelapp {systemtag} til {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systemmerkelappen %2$s ble fjernet fra %1$s av systemet",
    "System tag {systemtag} was removed from {file} by the system" : "Systemmerkelappen {systemtag} ble fjernet fra {file} av systemet",
    "You removed system tag %2$s from %1$s" : "Du fjernet system-merkelapp %2$s fra %1$s",
    "You removed system tag {systemtag} from {file}" : "Du fjernet system-merkelapp {systemtag} fra {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjernet system-merkelapp %3$s fra %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjernet system-merkelapp {systemtag} fra {file}",
    "%s (restricted)" : "%s (begrenset)",
    "%s (invisible)" : "%s (usynlig)",
    "<strong>System tags</strong> for a file have been modified" : "Endringer av en fils <strong>System-merkelapper</strong>",
    "Files" : "Filer",
    "Tags" : "Merkelapper",
    "All tagged %s …" : "Alle merket med %s…",
    "tagged %s" : "merket %s",
    "Collaborative tags" : "Samarbeidsmerkelapper",
    "Collaborative tagging functionality which shares tags among people." : "Samarbeidsmerkelapp-funksjonalitet som deler merkelapper mellom brukere.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbeidsmerkelapp-funksjonalitet som deler merkelapper mellom brukere. Flott for team.\n\t(Hvis du er en leverandør med en installasjon av flere leieforhold, anbefales det å deaktivere denne appen ettersom merkelapper deles.)",
    "Public" : "Offentlig",
    "Restricted" : "Begrenset",
    "Invisible" : "Usynlig",
    "Created tag" : "Opprettet merkelapp",
    "Failed to create tag" : "Oppretting av merkelapp feilet",
    "Updated tag" : "Merkelapp oppdatert",
    "Failed to update tag" : "Oppdatering av merkelapp feilet",
    "Deleted tag" : "Slettet merkelappen",
    "Failed to delete tag" : "Sletting av merkelapp feilet",
    "Create or edit tags" : "Opprett eller rediger merkelapper",
    "Search for a tag to edit" : "Søk etter en merkelapp å redigere",
    "No tags to select" : "Ingen merkelapper å velge",
    "Tag name" : "Navn på merkelapp",
    "Tag level" : "Nivå på merkelapp",
    "Create" : "Opprett",
    "Update" : "Oppdater",
    "Delete" : "Slett",
    "Reset" : "Tilbakestill",
    "{displayName} (hidden)" : "{displayName} (skjult)",
    "{displayName} (restricted)" : "{displayName} (begrenset tilgang)",
    "Failed to apply tags changes" : "Kunne ikke utføre endring av merkelapper",
    "Manage tags" : "Håndtere etiketter",
    "Applying tags changes…" : "Utfører endring av merkelapper…",
    "Search or create tag" : "Søk etter eller opprett merkelapp",
    "Change tag color" : "Endre farge på merkelapp",
    "Create new tag" : "Opprett ny merkelapp",
    "Cancel" : "Avbryt",
    "Apply" : "Bruk",
    "Failed to load selected tags" : "Lasting av valgte merkelapper feilet",
    "Failed to load tags" : "Lasting av merkelapper feilet",
    "Failed to select tag" : "Utvelging av merkelapp feilet",
    "Search or create collaborative tags" : "Søk etter eller opprett samarbeidende merkelapper",
    "No tags to select, type to create a new tag" : "Ingen merkelapper å velge, skriv for å opprette en ny merkelapp",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbeidsmerkelapper er tilgjengelige for alle brukere. Begrensede merkelapper er synlige for brukere, men kan ikke tildeles av dem. Usynlige merkelapper er for intern bruk, siden brukere ikke kan se eller tildele dem.",
    "Add tags" : "Legg til merker",
    "Assigned collaborative tags" : "Tildelt samarbeidstagger",
    "Open in Files" : "Åpne i Filer",
    "List of tags and their associated files and folders." : "Liste over merkelapper og deres assosierte filer og mapper.",
    "No tags found" : "Fant ingen merkelapper",
    "Tags you have created will show up here." : "Merkelapper du har opprettet, vil vises her.",
    "Failed to load tag" : "Kunne ikke laste merkelapp",
    "Failed to load last used tags" : "Lasting av sist brukte merkelapper feilet",
    "Missing \"Content-Location\" header" : "Mangler \"Innhold-Plassering\"-overskrift",
    "A tag with the same name already exists" : "En merkelapp med det navnet finnes allerede",
    "Failed to load tags for file" : "Lasting av merkelapper for filen feilet",
    "Failed to set tag for file" : "Kunne ikke angi merkelapp for fil",
    "Failed to delete tag for file" : "Sletting av merkelappen for filen feilet",
    "Collaborative tags …" : "Samarbeidende merkelapper...",
    "Loading …" : "Laster ...",
    "Loading collaborative tags …" : "Laster samarbeidende merkelapper..."
},
"nplurals=2; plural=(n != 1);");
