<?php
/**
 * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
return array (
  'vixens.comreaper999mor098go' => true,
  '123456789123456789123456789' => true,
  '052600888211335577998866442' => true,
  'zzzzzzuui7122728892bbvvctyw' => true,
  'zb.cmrflove2401103250484254' => true,
  'z7785286snajperz5561229ilja' => true,
  'yuzhakovaburdukovskayaelena' => true,
  'ykamaruuchiha48151623422119' => true,
  'xrfkjdcrbqhfqjyysqcel620130' => true,
  'windows.programmer.graphics' => true,
  'windows.programmer.controls' => true,
  'windows.nt.admin.networking' => true,
  'williamtruongphihai25251325' => true,
  'whiekamariaholthe_subway_on' => true,
  'whateverprettycdaniinpurple' => true,
  'welcomee96c4be46d2be184a9d8' => true,
  'vetalbstobvv001100123456789' => true,
  'vetal19940207vetall19940207' => true,
  'untraditionalfairygodmother' => true,
  'uhbyztdflfhmzfyfnjkmtdyf999' => true,
  'tyler2alsitinuratikah_yusma' => true,
  'turya_korostylevnovikov@mai' => true,
  'trustno1something_unsertain' => true,
  'trustno1thesexygrimriper666' => true,
  'tiggerxbragin-evgeniy1982qw' => true,
  'thundersouthernprincess1982' => true,
  'thundershamelesscowgirl2001' => true,
  'thunderjannickdamkristensen' => true,
  'thomasmmuzhchinykakrezhimt9' => true,
  'thomasjackiechungchuen_chin' => true,
  'thauanasilvarodrigues030791' => true,
  'thalita92055198cardimgaspar' => true,
  'thalesdruumondcariellogomes' => true,
  'teodioandreamandythebillsfa' => true,
  'tdpossonaqueleqmimfortalece' => true,
  'tarasovaveronicaandreevna15' => true,
  'supermanxxdouglasmartinezxx' => true,
  'supermannick.vyacheslav2010' => true,
  'supermanfloridahasanova-dav' => true,
  'sunshineelectrician-anthony' => true,
  'summerpuertorican_mami_1717' => true,
  'steelerssushenko.anastasiya' => true,
  'steelersmarco_tu_amigo_2004' => true,
  'steelersjustasmalltownninja' => true,
  'steelersguillaumebeaumont83' => true,
  'steelerselenaaaaaaaaaaaaaaa' => true,
  'starwarsxusan.nuriddinov.89' => true,
  'starwarsxbudimirq-zav0780id' => true,
  'starwarsgaudy_mortification' => true,
  'stalker301198fordfusion2007' => true,
  'sh75640hgdkdflbgfhjk34u840t' => true,
  'service=jaassecuritymanager' => true,
  'service=invalidationmanager' => true,
  'seroburomalinoviyvtochechku' => true,
  'scooterisaac_figueroa_27_pr' => true,
  'scooterleavethehousetonight' => true,
  'sasat1991zooopa250118192021' => true,
  'samirsbilderssamirsbilders1' => true,
  'rusheini_dannettepianielsen' => true,
  'robertlestgets3xyforasecond' => true,
  'rjhjnftdfbhbyfcthuttdyf1994' => true,
  'rhbcnzdyfvbcnb1234567890poi' => true,
  'rfnfhsubyfdthekblptalarm666' => true,
  'rfkbybylvbnhbqfylhttdbx1989' => true,
  'rfhnjirfjxtymdrecysqzrhenjr' => true,
  'razermegaladonandcallofduty' => true,
  'rangerstheasswashingmachine' => true,
  'putaquepariuvaisefuderporra' => true,
  'pocerfacepocerfacepocerface' => true,
  'pitpit06078684oozuh40pitpit' => true,
  'pepperzsizyy_nikandrhx1980v' => true,
  'passworexploding_monkeyface' => true,
  'passwordminkqwertygghhxdlol' => true,
  'password1williammcclendon20' => true,
  'password1canadianstudmuffin' => true,
  'password1kreamyhotchocolate' => true,
  'palnovachinovnikova22071985' => true,
  'nick54312345678900987654321' => true,
  'nfhfyjdftktyfdfcbkmtdyfvfvf' => true,
  'mustangv.zemlemerov.samsung' => true,
  'mtwildthrisolanoelizabeth82' => true,
  'monkeyandyreidsneglectedson' => true,
  'money1daniccapotosti.monica' => true,
  'michellewizuraialtamirano69' => true,
  'michaelusemyono-gleba1984da' => true,
  'michaelmohanrsmesh123ramesh' => true,
  'michaelelnaro4ka_balatukova' => true,
  'mexikanischespermaschleuder' => true,
  'merlinyourelectronicsoutlet' => true,
  'merlinadadadadaad-adadadada' => true,
  'mercedesomiralyev.zhangeldi' => true,
  'mercedesmmmmquietchild_4eva' => true,
  'maxalexmasjan130997420092x2' => true,
  'maverickrickrocksjanine2765' => true,
  'matthewbrian_beerman_miller' => true,
  'matrix70ithink!!savedtodisk' => true,
  'mastermarcio_corinthians_10' => true,
  'martinumaysaka-margar1982nw' => true,
  'mariaguadalupedeguadalajara' => true,
  'marchmarczildjian_zildjian7' => true,
  'makcemka5178982.1996.11.06.' => true,
  'lxgiwyl0234467asnaebhesoyam' => true,
  'londonthefabulousthelmatodd' => true,
  'ligostaefligostaefligostaef' => true,
  'lfybclbvfhbvvfhbvvfkbkzkbkz' => true,
  'lezartsurbainsxc3xa0xc3xa0&' => true,
  'letmeinaljaidi_91generation' => true,
  'kolobokpetkinvagner21061994' => true,
  'killerplacanicaversoleuropa' => true,
  'kfrom-f66b1a.21012313022004' => true,
  'kartoshkakartoshkakarchenko' => true,
  'karimovruslanaleksandrovich' => true,
  'kanev575318989nikita3742385' => true,
  'kaiquelindoecezar.oliviaper' => true,
  'jordanushulga.alyonkat1985o' => true,
  'jordanskorab-svyatosl1981kw' => true,
  'jon2x0919926875709535486250' => true,
  'jfdghfh3cbsdh4365rtygwey374' => true,
  'jfawoidfjjfawoidfjjfawoidfj' => true,
  'jeevesthorbovanspinningwill' => true,
  'jacksonsergiocarlos.caverna' => true,
  'jacksonjacckkssonkkoonnccee' => true,
  'is_gay_trojan_skript_kiddie' => true,
  'ilovslave666yashwantrana991' => true,
  'iloveyoup_i_t_e_r_m_a_r_i_y' => true,
  'iloveyouguzeliya_mahiyanova' => true,
  'ifyouliveforever89312026280' => true,
  'idontrememberitisstoredinpc' => true,
  'hockeypayasita_enamorada_20' => true,
  'hockeylifeissupposedtobefun' => true,
  'hesoyamaezakmiyecgaacoxefgu' => true,
  'harleysexymariposaencantada' => true,
  'guitarmuhammad.ubaydulozoda' => true,
  'guitarkazodoon_alfrahmun_12' => true,
  'guitardevil_johnconstantine' => true,
  'golfercharlie2884charlieuni' => true,
  'ghjdfktyrjnfvfhfvtktynbbdyf' => true,
  'ghbdt453mdke7385alfjnd394hd' => true,
  'georgewbylink-matryon1980oq' => true,
  'georgethe1st_pimpofglenn_10' => true,
  'georgeanishhenko.konstantin' => true,
  'genesis5353teamelitecontrol' => true,
  'gannoverragnariok2012masson' => true,
  'fusionstyleprofissional1017' => true,
  'fuckyouslobozhaninov-al1989' => true,
  'fuckyouallmotherfuckerdeath' => true,
  'fuckyoushittyshittybangbang' => true,
  'froget3778319415620limits18' => true,
  'fortalezajuntoemisturado100' => true,
  'footballrichardbranscum1957' => true,
  'footballmohamed_mohamed5209' => true,
  'footballcharlesemmanuelidis' => true,
  'footballbchernyh_sash1986.v' => true,
  'fktrctqdkflbvbhjdbx23031982' => true,
  'ferraritwistedfirestarter89' => true,
  'ferrariprettygorgeousbeauty' => true,
  'felipetrizotipiantini121097' => true,
  'familienkrankenversicherung' => true,
  'faleot123456789358789456123' => true,
  'escapethefate7028735pursuit' => true,
  'elgatosheamrichardrodriguez' => true,
  'eaglesprodamkvartryvgorodee' => true,
  'dungeon.commakeksa11keksa12' => true,
  'djexquisiteprodance21011993' => true,
  'dilok18091990ok1234567890ok' => true,
  'cvthnmbckfvbcnfvbcfnfybcnfv' => true,
  'cubanoamericanoesoutocubano' => true,
  'crafty4489082481019crafty44' => true,
  'cowboystente.alcansar.o.ceu' => true,
  'cossy2009cvikram_9885787371' => true,
  'corvettelunazul_celeste1982' => true,
  'corvettegoodboybadboy.sinha' => true,
  'computerkaylapaigemccann212' => true,
  'computerim_urs_4ever_alwayz' => true,
  'computerdiscerninggentleman' => true,
  'chuchito16teamoerestodopami' => true,
  'christtophersabrinasamantha' => true,
  'chickenthe-heavenly-panther' => true,
  'chickenbshantelleveroniquen' => true,
  'cherrytamayo022409297275238' => true,
  'charlielittletortillaboy007' => true,
  'changed031220021auraofakind' => true,
  'catolico7apostolico7romano7' => true,
  'camila22k877443901333142964' => true,
  'bustertvojmarschrut.evgenya' => true,
  'bigdogtgonch.anechkask1988b' => true,
  'baxsuper911rusikpas8712logo' => true,
  'baseballshailuwaitingforyou' => true,
  'baseballjohnstorm38-general' => true,
  'assholesurfingdaverosenberg' => true,
  'assholeshaggy_legend_killer' => true,
  'assholecheezedouglasw904ria' => true,
  'asdfghshinysquirtlesqaud123' => true,
  'asd456fghasd123jklasdfgh789' => true,
  'aryadnnasalles300897sempreu' => true,
  'areenarouch123myswtfrn@mang' => true,
  'anthonysirrobinthenotsobrav' => true,
  'anthonymarcos_mastertecnica' => true,
  'anthonyextremegamingcompany' => true,
  'andreafschep.fedosiyro1980k' => true,
  'amominhafamilia157155666222' => true,
  'amateurhackershavetinydicks' => true,
  'amandaraksako.velimir1988cl' => true,
  'amandafstrelko.ilonapg1988h' => true,
  'altynay.zholdoshbaykyzy1993' => true,
  'alizeeloveveronicaaa5532012' => true,
  'alice99610369rayssa91967116' => true,
  'alexseieresko123nemesis!1@2' => true,
  'adamyankirill11091997423651' => true,
  'accesschicago141chicago9033' => true,
  'abyfycsbrhtlbnbeg2015abudfv' => true,
  'taobietbb4everlacuataoday!!' => true,
  'lilbb1leretour2labassefolle' => true,
  'jenniferlopez02058600qscvbg' => true,
  'ilustilyhadthemostcountless' => true,
  'ga7bal8bri4la9el5re1li6ma23' => true,
  'alolexfor10kerbyy110228fate' => true,
  'allasaktaanamdy180859!aiman' => true,
  '@luizfelipedovalenascimento' => true,
  '??n???n???????n???123456789' => true,
  '9619836847katyushka_ryzhova' => true,
  '939144537045166134540nastya' => true,
  '911gxnnx8339kkdldd090338e8e' => true,
  '89128611692r5kru89121560500' => true,
  '8771172545521079490740damir' => true,
  '80964032815solia80964032815' => true,
  '77777777777777777777777777q' => true,
  '5g6dh9aj3hf1ng2qd7dh8w1hfp4' => true,
  '56767tgfgjhhjlku87786564545' => true,
  '52501charleighandreaskilton' => true,
  '50.412.1835.1885.2008-05-11' => true,
  '4tu8034yt34gf348gf348g34803' => true,
  '4435782010121520221992anton' => true,
  '41526380228777ctyz412539dom' => true,
  '35863544thaynaamichedocarmo' => true,
  '318180160199317093154176zxy' => true,
  '303madrib254850057553032548' => true,
  '253421175328335532254edward' => true,
  '210385deyler_iglesias_river' => true,
  '1qa2ws3ed4rf5tg6yh7uj8ik9ol' => true,
  '1q2a3w4s5e6d352052040159118' => true,
  '19851113.19851113.19851113.' => true,
  '190608dilusik170809adilusik' => true,
  '1892youllneverwalkalone1892' => true,
  '17111965dctpfvtxfntkmyj2706' => true,
  '1597537urizel66689512024233' => true,
  '15888666312798579613574632q' => true,
  '15282422timur.shigabutdinov' => true,
  '124816326412825651210242048' => true,
  '123661borinquena_prettygurl' => true,
  '1234gfgfvfvfdflbvktyfhjlbyf' => true,
  '123456789987654321lfhbyjxrf' => true,
  '123123say.stationmaster.die' => true,
  '123123qschastl.nadyawk1980r' => true,
  '123123kklimova.lianabb1981d' => true,
  '119zakirov339rep1990sh22bnm' => true,
  '111111genius.counter-strike' => true,
  '0925467e1cyou_are_mytruelov' => true,
  '08062009leonidkerch10061990' => true,
  '0802198614051991natalipavel' => true,
  '0752613prettyapril_butterfl' => true,
  '05995794881234567891200lana' => true,
  '011209250990130164ksudenlen' => true,
  '0101111478711sanya478711223' => true,
  '*396540olya.ylyana.6963801*' => true,
  '%e2%82%ac%e2%82%ac%e2%82%ac' => true,
);