.folder[data-v-74f30535]{display:flex;gap:16px;min-width:300px}.folder__info[data-v-74f30535]{display:flex;flex-direction:column;flex-grow:1;justify-content:center}.folder__path[data-v-74f30535]{font-weight:700}.photos-locations__title[data-v-55d997fb]{padding-inline-start:12px;font-weight:700}.photos-locations__description[data-v-55d997fb]{padding-inline-start:12px;color:var(--color-text-lighter)}.photos-locations__list[data-v-55d997fb]{padding-inline-start:12px;margin:16px 0}.photos-locations__list li[data-v-55d997fb]{list-style:none}
