OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "Wiederhergestellt",
    "Deleted files" : "Gelöschte Dateien",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Gelöschte Dateien und Ordner im Papierkorb (können während des Exports ablaufen, wenn der Speicherplatz knapp wird)",
    "This application enables people to restore files that were deleted from the system." : "Diese Anwendung ermöglicht es Personen, Dateien wiederherzustellen, die vom System gelöscht wurden.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Diese Anwendung ermöglicht es Personen, Dateien wiederherzustellen, die aus dem System gelöscht wurden. Es zeigt eine Liste der gelöschten Dateien in der Web-Oberfläche an und bietet die Möglichkeit, diese gelöschten Dateien in die Verzeichnisse der Personen wiederherzustellen oder sie dauerhaft aus dem System zu entfernen. Beim Wiederherstellen einer Datei werden auch die zugehörigen Dateiversionen wiederhergestellt, sofern die Versionsanwendung aktiviert ist. Wenn eine Datei aus einer Freigabe gelöscht wird, kann sie auf dem gleichen Weg wiederhergestellt werden, ist jedoch nicht mehr geteilt. Standardmäßig verbleiben gelöschte Dateien 30 Tage lang im Papierkorb.\nUm zu verhindern, dass einem Konto der Speicherplatz ausgeht, nutzt die Anwendung für gelöschte Dateien maximal 50 % des aktuell verfügbaren freien Kontingents. Wenn die gelöschten Dateien dieses Limit überschreiten, löscht die Anwendung die ältesten Dateien, bis sie unter dieses Limit fällt. Weitere Informationen findest du in der Dokumentation zu gelöschten Dateien.",
    "Restore" : "Wiederherstellen",
    "Not enough free space to restore the file/folder" : "Nicht genügend freier Speicherplatz zum Wiederherstellen der Datei/des Ordners",
    "Empty deleted files" : "Gelöschte Dateien leeren",
    "Confirm permanent deletion" : "Endgültiges Löschen bestätigen",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Möchtest du wirklich alle Dateien und Ordner im Papierkorb endgültig löschen? Dies kann nicht rückgängig gemacht werden.",
    "Cancel" : "Abbrechen",
    "Original location" : "Ursprünglicher Ort",
    "Deleted by" : "Gelöscht von",
    "Deleted" : "Gelöscht",
    "few seconds ago" : "Gerade eben",
    "A long time ago" : "Vor langer Zeit",
    "Unknown" : "Unbekannt",
    "All files" : "Alle Dateien",
    "You" : "Dir",
    "List of files that have been deleted." : "Liste der gelöschten Dateien.",
    "No deleted files" : "Keine gelöschten Dateien",
    "Files and folders you have deleted will show up here" : "Die von dir gelöschten Dateien und Ordner werden hier angezeigt",
    "All files have been permanently deleted" : "Alle Dateien wurden dauerhaft gelöscht",
    "Failed to empty deleted files" : "Gelöschte Dateien konnten nicht geleert werden"
},
"nplurals=2; plural=(n != 1);");
