OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Wachtwoord verlopen, gebruik 'wachtwoord vergeten' om te herstellen",
    "Password must not have been used recently before." : "Wachtwoord mag niet al eerder gebruikt zijn",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Het wachtwoord behoort tot de 1.000.000 meest gebruikte wachtwoorden. Maak het meer uniek.",
    "Password is present in compromised password list. Please choose a different password." : "Het wachtwoord is aanwezig in de lijst met gecompromitteerde wachtwoorden. Kies een ander.",
    "Password needs to be at least %s characters long." : "Het wachtwoord moet minimaal %s tekens lang zijn.",
    "Password needs to contain at least one numeric character." : "Het wachtwoord moet minimaal één cijfer bevatten.",
    "Password needs to contain at least one special character." : "Het wachtwoord moet minimaal één speciaal teken bevatten.",
    "Password needs to contain at least one lower and one upper case character." : "Het wachtwoord moet minimaal één kleine letter en één hoofdletter bevatten.",
    "Password policy" : "Wachtwoordenbeleid",
    "Allows admins to configure a password policy" : "Staat toe dat beheerders een wachtwoordenbeleid configureren",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Sta beheerder toe om bepaalde randvoorwaarden te definiëren voor het wachtwoord, zoals bijv. minimum wachtwoordlengte",
    "General password policies" : "Algemeen wachtwoordbeleid",
    "Add policy set" : "Beleidsgroep toevoegen",
    "Login policies" : "Loginbeleid",
    "Password history size" : "Grootte van wachtwoordgeschiedenis",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Aantal wachtwoorden dat moet worden bewaard (beveiligd gehasht) om te voorkomen dat gebruikers eerder gebruikte wachtwoorden hergebruiken.",
    "Maximum login attempts" : "Maximale inlogpogingen",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Aantal inlogpogingen voordat het gebruikersaccount wordt geblokkeerd totdat handmatige actie wordt ondernomen. (0 voor onbeperkt)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Let op, deze optie is bedoeld om aangevallen accounts te beschermen. Uitgeschakelde accounts moeten handmatig opnieuw worden ingeschakeld door de beheerder. Wanneer aanvallers wachtwoorden van accounts proberen te raden, wordt hun IP-adres geblokkeerd door de bruteforce-beveiliging, onafhankelijk van deze instelling.",
    "Number of days until user password expires" : "Aantal dagen tot het wachtwoord van de gebruiker verloopt",
    "Password expiration" : "Geldigheid van wachtwoord",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Waarschuwing: inschakelen wachtwoordvervalbeleid wordt tegenwoordig door meerder veiligeheidsinstellingen gezien als een beveligingsrisico.",
    "Remove policy" : "Beleid verwijderen",
    "Minimum password length" : "Minimale wachtwoordsterkte",
    "Forbid common passwords" : "Algemene wachtwoorden verbieden",
    "Enforce upper and lower case characters" : "Hoofdletters en kleine letters verplichten",
    "Enforce numeric characters" : "Cijfers verplichten",
    "Enforce special characters" : "Speciale tekens verplichten",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Controleer het wachtwoord met de lijst van gelekte wachtwoorden van haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Deze controle maakt een hash van het wachtwoord en verstuurd de eerste 5 tekens van deze hash naar de haveibeenpwned.com API om een lijst op te halen met al de hashes die ook daarmee beginnen. Daarna wordt deze lijst tegen de Nexcloud installatie gehouden om te controleren of de wachtwoord hash als resultaat terugkomt.",
    "Account password policies" : "Accountwachtwoordenbeleid",
    "Share password policies" : "Wachtwoordbeleid delen"
},
"nplurals=2; plural=(n != 1);");
