import{g as l}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as f}from"./prolog-CXI90EJ8.chunk.mjs";function c(e,a){for(var n=0;n<a.length;n++){const r=a[n];if(typeof r!="string"&&!Array.isArray(r)){for(const t in r)if(t!=="default"&&!(t in e)){const o=Object.getOwnPropertyDescriptor(r,t);o&&Object.defineProperty(e,t,o.get?o:{enumerable:!0,get:()=>r[t]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var i,g;function p(){if(g)return i;g=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/prolog" instead of "highlight.js/lib/languages/prolog.js"'))}return e(),i=f(),i}var s=p();const u=l(s),j=c({__proto__:null,default:u},[s]);export{j as p};
//# sourceMappingURL=prolog.js-BrEdGWFz.chunk.mjs.map
