OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Brute-force settings",
    "Whitelist IPs" : "Whitelist IPs",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address.",
    "The comment cannot exceed {max} characters." : "The comment cannot exceed {max} characters.",
    "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed." : "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms." : "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms.",
    "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection." : "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled." : "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled.",
    "Failed to add the IP address to the allow list." : "Failed to add the IP address to the allow list.",
    "Failed to save the rate limit setting." : "Failed to save the rate limit setting.",
    "Failed to update the allow list entry." : "Failed to update the allow list entry.",
    "Brute-force allow list" : "Brute-force allow list",
    "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all." : "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all.",
    "Bypass rate limiting for allowed IPs" : "Bypass rate limiting for allowed IPs",
    "Add new IP address" : "Add new IP address",
    "IP address" : "IP address",
    "Mask" : "Mask",
    "Comment" : "Comment",
    "Add" : "Add",
    "Edit comment for {subnet}" : "Edit comment for {subnet}",
    "Save" : "Save",
    "Delete entry for {subnet}" : "Delete entry for {subnet}",
    "Comment cannot exceed {max} characters." : "Comment cannot exceed {max} characters.",
    "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed." : "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed.",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment.",
    "There was an error adding the IP to the allow list." : "There was an error adding the IP to the allow list.",
    "There was an error updating the allow list entry." : "There was an error updating the allow list entry."
},
"nplurals=2; plural=(n != 1);");
