OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Jõuründe piiramise meetmete seadistused",
    "Whitelist IPs" : "Lubatud IP-aadressid",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "Jõuründe vastane kaitse on mõeldud kaitsmaks Nextcloudi serverit ja tema kasutajaid katsete eest eri viisidel ära aimata kasutajate salasõnu. Lisaks tavapärasele „*proovime läbi kõik hiidpika salasõnade loendi kirjed*“ tüüpi rünnakule, aitab see kaitse ka keerukamate rünnakute vastu, kus proovitakse salasõnu lähtestada või otsida rakenduste tunnuslube.\n\nKui jõuründe vastane kaitse käivitub, siis antud IP-aadressilt laekunud päringute puhul kasutatakse 24-tunni jooksul viivitamist päringutele vastamisel.\n\nSelle rakendusega saab peakasutaja lisada IP-aadresse või nende vahemikke lubatud aadresside loendisse, mille puhul kaitsemeetmed ei kehti. Sellest on kasu testimisel või liigsete valepositiivsete käivitumiste korral (palju tegelikke kasutajaid ühelt aadressilt).",
    "The comment cannot exceed {max} characters." : "Kommentaar ei või olla pikem, kui {max} tähemärki.",
    "Leave an internal comment explaining why this IP address is allowed, for example its location, so the entry can be removed when it is no longer needed." : "Lisa sisemiseks kasutusel mõeldud kommentaar, miks selle IP-aadressi puhul kaitsemeetmed ei kehti. Selleks võib olla asukoht või muud selgelt arusaadavat, mille alusel saab ta hiljem hõlpsasti eemaldada.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is currently throttled. Current delay: {delay} ms." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel jõuründe piiramise aeglustusmeetmena kasutusel {delay}-millisekundiline viivitus päringutele vastamisel.",
    "Your current IP address is detected as \"{remoteAddress}\". This address bypasses brute-force protection." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle aadressi puhul hetkel ei kehti jõuründe piiramise meetmed.",
    "Your current IP address is detected as \"{remoteAddress}\". This address is not currently throttled." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul hetkel ei kasutata jõuründe piiramise meetmena päringute viivitamist.",
    "Failed to add the IP address to the allow list." : "IP-aadressi lisamine lubatud aadresside loendisse ei õnnestunud.",
    "Failed to save the rate limit setting." : "Päringute viivitamise seadistuste salvestamine ei õnnestunud",
    "Failed to update the allow list entry." : "Lubatud loendi kirje uuendamine ei õnnestunud.",
    "Brute-force allow list" : "Lubatud IP-aadresside loend, kus jõuründe piiramise meetmed ei kehti",
    "To exclude IP ranges from the brute-force protection specify them below. Note that any allowed IP can perform authentication attempts without any throttling. For security reasons, it is recommended to list as few remote addresses as possible or ideally even none at all." : "Välistamaks konkreetseid IP-aadressivahemikke jõuründe piiramise meetmete alt, saad nad sisestada siia. Palun arvesta, et kõikidelt siia loendisse lisatud aadressidelt on võimalik teha autentimispäringuid piiramata arvus ja viisil. Turvakaalutlustel palun hoia see loend võimalikult napina või ideaalis sootuks tühjana.",
    "Bypass rate limiting for allowed IPs" : "Lubatud IP-aadressid, mille puhul kaitsemeetmed ei kehti.",
    "Add new IP address" : "Lisa uus IP-aadress",
    "IP address" : "IP-address",
    "Mask" : "Võrgumask",
    "Comment" : "Kommentaar",
    "Add" : "Lisa",
    "Edit comment for {subnet}" : "Muuda „{subnet}“ alamvõrgu kommentaari",
    "Save" : "Salvesta",
    "Delete entry for {subnet}" : "Kustuta „{subnet}“ kirje",
    "Comment cannot exceed {max} characters." : "Kommentaar ei või olla pikem, kui {max} tähemärki",
    "Leave an internal comment, why this IP is allowed, e.g. the  location, so it can be revoked, when it is no longer needed." : "Lisa sisemiseks kasutusel mõeldud kommentaar, miks selle IP-aadressi puhul kaitsemeetmed ei kehti. Selleks võib olla asukoht või muud selgelt arusaadavat, mille alusel saab ta hiljem hõlpsasti eemaldada.",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel jõuründe piiramise aeglustusmeetmena kasutusel {delay}-millisekundiline viivitus.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul hetkel ei kehti jõuründe piiramise meetmed.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul hetkel ei kasutata jõuründe piiramise meetmena päringute viivitamist.",
    "There was an error adding the IP to the allow list." : "IP-aadressi lisamisel lubatud aadresside loendisse tekkis viga.",
    "There was an error updating the allow list entry." : "Lubatud kirjete loendi kirje uuendamise tekkis viga."
},
"nplurals=2; plural=(n != 1);");
