OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendário",
    "Tasks" : "Tarefas",
    "Personal" : "Pessoal",
    "{actor} created calendar {calendar}" : "{actor} criou o calendário {calendar}",
    "You created calendar {calendar}" : "Você criou o calendário {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} excluiu o calendário {calendar}",
    "You deleted calendar {calendar}" : "Você excluiu o calendário {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atualizou o calendário {calendar}",
    "You updated calendar {calendar}" : "Você atualizou o calendário {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} restaurou o calendário {calendar}",
    "You restored calendar {calendar}" : "Você restaurou o calendário {calendar}",
    "You shared calendar {calendar} as public link" : "Você compartilhou o calendário {calendar} como um link público",
    "You removed public link for calendar {calendar}" : "Você removeu o link público para o calendário {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} compartilhou o calendário  {calendar} com você",
    "You shared calendar {calendar} with {user}" : "Você compartilhou o calendário {calendar} com {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} descompartilhou o calendário {calendar} com você",
    "You unshared calendar {calendar} from {user}" : "Você descompartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} descompartilhou o calendário {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} descompartilhou o calendário {calendar} deles mesmos",
    "You shared calendar {calendar} with group {group}" : "Você compartilhou o calendário {calendar} com o grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartilhou o calendário {calendar} com o grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Você descompartilhou o calendário {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} descompartilhou o calendário {calendar} do grupo {group}",
    "Untitled event" : "Evento sem título",
    "{actor} created event {event} in calendar {calendar}" : "{actor} criou o evento {event} no calendário {calendar}",
    "You created event {event} in calendar {calendar}" : "Você criou o evento {event} no calendário {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} excluiu o evento {event} do calendário {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Você excluiu o evento {event} do calendário {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} atualizou o evento {event} no calendário {calendar}",
    "You updated event {event} in calendar {calendar}" : "Você atualizou o evento {event} no calendário {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moveu o evento {event} do calendário {sourceCalendar} para o calendário {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Você moveu o evento {event} do calendário {sourceCalendar} para o calendário {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {event} do calendário {calendar}",
    "You restored event {event} of calendar {calendar}" : "Você restaurou o evento {event} do calendário {calendar}",
    "Busy" : "Ocupado",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} criou a tarefa {todo} na lista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} resolveu a tarefa {todo} na lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Você resolveu a tarefa {todo} na lista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reabriu a tarefa {todo} na lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Você reabriu a tarefa {todo} na lista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} moveu a tarefa {todo} da lista {sourceCalendar} para a lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Você moveu a tarefa {todo} da lista {sourceCalendar} para a lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendário, contatos e tarefas",
    "A <strong>calendar</strong> was modified" : "Um <strong>calendário</strong> foi modificado",
    "A calendar <strong>event</strong> was modified" : "Um <strong>evento</strong> de calendário foi modificado",
    "A calendar <strong>to-do</strong> was modified" : "Uma <strong>tarefa</strong> de calendário foi modificada",
    "Contact birthdays" : "Aniversário dos contatos",
    "Death of %s" : "Morte de %s",
    "Untitled calendar" : "Calendário sem título",
    "Calendar:" : "Calendário:",
    "Date:" : "Data:",
    "Where:" : "Onde:",
    "Description:" : "Descrição:",
    "_%n year_::_%n years_" : ["%n ano","%n anos","%n anos"],
    "_%n month_::_%n months_" : ["%n mês","%n meses","%n meses"],
    "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
    "%s (in %s)" : "%s (em %s)",
    "%s (%s ago)" : "%s (%s atrás)",
    "Calendar: %s" : "Calendário: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrição: %s",
    "Where: %s" : "Onde: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "In the past on %1$s for the entire day" : "No passado em %1$s para o dia inteiro",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Em %n minuto em %1$s para o dia inteiro","Em %n de minutos em %1$s para o dia inteiro","Em %n minutos em %1$s para o dia inteiro"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Em %n hora em %1$s para o dia inteiro","Em %n de horas em %1$s para o dia inteiro","Em %n horas em %1$s para o dia inteiro"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Em %n dia em %1$s para o dia inteiro","Em %n de dias em %1$s para o dia inteiro","Em %n dias em %1$s para o dia inteiro"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Em %n semana em %1$s para o dia inteiro","Em %n de semanas em %1$s para o dia inteiro","Em %n semanas em %1$s para o dia inteiro"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Em %n mês em %1$s para o dia inteiro","Em %n de meses em %1$s para o dia inteiro","Em %n meses em %1$s para o dia inteiro"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Em %n ano em %1$s para o dia inteiro","Em %n de anos em %1$s para o dia inteiro","Em %n anos em %1$s para o dia inteiro"],
    "In the past on %1$s between %2$s - %3$s" : "No passado em %1$s entre %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Em %n minuto em %1$s entre %2$s e %3$s","Em %n de minutos em %1$s entre %2$s e %3$s","Em %n minutos em %1$s entre %2$s e %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Em %n hora em %1$s entre %2$s e %3$s","Em %n de horas em %1$s entre %2$s e %3$s","Em %n horas em %1$s entre %2$s e %3$s"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Em %n dia em %1$s entre %2$s e %3$s","Em %n de dias em %1$s entre %2$s e %3$s","Em %n dias em %1$s entre %2$s e %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Em %n semana em %1$s entre %2$s e %3$s","Em %n de semanas em %1$s entre %2$s e %3$s","Em %n semanas em %1$s entre %2$s e %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Em %n mês em %1$s entre %2$s e %3$s","Em %n de meses em %1$s entre %2$s e %3$s","Em %n meses em %1$s entre %2$s e %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Em %n ano em %1$s entre %2$s e %3$s","Em %n de anos em %1$s entre %2$s e %3$s","Em %n anos em %1$s entre %2$s e %3$s"],
    "Could not generate when statement" : "Não foi possível gerar a indicação sobre quando",
    "Every Day for the entire day" : "Todo Dia durante o dia inteiro",
    "Every Day for the entire day until %1$s" : "Todo Dia para o dia inteiro até %1$s",
    "Every Day between %1$s - %2$s" : "Todo Dia entre %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Todo Dia entre %1$s - %2$s até %3$s",
    "Every %1$d Days for the entire day" : "A Cada %1$d Dias para o dia inteiro",
    "Every %1$d Days for the entire day until %2$s" : "A Cada %1$d Dias para o dia inteiro até %2$s",
    "Every %1$d Days between %2$s - %3$s" : "A Cada %1$d Dias entre %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "A Cada %1$d Dias entre %2$s - %3$s até %4$s",
    "Could not generate event recurrence statement" : "Não foi possível gerar a indicação de recorrência do evento",
    "Every Week on %1$s for the entire day" : "Toda Semana, %1$s para o dia inteiro",
    "Every Week on %1$s for the entire day until %2$s" : "Toda Semana, %1$s para o dia inteiro até %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Toda Semana, %1$s entre %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Toda Semana, %1$s entre %2$s - %3$s até %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "A Cada %1$d Semanas, %2$s para o dia inteiro",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "A Cada %1$d Semanas, %2$s para o dia inteiro até %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "A Cada %1$d Semanas, %2$s entre %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "A Cada %1$d Semanas, %2$s entre %3$s - %4$s até %5$s",
    "Every Month on the %1$s for the entire day" : "Todo Mês, dia: %1$s, para o dia inteiro",
    "Every Month on the %1$s for the entire day until %2$s" : "Todo Mês, dia: %1$s, para o dia inteiro até %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Todo Mês, dia: %1$s, entre %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Todo Mês, dia: %1$s, entre %2$s - %3$s até %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "A Cada %1$d Meses, dia: %2$s, para o dia inteiro",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "A Cada %1$d Meses, dia: %2$s, para o dia inteiro até %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "A Cada %1$d Meses, dia: %2$s, entre %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "A Cada %1$d Meses, dia: %2$s, entre %3$s - %4$s até %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Todo Ano em %1$s, dia: %2$s, para o dia inteiro",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Todo Ano em %1$s, dia: %2$s, para o dia inteiro até %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Todo Ano em %1$s, dia: %2$s, entre %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Todo Ano em %1$s, dia: %2$s, entre %3$s - %4$s até %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "A Cada %1$d Anos em %2$s, dia: %3$s, para o dia inteiro",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "A Cada %1$d Anos em %2$s, dia: %3$s, para o dia inteiro até %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "A Cada %1$d Anos em %2$s, dia: %3$s, entre %4$s - %5$s ",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "A Cada %1$d Anos em %2$s, dia: %3$s, entre %4$s - %5$s até %6$s",
    "On specific dates for the entire day until %1$s" : "Em datas específicas para o dia inteiro até %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "Em datas específicas entre %1$s - %2$s até %3$s",
    "In the past on %1$s" : "No passado em %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["Em %n minuto em %1$s","Em %n de minutos em %1$s","Em %n minutos em %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["Em %n hora em %1$s","Em %n de horas em %1$s","Em %n horas em %1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["Em %n dia em %1$s","Em %n de dias em %1$s","Em %n dias em %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["Em %n semana em %1$s","Em %n de semanas em %1$s","Em %n semanas em %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["Em %n mês em %1$s","Em %n de meses em %1$s","Em %n meses em %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["Em %n ano em %1$s","Em %n de anos em %1$s","Em %n anos em %1$s"],
    "In the past on %1$s then on %2$s" : "No passado em %1$s e depois em %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Em %n minuto em %1$s e depois em %2$s","Em %n de minutos em %1$s e depois em %2$s","Em %n minutos em %1$s e depois em %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Em %n hora em %1$s e depois em %2$s","Em %n de horas em %1$s e depois em %2$s","Em %n horas em %1$s e depois em %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Em %n dia em %1$s e depois em %2$s","Em %n de dias em %1$s e depois em %2$s","Em %n dias em %1$s e depois em %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Em %n semana em %1$s e depois em %2$s","Em %n de semanas em %1$s e depois em %2$s","Em %n semanas em %1$s e depois em %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Em %n mês em %1$s e depois em %2$s","Em %n de meses em %1$s e depois em %2$s","Em %n meses em %1$s e depois em %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Em %n ano em %1$s e depois em %2$s","Em %n de anos em %1$s e depois em %2$s","Em %n anos em %1$s e depois em %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "No passado em %1$s e depois em %2$s e %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Em %n minuto e %1$s e depois em %2$s e %3$s","Em %n de minutos e %1$s e depois em %2$s e %3$s","Em %n minutos e %1$s e depois em %2$s e %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Em %n hora e %1$s e depois em %2$s e %3$s","Em %n de horas e %1$s e depois em %2$s e %3$s","Em %n horas e %1$s e depois em %2$s e %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Em %n dia e %1$s e depois em %2$s e %3$s","Em %n de dias e %1$s e depois em %2$s e %3$s","Em %n dias e %1$s e depois em %2$s e %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Em %n semana e %1$s e depois em %2$s e %3$s","Em %n de semanas e %1$s e depois em %2$s e %3$s","Em %n semanas e %1$s e depois em %2$s e %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Em %n mês e %1$s e depois em %2$s e %3$s","Em %n de meses e %1$s e depois em %2$s e %3$s","Em %n meses e %1$s e depois em %2$s e %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Em %n ano e %1$s e depois em %2$s e %3$s","Em %n de anos e %1$s e depois em %2$s e %3$s","Em %n anos e %1$s e depois em %2$s e %3$s"],
    "Could not generate next recurrence statement" : "Não foi possível gerar a indicação da próxima recorrência",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" foi cancelado",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s aceitou seu convite",
    "%1$s has tentatively accepted your invitation" : "%1$s aceitou seu convite como tentativa",
    "%1$s has declined your invitation" : "%1$s recusou seu convite",
    "%1$s has responded to your invitation" : "%1$s respondeu ao seu convite",
    "Invitation updated: %1$s" : "Convite atualizado: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s atualizou o evento \"%2$s\"",
    "Invitation: %1$s" : "Convite: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s gostaria de convidar você para \"%2$s\"",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Participantes:",
    "Title:" : "Título:",
    "When:" : "Quando:",
    "Location:" : "Localização:",
    "Link:" : "Link:",
    "Occurring:" : "Ocorrendo:",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "More options …" : "Mais opções...",
    "More options at %s" : "Mais opções em %s",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado ",
    "Sunday" : "Domingo",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "First" : "1.º/ª",
    "Second" : "2.º/ª",
    "Third" : "3.º/ª",
    "Fourth" : "4.º/ª",
    "Fifth" : "5.º/ª",
    "Last" : "Último/a",
    "Second Last" : "Penúltimo/a",
    "Third Last" : "3.º/ª Último/a",
    "Fourth Last" : "4.º/ª Último/a",
    "Fifth Last" : "5.º/ª Último/a",
    "Contacts" : "Contatos",
    "{actor} created address book {addressbook}" : "{actor} criou o catálogo de endereços {addressbook}",
    "You created address book {addressbook}" : "Você criou o catálogo de endereços  {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} excluiu o catálogo de endereços {addressbook}",
    "You deleted address book {addressbook}" : "Você excluiu o catálogo de endereços {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} atualizou o catálogo de endereços {addressbook}",
    "You updated address book {addressbook}" : "Você atualizou o catálogo de endereços {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} compartilhou o catálogo de endereços {addressbook} com você",
    "You shared address book {addressbook} with {user}" : "Você compartilhou o catálogo de endereços {addressbook} com {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} compartilhou o catálogo de endereços {addressbook} com {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} retirou o compartilhamento do catálogo de endereços {addressbook} de você",
    "You unshared address book {addressbook} from {user}" : "Você retirou o compartilhamento do catálogo de endereços {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} retirou o compartilhamento do catálogo de endereços {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} retirou o compartilhamento do catálogo de endereços {addressbook} de si mesmo",
    "You shared address book {addressbook} with group {group}" : "Você compartilhou o catálogo de endereços {addressbook} com o grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} compartilhou o catálogo de endereços {addressbook} com o grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "Você retirou o compartilhamento do catálogo de endereços {addressbook} do grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} retirou o compartilhamento do catálogo de endereços {addressbook} do grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} criou o contato {card} no catálogo de endereços {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Você criou o contato {card} no catálogo de endereços {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} excluiu o contato {card} do catálogo de endereços {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Você exluiu o contato {card} do catálogo de endereços {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} atualizou o contato {card} no catálogo de endereços {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Você atualizou o contato {card} no catálogo de endereços {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Um <strong>contato</strong> ou <strong>catálogo de endereços</strong> foi modificado",
    "System address book disabled" : "Catálogo de endereços do sistema desativado",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "O catálogo de endereços de contatos do sistema foi desativado automaticamente durante a atualização. Isso significa que o catálogo de endereços não estará mais disponível para os usuários no aplicativo de contatos ou em outros clientes. O catálogo de endereços de contatos do sistema foi desativado porque a quantidade de contatos no catálogo excedeu o número máximo recomendado de contatos. Esse limite é definido para evitar problemas de desempenho. Você pode reativar o catálogo de endereços do sistema com o seguinte comando {command}",
    "Accounts" : "Contas",
    "System address book which holds all accounts" : "Catálogo de endereços do sistema que contém todas as contas",
    "File is not updatable: %1$s" : "O arquivo não é atualizável: %1$s",
    "Failed to get storage for file" : "Falha ao obter armazenamento para arquivo",
    "Could not write to final file, canceled by hook" : "Não foi possível gravar no arquivo final, cancelado pelo hook",
    "Could not write file contents" : "Não foi possível gravar o conteúdo do arquivo",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Erro ao copiar o arquivo para o local de destino (copiado: %1$s, tamanho de arquivo esperado: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Tamanho de arquivo esperado de %1$s, mas lido (do cliente Nextcloud) e gravado (no armazenamento Nextcloud) %2$s. Pode ser um problema de rede no lado de envio ou um problema de gravação no armazenamento no lado do servidor.",
    "Could not rename part file to final file, canceled by hook" : "Não foi possível renomear o arquivo de peça para o arquivo final, cancelado pelo hook",
    "Could not rename part file to final file" : "Não foi possível renomear o arquivo de peça para o arquivo final",
    "Failed to check file size: %1$s" : "Falha ao verificar o tamanho do arquivo: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Não foi possível abrir o arquivo: %1$s (%2$d), o arquivo parece existir",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Não foi possível abrir o arquivo: %1$s (%2$d), o arquivo parece não existir",
    "Failed to get size for : %1$s" : "Falha ao obter o tamanho para: %1$s",
    "Encryption not ready: %1$s" : "A criptografia não está pronta: %1$s",
    "Failed to open file: %1$s" : "Falha ao abrir arquivo: %1$s",
    "Failed to unlink: %1$s" : "Falha ao desvincular: %1$s",
    "Failed to write file contents: %1$s" : "Falha ao gravar o conteúdo do arquivo:%1$s",
    "File not found: %1$s" : "Arquivo não encontrado: %1$s",
    "Invalid target path" : "Caminho de destino inválido",
    "System is in maintenance mode." : "O sistema está em modo de manutenção",
    "Upgrade needed" : "Upgrade necessário",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Seu %s precisa estar configurado para usar HTTPS a fim de usar o CalDAV e o CardDAV com o iOS/macOS.",
    "Configures a CalDAV account" : "Configure uma conta CalDAV",
    "Configures a CardDAV account" : "Configure uma conta CardDAV",
    "Events" : "Eventos",
    "Untitled task" : "Tarefa sem título",
    "Completed on %s" : "Concluída em %s",
    "Due on %s by %s" : "Vence em %s até %s",
    "Due on %s" : "Vence em %s",
    "This is an example contact" : "Este é um exemplo de contato",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Bem-vindo ao Nextcloud Calendário!\n\nEste é um exemplo de evento - explore a flexibilidade do planejamento com o Nextcloud Calendário fazendo as edições que desejar!\n\nCom o Nextcloud Calendário, você pode:\n- Criar, editar e gerenciar eventos sem esforço.\n- Criar vários calendários e compartilhá-los com colegas de equipe, amigos ou familiares.\n- Verificar a disponibilidade e exibir seus horários de trabalho para outras pessoas.\n- Integrá-lo perfeitamente com aplicativos e dispositivos via CalDAV.\n- Personalizar sua experiência: agende eventos recorrentes, ajuste as notificações e outras configurações.",
    "Example event - open me!" : "Exemplo de evento - abra-me!",
    "System Address Book" : "Catálogo de Endereços do Sistema",
    "The system address book contains contact information for all users in your instance." : "O catálogo de endereços do sistema contém informações de contato de todos os usuários da sua instância.",
    "Enable System Address Book" : "Ativar Catálogo de Endereços do Sistema",
    "DAV system address book" : "Catálogo de endereços DAV do sistema",
    "No outstanding DAV system address book sync." : "Não há sincronização pendente do catálogo de endereços DAV do sistema.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "A sincronização do catálogo de endereços DAV do sistema ainda não foi executada porque sua instância tem mais de 1000 usuários ou porque ocorreu um erro. Execute-a manualmente chamando \"occ dav:sync-system-addressbook\".",
    "DAV system address book size" : "Tamanho do catálogo de endereços DAV do sistema",
    "The system address book is disabled" : "O catálogo de endereços do sistema está desativado",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "O catálogo de endereços do sistema está ativado, mas contém mais do que o limite configurado de %d contatos.",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "O catálogo de endereços do sistema está ativado e contém menos do que o limite configurado de %d contatos.",
    "WebDAV endpoint" : "Endpoint WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Não foi possível verificar se o seu servidor web está configurado corretamente para permitir a sincronização de arquivos via WebDAV. Verifique manualmente.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Seu servidor web ainda não está configurado corretamente para permitir a sincronização de arquivos, porque a interface do WebDAV parece estar quebrada.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Seu servidor web está configurado corretamente para permitir a sincronização de arquivos via WebDAV.",
    "Calendars including events, details and attendees" : "Calendários, incluindo eventos, detalhes e participantes",
    "Migrated calendar (%1$s)" : "Calendário migrado (%1$s)",
    "Contacts and groups" : "Contatos e grupos",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Ausência salva",
    "Failed to save your absence settings" : "Falha ao salvar suas configurações de ausência",
    "Absence cleared" : "Limpou a ausência",
    "Failed to clear your absence settings" : "Falha ao limpar suas configurações de ausência",
    "First day" : "Primeiro dia",
    "Last day (inclusive)" : "Último dia (inclusive)",
    "Out of office replacement (optional)" : "Substituto durante sua ausência (opcional)",
    "Name of the replacement" : "Nome do substituto",
    "Short absence status" : "Status curto sobre a ausência",
    "Long absence Message" : "Mensagem longa sobre a ausência",
    "Save" : "Salvar",
    "Disable absence" : "Desativar ausência",
    "Failed to load availability" : "Falha ao carregar a disponibilidade",
    "Saved availability" : "Disponibilidade salva",
    "Failed to save availability" : "Falha ao salvar a disponibilidade",
    "to" : "para",
    "Delete slot" : "Excluir slot",
    "No working hours set" : "Sem horário de trabalho definido",
    "Add slot" : "Adicionar slot ",
    "Weekdays" : "Dias da semana",
    "Pick a start time for {dayName}" : "Selecione um horário de início para {dayName}",
    "Pick a end time for {dayName}" : "Selecione um horário de fim para {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Defina automaticamente o status do usuário como \"Não perturbe\" fora de disponibilidade para silenciar todas as notificações.",
    "Cancel" : "Cancelar",
    "Import" : "Importar",
    "Error while saving settings" : "Erro ao salvar as configurações",
    "Contact reset successfully" : "O contato foi reiniciado com sucesso",
    "Error while resetting contact" : "Erro ao reiniciar o contato",
    "Contact imported successfully" : "O contato foi importado com sucesso",
    "Error while importing contact" : "Erro ao importar o contato",
    "Import contact" : "Importar contato",
    "Reset to default" : "Redefinir para o padrão",
    "Import contacts" : "Importar contatos",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "A importação de um novo arquivo .vcf excluirá o contato padrão existente e o substituirá pelo novo. Deseja continuar?",
    "Failed to save example event creation setting" : "Falha ao salvar a configuração de criação de evento de exemplo",
    "Failed to upload the example event" : "Falha ao fazer upload do evento de exemplo",
    "Custom example event was saved successfully" : "O evento de exemplo personalizado foi salvo com êxito",
    "Failed to delete the custom example event" : "Falha ao excluir o evento de exemplo personalizado",
    "Custom example event was deleted successfully" : "O evento de exemplo personalizado foi excluído com êxito",
    "Import calendar event" : "Importar evento de calendário",
    "Uploading a new event will overwrite the existing one." : "O upload de um novo evento substituirá o existente.",
    "Upload event" : "Fazer upload do evento",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale também o {calendarappstoreopen}aplicativo de calendário{linkclose} ou {calendardocopen}conecte sua área de trabalho e celular à sincronização ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Certifique-se de configurar corretamente {emailopen}o servidor de e-mail{linkclose}.",
    "Calendar server" : "Servidor de calendário",
    "Send invitations to attendees" : "Enviar convites aos participantes",
    "Automatically generate a birthday calendar" : "Gerar um calendário de aniversários automaticamente",
    "Birthday calendars will be generated by a background job." : "Os calendários de aniversários serão gerados na retaguarda.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Portanto, eles não estarão disponíveis imediatamente após a ativação, mas depois de algum tempo.",
    "Send notifications for events" : "Enviar notificações para eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "As notificações são enviadas via trabalhos em segundo plano, portanto, elas devem ocorrer com frequência suficiente.",
    "Send reminder notifications to calendar sharees as well" : "Enviar notificações de lembrete também para os compartilhadores de calendário",
    "Reminders are always sent to organizers and attendees." : "Lembretes são sempre enviados aos organizadores e participantes.",
    "Enable notifications for events via push" : "Ativar notificações para eventos via push",
    "Example content" : "Exemplo de conteúdo",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "O conteúdo de exemplo serve para mostrar os recursos do Nextcloud. O conteúdo padrão é fornecido com o Nextcloud e pode ser substituído por conteúdo personalizado.",
    "Availability" : "Disponibilidade",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Se você configurar seu horário de trabalho, outras pessoas verão quando você estiver ausente quando agendarem uma reunião.",
    "Absence" : "Ausência",
    "Configure your next absence period." : "Configure seu próximo período de ausência",
    "There was an error updating your attendance status." : "Houve um erro ao atualizar seu status de participação.",
    "Please contact the organizer directly." : "Por favor, contate o organizador diretamente.",
    "Are you accepting the invitation?" : "Você está aceitando o convite?",
    "Tentative" : "Tentativa",
    "Your attendance was updated successfully." : "Sua presença foi atualizada com sucesso.",
    "No results." : "Nenhum resultado.",
    "Start typing." : "Comece a digitar."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
