OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "System tag %1$s tilføjet af systemet",
    "Added system tag {systemtag}" : "Tilføjede systemtag {systemtag}",
    "Added system tag %1$s" : "Tilføjede systemtag %1$s",
    "%1$s added system tag %2$s" : "%1$s tilføjede systemtag %2$s",
    "{actor} added system tag {systemtag}" : "{actor} tilføjede systemtag {systemtag}",
    "System tag %1$s removed by the system" : "System tag %1$s fjernet af systemet",
    "Removed system tag {systemtag}" : "Fjernede systemtag {systemtag}",
    "Removed system tag %1$s" : " Fjernede systemmærket %1$s",
    "%1$s removed system tag %2$s" : "%1$s fjernede systemmærke %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjernede systemmærke {systemtag}",
    "You created system tag %1$s" : " Du oprettede systemmærke %1$s",
    "You created system tag {systemtag}" : " Du oprettede systemmærke {systemtag}",
    "%1$s created system tag %2$s" : "%1$s oprettede systemmærke %2$s",
    "{actor} created system tag {systemtag}" : "{actor} oprettede systemmærke {systemtag}",
    "You deleted system tag %1$s" : " Du slettede systemmærke %1$s",
    "You deleted system tag {systemtag}" : "Du slettede systemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s fjernede systemmærket %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} slettede systemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du ændrede systemmærket %2$s til %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du opdaterede {oldsystemtag} til {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ændrede systemmærket %3$s til %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} opdaterede systemtag  {oldsystemtag} til {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "System tag %2$s blev tilføjet til %1$s af systemet",
    "System tag {systemtag} was added to {file} by the system" : "System tag {systemtag} blev tilføjet til {file} af systemet",
    "You added system tag %2$s to %1$s" : "Du tilføjede system tag %2$s til %1$s",
    "You added system tag {systemtag} to {file}" : "Du tilføjede system tag {systemtag} til {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s tilføjede system tag %3$s til %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} tilføjede system tag {systemtag} til {file}",
    "System tag %2$s was removed from %1$s by the system" : "System tag %2$s blev fjernet fra %1$s af systemet",
    "System tag {systemtag} was removed from {file} by the system" : "System tag {systemtag} blev fjernet fra {file} af systemet",
    "You removed system tag %2$s from %1$s" : "Du fjernede system tag %2$s fra %1$s",
    "You removed system tag {systemtag} from {file}" : "Du fjernede system tag {systemtag} fra {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjernede systemtag %3$s fra %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjernede system tag {systemtag} fra {file}",
    "%s (restricted)" : "%s (begrænset)",
    "%s (invisible)" : "%s (usynlig)",
    "<strong>System tags</strong> for a file have been modified" : "En fils <strong>systemmærkning</strong> er blevet ændret",
    "Files" : "Filer",
    "Tags" : "Tags",
    "All tagged %s …" : "Alle tagget %s ...",
    "tagged %s" : "tagget %s",
    "Collaborative tags" : "Kollaborativ tags",
    "Collaborative tagging functionality which shares tags among people." : "Samarbejds tagnings funktionalitet, som deler tags blandt mennesker.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbejds tagnings funktionalitet, som deler tags blandt mennesker. Godt for teams.\n\t(Hvis du er en udbyder med en multi-tenancy installation, anbefales det at deaktivere denne app da tags bliver delt.)",
    "Public" : "Offentlig",
    "Restricted" : "Begrænset",
    "Invisible" : "Usynlig",
    "Created tag" : "Oprettede tag",
    "Failed to create tag" : "Kunne ikke oprette mærke",
    "Updated tag" : "Opdaterede tag",
    "Failed to update tag" : "Kunne ikke opdatere mærke",
    "Deleted tag" : "Slettet mærke",
    "Failed to delete tag" : "Kunne ikke slette mærke",
    "Create or edit tags" : "Opret eller redigér mærker",
    "Search for a tag to edit" : "Søg efter et tag til at redigere",
    "No tags to select" : "Ingen mærker at vælge",
    "Tag name" : "Mærkets navn",
    "Tag level" : "Tag niveau",
    "Create" : "Opret",
    "Update" : "Opdatér",
    "Delete" : "Slet",
    "Reset" : "Reset",
    "Loading …" : "Indlæser …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} vil blive indstillet og {tag2} vil blive fjernet fra 1 fil.","{tag1} vil blive sat og {tag2} vil blive fjernet fra {count} filer."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} vil blive sat til 1 fil.","{tag} vil blive sat til {count} filer."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} vil blive fjernet fra 1 fil.","{tag} vil blive fjernet fra {count} filer."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} og {lastTag} vil blive sat til en fil.","{tags} og {lastTag} vil blive sat til {count} filer."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} og {lastTag} vil blive fjernet fra en fil.","{tags} og {lastTag} vil blive fjernet fra {count} filer."],
    "{displayName} (hidden)" : "{displayName} (skjult)",
    "{displayName} (restricted)" : "{displayName} (begrænset)",
    "Only admins can create new tags" : "Kun administratorer kan oprette nye tags",
    "Failed to apply tags changes" : "Kunne ikke anvende tag ændringer",
    "Manage tags" : "Administrer tags",
    "Applying tags changes…" : "Anvender ændringer på mærker...",
    "Search or create tag" : "Søg eller opret mærke",
    "Search tag" : "Søgemærke",
    "Change tag color" : "Skift mærkefarve",
    "Create new tag" : "Opret nyt mærke",
    "Choose tags for the selected files" : "Vælg tags til de valgte filer",
    "Cancel" : "Annullér",
    "Apply" : "Anvend",
    "Failed to load selected tags" : "Kunne ikke indlæse markerede mærker",
    "Failed to load tags" : "Kunne ikke indlæse tags.",
    "Failed to select tag" : "Kunne ikke vælge mærke",
    "System admin disabled tag creation. You can only use existing ones." : "Systemadministrator deaktiverede oprettelse af tag. Du kan kun anvende eksisterende.",
    "Search or create collaborative tags" : "Søg eller opret samarbejds tags",
    "No tags to select, type to create a new tag" : "Ingen tag til at vælge, skriv for at oprette et nyt tag",
    "Unable to update setting" : "Indstillingen kunne ikke opdateres",
    "System tag creation is now restricted to administrators" : "Oprettelse af systemtags er nu begrænset til administratorer",
    "System tag creation is now allowed for everybody" : "Oprettelse af systemtags er nu tilladt for alle",
    "System tag management" : "System tag styring",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Hvis aktiveret, så kan kun administratorer oprette og redigere tags. Konti kan stadig tildele og fjerne dem fra filer.",
    "Restrict tag creation and editing to administrators" : "Begræns tag oprettelse og redigering til administratorer",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbejds tags er tilgængelige for alle brugere. Begrænsede tags er synlige for brugerne, men kan ikke tildeles af dem. Usynlige tags er til internt brug, da brugerne ikke kan se eller tildele dem.",
    "Assigned collaborative tags" : "Tildelte samarbejds tags",
    "Open in Files" : "Åben i Filer",
    "List of tags and their associated files and folders." : "Liste over tags og tilhørende filer og mapper.",
    "No tags found" : "Ingen tags fundet",
    "Tags you have created will show up here." : "Tags du har oprettet vil vises her.",
    "Failed to load tag" : "Kunne ikke indlæse mærke",
    "Failed to load last used tags" : "Kunne ikke indlæse senest brugte mærker",
    "Missing \"Content-Location\" header" : "Mangler header for \"Content-Location\"",
    "A tag with the same name already exists" : "Et tag med samme navn eksisterer allerede",
    "Failed to load tags for file" : "Kunne ikke indlæse tags til fil",
    "Failed to set tag for file" : "Kunne ikke sætte tag for fil",
    "Failed to delete tag for file" : "Kunne ikke slette tag for fil",
    "Collaborative tags …" : "Samarbejds tags ...",
    "Loading …" : "Indlæser …",
    "Loading collaborative tags …" : "Indlæser samarbejds tags ..."
},
"nplurals=2; plural=(n != 1);");
