.collection-cover[data-v-719cd191]{display:flex;flex-direction:column;padding:16px;border-radius:var(--border-radius-large)}.collection-cover[data-v-719cd191]:hover,.collection-cover[data-v-719cd191]:focus{background:var(--color-background-dark)}.collection-cover__image[data-v-719cd191]{width:350px;height:350px;object-fit:cover;border-radius:var(--border-radius-large)}@media only screen and (max-width: 1200px){.collection-cover__image[data-v-719cd191]{width:250px;height:250px}}.collection-cover__image--placeholder[data-v-719cd191]{background:var(--color-primary-element-light)}.collection-cover__image--placeholder[data-v-719cd191] .material-design-icon{width:100%;height:100%}.collection-cover__image--placeholder[data-v-719cd191] .material-design-icon .material-design-icon__svg{fill:var(--color-primary-element)}.collection-cover__details[data-v-719cd191]{display:flex;flex-direction:column;margin-top:16px;width:350px}@media only screen and (max-width: 1200px){.collection-cover__details[data-v-719cd191]{width:250px}}.collection-cover__details__title[data-v-719cd191]{display:flex;justify-content:space-between}.collection-cover__details__subtitle[data-v-719cd191]{display:flex;color:var(--color-text-lighter)}.collections[data-v-b585220f]{display:flex;flex-direction:column;height:100%}.collections__list[data-v-b585220f]{padding:32px 48px;flex-grow:1;display:flex;flex-wrap:wrap;gap:16px;align-items:flex-start;height:calc(100% - 60px);overflow-x:scroll}@media only screen and (max-width: 1200px){.collections__list[data-v-b585220f]{padding:32px 12px;justify-content:center}}
