OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Хронология на действията за %s",
    "Your feed URL is invalid" : "Емисията е с невалиден URL адрес",
    "Activity feed for %1$s" : "Информационен канал за активност %1$s",
    "Activity feed" : "Поток на активността",
    "Your settings have been updated." : "Вашите настройки са актуализирани.",
    "Settings have been updated." : "Настройките бяха актуализирани.",
    "remote user" : "\"отдалечен потребител\"",
    "Recent activity" : "Последна активност",
    "No activities" : "Няма активности",
    "More activities" : "Още активности",
    "Daily activity summary for %s" : "Обобщение на дневната активност за %s",
    "_and %n more…_::_and %n more…_" : ["и %n още...","и още %n..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : " Можете да изключите дневните обобщаващи имейли в <a href=\"%s\">настройки</a>",
    "You can disable daily digest emails in the settings: %s" : " Можете да изключите дневните обобщаващи имейли в настройки: %s",
    "All activities" : "Всички активности",
    "By others" : "От други",
    "By you" : "От Вас",
    "Activity at %s" : "Дейност в %s",
    "Hello %s" : "Здравейте %s",
    "Hello %s," : "Здравейте %s,",
    "There was some activity at %s" : "Имаше събитие в %s",
    "_and %n more _::_and %n more _" : ["и %n още ","и %n още "],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Можете да промените честотата на тези имейли или да ги деактивирате в <a href=\"%s\">настройките</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Можете да промените честотата на тези имейли или да ги деактивирате в настройките: %s",
    "Mail" : "Поща",
    "Push" : "Директно /push/",
    "Activity" : "Активност",
    "Notifications" : "Известия",
    "This application enables people to view a log of activities about them, their files or other data." : "Това приложение позволява на хората да преглеждат журнал на активности, свързани с тях, техните файлове или други данни.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Това приложение позволява на хората да виждат действия, свързани с техните файлове и данни в Nextcloud.\n\t\tВсеки човек може да конфигурира индивидуални настройки на дейностите си в личните настройки,\n\t\tда избере кои дейности да се изпращат на мобилни телефони, като изпращането е по имейл\n\t\tили дали всяка сутрин да се изпраща дневно обобщение.\n\t\tПовече информация е налична в документацията за дейността.",
    "Send email" : "Изпращане на имейл",
    "Send push notification" : "Изпращане на push известие",
    "Activity notification configuration" : "Конфигурация на известие за активност",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "You need to set up your email address before you can receive notification emails." : "Първо трябва да въведете вашия имейл адрес (в профила си), за да получавате известия.",
    "Send activity emails" : "Изпращане на имейли за активността",
    "As soon as possible" : "Възможно по-скоро",
    "Hourly" : "Всеки час",
    "Daily" : "Всеки ден",
    "Weekly" : "Всяка седмица",
    "You commented" : "Вие коментирахте",
    "Message deleted by author" : "Съобщението е изтрито от автора",
    "Open {filename}" : "Отвори файл {filename}",
    "in {path}" : "в {path}",
    "Home" : "Начало",
    "Could not load activities" : "Не може да се зареди активност",
    "Loading activities" : "Зареждане на активност",
    "This stream will show events like additions, changes & shares" : "Потокът ще показва събития като допълнения, изменения и споделяния",
    "No activity yet" : "Все още няма активност",
    "Loading more activities" : "Зареждане на още активност",
    "No more activities." : "Няма активност.",
    "Could not enable RSS link" : "Не може да се установи RSS връзка",
    "RSS link copied to clipboard" : "RSS връзката е копирана в клипборда",
    "Could not copy the RSS link, please copy manually:" : "Не може да се копира RSS връзката, моля копирайте ръчно:",
    "Activity settings" : "Настройки за активност",
    "Enable RSS feed" : "Разрешаване на RSS емисии",
    "RSS feed" : "RSS емисия",
    "Copy RSS feed link" : "Копиране на връзка за RSS емисия",
    "Personal notification settings" : "Лични настройки за известие",
    "Unable to load the activity list" : "Неуспешно зареждане на списъкът с активности",
    "Choose for which activities you want to get an email or push notification." : "Изберете за кои активности да получавате имейл или директно известие.",
    "Choose for which activities you want to get a push notification." : "Изберете за кои активности да получавате директно известие.",
    "Notification" : "Известие",
    "Enable notification emails" : "Разрешаване на е-мейл известия",
    "Daily activity summary" : "Обобщение на дневната активност",
    "Send daily activity summary in the morning" : "Да се изпраща сутрин обобщение на дневната активност",
    "Default settings" : "Стандартни настройки",
    "Configure the default notification settings for new accounts." : "Настройки по подразбиране за нови профили",
    "Unable to save the settings" : "Настройките не могат да бъдат запазени",
    "No more events to load" : "Няма повече известия за зареждане"
},
"nplurals=2; plural=(n != 1);");
