OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Wykryto nową lokalizację logowania",
    "More info about the suspicious IP address available on %s" : "Więcej informacji o podejrzanym adresie IP znajdziesz na %s",
    "Open %s ↗" : "Otwórz %s ↗",
    "Suspicious Login" : "Podejrzane logowanie",
    "New login detected" : "Wykryto nowe logowanie",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Wykryj i ostrzeż o logowaniu do Nextcloud z podejrzanego adresu IP\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Wykryto nowe logowanie do Twojego konta. Adres IP %s został sklasyfikowany jako podejrzany. Jeśli byłeś to Ty, to możesz zignorować tę wiadomość. W przeciwnym razie należy zmienić hasło."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
