OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "vraćeno",
    "Deleted files" : "Izbrisane datoteke",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Izbrisane datoteke i mape u košu za smeće (mogu isteći tijekom izvoza ako nemate dovoljno prostora za pohranu).",
    "This application enables people to restore files that were deleted from the system." : "Ova aplikacija omogućuje korisnicima vraćanje datoteka koje su izbrisane iz sustava.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Ova aplikacija omogućuje korisnicima vraćanje datoteka koje su izbrisane iz sustava. Prikazuje popis izbrisanih datoteka u web-sučelju te nudi mogućnosti vraćanja tih datoteka u korisničke direktorije ili njihova trajnog uklanjanja iz sustava. Prilikom vraćanja datoteke vraćaju se i povezane verzije datoteka, ako je omogućena aplikacija Verzije. Kada se datoteka izbriše iz dijeljenja, može se vratiti na isti način, ali više neće biti dijeljena. Prema zadanim postavkama, te datoteke ostaju u košu za smeće 30 dana.\nKako bi se spriječilo da korisnički račun ostane bez prostora na disku, aplikacija Izbrisane datoteke neće koristiti više od 50 % trenutačno dostupne slobodne kvote za izbrisane datoteke. Ako izbrisane datoteke premaše to ograničenje, aplikacija će brisati najstarije datoteke dok se ne spusti ispod tog ograničenja. Više informacija dostupno je u dokumentaciji aplikacije Izbrisane datoteke.",
    "Restore" : "Vrati",
    "Not enough free space to restore the file/folder" : "Nema dovoljno slobodnog prostora za vraćanje datoteke/mape.",
    "Empty deleted files" : "Isprazni izbrisane datoteke",
    "Confirm permanent deletion" : "Potvrdi trajno brisanje",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Jeste li sigurni da želite trajno izbrisati sve datoteke i mape u košu za smeće? Ovu radnju nije moguće poništiti.",
    "Cancel" : "Odustani",
    "Original location" : "Originalna lokacija",
    "Deleted by" : "Izbrisao",
    "Deleted" : "Izbrisano",
    "few seconds ago" : "prije nekoliko sekundi",
    "A long time ago" : "davno",
    "Unknown" : "Nepoznata pogreška",
    "All files" : "Sve datoteke",
    "You" : "Vi",
    "List of files that have been deleted." : "Lista izbrisanih datoteka.",
    "No deleted files" : "Nema izbrisanih datoteka",
    "Files and folders you have deleted will show up here" : "Ovdje će se prikazivati datoteke i mape koje ste izbrisali.",
    "All files have been permanently deleted" : "Sve su datoteke trajno izbrisane.",
    "Failed to empty deleted files" : "Pražnjenje izbrisanih datoteka nije uspjelo."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
