OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Maxfiylik",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Maxfiylik markazi sizga ma'lumotlaringiz qayerda saqlanganligini va ularga kim kira olishi mumkinligini ko'rsatadi, chunki siz ular bilan ulashgansiz yoki ular administrator bo'lgani uchun.",
    "Error loading additional administrator." : "Qo'shimcha administratorni yuklashda xatolik.",
    "Error adding new administrator." : "Yangi administrator qo'shishda xatolik.",
    "Error deleting new administrator." : "Yangi administratorni o'chirishda xatolik.",
    "Administrators" : "Administratorlar",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Quyidagi hisoblar tayinlangan administratorlar bo'lib, tizim xotirasi yoki zaxira nusxalari orqali ma'lumotlaringizga kirish huquqiga ega bo'lishi mumkin. Biroq, ular veb-interfeys yoki mijoz ilovalari orqali ma'lumotlaringizga oson kirish imkoniga ega emaslar.",
    "Loading administrators …" : "Administratorlar yuklanmoqda…",
    "Remove external {propertyName} admin" : "Tashqi {propertyName} administratorini olib tashlash",
    "Add external admin" : "Tashqi administrator qo'shish",
    "Cancel" : "Bekor qilish",
    "Add" : "Add",
    "Name of external admin" : "Tashqi administrator nomi",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Uy xotirangiz {linkopen}server tomonidagi shifrlash ↗{linkclose} yordamida asosiy kalit yordamida shifrlangan. Bu shuni anglatadiki, administratorlar fayllaringizga kirishlari mumkin, lekin ularning tarkibini o'qiy olmaydilar.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Tashqi xotiradagi fayllaringiz konfiguratsiyasiga asoslangan holda asosiy kalit bilan {linkopen}server tomonidagi shifrlash ↗{linkclose} yordamida shifrlanishi mumkin.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Uy xotirangiz {linkopen}server tomonidagi shifrlash ↗{linkclose} yordamida alohida foydalanuvchi kaliti yordamida shifrlangan. Bu shuni anglatadiki, administratorlar fayllaringizga kirishlari mumkin, lekin ularning tarkibini o'qiy olmaydilar.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration.",
    "Additionally, this server is protected with full-disk-encryption." : "Bundan tashqari, ushbu server to'liq disk shifrlash bilan himoyalangan.",
    "This server is protected with full-disk-encryption." : "Bu server to'liq disk shifrlash bilan himoyalangan.",
    "Your files are not protected by encryption." : "Fayllaringiz shifrlash bilan himoyalanmagan.",
    "Error saving new state of full-disk-encryption" : "To'liq diskda shifrlashning yangi holatini saqlashda xatolik yuz berdi",
    "Encryption" : "Encryption",
    "Edit encryption" : "Shifrlashni tahrirlash",
    "Edit" : "Tahrirlash",
    "This server is using full-disk-encryption." : "Bu server to'liq disk shifrlashdan foydalanmoqda.",
    "Privacy policy" : "Maxfiylik siyosati",
    "Read the privacy policy ↗" : "Maxfiylik siyosatini o'qing ↗",
    "Error loading information about shares." : "Aksiyalar haqidagi ma'lumotlarni yuklashda xatolik.",
    "People you've shared with" : "Siz ulashgan odamlar",
    "Loading people you've shared with …" : "Siz ulashgan odamlar yuklanmoqda …",
    "You do not have any shares with individual users." : "Sizda alohida foydalanuvchilar bilan ulashishlar yo'q.",
    "Your {serverName} account" : "Sizning {serverName} hisobingiz",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Ma'lumotlaringiz sizning kimligingizni ifodalaydi va osongina suiiste'mol qilinishi mumkin. Nextcloud’da biz sizning ma'lumotlaringiz bilan nima bo'lishini hal qilish huquqiga egasiz, deb hisoblaymiz. Nextcloud Foydalanuvchi ma'lumotlari manifestida belgilanganidek, sizning huquqlaringizni himoya qiladi!",
    "Who has access to your data?" : "Ma'lumotlaringizga kim kirish huquqiga ega?",
    "Error saving new location of the server" : "Serverning yangi joylashuvini saqlashda xatolik",
    "Where is your data?" : "Ma'lumotlaringiz qayerda?",
    "Your data is located in:" : "Ma'lumotlaringiz quyidagi joyda joylashgan:",
    "An admin has not selected the location of the server yet." : "Administrator hali server joylashuvini tanlamagan.",
    "Change data location" : "Ma'lumotlar joylashuvini o'zgartirish",
    "Region" : "Mintaqa",
    "Please select a region" : "Iltimos, mintaqani tanlang",
    "{bold}Control{/bold} over user data access" : "Foydalanuvchi ma'lumotlariga kirishni {bold}nazorat qilish{/bold}",
    "{bold}Knowledge{/bold} of how the data is stored" : "Ma'lumotlar qanday saqlanishi haqida {bold}Bilim{/bold}",
    "{bold}Freedom{/bold} to choose a platform" : "Platformani tanlash uchun {bold}Erkinlik{/bold}",
    "User Data Manifesto 2.0" : "Foydalanuvchi ma'lumotlari manifesti 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Internet davrida odamlarning o'z ma'lumotlarini boshqarish bo'yicha asosiy huquqlarini belgilash.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Foydalanuvchi tomonidan aniq va ixtiyoriy ravishda yuklangan ma'lumotlar foydalanuvchining yakuniy nazorati ostida bo'lishi kerak. Foydalanuvchilar o'z ma'lumotlariga kimga to'g'ridan-to'g'ri kirish huquqini berishni va bunday kirish qanday ruxsatnomalar va litsenziyalar bilan berilishi kerakligini hal qilishlari kerak.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Ma'lumotlar ma'lum bir xizmat ko'rsatuvchi provayderga yuklanganda, foydalanuvchilarga ushbu ma'lum bir xizmat ko'rsatuvchi provayder ma'lumotlarni qayerda saqlashi, qancha vaqt saqlashi, ma'lum bir xizmat ko'rsatuvchi provayder qaysi yurisdiktsiyada ishlashi va qaysi qonunlar qo'llanilishi haqida ma'lumot berilishi kerak.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Foydalanuvchilar har doim o'z ma'lumotlarini xizmatdan istalgan vaqtda, hech qanday sotuvchi tomonidan bloklanmasdan olishlari kerak. Bunga kafolat berish uchun formatlar va protokollar uchun ochiq standartlar zarur.",
    "Learn more ↗" : "Ko'proq ma'lumot oling. ↗",
    "Somaliland" : "Somali",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Birlashgan Arab Amirliklari",
    "Afghanistan" : "Afg'oniston",
    "Antigua and Barbuda" : "Antigua va Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albaniya",
    "Armenia" : "Armaniston",
    "Angola" : "Angola",
    "Antarctica" : "Antarktida",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerika Samoasi",
    "Austria" : "Avstriya",
    "Australia" : "Avstraliya",
    "Aruba" : "Aruba",
    "Åland Islands" : "Aland orollari",
    "Azerbaijan" : "Ozarbayjon",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgiya",
    "Burkina Faso" : "Burkina-Faso",
    "Bulgaria" : "Bolgariya",
    "Bahrain" : "Bahrayn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sent-Bartelemi",
    "Bermuda" : "Bermud orollari",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius va Saba",
    "Brazil" : "Braziliya",
    "Bahamas" : "Bagama orollari",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Beliz",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokos (Kiling) orollari",
    "Democratic Republic of the Congo" : "Kongo Democratik Republikasi",
    "Central African Republic" : "Markaziy Afrika Respublikasi",
    "Congo" : "Kongo",
    "Switzerland" : "Shveytsariya",
    "Cote d'Ivoire" : "Kote di Uvar",
    "Cook Islands" : "Kuk orollari",
    "Chile" : "Chili",
    "Cameroon" : "Kamerun",
    "China" : "Xitoy",
    "Colombia" : "Kolumbiya",
    "Costa Rica" : "Kosta-Rika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kabo Verde",
    "Curaçao" : "Kyurasao",
    "Christmas Island" : "Rojdestvo oroli",
    "Cyprus" : "Kipr",
    "Czech" : "chex",
    "Germany" : "Germaniya",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Dominika Respublikasi",
    "Algeria" : "Jazoir",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estoniya",
    "Egypt" : "Misr",
    "West Sahara" : "G'arbiy Sahara",
    "Eritrea" : "Eritreya",
    "Spain" : "Ispaniya",
    "Ethiopia" : "Efiopiya",
    "Finland" : "Finlyandiya",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Folklend orollari",
    "Micronesia" : "Mikronesiya",
    "Faroe Islands" : "Farer orollari",
    "France" : "Fransiya",
    "Gabon" : "Gabon",
    "United Kingdom" : "Birlashgan Qirollik",
    "Grenada" : "Grenada",
    "Georgia" : "Gruziya",
    "French Guiana" : "Fransuz Gvianasi",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenlandiya",
    "Gambia" : "Gambiya",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Gvadelupa",
    "Equatorial Guinea" : "Ekvatorial Gvineya",
    "Greece" : "Gretsiya",
    "South Georgia and the South Sandwich Islands" : "Janubiy Jorjiya va Janubiy Sandvich orollari",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Gonkong",
    "Heard Island and McDonald Islands" : "Heard oroli va Makdonald orollari",
    "Honduras" : "Gonduras",
    "Croatia" : "Xorvatiya",
    "Haiti" : "Gaiti",
    "Hungary" : "Vengriya",
    "Indonesia" : "Indoneziya",
    "Ireland" : "Irlandiya",
    "Israel" : "Isroil",
    "Isle of Man" : "Man oroli",
    "India" : "Hindiston",
    "British Indian Ocean Territory" : "Britaniya Hind okeani hududi",
    "Iraq" : "Iroq",
    "Iran" : "Eron",
    "Iceland" : "Islandiya",
    "Italy" : "Italiya",
    "Jamaica" : "Yamayka",
    "Jordan" : "Iordaniya",
    "Japan" : "Yaponiya",
    "Kenya" : "Keniya",
    "Kyrgyzstan" : "Qirg'iziston",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comores" : "Komor",
    "Saint Kitts and Nevis" : "Sent-Kitts va Nevis",
    "North Korea" : "Shimoliy Koreya",
    "South Korea" : "Janubiy Koreya",
    "Kuwait" : "Quvayt",
    "Cayman Islands" : "Kayman orollari",
    "Kazakhstan" : "Qozog'iston",
    "Laos" : "Laos",
    "Lebanon" : "Livan",
    "Saint Lucia" : "Sent-Lyusiya",
    "Liechtenstein" : "Lixtenshteyn",
    "Sri Lanka" : "Shri-Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litva",
    "Luxembourg" : "Lyuksemburg",
    "Latvia" : "Latviya",
    "Libya" : "Libya",
    "Morocco" : "Marokash",
    "Monaco" : "Monako",
    "Moldova" : "Moldoviya",
    "Montenegro" : "Chernogoriya",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall orollari",
    "Macedonia" : "Makedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanma",
    "Mongolia" : "Mo'g'uliston",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Shimoliy Mariana orollari",
    "Mauritania" : "Mavritaniya",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mavrikiy",
    "Maldives" : "Maldiv orollari",
    "Malawi" : "Malavi",
    "Mexico" : "Meksika",
    "Malaysia" : "Malayziya",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibiya",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk oroli",
    "Nigeria" : "Nigeriya",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Niderlandiya",
    "Norway" : "Norvegiya",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Ummon",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransuz Polineziyasi",
    "Papua New Guinea" : "Papua-Yangi Gvineya",
    "Philippines" : "Filippin",
    "Pakistan" : "Pokiston",
    "Poland" : "Polsha",
    "Saint Pierre and Miquelon" : "Sent-Pyer va Mikelon",
    "Pitcairn" : "Pitkern",
    "Puerto Rico" : "Puerto-Riko",
    "Palestine" : "Falastin",
    "Portugal" : "Portugaliya",
    "Palau" : "Palau",
    "Paraguay" : "Paragvay",
    "Qatar" : "Qatar",
    "Réunion" : "Reunion",
    "Romania" : "Ruminiya",
    "Serbia" : "Serbiya",
    "Russia" : "Rossiya",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudiya Arabistoni",
    "Solomon Islands" : "Solomon orollari",
    "Seychelles" : "Seyshel orollari",
    "Sudan" : "Sudan",
    "Sweden" : "Shvetsiya",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Avliyo Yelena, Ko'tarilish va Tristan da Kunya",
    "Slovenia" : "Sloveniya",
    "Svalbard and Jan Mayen" : "Svalbard va Yan Mayen",
    "Slovakia" : "Slovakiya",
    "Sierra Leone" : "Syerra-Leone",
    "San Marino" : "San-Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somali",
    "Suriname" : "Surinam",
    "South Sudan" : "Janubiy Sudan",
    "Sao Tome and Principe" : "San-Tome va Prinsipi",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Siriya",
    "Swaziland" : "Svazilend",
    "Turks and Caicos Islands" : "Turks va Kaykos orollari",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarctic yerlari",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tojikiston",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmaniston",
    "Tunisia" : "Tunis",
    "Tonga" : "Tonga",
    "Turkey" : "Turkiya",
    "Trinidad and Tobago" : "Trinidad va Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tayvan",
    "Tanzania" : "Tanzaniya",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Amerika Qo'shma Shtatlarining Kichik Chet orollari",
    "United States" : "Qo'shma Shtatlar",
    "Uruguay" : "Urugvay",
    "Uzbekistan" : "O'zbekiston",
    "Holy See" : "Muqaddas orollar",
    "Saint Vincent and the Grenadines" : "Sent-Vinsent va Grenadin orollari",
    "Venezuela" : "Venetsuela",
    "Virgin Islands (British)" : "Virjiniya orollari (Britaniya)",
    "Virgin Islands (U.S.)" : "Virjiniya orollari (AQSh)",
    "Vietnam" : "V'etnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Uollis va Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yaman",
    "Mayotte" : "Mayotte",
    "South Africa" : "Janubiy Afrika",
    "Zambia" : "Zambiya",
    "Zimbabwe" : "Zimbabve",
    "Loading administrators …" : "Administratorlar yuklanmoqda…",
    "Loading people you've shared with …" : "Siz ulashgan odamlar yuklanmoqda …",
    "Control" : "Boshqaruv",
    "over user data access" : "foydalanuvchi ma'lumotlariga kirish orqali",
    "Knowledge" : "Bilim",
    "of how the data is stored" : "ma'lumotlar qanday saqlanishi haqida",
    "Freedom" : "Ozodlik",
    "to choose a platform" : "platforma tanlash uchun"
},
"nplurals=1; plural=0;");
