OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Llif gweithgarwch personol ar gyfer %s",
    "Your feed URL is invalid" : "Mae eich URL llif yn annilys",
    "Activity feed" : "Llif gweithgaredd",
    "Your settings have been updated." : "Mae eich gosodiadau wedi'u diweddaru.",
    "Settings have been updated." : "Mae'r gosodiadau wedi'u diweddaru.",
    "Recent activity" : "Gweithgaredd diweddar",
    "No activities" : "Dim gweithgareddau",
    "More activities" : "Mwy o weithgareddau",
    "Daily activity summary for %s" : "Crynodeb o weithgarwch dyddiol ar gyfer %s",
    "All activities" : "Pob gweithgaredd",
    "By others" : "Gan eraill",
    "By you" : "Gennych chi",
    "Activity at %s" : "Gweithgarwch yn %s",
    "Hello %s" : "Helo %s",
    "Hello %s," : "Helo %s,",
    "There was some activity at %s" : "Roedd rhywfaint o weithgarwch yn %s",
    "_and %n more _::_and %n more _" : ["a %n arall ","a %n arall ","a %n arall ","a %n arall "],
    "Mail" : "E-bost",
    "Push" : "Gwthio",
    "Activity" : "Gweithred",
    "Notifications" : "Hysbysiadau",
    "This application enables people to view a log of activities about them, their files or other data." : "Mae'r rhaglen hon yn galluogi pobl i weld cofnod o weithgareddau amdanynt, eu ffeiliau neu ddata arall.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Mae'r ap hwn yn caniatáu i bobl weld gweithredoedd sy'n gysylltiedig â'u ffeiliau a'u data yn Nextcloud.\n\t\tGall pob person ffurfweddu eu gosodiadau gweithgaredd unigol yn y gosodiadau personol,\n\t\ti ddewis pa weithgaredd y dylid ei wthio i ffonau symudol, ei anfon trwy e-bost\n\t\tneu a anfonir crynodeb dyddiol bob bore.\n\t\tMae rhagor o wybodaeth ar gael yn y ddogfennaeth Gweithgaredd.",
    "Send email" : "Anfon e-bost",
    "Send push notification" : "Anfon hysbysiad gwthio",
    "Activity notification configuration" : "Ffurfweddiad hysbysiad gweithgaredd",
    "Today" : "Heddiw",
    "Yesterday" : "Ddoe",
    "You need to set up your email address before you can receive notification emails." : "Mae angen i chi osod eich cyfeiriad e-bost cyn y gallwch dderbyn negeseuon e-bost hysbysu.",
    "Send activity emails" : "Anfon e-byst gweithgaredd",
    "As soon as possible" : "Cyn gynted ā phosib",
    "Hourly" : "Pob awr",
    "Daily" : "Dyddiol",
    "Weekly" : "Wythnosol",
    "Open {filename}" : "Agor {filename}",
    "in {path}" : "yn {path}",
    "Home" : "Cartref",
    "This stream will show events like additions, changes & shares" : "Bydd y llif hon yn dangos digwyddiadau fel ychwanegiadau, newidiadau a chyfrannau",
    "No activity yet" : "Dim gweithred eto",
    "Activity settings" : "Gosodiadau gweithgaredd",
    "Enable RSS feed" : "Galluogi llif RSS",
    "RSS feed" : "Llif RSS",
    "Copy RSS feed link" : "Copïo dolen llif RSS",
    "Personal notification settings" : "Gosodiadau hysbysu personol",
    "Unable to load the activity list" : "Methu llwytho'r rhestr gweithgaredd",
    "Choose for which activities you want to get an email or push notification." : "Dewiswch ar gyfer pa weithgareddau rydych chi am gael e-bost neu hysbysiad gwthio.",
    "Choose for which activities you want to get a push notification." : "Dewiswch ar gyfer pa weithgareddau rydych chi am gael hysbysiad gwthio.",
    "Notification" : "Hysbysiad",
    "Enable notification emails" : "Galluogi e-byst hysbysu",
    "Daily activity summary" : "Crynodeb gweithgaredd dyddiol",
    "Send daily activity summary in the morning" : "Anfonwch grynodeb gweithgaredd dyddiol yn y bore",
    "Default settings" : "Gosodiadau rhagosodedig",
    "Configure the default notification settings for new accounts." : "Ffurfweddwch y gosodiadau hysbysu rhagosodedig ar gyfer cyfrifon newydd.",
    "Unable to save the settings" : "Methu cadw'r gosodiadau",
    "No more events to load" : "Dim mwy o ddigwyddiadau i'w llwytho"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
