OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "restaurat",
    "Deleted files" : "Fișiere șterse",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Fișierele și folderele șterse din coșul de gunoi (pot expira în timpul exportului dacă spațiul de stocare e limitat)",
    "Restore" : "Restaurare",
    "Cancel" : "Anulare",
    "Deleted" : "A fost șters.",
    "Unknown" : "Necunoscut",
    "All files" : "Toate fișierele",
    "You" : "Tu",
    "List of files that have been deleted." : "Lista fișierelor șterse.",
    "No deleted files" : "Nu sunt fișiere șterse",
    "Files and folders you have deleted will show up here" : "Fișierele și dosarele șterse vor fi afișate aici"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
