OC.L10N.register(
    "support",
    {
    "Generate system report" : "Gerar relatório do sistema",
    "Forum" : "Forúm",
    "News" : "Notícias",
    "Like our Facebook page" : "Deixe um Gosto na nossa página do Facebook",
    "Follow us on Twitter" : "Siga-nos no Twitter",
    "Check out our blog" : "Veja o nosso blog",
    "Subscribe to our newsletter" : "Subscreva as nossas notícias"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
