OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna plošča",
    "Dashboard app" : "Program Nadzorna plošča",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Začnite dan s pravimi informacijami\n\nNadzorna plošča Nextcloud je prva točka dneva, ki vam omogoča\npregled prihajajočih sestankov, nujnih elektronskih sporočil in sporočil klepeta, podrobnosti o prejetih nalogah, najnovejših sporočilih z družbenih omrežij in še veliko več! Vsak uporabnik lahko doda gradnike in spreminja ozadje po svojih željah.",
    "Weather" : "Vreme",
    "Status" : "Stanje",
    "Good morning" : "Dobro jutro",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good afternoon" : "Dober dan",
    "Good afternoon, {name}" : "Dober dan, {name}",
    "Good evening" : "Dober večer",
    "Good evening, {name}" : "Dober večer, {name}",
    "Hello" : "Pozdravljeni",
    "Hello, {name}" : "Pozdravljeni, {name}",
    "Customize" : "Prilagodi",
    "Edit widgets" : "Izbor gradnikov",
    "Get more widgets from the App Store" : "Pridobi več gradnikov s spletišča App Store",
    "Weather service" : "Vremenske storitve",
    "Weather data from Met.no" : "Podatke vremena omogoča Met.no",
    "geocoding with Nominatim" : "geokodiranje Nominatim",
    "elevation data from OpenTopoData" : "podatke nadmorske višine OpenTopoData"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
