OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Non se atopou a configuración do servizo",
    "Error starting install of ExApp" : "Produciuse un erro ao iniciar a instalación da ExApp",
    "ExApp failed to register, check the NC logs" : "Produciuse un fallo ao rexistrar a ExApp, consulte os ficheiros de rexistro de Nextcloud",
    "ExApp not found, failed to get status" : "Non se atopou a ExApp, produciuse un fallo ao obter o estado",
    "Error adding Docker registry" : "Produciuse un erro ao engadir o rexistro de Docker",
    "Error removing Docker registry" : "Produciuse un erro ao retirar o rexistro de Docker",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Esta aplicación non foi instalada desde a tenda de aplicacións. Non hai información adicional dispoñíbel. Só se permiten as accións de activar/desactivar e retirar.",
    "Could not perform installation of ExApp" : "Non foi posíbel realizar a instalación da ExApp",
    "Failed to enable ExApp" : "Produciuse un fallo ao activar a ExApp",
    "Failed to disable ExApp" : "Produciuse un fallo ao desactivar a ExApp",
    "Could not update ExApp" : "Non foi posíbel actualizar a ExApp",
    "Error starting update of ExApp" : "Produciuse un erro ao iniciar a actualización da ExApp",
    "Could not perform update of ExApp" : "Non foi posíbel realizar a actualización da ExApp",
    "ExApp not found, failed to get logs" : "Non se atopou a ExApp, produciuse un fallo ao obter os rexistros",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Produciuse un erro ao obter os rexistros do contedor. Nota: a descarga do contedor Docker só funciona para contedores co controlador de rexistro json-file ou journald. Erro: %s",
    "ExApp not found, failed to get deploy options" : "Non se atopou a ExApp, produciuse un fallo ao obter as opcións de despregadura",
    "AppAPI authentication failed" : "Fallou a autenticación da AppAPI",
    "AppAPI ExApp notifier" : "Notificador de AppAPI a ExApp",
    "AppAPI" : "AppAPI (API de ExApps)",
    "AI Integration Team" : "Equipo de integración de IA",
    "ExApps Settings" : "Axustes das ExApps",
    "AppAPI deploy daemon" : "Sevizo de despregadura AppAPI",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "O servizo de despregadura predeterminado de AppAPI non está definido. Rexistre un servizo de despregadura predeterminado nos axustes para instalar aplicacións externas (Ex-Apps).",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "O servizo de despregadura predeterminado de «%s»I non é accesíbel. Comprobe a configuración do servizo.",
    "The AppAPI default deploy daemon is not using HaRP. Please consider switching to HaRP for better performance." : "O servizo de despregadura predeterminado de AppAPI non emprega HaRP. Considere cambiar a HaRP para mellorar o rendemento.",
    "AppAPI HaRP version check" : "Comprobación da versión HaRP de AppAPI",
    "Could not retrieve HaRP version from daemon \"%s\"" : "Non foi posíbel recuperar a versión HaRP do servizo «%s»",
    "HaRP version for daemon \"%s\" is \"%s\", which is too old. The minimum required version is \"%s\". Please update the daemon to the latest version." : "A versión de HaRP para o servizo «%s» é «%s», que é antiga de máis. A versión mínima requirida é «%s». Actualice o servizo á última versión.",
    "Failed to check HaRP version for daemon \"%s\": %s" : "Produciuse un fallo ao comprobar a versión de HaRP para o servizo «%s»: %s",
    "Nextcloud AppAPI" : "AppAPI (API de ExApps) de Nextcloud",
    "External Apps management" : "Xestión de aplicacións externas",
    "Admin options saved" : "Gardáronse as opcións de administración",
    "Failed to save admin options" : "Produciuse un fallo ao gardar as opcións de administración.",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "O proxecto AppAPI é unha iniciativa emocionante que ten como obxectivo revolucionar a forma na que se desenvolven as aplicacións para Nextcloud a través do uso de contedores docker. Permitindo unha maior escolla de linguaxe de programación e permitindo que as tarefas computacionalmente custosas sexan descargadas a un servidor diferente.",
    "Deploy daemons" : "Servizos de despregadura",
    "A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Un servizo de despregadura (DaemonConfig) é un servizo de orquestración de ExApps",
    "Deploy daemons. A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Servizos de despregadura. Un servizo de despregadura (DaemonConfig) é un servizo de orquestración de ExApps.",
    "Default deploy daemon is not accessible. Please check its configuration" : "Non é posíbel acceder ao servizo predeterminado de despregadura. Comprobe a súa configuración",
    "ExApp init timeout (minutes)" : "Tempo de espera de inicio da ExApp (minutos)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Tempo de espera do proceso de preparación da ExApp após do cal AppAPI marcarao como fallado",
    "ExApp init timeout" : "Tempo de espera de inicio da ExApp",
    "ExApp container restart policy" : "Directiva de reinicio do contedor da ExApp",
    "Choose the container restart policy, e.g. 'always' to ensure ExApps will be running after a daemon server reboot" : "Escolla a directiva de reinicio do contedor, p. ex. «sempre» para garantir que ExApps se execute após o reinicio do servidor do servizo",
    "This settings changes are effective only for newly created containers" : "Os cambios destes axustes son efectivos só para contedores creados recentemente",
    "Deploy daemon deletion confirmation" : "Confirmación de eliminación do servizo de despregadura",
    "Are you sure you want delete the \"{name}\" deploy daemon?" : "Confirma que quere eliminar o servizo de despregadura «{name}»?",
    "Remove all ExApps installed on this daemon" : "Retirara todas as ExApps instaladas neste servizo",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "A \"manual-install\" deploy daemon cannot be set as default" : "Un servizo de despregadura «manual-install» non pode ser definido como predeterminado",
    "Failed to save admin settings. Check the logs" : "Produciuse un fallo ao gardar os axustes de administración. Consulte os ficheiros de rexistro",
    "Password confirmation failed" : "Produciuse un fallo ao confirmar o contrasinal",
    "Default" : "Predeterminado",
    "Set as default" : "Definir como predeterminado",
    "Test deploy" : "Proba da despregadura",
    "Docker registries" : "Rexistros de Docker",
    "Edit" : "Editar",
    "Daemon connection successful" : "Conexión satisfactoria do servizo",
    "Failed to connect to the daemon. Check the logs" : "Produciuse un fallo ao conectar co servizo. Consulte os ficheiros de rexistro",
    "Failed to check connection to the daemon. Check the logs" : "Produciuse un fallo ao comprobar a conexión co servizo. Consulte os ficheiros de rexistro",
    "Unlimited" : "Sen límites",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} CPU","{n} CPU"],
    "Deploy daemon configuration" : "Configuración do servizo de despregadura",
    "Deploy daemon configuration details" : "Detalles de configuración do servizo de despregadura",
    "Deploy daemon" : "Servizo de despregadura",
    "Default daemon. ExApps will be installed on it" : "Servizo predeterminado. As ExApps instalaranse nel",
    "The \"Manual install\" daemon is usually used for development. It cannot be set as the default daemon." : "O servizo de «instalación manual» adoita empregarse para desenvolvemento. Non é posíbel definilo como servizo predeterminado.",
    "ExApps installed" : "ExApps instaladas",
    "Name" : "Nome",
    "Protocol" : "Protocolo",
    "Host" : "Servidor",
    "ExApp direct communication (FRP disabled)" : "Comunicación directa coa ExApp (FRP desactivado)",
    "Deploy options" : "Opcións de despregadura",
    "Docker network" : "Rede Docker",
    "Nextcloud URL" : "URL de Nextcloud",
    "HaProxy password" : "Contrasinal de HaProxy",
    "GPU support" : "Compatibilidade con GPU",
    "Computation device" : "Dispositivo de computación",
    "Memory limit" : "Límite de memoria",
    "CPU limit" : "Límite de CPU",
    "Additional options" : "Opcións adicionais",
    "Check connection" : "Comprobar a conexión",
    "Registered Deploy daemons list" : "Lista de servizos de despregadura rexistrados",
    "No Deploy daemons are registered" : "Non hai ningún servizo de despregadura rexistrado",
    "Register a custom one or configure one from the available templates" : "Rexistre un personalizado ou configúreo a partir dos modelos dispoñíbeis",
    "Register daemon" : "Rexistrar o servizo",
    "Register ExApp in Nextcloud" : "Rexistrar a ExApp en Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Comprobar se a ExApp está rexistrada en Nextcloud antes da despregadura",
    "Image pull" : "Extraer a imaxe",
    "Check if the image is successfully pulled" : "Comprobe se a imaxe foi extraída correctamente",
    "Container started" : "O contedor foi iniciado",
    "Check if the image successfully pulled and container is created and started" : "Comprobe se a imaxe foi extraída correctamente e se se creou e se iniciou o contedor",
    "Heartbeat" : "Latexo (proba de execución)",
    "Check for the heartbeat is finished and healthy" : "Comprobe se o latexo está rematado e é saudábel",
    "Init step" : "Paso inicial",
    "Wait for initialization step to finish" : "Agarde a que remate o paso de preparación",
    "Enabled" : "Activado",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Comproba se a ExApp xestionou correctamente o evento activado e rexistrou todo correctamente",
    "Only if ExApp container is preset" : "Só se o contedor da ExApp está predefinido",
    "Deploy test passed successfully!" : "A proba de despregadura foi superada satisfactoriamente!",
    "Deploy test failed at step \"{step}\"" : "Produciuse un fallo na proba de despregadura no paso «{step}»",
    "AppAPI will try to install small skeleton ExApp to check that the daemon is configured correctly and the deployment steps are successful." : "AppAPI tentará instalar un pequeno esqueleto da ExApp para comprobar que o servizo está configurado correctamente e que se están a cumprir os pasos da despregadura.",
    "The following deploy test checks must succeed:" : "As seguintes comprobacións da proba de despregadura deben ser satisfactorias:",
    "More information" : "Máis información",
    "Download ExApp logs" : "Descargar os rexistros da ExApp",
    "Remove the test ExApp" : "Retirar a proba da ExApp",
    "Start the deploy test" : "Iniciar a proba de despregadura",
    "Stop the deploy test" : "Deter a proba de despregadura",
    "The test ExApp is unregistered and its container is removed on \"Stop the deploy test\"" : "A ExApp non está rexistrada e o contedor retirarase ao «Deter a proba de despregadura»",
    "Please enter a registry domain" : "Introduza un dominio de rexistro",
    "\"From\" cannot be \"local\"" : "«Desde» non pode ser «local»",
    "This registry mapping already exists" : "Xa existe esta asignación de rexistro",
    "\"From\" and \"To\" cannot be the same" : "«Desde» e «Ata» non poden ser o mesmo",
    "Docker registry mapping added" : "Engadiuse a asignación do rexistro de Docker",
    "Error adding Docker registry mapping" : "Produciuse un erro ao engadir a asignación do rexistro de Docker",
    "Docker registry mapping removed" : "Foi retirada a asignación do rexistro de Docker",
    "Error removing Docker registry mapping" : "Produciuse un erro ao retirar a asignación do rexistro de Docker",
    "Override Docker registries" : "Anular os rexistros de Docker",
    "Configure Docker registry override mappings for the selected daemon." : "Configurar as asignacións de anulación do rexistro de Docker para o servizo seleccionado.",
    "The matching source registry in ExApp info.xml will be overwritten during deployment (image pull step)." : "O rexistro de orixe correspondente en ExApp info.xml sobrescribirase durante a despregadura (paso de extracción de imaxe).",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "Isto é útil se quere usar un rexistro Docker personalizado, por exemplo, para usar un rexistro Docker privado, ou para usar un rexistro Docker diferente para probas.",
    "Image pull will be skipped" : "Omitirase a extracción da imaxe",
    "Remove" : "Retirar",
    "No custom Docker registries are registered" : "Non está rexistrado ningún rexistro personalizado de Docker ",
    "Add registry override mapping" : "Engadir a asignación de anulación do rexistro",
    "From" : "Desde",
    "registry URL (e.g. ghcr.io)" : "URL do rexistro (p. ex., ghcr.io)",
    "To" : "Ata",
    "registry URL (e.g. docker.io)" : "URL do rexistro (p. ex., docker.io)",
    "Add" : "Engadir",
    "Hostname used by Nextcloud to access the ExApps" : "Nome do servidor empregado para acceder a ExApps",
    "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}." : "O nome do servidor (e o porto) no que {name} está dispoñíbel. Isto non ten por que ser unha máquina pública, só unha máquina accesíbel polo servidor Nextcloud, p. ex. {host}.",
    "The hostname (and port) or path at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server. It can also be the path to the Docker socket. (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "O nome do servidor (e o porto) ou ruta no que {name} está dispoñíbel. Isto non ten por que ser unha máquina pública, só unha máquina accesíbel polo servidor Nextcloud. Tamén pode ser unha ruta para o conectador Docker. (p. ex., nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "A daemon with this name already exists" : "Xa existe un servizo con ese nome",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "A chave secreta para a comunicación de contedores HaRP (HP_SHARED_KEY).",
    "AppAPI Docker Socket Proxy authentication password" : "Contrasinal de autenticación do proxy de AppAPI Docker Socket",
    "Changes are only effective for newly installed ExApps. For existing ExApps, the Docker containers should be recreated to apply the new settings values." : "Os cambios só son efectivos para ExApps instaladas recentemente. Para ExApps existentes, os contedores Docker deberían ser creados de novo para aplicar os novos valores dos axustes.",
    "The Docker network that the deployed ExApps will use." : "A rede docker que empregarán as ExApps despregadas.",
    "The URL should start with http:// or https://" : "O URL debe comezar por http:// ou https://",
    "For a HTTPS daemon, the Nextcloud URL should be HTTPS" : "Para un servizo HTTPS, o URL de Nextcloud debe ser HTTPS",
    "All available GPU devices on the daemon host need to be enabled in ExApp containers by Docker." : "Todos os dispositivos GPU dispoñíbeis no servidor do servizo deben estar activados nos contedores ExApp por Docker.",
    "DaemonConfig successfully registered" : "DaemonConfig foi rexistrado satisfactoriamente",
    "Failed to register DaemonConfig. Check the logs" : "Produciuse un fallo ao rexistrar DaemonConfig. Consulte os ficheiros de rexistro",
    "DaemonConfig successfully updated" : "DaemonConfig foi actualizado satisfactoriamente",
    "Failed to update DaemonConfig. Check the logs" : "Produciuse un fallo ao actualizar DaemonConfig. Consulte os ficheiros de rexistro",
    "Failed to connect to Daemon. Check the logs" : "Produciuse un fallo ao conectar co servizo. Consulte os ficheiros de rexistro",
    "Failed to check connection to Daemon. Check the logs" : "Produciuse un fallo ao comprobar a conexión co servizo. Consulte os ficheiros de rexistro",
    "Edit the deploy daemon" : "Editar o servizo de despregadura",
    "Register a new deploy daemon" : "Rexistrar un novo servizo de despregadura",
    "Daemon configuration template" : "Modelo de configuración do servizo",
    "Select a daemon configuration template" : "Seleccione un modelo de configuración do servizo",
    "Daemon registration form" : "Formulario de rexistro do servizo",
    "Unique deploy daemon name" : "Nome único do servizo de despregadura",
    "Unique deploy Daemon name" : "Nome único do servizo de despregadura",
    "Display name" : "Nome para amosar",
    "Deployment method" : "Método de despregadura",
    "Select the daemon deploy method" : "Seleccione o método de despregadura do servizo",
    "HaRP host" : "Servidor HaRP",
    "Daemon host" : "Servidor do servizo",
    "HaRP shared key" : "Chave compartida de HaRP",
    "The password must be at least 12 characters long" : "O contrasinal precisa ser polo menos de 12 caracteres de lonxitude",
    "Set this daemon as the default one" : "Definir este servizo como o predeterminado",
    "Set as the default daemon" : "Definir como servizo predeterminado",
    "Enable HTTPS" : "Activar HTTPS",
    "Show deploy options" : "Amosar as opcións de despregadura",
    "Hide deploy options" : "Agochar as opcións de despregadura",
    "Enable HaRP" : "Activar HaRP",
    "FRP server address" : "Enderezo do servidor FRP",
    "The address (host:port) of the FRP server that should be reachable by the ExApp in the network defined in the 'Docker network' section." : "O enderezo (máquina:porto) do servidor FRP que debe ser alcanzado pola ExApp na rede definida  na sección «Rede Docker».",
    "Docker socket proxy port" : "Porto do proxy do conectador Docker",
    "The port in HaRP which the Docker socket proxy connects to. This should be exposed but for the in-built one, it is not required to be exposed or changed." : "O porto en HaRP ao que se conecta o proxy do conectador Docker. Este debe estar exposto, mais no caso do porto incorporado, non é necesario expoñelo nin cambialo.",
    "Disable FRP" : "Desactivar FRP",
    "Flag for advanced setups only. Disables the FRP tunnel between ExApps and HaRP." : "Indicador só para as configuracións avanzadas. Desactiva o túnel FRP entre ExApps e HaRP.",
    "Docker network for ex-app deployment must be defined" : "Debe definirse a rede Docker para a despregadura da ExApp",
    "Compute device" : "Dispositivo de computación",
    "Memory limit (in MiB)" : "Límite de memoria (en MiB)",
    "Must be a positive integer" : "Debe ser un número enteiro positivo.",
    "Maximum amount of memory that the ExApp container can use in mebibytes" : "Cantidade máxima de memoria en mebibytes que pode empregar o contedor ExApp",
    "CPU limit as decimal value" : "Límite da CPU como valor decimal",
    "Must be a positive number" : "Debe ser un número positivo.",
    "Maximum number of CPU cores that the ExApp container can use (e.g. 0.5 for half a core, 2 for two cores)" : "Número máximo de núcleos de CPU que pode empregar o contedor ExApp (por exemplo, 0,5 para medio núcleo, 2 para dous núcleos)",
    "Add additional option" : "Engadir unha opción adicional",
    "Option key (unique)" : "Clave de opción (única)",
    "Option key (unique, e.g. my_key)" : "Clave de opción (única, p. ex., a_miña_clave)",
    "Option key is required" : "É necesaria a clave de opción",
    "Option value" : "Valor da opción",
    "Option value is required" : "É necesario o valor da opción",
    "Confirm" : "Confirmar",
    "Save" : "Gardar",
    "Register" : "Rexistrarse",
    "External Apps" : "Aplicacións externas",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Reforce o seu Nextcloud con AppAPI e as súas aplicacións deseñadas especialmente.\n\n\nA AppAPI é un proxecto dentro do ecosistema Nextcloud deseñado para axilizar e mellorar o proceso de\ndesenvolvemento, despregadura e xestión de aplicacións.\n\nIntroduce unha nova metodoloxía que permite aos desenvolvedores crear\naplicacións empregando diversas linguaxes de programación, sen limitarse a PHP, que era o que se usaba tradicionalmente no desenvolvemento de Nextcloud.\n\n### Aplicación integrada\n\n**A partir de Nextcloud 30.0.1, esta aplicación inclúese no paquete predeterminado de Nextcloud.**\n\n### Apoio\n\nAgradecemos calquera apoio a este proxecto:\n\n- ⭐ Saliente o noso traballo en GitHub\n- ❗ Cree unha incidencia ou solicitude de funcionalidade\n- 💁 Solucione unha incidencia e faga unha solicitude de extracción (PR)\n\n- 🧑‍💻 Desenvolva a súa propia aplicación usando AppAPI\n\nEstamos moi entusiasmados co futuro do proxecto AppAPI e o seu potencial de transformación do\nxeito como se desenvolven e experimentan as aplicacións dentro de Nextcloud.\n\nMentres nos embarcamos nesta viaxe, convidámosvos cordialmente — desenvolvedores, pensadores, creadores e visionarios —\npara unirse a nós e dar forma a unha paisaxe de aplicacións máis versátil, estábel e segura.\n\n*As súas ideas, suxestións e colaboracións son inestimábeis para nós.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "O Proxecto AppAPI é unha iniciativa emocionante que pretende revolucionar a maneira na que se desenvolven as aplicacións para Nextcloud.",
    "Deploy Daemons" : "Servizos de despregadura",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "O servizo de despregadura (DaemonConfig) é un servizo de orquestración de ExApps",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Servizos de despregadura. O servizo de despregadura (DaemonConfig) é un servizo de orquestración de ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Non é posíbel acceder ao servizo predeterminado de  despregadura. Verifique a súa configuración",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Especifique a directiva de reinicio do contedor, p. ex. «sempre» para garantir que a ExApp se execute após o reinicio do servidor do servizo",
    "This settings changes are reflected only for newly created containers" : "Os cambios destes axustes só se reflícten nos contedores creados recentemente",
    "{license}-licensed" : "Licenciado baixo a {license}",
    "Update to {version}" : "Actualizar a {version}",
    "Delete data on remove" : "Eliminar os datos ao retirar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación non dispón dunha versión mínima de Nextcloud asignada. Isto será un erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación non dispón dunha versión máxima de Nextcloud asignada. Isto será un erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Non é posíbel instalar esta aplicación por mor de non cumprirse as dependencias:",
    "View in store" : "Ver na tenda",
    "Visit website" : "Visite o sitio web",
    "Report a bug" : "Informar dun fallo",
    "User documentation" : "Documentación do usuario",
    "Admin documentation" : "Documentación da administración da instancia",
    "Developer documentation" : "Documentación para desenvolvedores",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Esta aplicación non está rexistrada na tenda de aplicacións. Non hai información adicional dispoñíbel. Só se permiten as accións de activar/desactivar e retirar.",
    "This app is supported via your current Nextcloud subscription." : "Esta aplicación é compatíbel cos súa subscrición actual a Nextcloud.",
    "Supported" : "Compatíbel",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "As aplicacións destacadas están desenvolvidas por e dentro da comunidade. Ofrecen unha funcionalidade central e están preparadas para o seu uso en produción.",
    "Featured" : "Destacada",
    "Update to {update}" : "Actualizar a {update}",
    "All ExApps are up-to-date." : "Todas as ExApps están actualizadas.",
    "Default Deploy daemon is not accessible" : "Non é posíbel acceder ao servizo predeterminado de despregadura.",
    "Icon" : "Icona",
    "Version" : "Versión",
    "Daemon" : "Servizo",
    "Level" : "Nivel",
    "Actions" : "Accións",
    "Results from other categories" : "Resultados doutras categorías",
    "No apps found" : "Non se atopou ningunha aplicación",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n aplicación externa (ExApp) ten unha actualización dispoñíbel","%n aplicacións teñen unha actualización dispoñíbel"],
    "_Update_::_Update all_" : ["Actualizar","Actualizar todo"],
    "Deploy Daemon" : "Servizo de despregadura",
    "Type" : "Escribir",
    "Display Name" : "Nome para amosar",
    "GPUs support" : "Compatibilidade con GPU",
    "Are you sure you want delete Deploy Daemon" : "Confirma que quere eliminar o servizo de despregadura",
    "All ExApps on this daemon will be removed" : "Retiraranse todas as ExApps deste servizo",
    "All ExApps installed on this daemon will be removed" : "Retiraranse todas as ExApps instaladas neste servizo",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "O servizo de despregadura «manual-install» non pode ser definido como predeterminado",
    "Failed to save admin options. Check the logs" : "Produciuse un fallo ao gardar as opcións de administración. Consulte os ficheiros de rexistro",
    "Deploy daemon config details" : "Detalles de configuración do servizo de despregadura",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "O servizo de instalación manual que adoita usarse para o desenvolvemento. Non é posíbel definilo como servizo predeterminado.",
    "Deploy config" : "Configuración da despregadura",
    "Verify connection" : "Verificar a conexión",
    "No Deploy daemons configured" : "Non hai ningún servizo de despregadura configurado",
    "Register a custom one or setup from available templates" : "Rexistre un personalizado ou configúreo a partir dos modelos dispoñíbeis",
    "Register Daemon" : "Rexistrar o servizo",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI tentará instalar un pequeno esqueleto da ExApp para verificar que o servizo está configurado correctamente e que se están a cumprir os pasos da despregadura.",
    "The following Deploy test checks must be passed to succeed:" : "As seguintes comprobacións de proba de despregadura deben superarse para ser satisfactoria:",
    "More info" : "Máis información",
    "Remove test ExApp" : "Retirar a proba da ExApp",
    "Start Deploy test" : "Iniciar a proba de despregadura",
    "Stop Deploy test" : "Deter a proba de despregadura",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "A ExApp non está rexistrada e o contedor retirarase ao «Deter a proba de despregadura»",
    "Hostname to access ExApps" : "Nome de servidor para acceder a ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nome da máquina ou ruta para acceder ao servizo Docker (p. ex., nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Xa existe un servizo con ese nome",
    "Password must be at least 12 characters long" : "O contrasinal precisa ser polo menos de 12 caracteres de lonxitude",
    "With https enabled network is set to host" : "Con https activado, a rede defínese como servidor",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Os cambios aplicaranse só ás ExApps instaladas recentemente. Para as ExApps existentes, deberían volver crearse os contedores Docker.",
    "URL should start with http:// or https://" : "O URL debe comezar por http:// ou https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Para o servizo HTTPS, o URL de Nextcloud debe ser HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Docker solicitará que todos os dispositivos GPU dispoñíbeis no servidor do servizo estean activados nos contedores de ExApp.",
    "Edit Deploy Daemon" : "Editar os servizos de despregadura",
    "Register Deploy Daemon" : "Servizos de despregadura rexistrados",
    "Select daemon configuration template" : "Seleccione o modelo de configuración do servizo",
    "Unique Deploy Daemon Name" : "Nome único do servizo de despregadura",
    "Select daemon deploy method" : "Seleccione o método de despregadura do servizo",
    "Set daemon as default" : "Definir o servizo como predeterminado",
    "Set as default daemon" : "Definir como servizo predeterminado",
    "Enable https" : "Activar https",
    "Show deploy config" : "Amosar a configuración da despregadura",
    "Hide deploy config" : "Agochar a configuración da despregadura",
    "Network" : "Rede",
    "Docker network name" : "Nome da rede Docker",
    "Additional option" : "Opción adicional",
    "by {author}\n{license}" : "por {author}\n{license}",
    "Your apps" : "As súas aplicacións",
    "Documentation" : "Documentación",
    "Details" : "Detalles",
    "Changelog" : "Notas da versión",
    "Active apps" : "Aplicacións activas",
    "Disabled apps" : "Aplicacións desactivadas",
    "Updates" : "Actualizacións",
    "Featured apps" : "Aplicacións destacadas",
    "Supported apps" : "Aplicacións compatíbeis",
    "manual-install apps cannot be updated" : "non é posíbel actualizar as aplicacións de instalación manual",
    "{progress}% Deploying" : "{progress}% despregando",
    "{progress}% Initializing" : "{progress}% preparando",
    "Healthchecking" : "Control de integridade",
    "Deploy and Enable" : "Despregar e activar",
    "Enable" : "Activar",
    "Disable" : "Desactivar",
    "Allow untested app" : "Permitir aplicación non probada",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Non é posíbel acceder ao servizo predeterminado de  despregadura. Verifique a súa configuración",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "A aplicación descargarase da tenda de aplicacións e despregarase no servizo de despregadura predeterminado",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación non está marcado como compatíbel coa súa versión de Nextcloud. Se continúa, poderá instalar a aplicación. Teña en conta que é probábel que a aplicación non funcione como se agarda.",
    "Your ExApps" : "As súas ExApps",
    "An error occurred during the request. Unable to proceed." : "Produciuse un erro durante a solicitude. Non é posíbel continuar.",
    "The app has been enabled but needs to be updated." : "Activouse a aplicación mais cómpre actualizala.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erro: non é posíbel activar esta aplicación porque fai que o servidor sexa inestábel",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Reforce o seu Nextcloud con AppAPI e as súas aplicacións deseñadas especialmente.\n\n\nA AppAPI é un proxecto dentro do ecosistema Nextcloud deseñado para axilizar e mellorar o proceso de\ndesenvolvemento, despregadura e xestión de aplicacións.\n\nIntroduce unha nova metodoloxía que permite aos desenvolvedores crear\naplicacións empregando diversas linguaxes de programación, sen limitarse a PHP, que era o que se usaba tradicionalmente no desenvolvemento de Nextcloud.\n\n\n### Lista de aplicacións que requiren AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot\n\n_Se quere desenvolver unha aplicación, estaremos encantados de axudarlle._\n\n### Apoio\n\nAgradecemos calquera apoio a este proxecto:\n\n- ⭐ Saliente o noso traballo en GitHub\n- ❗ Cree unha incidencia ou solicitude de funcionalidade\n- 💁 Solucione unha incidencia e faga unha solicitude de extracción (PR)\n\n- 🧑‍💻 Desenvolva a súa propia aplicación usando AppAPI\n\nEstamos moi entusiasmados co futuro do proxecto AppAPI e o seu potencial de transformación do\nxeito como se desenvolven e experimentan as aplicacións dentro de Nextcloud.\n\nMentres nos embarcamos nesta viaxe, convidámosvos cordialmente — desenvolvedores, pensadores, creadores e visionarios —\npara unirse a nós e dar forma a unha paisaxe de aplicacións máis versátil, estábel e segura.\n\n*As súas ideas, suxestións e colaboracións son inestimábeis para nós.*"
},
"nplurals=2; plural=(n != 1);");
