OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Added to favorites",
    "Removed from favorites" : "Removed from favorites",
    "You added {file} to your favorites" : "You added {file} to your favorites",
    "You removed {file} from your favorites" : "You removed {file} from your favorites",
    "Favorites" : "ລາຍການທີ່ມັກ",
    "File changes" : "File changes",
    "Created by {user}" : "Created by {user}",
    "Changed by {user}" : "Changed by {user}",
    "Deleted by {user}" : "Deleted by {user}",
    "Restored by {user}" : "Restored by {user}",
    "Renamed by {user}" : "Renamed by {user}",
    "Moved by {user}" : "Moved by {user}",
    "\"remote account\"" : "\"remote account\"",
    "You created {file}" : "You created {file}",
    "You created an encrypted file in {file}" : "You created an encrypted file in {file}",
    "{user} created {file}" : "{user} created {file}",
    "{user} created an encrypted file in {file}" : "{user} created an encrypted file in {file}",
    "{file} was created in a public folder" : "{file} was created in a public folder",
    "You changed {file}" : "You changed {file}",
    "You changed an encrypted file in {file}" : "You changed an encrypted file in {file}",
    "{user} changed {file}" : "{user} changed {file}",
    "{user} changed an encrypted file in {file}" : "{user} changed an encrypted file in {file}",
    "You deleted {file}" : "You deleted {file}",
    "You deleted an encrypted file in {file}" : "You deleted an encrypted file in {file}",
    "{user} deleted {file}" : "{user} deleted {file}",
    "{user} deleted an encrypted file in {file}" : "{user} deleted an encrypted file in {file}",
    "You restored {file}" : "You restored {file}",
    "{user} restored {file}" : "{user} restored {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "You renamed {oldfile} (hidden) to {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "You renamed {oldfile} (hidden) to {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "You renamed {oldfile} to {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "You renamed {oldfile} to {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renamed {oldfile} (hidden) to {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renamed {oldfile} (hidden) to {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renamed {oldfile} to {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renamed {oldfile} to {newfile}",
    "You moved {oldfile} to {newfile}" : "You moved {oldfile} to {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favorites</strong>",
    "Files" : "ຟາຍ",
    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "A favorite file or folder has been <strong>changed</strong>",
    "Failed to authorize" : "Failed to authorize",
    "Invalid folder path" : "Invalid folder path",
    "Folder not found" : "Folder not found",
    "The file cannot be found" : "The file cannot be found",
    "The destination path does not exist: %1$s" : "The destination path does not exist: %1$s",
    "You do not have permission to create a file at the specified location" : "You do not have permission to create a file at the specified location",
    "The file could not be converted." : "The file could not be converted.",
    "Could not get relative path to converted file" : "Could not get relative path to converted file",
    "Limit must be a positive integer." : "Limit must be a positive integer.",
    "The replacement character may only be a single character." : "The replacement character may only be a single character.",
    "Filename sanitization already started." : "Filename sanitization already started.",
    "No filename sanitization in progress." : "No filename sanitization in progress.",
    "Favorite files" : "Favorite files",
    "No favorites" : "No favorites",
    "More favorites" : "More favorites",
    "Accept" : "ຍອມຮັບ",
    "Reject" : "Reject",
    "Incoming ownership transfer from {user}" : "Incoming ownership transfer from {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour.",
    "Ownership transfer denied" : "Ownership transfer denied",
    "Your ownership transfer of {path} was denied by {user}." : "Your ownership transfer of {path} was denied by {user}.",
    "Ownership transfer failed" : "Ownership transfer failed",
    "Your ownership transfer of {path} to {user} failed." : "Your ownership transfer of {path} to {user} failed.",
    "The ownership transfer of {path} from {user} failed." : "The ownership transfer of {path} from {user} failed.",
    "Ownership transfer done" : "Ownership transfer done",
    "Your ownership transfer of {path} to {user} has completed." : "Your ownership transfer of {path} to {user} has completed.",
    "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
    "in %s" : "ໃນ %s",
    "Transferred from %1$s on %2$s" : "Transferred from %1$s on %2$s",
    "File Management" : "File Management",
    "Home" : "ໜ້າຫຼັກ",
    "Target folder does not exist any more" : "Target folder does not exist any more",
    "Reload current directory" : "Reload current directory",
    "Go to the \"{dir}\" directory" : "Go to the \"{dir}\" directory",
    "Current directory path" : "Current directory path",
    "Share" : "ແບ່ງປັນ",
    "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
    "You do not have permission to upload or create files here." : "You do not have permission to upload or create files here.",
    "Drag and drop files here to upload" : "Drag and drop files here to upload",
    "Favorite" : "ລາຍການທີ່ມັກ",
    "Back" : "ກັບຄືນ",
    "Toggle selection for file \"{displayName}\"" : "Toggle selection for file \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Toggle selection for folder \"{displayName}\"",
    "File is loading" : "File is loading",
    "Folder is loading" : "Folder is loading",
    "Filename" : "ຊື່ຟາຍ",
    "Folder name" : "ຊື່ໂຟນເດີ",
    "This node is unavailable" : "This node is unavailable",
    "Another entry with the same name already exists." : "Another entry with the same name already exists.",
    "Invalid filename." : "Invalid filename.",
    "Rename file" : "Rename file",
    "Folder" : "Folder",
    "Unknown file type" : "Unknown file type",
    "{ext} image" : "{ext} image",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} audio",
    "{ext} text" : "{ext} text",
    "Pending" : "ທີ່ກໍາລັງລໍຖ້າ",
    "Unknown date" : "Unknown date",
    "Active filters" : "Active filters",
    "Remove filter" : "ລຶບໂຕກອງ",
    "Today" : "ມື້ນີ້",
    "Last 7 days" : "Last 7 days",
    "Last 30 days" : "Last 30 days",
    "This year ({year})" : "This year ({year})",
    "Last year ({year})" : "Last year ({year})",
    "Custom range" : "ກຳນົດຊ່ວງເອງ",
    "Custom date range" : "Custom date range",
    "Search everywhere" : "ຄົ້ນຫາທຸກບ່ອນ",
    "Documents" : "ເອກະສານ",
    "Spreadsheets" : "Spreadsheets",
    "Presentations" : "Presentations",
    "PDFs" : "PDFs",
    "Folders" : "Folders",
    "Audio" : "ສຽງ",
    "Images" : "ຮູບພາບ",
    "Videos" : "ວິດີໂອ",
    "Filters" : "ຟິວເຕີ",
    "Appearance" : "Appearance",
    "Show hidden files" : "ສະແດງຟາຍທີ່ເຊື່ອງໄວ້",
    "Show file type column" : "Show file type column",
    "Show file extensions" : "Show file extensions",
    "Crop image previews" : "Crop image previews",
    "General" : "ທົ່ວໄປ",
    "Sort favorites first" : "Sort favorites first",
    "Sort folders before files" : "Sort folders before files",
    "Enable folder tree view" : "Enable folder tree view",
    "Default view" : "Default view",
    "All files" : "ຟາຍທັງໝົດ",
    "Personal files" : "Personal files",
    "Additional settings" : "Additional settings",
    "Actions" : "Actions",
    "File actions" : "File actions",
    "Selection" : "Selection",
    "Select all files" : "Select all files",
    "Deselect all" : "ເລືອກຄຶນທັງໝົດ",
    "Select or deselect" : "Select or deselect",
    "Select a range" : "Select a range",
    "Navigation" : "ການນຳທາງ",
    "Go to parent folder" : "Go to parent folder",
    "Go to file above" : "Go to file above",
    "Go to file below" : "Go to file below",
    "Go left in grid" : "Go left in grid",
    "Go right in grid" : "Go right in grid",
    "View" : "ເບິ່ງ",
    "Toggle grid view" : "Toggle grid view",
    "Show those shortcuts" : "Show those shortcuts",
    "Warnings" : "Warnings",
    "Warn before changing a file extension" : "Warn before changing a file extension",
    "Warn before deleting a file" : "Warn before deleting a file",
    "WebDAV URL" : "WebDAV URL",
    "Create an app password" : "Create an app password",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account.",
    "How to access files using WebDAV" : "How to access files using WebDAV",
    "Total rows summary" : "Total rows summary",
    "Toggle selection for all files and folders" : "Toggle selection for all files and folders",
    "Name" : "ຊື່",
    "File type" : "File type",
    "Size" : "ຂະຫນາດ",
    "Modified" : "\"{name}\" ແມ່ນຊື່ໄຟລ໌ທີ່ບໍ່ຖືກຕ້ອງ.",
    "{displayName}: failed on some elements" : "{displayName}: failed on some elements",
    "{displayName}: done" : "{displayName}: done",
    "{displayName}: failed" : "{displayName}: failed",
    "(selected)" : "(selected)",
    "List of files and folders." : "List of files and folders.",
    "You have used your space quota and cannot upload files anymore." : "You have used your space quota and cannot upload files anymore.",
    "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
    "File not found" : "File not found",
    "_{count} selected_::_{count} selected_" : ["ເລືອກ{count}"],
    "Views" : "Views",
    "Search everywhere …" : "Search everywhere …",
    "Search here …" : "Search here …",
    "Search scope options" : "Search scope options",
    "Search here" : "Search here",
    "Owner" : "Owner",
    "{usedQuotaByte} used" : "{usedQuotaByte} used",
    "{used} of {quota} used" : "{used} of {quota} used",
    "{relative}% used" : "{relative}% used",
    "Could not refresh storage stats" : "Could not refresh storage stats",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Storage information" : "Storage information",
    "Storage quota" : "Storage quota",
    "New folder" : "ໂຟນເດີໃຫມ່",
    "Create new folder" : "ສ້າງໂຟນເດີໃຫມ່",
    "This name is already in use." : "This name is already in use.",
    "Create" : "ສ້າງ",
    "Files starting with a dot are hidden by default" : "Files starting with a dot are hidden by default",
    "Failed to start filename sanitization." : "Failed to start filename sanitization.",
    "Failed to refresh filename sanitization status." : "Failed to refresh filename sanitization status.",
    "Filename sanitization in progress." : "Filename sanitization in progress.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Currently {processedUsers} of {totalUsers} accounts are already processed.",
    "Preparing …" : "Preparing …",
    "Refresh" : "Refresh",
    "All files have been santized for Windows filename support." : "All files have been santized for Windows filename support.",
    "Some files could not be sanitized, please check your logs." : "Some files could not be sanitized, please check your logs.",
    "Sanitization errors" : "Sanitization errors",
    "Not sanitized filenames" : "Not sanitized filenames",
    "Windows filename support has been enabled." : "Windows filename support has been enabled.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time.",
    "Please note that this may cause high workload on the sync clients." : "Please note that this may cause high workload on the sync clients.",
    "Limit" : "Limit",
    "This allows to configure how many users should be processed in one background job run." : "This allows to configure how many users should be processed in one background job run.",
    "Sanitize filenames" : "Sanitize filenames",
    "(starting)" : "(starting)",
    "Fill template fields" : "Fill template fields",
    "Submitting fields …" : "Submitting fields …",
    "Submit" : "ສົ່ງ",
    "Choose a file or folder to transfer" : "Choose a file or folder to transfer",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Transfer {path} to {userid}",
    "Ownership transfer request sent" : "Ownership transfer request sent",
    "Cannot transfer ownership of a file or folder you do not own" : "Cannot transfer ownership of a file or folder you do not own",
    "Transfer ownership of a file or folder" : "Transfer ownership of a file or folder",
    "New owner" : "New owner",
    "Keep {old}" : "Keep {old}",
    "Keep without extension" : "Keep without extension",
    "Use {new}" : "Use {new}",
    "Remove extension" : "Remove extension",
    "Change file extension" : "Change file extension",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Removing the file extension \"{old}\" may render the file unreadable.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Adding the file extension \"{new}\" may render the file unreadable.",
    "Do not show this dialog again." : "Do not show this dialog again.",
    "Cancel" : "ຍົກເລີກ",
    "Rename" : "ປ່ຽນຊື່",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Choose {file}" : "Choose {file}",
    "Files settings" : "Files settings",
    "Switch to list view" : "ປ່ຽນເປັນມຸມມອງລາຍການ",
    "Switch to grid view" : "Switch to grid view",
    "The file could not be found" : "The file could not be found",
    "Upload was cancelled by user" : "Upload was cancelled by user",
    "Not enough free space" : "Not enough free space",
    "Operation is blocked by access control" : "Operation is blocked by access control",
    "Error during upload: {message}" : "Error during upload: {message}",
    "Error during upload, status code {status}" : "Error during upload, status code {status}",
    "Unknown error during upload" : "Unknown error during upload",
    "Loading current folder" : "Loading current folder",
    "Retry" : "Retry",
    "No files in here" : "ບໍ່ມີຟາຍໃນທີ່ນີ້",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "Go back" : "Go back",
    "Loading …" : "Loading …",
    "Your files" : "Your files",
    "Open in files" : "Open in files",
    "File cannot be accessed" : "File cannot be accessed",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
    "No search results for “{query}”" : "No search results for “{query}”",
    "Search for files" : "Search for files",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
    "Failed to toggle Windows filename support" : "Failed to toggle Windows filename support",
    "Files compatibility" : "Files compatibility",
    "Enforce Windows compatibility" : "Enforce Windows compatibility",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
    "Blank" : "Blank",
    "Unable to create new file from template" : "Unable to create new file from template",
    "Pick a template for {name}" : "Pick a template for {name}",
    "Create a new file with the selected template" : "Create a new file with the selected template",
    "Creating file" : "Creating file",
    "Save as {displayName}" : "Save as {displayName}",
    "Save as …" : "Save as …",
    "Converting files …" : "Converting files …",
    "Failed to convert files: {message}" : "Failed to convert files: {message}",
    "All files failed to be converted" : "All files failed to be converted",
    "One file could not be converted: {message}" : "One file could not be converted: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n files could not be converted"],
    "_%n file converted_::_%n files converted_" : ["%n files converted"],
    "Files converted" : "Files converted",
    "Failed to convert files" : "Failed to convert files",
    "Converting file …" : "Converting file …",
    "File successfully converted" : "File successfully converted",
    "Failed to convert file: {message}" : "Failed to convert file: {message}",
    "Failed to convert file" : "Failed to convert file",
    "Delete" : "ລຶບ",
    "Leave this share" : "Leave this share",
    "Leave these shares" : "Leave these shares",
    "Disconnect storage" : "Disconnect storage",
    "Disconnect storages" : "Disconnect storages",
    "Delete permanently" : "Delete permanently",
    "Delete and unshare" : "Delete and unshare",
    "Delete file" : "Delete file",
    "Delete files" : "Delete files",
    "Delete folder" : "Delete folder",
    "Delete folders" : "Delete folders",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} items"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item"],
    "Confirm deletion" : "Confirm deletion",
    "Download" : "ດາວໂຫລດ",
    "The requested file is not available." : "The requested file is not available.",
    "The requested files are not available." : "The requested files are not available.",
    "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
    "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
    "Add or remove favorite" : "Add or remove favorite",
    "Move" : "ຍ້າຍ",
    "Copy" : "ສຳເນົາ",
    "Move or copy" : "ຍ້າຍ ຫຼື ສຳເນົາ",
    "Destination is not a folder" : "Destination is not a folder",
    "This file/folder is already in that directory" : "This file/folder is already in that directory",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
    "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
    "The files are locked" : "The files are locked",
    "The file does not exist anymore" : "The file does not exist anymore",
    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
    "Choose destination" : "Choose destination",
    "Copy to {target}" : "ສຳເນົາໄປທີ່ {target}",
    "Move to {target}" : "ຍ້າຍໄປທີ່ {target}",
    "Move or copy operation failed" : "Move or copy operation failed",
    "Open folder" : "Open folder",
    "Open folder {displayName}" : "Open folder {displayName}",
    "Open in Files" : "ເປີດໃນ Files",
    "Open locally" : "Open locally",
    "Failed to redirect to client" : "Failed to redirect to client",
    "Open file locally" : "Open file locally",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "The file should now open on your device. If it doesn't, please check that you have the desktop app installed.",
    "Retry and close" : "Retry and close",
    "Open online" : "Open online",
    "Details" : "ລາຍລະອຽດ",
    "View in folder" : "ເບິ່ງໃນໂຟນເດີ",
    "Type" : "ພິມ",
    "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
    "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
    "Create templates folder" : "Create templates folder",
    "Templates" : "Templates",
    "New template folder" : "New template folder",
    "In folder" : "In folder",
    "Search in all files" : "Search in all files",
    "Search in folder: {folder}" : "Search in folder: {folder}",
    "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Your browser does not support the Filesystem API. Directories will not be uploaded",
    "No files to upload" : "No files to upload",
    "Unable to create the directory {directory}" : "Unable to create the directory {directory}",
    "Some files could not be uploaded" : "Some files could not be uploaded",
    "Files uploaded successfully" : "Files uploaded successfully",
    "No files to process" : "No files to process",
    "Files copied successfully" : "Files copied successfully",
    "Files moved successfully" : "Files moved successfully",
    "Some files could not be copied" : "Some files could not be copied",
    "Some files could not be moved" : "ບາງຟາຍບໍ່ສາມາດເຄື່ອນຍ້າຍໄດ້",
    "Conflicts resolution skipped" : "Conflicts resolution skipped",
    "Upload cancelled" : "Upload cancelled",
    "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
    "This operation is forbidden" : "This operation is forbidden",
    "This folder is unavailable, please try again later or contact the administration" : "This folder is unavailable, please try again later or contact the administration",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Unexpected error: {error}" : "Unexpected error: {error}",
    "Unknown error" : "ຜິດພາດທີ່ບໍ່ຮູ້ຈັກ",
    "_%n file_::_%n files_" : ["%n files"],
    "_%n folder_::_%n folders_" : ["%n folders"],
    "_%n hidden_::_%n hidden_" : ["%n hidden"],
    "Filename must not be empty." : "ຊື່ໄຟລ໌ຕ້ອງບໍ່ຫວ່າງເປົ່າ.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" is not allowed inside a filename.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" is a reserved name and not allowed for filenames.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" is not an allowed filetype.",
    "Filenames must not end with \"{extension}\"." : "Filenames must not end with \"{extension}\".",
    "List of favorite files and folders." : "List of favorite files and folders.",
    "No favorites yet" : "ຍັງບໍ່ມີລາຍການທີ່ມັກເທື່ຶຶອ",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favorite will show up here",
    "List of your files and folders." : "List of your files and folders.",
    "Folder tree" : "Folder tree",
    "List of your files and folders that are not shared." : "List of your files and folders that are not shared.",
    "No personal files found" : "No personal files found",
    "Files that are not shared will show up here." : "Files that are not shared will show up here.",
    "Recent" : "ຫວ່າງບໍ່ດົນມາ ນີ້",
    "List of recently modified files and folders." : "List of recently modified files and folders.",
    "No recently modified files" : "No recently modified files",
    "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
    "Search" : "ຄົ້ນຫາ",
    "Search results within your files." : "Search results within your files.",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "ເລືອກທັງໝົດ",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
    "Clear filter" : "Clear filter",
    "Open file sidebar" : "Open file sidebar",
    "Search everywhere …" : "Search everywhere …",
    "Search here …" : "Search here …",
    "Preparing …" : "Preparing …",
    "Submitting fields …" : "Submitting fields …",
    "Invalid path selected" : "ເສັ້ນທາງທີ່ເລືອກບໍ່ຖືກຕ້ອງ",
    "Choose file or folder to transfer" : "Choose file or folder to transfer",
    "Change" : "Change",
    "Shared by link" : "ແບ່ງປັນດ້ວຍລິ້ງ",
    "Shared" : "ແບ່ງປັນ",
    "You" : "You",
    "Shared multiple times with different people" : "ແບ່ງປັນຫຼາຍຄັ້ງກັບຄົນຕ່າງກັນ",
    "Unable to change the favorite state of the file" : "Unable to change the favorite state of the file",
    "Error while loading the file data" : "Error while loading the file data",
    "Tags" : "ປ້າຍກຳກັບ",
    "Save as …" : "Save as …",
    "Converting files …" : "Converting files …",
    "Converting file …" : "Converting file …"
},
"nplurals=1; plural=0;");
