/* extracted by css-entry-points-plugin */
@import './text-BrKBJp1J.chunk.css';
@import './NcLoadingIcon-KhuNWNbx.chunk.css';
@import './NcCheckboxRadioSwitch-DJmw98x9-DACj1PYL.chunk.css';
@import './NcNoteCard-CwNXZ4vV-B785Dwxz.chunk.css';
@import './Wrapper-DtEXsk11.chunk.css';
@import './MenuBar-cvOyEjIa.chunk.css';
@import './Editor-C0IhEKq2.chunk.css';