"use strict";(self.webpackChunkfiles_pdfviewer=self.webpackChunkfiles_pdfviewer||[]).push([["node_modules_nextcloud_dialogs_node_modules_nextcloud_vue_dist_components_NcSelect_index_mjs"],{594:(e,_,d)=>{d.r(_),d.d(_,{default:()=>s.N});var s=d(6035)}}]);