OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "PDF үзэгч",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Nextcloud дотроо PDF баримт бичгүүдийг шууд үзнэ үү.\nНэмэлт давуу тал болгон энэ програм Adobe Illustrator (.ai) файлуудыг мөн харуулж чадна.\n[pdf.js](https://mozilla.github.io/pdf.js/)-ээр хангагдсан",
    "Failed to save settings" : "Тохиргоог хадгалж чадсангүй",
    "File upload failed." : "Файл байршуулж чадсангүй.",
    "To view a shared PDF file, the download needs to be allowed for this file share" : "Хуваалцсан PDF файлыг үзэхийн тулд энэ файлын хуваалцалтад татаж авах зөвшөөрөл олгогдсон байх шаардлагатай"
},
"nplurals=2; plural=(n != 1);");
