OC.L10N.register(
    "dav",
    {
    "Calendar" : "日曆",
    "Tasks" : "任務",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
    "You created calendar {calendar}" : "您建立了日曆 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 刪除了日曆 {calendar}",
    "You deleted calendar {calendar}" : "您刪除了日曆 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日曆 {calendar}",
    "You updated calendar {calendar}" : "你更新了日曆 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 復原了日曆 {calendar}",
    "You restored calendar {calendar}" : "您復原了日曆 {calendar}",
    "You shared calendar {calendar} as public link" : "你將 {calendar} 日曆以公開連結分享",
    "You removed public link for calendar {calendar}" : "您刪除了 {calendar} 日曆的公開分享連結",
    "{actor} shared calendar {calendar} with you" : "{actor} 與你分享了日曆 {calendar} ",
    "You shared calendar {calendar} with {user}" : "您與 {user} 分享了日曆 {calendar} ",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 與 {user} 分享了日曆 {calendar} ",
    "{actor} unshared calendar {calendar} from you" : "{actor} 停止與您分享日曆 {calendar}",
    "You unshared calendar {calendar} from {user}" : "您停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 停止與他們自己分享日曆 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您與群組 {group} 分享了日曆 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 與群組 {group} 分享了日曆 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您已停止與群組 {group} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 從 {group} 群組中取消了分享日曆 {calendar}",
    "Untitled event" : "無標題活動",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 新增了日曆 {calendar} 中的活動 {event}",
    "You created event {event} in calendar {calendar}" : "您新增了日曆 {calendar} 中的活動 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 從日曆 {calendar} 中刪除了活動 {event}",
    "You deleted event {event} from calendar {calendar}" : "您從日曆 {calendar} 中刪除了活動 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 更新了日曆 {calendar} 中的活動 {event}",
    "You updated event {event} in calendar {calendar}" : "您更新了日曆 {calendar} 中的活動 {event}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} 將活動 {event} 從日曆 {sourceCalendar} 移到日曆 {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "您將活動 {event} 從日曆 {sourceCalendar} 移到日曆 {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 復原了日曆 {calendar} 的活動 {event}",
    "You restored event {event} of calendar {calendar}" : "您復原了日曆 {calendar} 的活動 {event}",
    "Busy" : "忙碌中",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} 在任務清單 {calendar} 中建立了待辦事項 {todo}",
    "You created to-do {todo} in list {calendar}" : "您在任務清單 {calendar} 中建立了待辦事項 {todo}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} 從任務清單 {calendar} 中刪除了待辦事項 {todo}",
    "You deleted to-do {todo} from list {calendar}" : "您從任務清單 {calendar} 中刪除了待辦事項 {todo}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} 從任務清單 {calendar} 中更新了待辦事項 {todo}",
    "You updated to-do {todo} in list {calendar}" : "您在任務清單 {calendar} 中更新了待辦事項 {todo}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} 解决了任務清單 {calendar} 中的代辦事項 {todo}",
    "You solved to-do {todo} in list {calendar}" : "您解决了任務清單 {calendar} 中的代辦事項 {todo}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} 重新開啟了任務清單 {calendar} 中的代辦事項 {todo}",
    "You reopened to-do {todo} in list {calendar}" : "你重新開啟了任務清單 {calendar} 中的代辦事項 {todo}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} 將待辦事項 {todo} 從清單 {sourceCalendar} 移到清單 {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "您將待辦事項 {todo} 從清單 {sourceCalendar} 移到清單 {targetCalendar}",
    "Calendar, contacts and tasks" : "日曆、聯絡人和任務",
    "A <strong>calendar</strong> was modified" : "<strong>日曆</strong>被修改",
    "A calendar <strong>event</strong> was modified" : "日曆<strong>活動</strong>被修改",
    "A calendar <strong>to-do</strong> was modified" : "日曆<strong>代辦事項</strong>被修改",
    "Contact birthdays" : "聯絡人生日",
    "Death of %s" : "%s之卒",
    "Untitled calendar" : "未命名日曆",
    "Calendar:" : "日曆：",
    "Date:" : "日期：",
    "Where:" : "地點：",
    "Description:" : "描述：",
    "_%n year_::_%n years_" : ["%n 年"],
    "_%n month_::_%n months_" : ["%n 月"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n hour_::_%n hours_" : ["%n 小時"],
    "_%n minute_::_%n minutes_" : ["%n 分鐘"],
    "%s (in %s)" : "%s（共 %s）",
    "%s (%s ago)" : "%s（%s 前）",
    "Calendar: %s" : "日曆：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地點：%s",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "In the past on %1$s for the entire day" : "在過去 %1$s 的整天",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["將在 %n 分鐘之後於 %1$s 整天進行"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["將在 %n 小時之後於 %1$s 整天進行"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["將在 %n 天之後於 %1$s 整天進行"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["將在 %n 星期之後於 %1$s 整天進行"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["將在 %n 個月之後於 %1$s 整天進行"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["將在 %n 年之後於 %1$s 整天進行"],
    "In the past on %1$s between %2$s - %3$s" : "於已經過去的 %1$s %2$s - %3$s 之間進行",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["將在 %n 分鐘之後於 %1$s %2$s - %3$s 之間進行"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["將在 %n 小時之後於 %1$s %2$s - %3$s 之間進行"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["將在 %n 天之後於 %1$s %2$s - %3$s 之間進行"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["將在 %n 星期之後於 %1$s %2$s - %3$s 之間進行"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["將在 %n 個月之後於 %1$s %2$s - %3$s 之間進行"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["將在 %n 年之後於 %1$s %2$s - %3$s 之間進行"],
    "Could not generate when statement" : "無法產生 when 陳述",
    "Every Day for the entire day" : "每天一整天",
    "Every Day for the entire day until %1$s" : "每天一整天，直至 %1$s",
    "Every Day between %1$s - %2$s" : "每天於 %1$s - %2$s 之間",
    "Every Day between %1$s - %2$s until %3$s" : "每天於 %1$s - %2$s 之間，直至 %3$s",
    "Every %1$d Days for the entire day" : "每 %1$d 天整天",
    "Every %1$d Days for the entire day until %2$s" : "每 %1$d 天整天，直至 %2$s",
    "Every %1$d Days between %2$s - %3$s" : "每 %1$d 天於 %2$s - %3$s 之間",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "每 %1$d 天於 %2$s - %3$s 之間，直至 %4$s",
    "Could not generate event recurrence statement" : "無法產生事件重複陳述",
    "Every Week on %1$s for the entire day" : "每週於 %1$s 整天",
    "Every Week on %1$s for the entire day until %2$s" : "每週於 %1$s 整天，直到 %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "每週於 %1$s，在  %2$s - %3$s 之間",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "每週於 %1$s，在  %2$s - %3$s 之間，直到 %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "每 %1$d 週於 %2$s 整天",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "每 %1$d 週於 %2$s 整天，直至 %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "每 %1$d 週於 %2$s，在 %3$s - %4$s 之間，直至 %5$s",
    "Every Month on the %1$s for the entire day" : "每個月於 %1$s 整天",
    "Every Month on the %1$s for the entire day until %2$s" : "每個月於 %1$s 整天，直至 %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "每個月於 %1$s，在  %2$s - %3$s 之間",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "每個月於 %1$s，在  %2$s - %3$s 之間，直至 %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "每 %1$d 個月於 %2$s 整天",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "每 %1$d 個月於 %2$s 整天，直至 %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "每 %1$d 個月於 %2$s，在 %3$s - %4$s 之間，直至 %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "每年於 %1$s 的 %2$s 整天",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "每年於 %1$s 的 %2$s 整天，直至 %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "每年於 %1$s 的 %2$s，在 %3$s - %4$s 之間，直至 %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "每 %1$d 年於 %2$s 的 %3$s 整天",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "每 %1$d 年於 %2$s 的 %3$s 整天，直至 %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間，直至 %6$s",
    "On specific dates for the entire day until %1$s" : "在特定日期的整天，直至 %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 之間的特定日期，直至 %3$s",
    "In the past on %1$s" : "於已經過去的 %1$s 進行",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["將在 %n 分鐘之後於 %1$s 進行"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["將在 %n 小時之後於 %1$s 進行"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["將在 %n 天之後於 %1$s 進行"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["將在 %n 星期之後於 %1$s 進行"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["將在 %n 個月之後於 %1$s 進行"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["將在 %n 年之後於 %1$s 進行"],
    "In the past on %1$s then on %2$s" : "在過去的 %1$s，然後在 %2$s 進行",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 再次進行"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 再次進行"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 再次進行"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 再次進行"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 再次進行"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 再次進行"],
    "In the past on %1$s then on %2$s and %3$s" : "在過去的 %1$s 進行，然後在 %2$s 及 %3$s 再次進行",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
    "Could not generate next recurrence statement" : "無法產生下一個重複語句",
    "Cancelled: %1$s" : "已取消：%1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" 已被取消",
    "Re: %1$s" : "關於: %1$s",
    "%1$s has accepted your invitation" : "%1$s 已接受您的邀請",
    "%1$s has tentatively accepted your invitation" : "%1$s 暫時接受了您的邀請",
    "%1$s has declined your invitation" : "%1$s 已婉拒您的邀請",
    "%1$s has responded to your invitation" : "%1$s 已回應您的邀請",
    "Invitation updated: %1$s" : "邀請已更新︰%1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s 已更新了活動 \"%2$s\"",
    "Invitation: %1$s" : "邀請：%1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s 想邀請您加入“%2$s”",
    "Organizer:" : "主辦單位：",
    "Attendees:" : "參加者：",
    "Title:" : "標題：",
    "When:" : "時間：",
    "Location:" : "位置：",
    "Link:" : "連結：",
    "Occurring:" : "發生：",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "More options …" : "更多選項 ...",
    "More options at %s" : "%s有更多選項",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Sunday" : "星期日",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "First" : "首頁",
    "Second" : "第二",
    "Third" : "第三",
    "Fourth" : "第四",
    "Fifth" : "第五",
    "Last" : "最後",
    "Second Last" : "尾二",
    "Third Last" : "尾三",
    "Fourth Last" : "尾四",
    "Fifth Last" : "尾五",
    "Contacts" : "聯絡人",
    "{actor} created address book {addressbook}" : "{actor} 創建了通訊錄 {addressbook} ",
    "You created address book {addressbook}" : "您創建了通訊錄 {addressbook} ",
    "{actor} deleted address book {addressbook}" : "{actor} 刪除了通訊錄 {addressbook} ",
    "You deleted address book {addressbook}" : "您刪除了通訊錄 {addressbook} ",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通訊錄 {addressbook} ",
    "You updated address book {addressbook}" : "您更新了通訊錄 {addressbook} ",
    "{actor} shared address book {addressbook} with you" : "{actor} 與您分享了通訊錄 {addressbook} ",
    "You shared address book {addressbook} with {user}" : "您與 {user} 分享了通訊錄 {addressbook} ",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 與 {user} 分享了通訊錄 {addressbook} ",
    "{actor} unshared address book {addressbook} from you" : "{actor} 停止與您分享通訊錄 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "您停止與 {user} 分享通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 停止與 {user} 分享通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 停止與他們自己分享通訊錄 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "您與群組 {group} 分享了通訊錄 {addressbook} ",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 與 群組 {group} 分享了通訊錄 {addressbook} ",
    "You unshared address book {addressbook} from group {group}" : "您停止與群組 {group} 分享通訊錄 {addressbook}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 停止與群組 {group} 分享通訊錄 {addressbook}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 創建了通訊錄 {addressbook} 中的聯絡人 {card}",
    "You created contact {card} in address book {addressbook}" : "您創建了通訊錄 {addressbook} 中的聯絡人 {card}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 刪除了通訊錄 {addressbook} 中的聯絡人 {card}",
    "You deleted contact {card} from address book {addressbook}" : "您刪除了通訊錄 {addressbook} 中的聯絡人 {card}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 更新了通訊錄 {addressbook} 中的聯絡人 {card}",
    "You updated contact {card} in address book {addressbook}" : "您更新了通訊錄 {addressbook} 中的聯絡人 {card}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "聯絡人或通訊錄被修改",
    "System address book disabled" : "系統通訊錄已停用",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "系統通訊錄在升級過程中已自動停用。這表示使用者將無法在通訊錄應用程式或其他客戶端存取該通訊錄。停用原因在於通訊錄中的聯絡人數量已超過建議上限，此限制旨在避免效能問題。您可透過以下指令重新啟用系統通訊錄：{command}",
    "Accounts" : "帳戶",
    "System address book which holds all accounts" : "包含所有帳戶的系統通訊錄",
    "File is not updatable: %1$s" : "檔案無法更新：%1$s",
    "Failed to get storage for file" : "無法取得檔案儲存空間",
    "Could not write to final file, canceled by hook" : "無法寫入最終檔案，被掛勾取消",
    "Could not write file contents" : "無法寫入檔案內容",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "將檔案複製到目標位置時發生錯誤（已複製：%1$s，預期的檔案大小：%2$s）",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "預期的檔案大小為 %1$s，但讀取（從 Nextcloud 客戶端）與寫入（至 Nextcloud 儲存空間）%2$s。可能是傳送端的網路問題或是伺服器端的儲存空間寫入問題。",
    "Could not rename part file to final file, canceled by hook" : "無法將部份檔案重新命名為最終檔案，被掛勾取消",
    "Could not rename part file to final file" : "無法將部份檔案重新命名為最終檔案",
    "Failed to check file size: %1$s" : "檢查檔案大小失敗：%1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "無法開啟檔案：%1$s（%2$d），檔案似乎存在",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "無法開啟檔案：%1$s（%2$d），檔案似乎不存在",
    "Failed to get size for : %1$s" : "無法取得以下項目的大小：%1$s",
    "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
    "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
    "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
    "Failed to write file contents: %1$s" : "寫入檔案內容失敗：%1$s",
    "File not found: %1$s" : "找不到檔案：%1$s",
    "Invalid target path" : "無效的目標路徑",
    "System is in maintenance mode." : "系統處於維護模式。",
    "Upgrade needed" : "需要升級",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 必須要設定 HTTPS ，才能在 iOS/macOS 上使用 CalDAV 和 CardDAV",
    "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
    "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
    "Events" : "活動",
    "Untitled task" : "無標題任務",
    "Completed on %s" : "完成於 %s",
    "Due on %s by %s" : "完成日期為 %s %s",
    "Due on %s" : "完成日期 %s",
    "This is an example contact" : "此為示例聯絡人",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "歡迎使用 Nextcloud 日曆！\n\n這是範例事件 - 使用 Nextcloud 日曆進行任何編輯，探索規劃的彈性！\n\n使用 Nextcloud 日曆，您可以：\n- 毫不費力地建立、編輯與管理活動。\n- 建立多個日曆，並與同事、朋友或家人分享。\n- 檢查可得性，並向他人顯示您的忙碌時間。\n- 透過 CalDAV 與應用程式與裝置無縫整合。\n- 自訂您的體驗：排定定期活動、調整通知與其他設定。",
    "Example event - open me!" : "範例活動 - 打開我！",
    "System Address Book" : "系統通訊錄",
    "The system address book contains contact information for all users in your instance." : "系統通訊錄包含您實例中的所有聯絡人資訊。",
    "Enable System Address Book" : "啟用系統通訊錄",
    "DAV system address book" : "DAV 系統通訊錄",
    "No outstanding DAV system address book sync." : "沒有未完成的 DAV 系統通訊錄同步。",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 系統通訊錄同步尚未執行，因為您的實例有超過 1000 個用戶，或是因為遇到錯誤。請透過 \"occ dav:sync-system-addressbook\" 手動執行。",
    "DAV system address book size" : "DAV 系統通訊錄大小",
    "The system address book is disabled" : "系統通訊錄已停用",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "系統通訊錄已啟用，但其中聯絡人數量超過設定 %d 個的上限。",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "系統通訊錄已啟用，且其中聯絡人數量少於設定 %d 個的上限。",
    "WebDAV endpoint" : "WebDAV 端點",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "無法檢查您的網頁伺服器是否正確設置以允許透過 WebDAV 進行檔案同步。請手動進行檢查。",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 界面似乎為故障狀態，導致您的網頁伺服器無法提供檔案同步功能。",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "您的網頁伺服器已正確設定為允許透過 WebDAV 進行檔案同步。",
    "Calendars including events, details and attendees" : "日曆，包括活動、詳細信息和與會者",
    "Migrated calendar (%1$s)" : "遷移的日曆（%1$s）",
    "Contacts and groups" : "聯絡人和群組",
    "WebDAV" : "WebDAV",
    "Absence saved" : "缺席時段已儲存",
    "Failed to save your absence settings" : "無法保存您的缺席設定",
    "Absence cleared" : "缺席時段已清除",
    "Failed to clear your absence settings" : "無法清除您的缺席設定",
    "First day" : "第一天",
    "Last day (inclusive)" : "最後一天（含）",
    "Out of office replacement (optional)" : "外出時的替代人員（非強制的）",
    "Name of the replacement" : "替代人員姓名",
    "Short absence status" : "短暫缺席狀態",
    "Long absence Message" : "長期缺席訊息",
    "Save" : "保存",
    "Disable absence" : "停用缺席",
    "Failed to load availability" : "加載空閒時間失敗",
    "Saved availability" : "已保存空閒時間",
    "Failed to save availability" : "未能保存空閒時間",
    "to" : "至",
    "Delete slot" : "刪除欄位",
    "No working hours set" : "尚未設置工作時間",
    "Add slot" : "新增欄位",
    "Weekdays" : "平日",
    "Pick a start time for {dayName}" : "為 {dayName} 挑選開始時間",
    "Pick a end time for {dayName}" : "為 {dayName} 挑選結束時間",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "在忙碌時，自動將用戶狀態設定為「請勿打擾」以靜音所有通知。",
    "Cancel" : "取消",
    "Import" : "導入",
    "Error while saving settings" : "儲存設定時發生錯誤",
    "Contact reset successfully" : "聯絡人重設成功",
    "Error while resetting contact" : "重設聯絡人時發生錯誤",
    "Contact imported successfully" : "成功導入了聯絡人",
    "Error while importing contact" : "導入聯絡人時發生錯誤",
    "Import contact" : "導入聯絡人",
    "Reset to default" : "恢復預設值",
    "Import contacts" : "導入聯絡人",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "導入新的 .vcf 檔案將刪除現有的默認聯絡人並將其替換為新的聯絡人。您想繼續嗎？",
    "Failed to save example event creation setting" : "儲存範例事件建立設定失敗",
    "Failed to upload the example event" : "上傳範例事件失敗",
    "Custom example event was saved successfully" : "已成功儲存自訂範例事件",
    "Failed to delete the custom example event" : "刪除自訂範例事件失敗",
    "Custom example event was deleted successfully" : "已成功刪除自訂範例事件",
    "Import calendar event" : "導入日曆活動",
    "Uploading a new event will overwrite the existing one." : "上傳新活動將會覆寫原有的",
    "Upload event" : "上傳活動",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安裝 {calendarappstoreopen}日曆應用程式{linkclose}或安裝{calendardocopen}以連接您的桌面電腦和流動裝置進行同步↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "請確保正確設置{emailopen}電郵伺服器{linkclose}。",
    "Calendar server" : "日曆伺服器",
    "Send invitations to attendees" : "發送邀請函給參加者",
    "Automatically generate a birthday calendar" : "自動生成生日日曆",
    "Birthday calendars will be generated by a background job." : "生日日曆將由後台作業生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，啟用後不會立即可用，但會在一段時間後顯示。",
    "Send notifications for events" : "發送活動通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通告將透過後台任務發送，所以任務的頻率要足夠高。",
    "Send reminder notifications to calendar sharees as well" : "也向共享日曆者傳送提醒通告",
    "Reminders are always sent to organizers and attendees." : "一律傳送提醒通知給舉辦者與參與者。",
    "Enable notifications for events via push" : "啟用推送活動通知",
    "Example content" : "範例內容",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "範例內容用來展示 Nextcloud 的功能。Nextcloud 隨附預設內容，可由自訂內容取代。",
    "Availability" : "空閒時間",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他人仕在預約會議時就會知道您何時不在辦公室。",
    "Absence" : "缺席",
    "Configure your next absence period." : "設定您的下一個缺席時段。",
    "There was an error updating your attendance status." : "更新您的參與狀況時發生錯誤",
    "Please contact the organizer directly." : "請直接聯繫絡主辦人",
    "Are you accepting the invitation?" : "接受邀請嗎？",
    "Tentative" : "暫定",
    "Your attendance was updated successfully." : "您的參與狀況成功更新",
    "No results." : "沒有結果。",
    "Start typing." : "開始輸入。"
},
"nplurals=1; plural=0;");
