OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Προσωπική δραστηριότητα ροής πληροφοριών για %s",
    "Your feed URL is invalid" : "Η διεύθυνση ροής πληροφοριών URL δεν είναι έγκυρη",
    "Activity feed for %1$s" : "Ροή δραστηριότητας για %1$s",
    "Activity feed" : "Ροή Δραστηριότητας",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "Settings have been updated." : "Οι ρυθμίσεις έχουν ενημερωθεί.",
    "remote user" : "απομακρυσμένος χρήστης",
    "Recent activity" : "Πρόσφατη δραστηριότητα",
    "No activities" : "Καμία δραστηριότητα",
    "More activities" : "Περισσότερες δραστηριότητες",
    "Daily activity summary for %s" : "Σύνοψη ημερήσιας δραστηριότητας για %s",
    "_and %n more…_::_and %n more…_" : ["και %n ακόμη…","και %n ακόμη…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Μπορείτε να απενεργοποιήσετε τα ημερήσια email σύνοψης στις <a href=\"%s\">ρυθμίσεις</a>.",
    "You can disable daily digest emails in the settings: %s" : "Μπορείτε να απενεργοποιήσετε τα ημερήσια email σύνοψης στις ρυθμίσεις: %s",
    "All activities" : "Όλες οι δραστηριότητες",
    "By others" : "Από άλλους",
    "By you" : "Από εσάς",
    "Activity at %s" : "Δραστηριότητα στο %s",
    "Hello %s" : "Γεια σας %s",
    "Hello %s," : "Γεια σας %s,",
    "There was some activity at %s" : "Υπήρξε δραστηριότητα στο %s",
    "_and %n more _::_and %n more _" : ["και %n επιπλέον","και %n επιπλέον"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις <a href=\"%s\"> ρυθμίσεις </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις ρυθμίσεις: 1%s",
    "Mail" : "Ταχυδρομείο",
    "Push" : "Ειδοποίηση Push",
    "Activity" : "Δραστηριότητα",
    "Notifications" : "Ειδοποιήσεις",
    "This application enables people to view a log of activities about them, their files or other data." : "Αυτή η εφαρμογή δίνει τη δυνατότητα στους χρήστες να προβάλλουν ένα αρχείο καταγραφής δραστηριοτήτων σχετικά με αυτούς, τα αρχεία τους ή άλλα δεδομένα.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Αυτή η εφαρμογή επιτρέπει στους χρήστες να βλέπουν ενέργειες που σχετίζονται με τα αρχεία και τα δεδομένα τους στο Nextcloud.\n\n\t\tΚάθε άτομο μπορεί να διαμορφώσει τις ατομικές ρυθμίσεις δραστηριότητάς του στις προσωπικές ρυθμίσεις,\n\t\tγια να επιλέξει ποια δραστηριότητα θα προωθηθεί σε κινητά τηλέφωνα, θα αποσταλεί με email\n\t\tή  εάν μια ημερήσια περίληψη θα αποστέλλεται κάθε πρωί.\n\t\tΠερισσότερες πληροφορίες διατίθενται στην τεκμηρίωση για τις Δραστηριότητες.",
    "Send email" : "Αποστολή email",
    "Send push notification" : "Αποστολή ειδοποίησης push",
    "Activity notification configuration" : "Ρύθμιση ειδοποιήσεων δραστηριότητας",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθες",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση email σας για να μπορείτε να λαμβάνετε ειδοποιήσεις μέσω email.",
    "Send activity emails" : "Αποστολή email δραστηριοτήτων",
    "As soon as possible" : "Το συντομότερο δυνατό",
    "Hourly" : "Ωριαία",
    "Daily" : "Καθημερινά",
    "Weekly" : "Εβδομαδιαία",
    "You commented" : "Σχολιάσατε",
    "Message deleted by author" : "Το μήνυμα διαγράφηκε από τον συντάκτη",
    "Open {filename}" : "Άνοιγμα {filename}",
    "in {path}" : "στην {path}",
    "Home" : "Αρχική",
    "Could not load activities" : "Δεν ήταν δυνατή η φόρτωση των δραστηριοτήτων",
    "Loading activities" : "Φόρτωση δραστηριοτήτων",
    "This stream will show events like additions, changes & shares" : "Αυτή η ροή θα δείξει γεγονότα όπως προσθήκες, αλλαγές και διαμοιρασμούς",
    "No activity yet" : "Καμία δραστηριότητα ακόμα",
    "Loading more activities" : "Φόρτωση περισσότερων δραστηριοτήτων",
    "No more activities." : "Δεν υπάρχουν άλλες δραστηριότητες.",
    "Could not enable RSS link" : "Δεν ήταν δυνατή η ενεργοποίηση του συνδέσμου RSS",
    "RSS link copied to clipboard" : "Ο σύνδεσμος RSS αντιγράφηκε στο πρόχειρο",
    "Could not copy the RSS link, please copy manually:" : "Δεν ήταν δυνατή η αντιγραφή του συνδέσμου RSS, παρακαλώ αντιγράψτε τον χειροκίνητα.",
    "Activity settings" : "Ρυθμίσεις δραστηριότητας",
    "Enable RSS feed" : "Ενεργοποίηση ροής πληροφοριών RSS",
    "RSS feed" : "Ροή RSS",
    "Copy RSS feed link" : "Αντιγραφή συνδέσμου ροής πληροφοριών RSS",
    "Personal notification settings" : "Ρυθμίσεις προσωπικών ειδοποιήσεων",
    "Unable to load the activity list" : "Δεν είναι δυνατή η φόρτωση της λίστας δραστηριοτήτων",
    "Choose for which activities you want to get an email or push notification." : "Επιλέξτε για ποιες δραστηριότητες θέλετε να λαμβάνετε ειδοποιήσεις μέσω e-mail ή στη συσκευή σας.",
    "Choose for which activities you want to get a push notification." : "Επιλέξτε για ποιες δραστηριότητες θέλετε να λαμβάνετε ειδοποιήσεις στη συσκευή σας.",
    "Notification" : "Ειδοποίηση",
    "Enable notification emails" : "Ενεργοποίηση ειδοποιήσεων μέσω e-mail",
    "Daily activity summary" : "Σύνοψη ημερήσιας δραστηριότητας",
    "Send daily activity summary in the morning" : "Αποστολή σύνοψης της ημερήσιας δραστηριότητας κάθε πρωί",
    "Default settings" : "Προεπιλεγμένες ρυθμίσεις",
    "Configure the default notification settings for new accounts." : "Καθορίστε τις προεπιλεγμένες ρυθμίσεις ειδοποιήσεων για νέους λογαριασμούς.",
    "Unable to save the settings" : "Αδυναμία αποθήκευσης των ρυθμίσεων",
    "No more events to load" : "Δεν υπάρχουν άλλα γεγονότα προς φόρτωση"
},
"nplurals=2; plural=(n != 1);");
