OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Hiányzik a helyreállítási kulcs jelszava",
    "Please repeat the recovery key password" : "Ismételje meg a helyreállítási kulcs jelszavát",
    "Repeated recovery key password does not match the provided recovery key password" : "A megismételt helyreállítási kulcsjelszó nem egyezik meg a megadott helyreállítási kulcs jelszavával",
    "Recovery key successfully enabled" : "A helyreállítási kulcs sikeresen engedélyezve",
    "Could not enable recovery key. Please check your recovery key password!" : "A helyreállítási kulcsot nem lehetett engedélyezni. Ellenőrizze a helyreállítási kulcsa jelszavát!",
    "Recovery key successfully disabled" : "A helyreállítási kulcs sikeresen letiltva",
    "Could not disable recovery key. Please check your recovery key password!" : "A helyreállítási kulcsot nem lehetett letiltani. Ellenőrizze a helyreállítási kulcsa jelszavát!",
    "Please provide the old recovery password" : "Adja meg a régi helyreállítási jelszót",
    "Please provide a new recovery password" : "Adja meg az új helyreállítási jelszót",
    "Please repeat the new recovery password" : "Ismételje meg az új helyreállítási jelszót",
    "Password successfully changed." : "Jelszó sikeresen megváltoztatva.",
    "Could not change the password. Maybe the old password was not correct." : "A jelszót nem lehet megváltoztatni. Lehet, hogy hibás volt a régi jelszó.",
    "Recovery Key disabled" : "Helyreállítási kulcs letiltva",
    "Recovery Key enabled" : "Helyreállítási kulcs engedélyezve",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nem sikerült engedélyezni a helyreállítási kulcsot, próbálja meg újra vagy lép jen kapcsolatba a rendszergazdával",
    "Could not update the private key password." : "Nem sikerült frissíteni a titkos kulcs jelszavát.",
    "The old password was not correct, please try again." : "A régi jelszó nem volt helyes, próbálja újra.",
    "The current log-in password was not correct, please try again." : "A jelenlegi bejelentkezési jelszó nem helyes, próbálja meg újra.",
    "Private key password successfully updated." : "A titkos kulcs jelszava sikeresen frissítve.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "A titkosító alkalmazás titkos kulcsa érvénytelen. A titkosított fájljaihoz való hozzáféréshez frissítse a titkos kulcsa jelszavát a személyes beállításokban.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "A fájlok titkosítása engedélyezve van, de az Ön titkos kulcsai nincsenek beállítva. Jelentkezzen ki, és lépjen be újra.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Engedélyezze a kiszolgálóoldali titkosítást a rendszergazdai beállításokban, hogy használhassa a titkosítás modult.",
    "Encryption app is enabled and ready" : "A titkosító alkalmazás engedélyezett és készen áll",
    "Bad Signature" : "Hibás aláírás",
    "Missing Signature" : "Hiányzó aláírás",
    "one-time password for server-side-encryption" : "kiszolgálóoldali titkosítás egyszer használatos jelszava",
    "Encryption password" : "Titkosítási jelszó",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "A rendszergazda bekapcsolta a kiszolgálóoldali titkosítást. A fájljai a következő jelszóval lettek titkosítva: <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "A rendszergazda bekapcsolta a kiszolgálóoldali titkosítást. A fájljai a következő jelszóval lettek titkosítva: „%s”.",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Jelentkezzen be a webes felületre, ugorjon a személyes beállításai „Biztonság” szakaszához, és frissítse a titkosítási jelszavát úgy, hogy megadja ezt a jelszót a „Régi bejelentkezési jelszó” mezőben, majd megadja a jelenlegi bejelentkezési jelszavát.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "A fájl nem fejthető vissza, valószínűleg ez egy megosztott fájl. Kérje meg a fájl tulajdonosát, hogy ossza meg újra Önnel ezt a fájlt.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ez a fájl nem olvasható, valószínűleg ez egy megosztott fájl. Kérje meg a fájl tulajdonosát, hogy ossza meg újra Önnel ezt a fájlt.",
    "Default Encryption Module" : "Alapértelmezett titkosítási modul",
    "Default encryption module for Nextcloud Server-side Encryption (SSE)" : "Alapértelmezett titkosítási modul a kiszolgálóoldali titkosításhoz (SSE)",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "A lehetőség engedélyezésekor minden fájlt titkosít a fő tárolóban, egyébként csak a külső tárolókon lévő fájlok lesznek titkosítva",
    "Encrypt the home storage" : "Helyi tároló titkosítása",
    "Disable recovery key" : "Helyreállítási kulcs letiltása",
    "Enable recovery key" : "Helyreállítási kulcs engedélyezése",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "A helyreállítási kulcs egy további titkosítási kulcs fájlok titkosításához. Arra szolgál, hogy egy fiókból vissza lehessen állítani a fájlokat, ha a jelszót elfelejtették.",
    "Recovery key password" : "Helyreállítási kulcs jelszava",
    "Repeat recovery key password" : "Ismételje meg a heylreállítási kulcs jelszavát",
    "Old recovery key password" : "Régi helyreállítási kulcs jelszava",
    "New recovery key password" : "Új helyreállítási kulcs jelszava",
    "Repeat new recovery key password" : "Ismételje meg az új helyreállítási kulcs jelszavát",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Ha nem emlékszik a régi jelszavára, akkor megkérheti a rendszergazdát, hogy állítsa helyre a fájljait.",
    "Old log-in password" : "Régi bejelentkezési jelszó",
    "Current log-in password" : "Jelenlegi bejelentkezési jelszó",
    "Update" : "Frissítés",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "A beállítás lehetővé teszi, hogy visszanyerje a titkosított fájlok tartalmát, ha elfelejtette a jelszavát",
    "Default encryption module" : "Alapértelmezett titkosítási modul",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "A titkosító alkalmazás engedélyezett, de a kulcsai még nincsenek előkészítve. Lépjen ki, majd lépjen be újra.",
    "Basic encryption module" : "Alapvető titkosítási modul",
    "Missing parameters" : "Hiányzó paraméterek",
    "Default encryption module for server-side encryption" : "Alapértelmezett titkosítási modul a kiszolgálóoldali titkosításhoz",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Ahhoz, hogy ezt a titkosítási modult használhassa, be kell kapcsolnia a kiszolgálóoldali titkosítást az adminisztrációs felületen. Engedélyezést követően a modul minden fájlt transzparensen titkosít. A titkosítás AES 256 kulcsokon alapul.\nA modul nem módosítja a meglévő fájlokat, csak az újakat titkosítja, miután bekapcsolta a kiszolgálóoldali titkosítást. Nem lehet kikapcsolni a titkosítást, hogy titkosítatlan rendszerre váltson vissza.\nOlvassa el a dokumentációt, hogy minden következménnyel tisztában legyen, mielőtt úgy dönt, hogy engedélyezi a kiszolgálóoldali titkosítást.",
    "Change recovery key password:" : "Helyreállítási kulcs jelszavának módosítása:",
    "Change Password" : "Jelszó módosítása",
    "Your private key password no longer matches your log-in password." : "A titkos kulcsa jelszava már nem egyezik meg a bejelentkezési jelszavával. ",
    "Set your old private key password to your current log-in password:" : "A régi privát kulcsának jelszavának beállítása a jelenlegi bejelentkezési jelszavára:",
    "Update Private Key Password" : "Titkos kulcs jelszavának frissítése",
    "Enable password recovery:" : "Jelszó-helyreállítás engedélyezése:",
    "Enabled" : "Engedélyezve",
    "Disabled" : "Letiltva",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to \n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Ez az alkalmazás biztosítja az (alapértelmezett) titkosítási megvalósítást a Nextcloud kiszolgálóoldali titkosítási (SSE) funkciójához.\n\n\t\t\t**Titkosítás részletei**\n\t\t\t* **Titkosítási mód:** AES-256-CTR (alapértelmezett)\n\t\t\t* **Hitelesítés:** HMAC-SHA256\n\n\t\t\t**Fontos figyelmeztetések**\n\t\t\t* **VESZÉLY:** Ne tiltsa le az alkalmazást addig, amíg fel nem oldotta az összes fájl titkosítását (`occ encryption:decrypt-all`).\n\t\t\t* **FIGYELMEZTETÉS**: A nem titkosított fájltárolásra visszaálláshoz parancssoros hozzáférés szükséges. A művelet a webes felületen végleges.\"\n\n\t\t\t**Megjegyzés a meglévő fájlokhoz**\n\t\t\t* Alapértelmezés szerint az SSE engedélyezése nem titkosítja a meglévő fájlokat; csak az új fájlok lesznek titkosítva.\n\t\t\t* Az összes meglévő fájl titkosításához használja az `occ encryption:encrypt-all` parancsot.\n\n\t\t\t**Mielőtt nekikezd**\n\t\t\t* **Olvassa el a dokumentációt:** Az SSE engedélyezése, a meglévő fájlok titkosítása vagy az SSE letiltása előtt \n\t\t\t\telengedhetetlen a dokumentáció elolvasása, hogy tisztában legyen a következményekkel, és az adatvesztés\n\t\t\t\telkerülését eredményező folyamatokkal."
},
"nplurals=2; plural=(n != 1);");
