import{g as c}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as f}from"./leaf-DfTGz3CY.chunk.mjs";function s(r,i){for(var o=0;o<i.length;o++){const t=i[o];if(typeof t!="string"&&!Array.isArray(t)){for(const e in t)if(e!=="default"&&!(e in r)){const n=Object.getOwnPropertyDescriptor(t,e);n&&Object.defineProperty(r,e,n.get?n:{enumerable:!0,get:()=>t[e]})}}}return Object.freeze(Object.defineProperty(r,Symbol.toStringTag,{value:"Module"}))}var a=f();const l=c(a),u=s({__proto__:null,default:l},[a]);export{u as l};
//# sourceMappingURL=leaf-C2gR9qkE.chunk.mjs.map
