import{g as c}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as f}from"./ebnf-C_sav2Hd.chunk.mjs";function s(r,i){for(var o=0;o<i.length;o++){const e=i[o];if(typeof e!="string"&&!Array.isArray(e)){for(const t in e)if(t!=="default"&&!(t in r)){const n=Object.getOwnPropertyDescriptor(e,t);n&&Object.defineProperty(r,t,n.get?n:{enumerable:!0,get:()=>e[t]})}}}return Object.freeze(Object.defineProperty(r,Symbol.toStringTag,{value:"Module"}))}var a=f();const p=c(a),u=s({__proto__:null,default:p},[a]);export{u as e};
//# sourceMappingURL=ebnf-BLbrO-zC.chunk.mjs.map
