OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Calendario",
    "Calendar \"%s\"" : "Calendario \"%s\"",
    "Deck" : "Deck",
    "Deck board \"%s\"" : "Lavagna di Deck \"%s\"",
    "Files" : "File",
    "File \"%s\"" : "File \"%s\"",
    "Group Folder" : "Cartella del gruppo",
    "Group Folder \"%s\"" : "Cartella del gruppo \"%s\"",
    "Talk conversation" : "Conversazione di Talk",
    "Conversation with %s" : "Conversazione con %s",
    "Talk" : "Talk",
    "Talk conversation \"%s\"" : "Conversazioni di Talk %s",
    "Related Resources" : "Risorse correlate",
    "Displays resources related to current item in right panel" : "Visualizza le risorse relative all'elemento corrente nel pannello di destra",
    "Displays resources related to current item in right panel." : "Visualizza le risorse relative all'elemento corrente nel pannello di destra."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
