<?php
/**
 * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
return array (
  'ytp3hhuucto9kytp3hhuucto9kytp3hhuucto9k' => true,
  'greendaybilliejoearmstrongadbcjkmmlm123' => true,
  'ghbdtncnde.gfhnythcndjpjkjnjqrejrdfvhfl' => true,
  'fuckuassholesiknowuwannatakemypassowrds' => true,
  'alinka00112212345678900987654321malinka' => true,
  'imnotreallykrashedthisisatestingaccount' => true,
);