OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Annonces Nextcloud",
    "Nextcloud announcement" : "Annonce Nextcloud",
    "Read more" : "En savoir plus",
    "Disable announcements" : "Désactiver les annonces",
    "(These announcements are only shown to administrators)" : "(Les annonces ne sont affichées qu'aux administrateurs)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Annonces Nextcloud rapporte les dernières nouvelles de Nextcloud dans vos notifications"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
