OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : " ID de sa nue virtuale federada non bàlidu",
    "Server to server sharing is not enabled on this server" : "Sa cumpartzidura intre serbidores no est ativada in custu serbidore",
    "Couldn't establish a federated share." : "No at fatu a istabilire una cumpartzidura federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "No at fatu a istabilire una cumpartzidura federada, fortzis sa crae no es curreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Dimanda de cumpartzidura federada fata, as a retzire unu cumbidu. controlla is notèificas tuas.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No at fatu a istabilire una cumpartzidura federada, paret chi su serbidore de federare siat de tropu tempus (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No est permèitidu de imbiare cumpartziduras de grupu federadas dae custu serbidore.",
    "Federated shares require read permissions" : "Cumpartziduras federadas rechedent permissos de letura",
    "File is already shared with %s" : "S'archìviu est giai cumpartzidu cun %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sa cumpartzidura %1$s faddida, non at a fatu a agatare %2$s, mancari su serbidore immoe non si podet cuntatare o impreat unu tzertificadu firmadu da issu etotu.",
    "Could not find share" : "No at fatu a agatare sa cumpartzidura",
    "Federated sharing" : "Cumpartzidura federada",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "As retzidu {share} comente cumpartziduraremota dae {user} (pro parte de {behalf})",
    "You received {share} as a remote share from {user}" : " As retzidu {share} comente cumpartzidura remota dae {user}",
    "Accept" : "Atzeta",
    "Decline" : "Refuda",
    "Federated Cloud Sharing" : "Cumpartzidura Nue virtuale federada",
    "Sharing" : "Cumpartzidura",
    "Federated file sharing" : "Cumpartzidura archìviu federadu",
    "Provide federated file sharing across servers" : "Frunit una cumpartzidura de archìvios federados intre serbidores",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Cumpartzi cun megus tràmite s'ID meu de nue virtuale federada #Nextcloud Federated Cloud ID",
    "Share with me via Nextcloud" : "Cumpartzi cun megus tràmite Nextcloud",
    "Copy" : "Còpia",
    "Copied!" : "Copiadu!",
    "Federated Cloud" : "Nue virtuale federada",
    "Share it so your friends can share files with you:" : " Condividilo in modo che i tuoi amici possano condividere file con te:",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Agiunghe a su situ web tuo",
    "HTML Code:" : "Còdighe HTML:",
    "Cancel" : "Annulla",
    "Add remote share" : "Agiunghe cumpartzidura remota",
    "Remote share" : "Cumpartzidura remota",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Nche cheres agiùnghere sa cumpartzidura remota {name} dae {owner}@{remote}?",
    "Remote share password" : "Cumpartzidura remota crae",
    "X (formerly Twitter)" : "X (in antis, Twitter)",
    "formerly Twitter" : "in antis, Twitter"
},
"nplurals=2; plural=(n != 1);");
