import{g as c}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as s}from"./elm-BZEvCvhB.chunk.mjs";function a(r,f){for(var o=0;o<f.length;o++){const e=f[o];if(typeof e!="string"&&!Array.isArray(e)){for(const t in e)if(t!=="default"&&!(t in r)){const n=Object.getOwnPropertyDescriptor(e,t);n&&Object.defineProperty(r,t,n.get?n:{enumerable:!0,get:()=>e[t]})}}}return Object.freeze(Object.defineProperty(r,Symbol.toStringTag,{value:"Module"}))}var i=s();const l=c(i),g=a({__proto__:null,default:l},[i]);export{g as e};
//# sourceMappingURL=elm-DKZA7Bj0.chunk.mjs.map
