OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "Nie ste prihlásený",
    "Permission denied" : "Prístup zamietnutý",
    "Forbidden to manage local mounts" : "Zakázané spravovať lokálne pripojenia",
    "Storage with ID \"%d\" not found" : "Úložisko s ID \"%d\" sa nenašlo",
    "Invalid backend or authentication mechanism class" : "Neplatný backend, prípadne trieda mechanizmu autentifikácie",
    "Invalid mount point" : "Chybný prípojný bod",
    "Objectstore forbidden" : "Objectstore je zakáazaný",
    "Invalid storage backend \"%s\"" : "Neplatný backend úložiska \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nie je povolené použiť backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nie je povolené použiť autentifikačný mechanizmus \"%s\"",
    "Unsatisfied backend parameters" : "Nedostatočné parametre backendu",
    "Unsatisfied authentication mechanism parameters" : "Nedostatočné parametre autentifikačného mechanizmu",
    "Insufficient data: %s" : "Nedostatočné dáta: %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Úložisko s ID \"%d\" nie je upraviteľné neadministrátormi.",
    "Static credentials" : "Statické poverenia",
    "Access key ID" : "ID prístupového kľúča",
    "Secret access key" : "Tajný prístupový kľúč",
    "Builtin" : "Vstavaný",
    "None" : "Žiadny",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Prihlásiť sa",
    "Password" : "Heslo",
    "Tenant name" : "Meno nájomcu",
    "Identity endpoint URL" : "Endpoint URL identita",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Doména",
    "Rackspace" : "Rackspace",
    "API key" : "API kľúč",
    "Global credentials" : "Globálne oprávnenia",
    "Log-in credentials, save in database" : "Prihlasovacie údaje, ukladať v databáze",
    "Login and password" : "Meno a heslo",
    "Log-in credentials, save in session" : "Prihlasovacie údaje, ukladať do relácie",
    "Global credentials, manually entered" : "Globálne oprávnenia, manuálne zadané",
    "Manually entered, store in database" : "Manuálne zadané, uložené do databázy",
    "RSA public key" : "RSA verejný kľúč",
    "Public key" : "Verejný kľúč",
    "RSA private key" : "RSA súkromný kľúč",
    "Private key" : "Súkromný kľúč",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Predvolená oblasť Kerberos, ak nie je nastavené použije sa \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Kerberos ticket v režime Apache",
    "Kerberos ticket" : "Kerberos tiket",
    "Bucket" : "Sektor",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Proxy" : "Proxy",
    "Region" : "Región",
    "Storage Class" : "Typ úložného priestoru",
    "Use Legacy S3 signing (v2)" : "Použiť staré podpisovanie S3 (v2)",
    "Enable multipart copy" : "Povoliť kópiu mutlipart správy",
    "SSE-C encryption key" : "Šifrovací kľúč SSE-C",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Vzdialený podpriečinok",
    "Secure https://" : "Zabezpečené https://",
    "Host" : "Hostiteľ",
    "Secure ftps://" : "Zabezpečené ftps://",
    "Location" : "Umiestnenie",
    "Root" : "Root",
    "Share" : "Zdieľaný priečinok",
    "Show hidden files" : "Zobraziť skryté súbory",
    "Case sensitive file system" : "Súborový systém rozlišujúci veľkosti písmen",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Zakázaním, bude možné používať súborový systém bez ohľadu na veľkosť písmen, ale s tým je spojený  pokles výkonu.",
    "Verify ACL access when listing files" : "Overovať ACL prístup pri vypisovaní súborov",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Kontrola ACL každého súboru alebo priečinka vnútri adresára pre vyfiltrovanie položiek, ku ktorým účet nemá oprávnenie pre čítanie, znamená zníženie výkonu",
    "Timeout" : "Vypršanie času",
    "Login as share" : "Prihlásiť sa ako zdieľanie.",
    "Service name" : "Názov služby",
    "Request timeout (seconds)" : "Timeout požiadavky (s)",
    "External storage" : "Externé úložisko",
    "External storage support" : "Podpora externého úložiska",
    "Adds basic external storage support" : "Pridáva základnú podporu externého úložiska",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Táto aplikácia umožňuje správcom nastaviť prepojenia na poskytovateľov externých úložísk, ako napríklad servery FTP, S3 alebo SWIFT objektové úložiská, iné Nextcloudu servery, WebDAV servery a pod. Správci môžu zvoliť, ktoré typy úložísk zapnúť a prípadne ich pripojiť pre účet, skupinu alebo celý systém. Užívatelia uvidia nový priečinok v ich koreňovom Nextcloud priečinku, do ktorého môžu pristupovať a používať ako akýkoľvek iný priečinok v Nextcloude. Externé úložisko tiež umožňuje ľuďom sprístupňovať v ňom uložené súbory. V takých prípadoch sa použijú prihlasovacie údaje vlastníka súboru keď si príjemca vyžiada súbor z externého úložiska, čím je zaistené, že príjemca môže pristupovať k sprístupnenému súboru.\n\nExterné úložisko je možné nastaviť pomocou web rozhrania alebo z príkazového riadku. Druhá možnosť poskytuje správcom väčšie možnosti prispôsobenia pre nastavenie viac typov pripojení externých úložísk a nastavenia priorít pre pripájanie. Viac informácií je k dispozícii v dokumentácii k externým úložiskám vo web rozhraní a dokumentácii k súboru s nastaveniami pre externé úložiská.",
    "Edit storage" : "Upraviť úložisko",
    "Add storage" : "Pridať úložisko",
    "Folder name" : "Názov priečinka",
    "Authentication" : "Autentifikácia",
    "Cancel" : "Cancel",
    "Edit" : "Upraviť",
    "Create" : "Vytvoriť",
    "Restrict to" : "Obmedziť na",
    "Storage configuration" : "Konfigurácia úložiska",
    "Never" : "Nikdy",
    "Once every direct access" : "S každým priamym prístupom",
    "Always" : "Vždy",
    "Mount options" : "Možnosti pripojenia",
    "Check filesystem changes" : "Skontrolujte zmeny v súborovom systéme",
    "Read only" : "Len na čítanie",
    "Enable previews" : "Povoliť náhľady",
    "Enable sharing" : "Povoliť zdieľanie",
    "Enable encryption" : "Povoliť šifrovanie",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilita s Mac NFD enkódovaním (pomalé)",
    "External storages" : "Externé úložiská",
    "Status" : "Stav",
    "Restricted to" : "Obmedzené na",
    "Actions" : "Akcie",
    "Checking …" : "Kontrolujem …",
    "Recheck status" : "Prekontrolovať stav",
    "Delete" : "Vymazať",
    "System provided storage" : "Skladovanie poskytované systémom",
    "Saved" : "Uložené",
    "Error while saving" : "Chyba pri ukladaní",
    "Saved allowed backends" : "Uložené povolené back-endy",
    "Failed to save allowed backends" : "Nepodarilo sa uložiť povolené backendy",
    "Advanced options for external storage mounts" : "Rozšírené možnosti pre pripojenie externého úložiska",
    "Allow people to mount external storage" : "Povoliť užívateľom pripojiť externé úložiská",
    "External storage backends people are allowed to mount" : "Externé úložiská, ktoré môžu ľudia pripojiť",
    "Error generating key pair" : "Chyba pri vytváraní dvojice kľúčov",
    "Key size" : "Veľkosť klľúča",
    "Generate keys" : "Vytvoriť kľúče",
    "Confirm" : "Potvrdiť",
    "Storage credentials" : "Poverenia k úložisku",
    "To access the storage, you need to provide the authentication credentials." : "Ak chcete získať prístup k úložisku, musíte zadať autentifikačné poverenia.",
    "Enter the storage login" : "Zadajte prihlasovacie meno do úložiska",
    "Enter the storage password" : "Zadajte heslo do úložiska",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices." : "Externé úložisko vám umožňuje pripojiť externé úložné služby a zariadenia ako sekundárne úložiská Nextcloud.",
    "You may also allow people to mount their own external storage services." : "Môžete tiež umožniť ľuďom pripojiť ich vlastné externé úložné služby.",
    "The cURL support in PHP is not enabled or installed." : "Podpora cURL v PHP nie je povolená ani nainštalovaná.",
    "The FTP support in PHP is not enabled or installed." : "Podpora FTP v PHP nie je povolená alebo nainštalovaná.",
    "{module} is not installed." : "{module} nie je nainštalované.",
    "Dependant backends" : "Závislé backendy",
    "No external storage configured or you do not have the permission to configure them" : "Žiadne externé úložisko nie je nakonfigurované alebo nemáte povolenie na jeho konfiguráciu",
    "Add external storage" : "Pridať externé úložisko",
    "Global credentials saved" : "Globálne poverenia uložené",
    "Could not save global credentials" : "Nepodarilo sa uložiť globálne poverenia",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Globálne prihlasovacie údaje je možné použiť pre overenie s viacerými externými úložiskami, ktoré majú rovnaké prihlasovacie údaje.",
    "Saving …" : "Ukladanie …",
    "Save" : "Uložiť",
    "Unable to update this external storage config. {statusMessage}" : "Nepodarilo sa aktualizovať konfiguráciu externého úložiska. {statusMessage}",
    "New configuration successfully saved" : "Nová konfigurácia úspešne uložená",
    "Enter missing credentials" : "Zadajte chýbajúce prihlasovacie údaje",
    "Credentials successfully set" : "Prístupové údaje boli úspešne nastavené",
    "Error while setting credentials: {error}" : "Chyba pri nastavovaní prístupových údajov: {error}",
    "Checking storage …" : "Kontrola úložiska …",
    "There was an error with this external storage." : "Vyskytla sa chyba s externým úložiskom.",
    "We were unable to check the external storage {basename}" : "Nepodarilo sa nám skontrolovať externé úložisko {basename}",
    "Examine this faulty external storage configuration" : "Skúste preskúmať chybnú konfiguráciu externého úložiska",
    "Open in Files" : "Otvoriť v súboroch",
    "External mount error" : "Chyba externého úložiska",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Bola zaznamenaná chyba s týmto externým úložiskom. Chcete skontrolovať konfiguráciu tohto pripojenia na stránke nastavení?",
    "Open settings" : "Otvoriť nastavenia",
    "Ignore" : "Ignorovať",
    "List of external storage." : "Zoznam externého úložiska.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Nie je konfigurované žiadne externé úložisko. Môžete ich nakonfigurovať vo svojich osobných nastaveniach.",
    "There is no external storage configured and you don't have the permission to configure them." : "Žiadne externé úložisko nie je nakonfigurované a nemáte práva ich konfigurovať.",
    "No external storage" : "Žiadne externé úložiská",
    "Storage type" : "Typ úložiska",
    "Unknown" : "Neznámy",
    "Scope" : "Rozsah",
    "Personal" : "Osobné",
    "System" : "Systém",
    "Connected" : "Pripojené",
    "Error" : "Chyba",
    "Indeterminate" : "Neurčité",
    "Incomplete configuration" : "Nedokončená konfigurácia",
    "Unauthorized" : "Nepovolené",
    "Network error" : "Chyba siete",
    "Grant access" : "Povoliť prístup",
    "Error configuring OAuth2" : "Chyba konfigurovania OAuth2",
    "%s" : "%s",
    "Access key" : "Prístupový kľúč",
    "Secret key" : "Tajný kľúč",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Heslo klienta",
    "S3 Storage" : "S3 Úložisko",
    "Enable SSL" : "Povoliť SSL",
    "Enable Path Style" : "Povoliť štýl cesty",
    "Legacy (v2) authentication" : "Staršie (v2) overovanie",
    "FTP" : "FTP",
    "Local" : "Lokálny",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP prihlásenie pomocou tajného kľúča",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS s použitím OC prihlásenia",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná cURL podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná FTP podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "Nie je nainštalované \"%1$s\". Pripojenie %2$s nie je možné. Požiadajte svojho správcu o inštaláciu.",
    "Checking storage …" : "Kontrolujem úložisko ...",
    "Type to select account or group." : "Zadajte text pre výber účtu alebo skupiny.",
    "(Group)" : "(Skupina)",
    "Check for changes" : "Zisťovať zmeny",
    "Disconnect" : "Odpojiť",
    "Unknown backend: {backendName}" : "Neznámy backend: {backendName}",
    "Admin defined" : "Nastavené správcom",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatická kontrola stavu je zakázaná z dôvodu veľkého počtu nakonfigurovaných úložísk, kliknutím skontrolujte stav",
    "Are you sure you want to disconnect this external storage?" : "Naozaj chcete odpojiť tento externý úložný priestor?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Spôsobí, že úložisko v {instanceName} bude nedostupné a vedie k vymazaniu týchto súborov a priečinkov na akomkoľvek synchronizačnom klientovi, ktorý je aktuálne pripojený, ale nevymaže žiadne súbory a priečinky na samotnom externom úložisku.",
    "Delete storage?" : "Zmazať externé úložisko?",
    "Click to recheck the configuration" : "Kliknite na opätovnú kontrolu konfigurácie",
    "Saving …" : "Ukladá sa...",
    "Failed to save global credentials" : "Nepodarilo sa uložiť globálne prihlasovacie údaje",
    "Failed to save global credentials: {message}" : "Nepodarilo sa uložiť globálne prihlasovacie údaje: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Žiadne externé úložisko nie je nakonfigurované alebo nemáte práva ich konfigurovať",
    "Open documentation" : "Otvoriť dokumentáciu",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "Externé úložisko umožňuje pripojiť služby externých úložísk a zariadení ako sekundárne zariadenia na ukladanie pre Nextcloud. Môžete tiež umožniť ľuďom pripájať ich vlastné služby externých úložísk.",
    "Configuration" : "Nastavenia",
    "Available for" : "K dispozícii pre",
    "All people" : "Všetci ľudia",
    "Advanced settings" : "Rozšírené nastavenia",
    "Use presigned S3 url" : "Použiť predpísanú S3 URL"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
