OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "Vous n'êtes pas connecté",
    "Permission denied" : "Autorisation refusée",
    "Forbidden to manage local mounts" : "Interdiction de gérer les montages locaux",
    "Storage with ID \"%d\" not found" : "Stockage avec l'ID \"%d\" non trouvé",
    "Invalid backend or authentication mechanism class" : "Service ou méthode d'authentification non valide",
    "Invalid mount point" : "Point de montage non valide",
    "Objectstore forbidden" : "« Objectstore » interdit",
    "Invalid storage backend \"%s\"" : "Service de stockage non valide : \"%s\"",
    "Not permitted to use backend \"%s\"" : "Non autorisé à utiliser le service \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Non autorisé à utiliser le mécanisme d'authentification \"%s\"",
    "Unsatisfied backend parameters" : "Paramètres du service incorrects",
    "Unsatisfied authentication mechanism parameters" : "Paramètres pour la méthode d'authentification incorrects",
    "Insufficient data: %s" : "Données insuffisantes : %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Le support de stockage avec l'ID \"%d\" n'est pas modifiable par les non-administrateurs.",
    "Builtin" : "Intégré",
    "None" : "Aucun",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Identifiant",
    "Password" : "Mot de passe",
    "Tenant name" : "Nom du locataire",
    "Identity endpoint URL" : "URL de l'identity endpoint",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domaine",
    "Rackspace" : "Rackspace",
    "API key" : "Clé API",
    "Global credentials" : "Informations d'identification globales",
    "Log-in credentials, save in database" : "Identifiants de connexion, sauvegarder dans la base de données",
    "Login and password" : "Identifiant et mot de passe",
    "Log-in credentials, save in session" : "Identifiants de connexion, sauvegarder dans la session",
    "Global credentials, manually entered" : "Identifiants globaux, saisis manuellement",
    "Manually entered, store in database" : "Saisi manuellement, stocker dans la base de données",
    "RSA public key" : "Clé publique RSA",
    "Public key" : "Clé publique",
    "RSA private key" : "Clé privée RSA",
    "Private key" : "Clé privée",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Domaine Kerberos par défault, valeur par défaut \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Ticket Kerberos, mode Apache",
    "Kerberos ticket" : "Ticket Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Nom de l’hôte",
    "Port" : "Port",
    "Proxy" : "Proxy",
    "Region" : "Région",
    "Storage Class" : "Classe de stockage",
    "Enable multipart copy" : "Activer la copie multiple",
    "SSE-C encryption key" : "Clé de chiffrement SSE-C",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sous-dossier distant",
    "Secure https://" : "Sécurisation https://",
    "Host" : "Hôte",
    "Secure ftps://" : "Sécurisation ftps://",
    "Location" : "Emplacement",
    "Root" : "Racine",
    "Share" : "Partage",
    "Show hidden files" : "Afficher les fichiers masqués",
    "Case sensitive file system" : "Système de fichiers sensible à la casse",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Le désactiver va permettre d'utiliser un système de fichiers insensible à la casse mais cela a un impact sur les performances.",
    "Verify ACL access when listing files" : "Vérifier l'accès ACL lors de l'affichage de la liste des fichiers",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Contrôler les ACL de chaque fichier ou dossier à l'intérieur d'un répertoire afin de filtrer les éléments pour lesquels le compte n'a pas d'accès en lecture, cela a un impact sur les performances",
    "Timeout" : "Délai d'attente",
    "Login as share" : "Se connecter en tant que partage",
    "Service name" : "Nom du service",
    "Request timeout (seconds)" : "Délai d'expiration des requêtes (en secondes)",
    "External storage" : "Stockage externe",
    "External storage support" : "Support de stockage externe",
    "Adds basic external storage support" : "Ajoute la prise en charge de base du stockage externe",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Cette application permet aux administrateurs de configurer des connexions à des stockage externes, tels que des serveurs FTP, des stockages d'objets S3 ou SWIFT, d'autres serveurs Nextcloud, des serveurs WebDAV, etc. L'administrateur peut choisir les types de stockage à activer et peut monter ces emplacements de stockage pour un compte, un groupe ou l'ensemble du système. Les utilisateurs verront apparaître un nouveau dossier dans leur répertoire racine Nextcloud, auquel ils pourront accéder et utiliser comme n'importe quel autre dossier Nextcloud. Le stockage externe permet également aux personnes de partager des fichiers stockés dans ces emplacements externes. Dans ce cas, les informations d'identification du propriétaire du fichier sont utilisées lorsque le destinataire demande le fichier à partir du stockage externe, garantissant ainsi que le destinataire peut accéder au fichier partagé.\n\nLe stockage externe peut être configuré à l'aide de l'interface graphique ou via l'interface en ligne de commande. Cette deuxième option offre à l'administration une plus grande flexibilité pour configurer les montages de stockage externes en masse et définir les priorités de montage. D'autres informations sont disponibles dans la documentation de l'interface graphique de stockage externe et la documentation du fichier de configuration de stockage externe.",
    "Edit storage" : "Modifier le stockage",
    "Add storage" : "Ajouter un stockage",
    "Folder name" : "Nom du dossier",
    "Authentication" : "Authentification",
    "Cancel" : "Annuler",
    "Edit" : "Modifier",
    "Create" : "Créer",
    "Restrict to" : "Restreindre à",
    "Storage configuration" : "Configuration du stockage",
    "Never" : "Jamais",
    "Once every direct access" : "Une fois par accès direct",
    "Always" : "Toujours",
    "Mount options" : "Options de montage",
    "Check filesystem changes" : "Vérifier les changements de système de fichiers",
    "Read only" : "Lecture seule",
    "Enable previews" : "Activer les prévisualisations",
    "Enable sharing" : "Activer le partage",
    "Enable encryption" : "Activer le chiffrement",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilité avec l'encodage Mac NFD (lent)",
    "External storages" : "Stockages externes",
    "Status" : "Statut",
    "Restricted to" : "Restreint à",
    "Actions" : "Actions",
    "Checking …" : "Vérification  ...",
    "Recheck status" : "Vérifier à nouveau le statut",
    "Delete" : "Supprimer",
    "System provided storage" : "Stockage fourni par le système",
    "Saved" : "Enregistré",
    "Error while saving" : "Erreur lors de l'enregistrement",
    "Saved allowed backends" : "Backends autorisés enregistrés",
    "Failed to save allowed backends" : "Impossible d'enregistrer les backends autorisés",
    "Advanced options for external storage mounts" : "Options avancées pour les montages de stockage externes",
    "Allow people to mount external storage" : "Autoriser les utilisateurs à monter des périphériques de stockage externes",
    "External storage backends people are allowed to mount" : "Backend de stockage externes que les personnes sont autorisées à monter",
    "Error generating key pair" : "Erreur lors de la génération des clés",
    "Key size" : "Taille de la clé",
    "Generate keys" : "Générer des clés",
    "Confirm" : "Confirmer",
    "Storage credentials" : "Identifiants de stockage",
    "To access the storage, you need to provide the authentication credentials." : "Pour accéder au stockage, vous devez fournir les informations d’authentification.",
    "Enter the storage login" : "Entrez l'identifiant du stockage",
    "Enter the storage password" : "Entrez le mot de passe du stockage",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices." : "Le stockage externe vous permet de monter des services et appareils de stockage extenres en tant qu'appareils de stockage Nextcloud secondaires.",
    "You may also allow people to mount their own external storage services." : "Vous pouvez aussi autoriser les personnes à monter leurs propres services de stockage externe.",
    "The cURL support in PHP is not enabled or installed." : "La prise en charge de cURL dans PHP n'est pas activée ou installée.",
    "The FTP support in PHP is not enabled or installed." : "La prise en charge de FTP dans PHP n'est pas activée ou installée.",
    "{module} is not installed." : "{module} n’est pas installé",
    "Dependant backends" : "Backends dépendants",
    "No external storage configured or you do not have the permission to configure them" : "Aucun stockage externe configuré, ou vous n'avez pas la permission d'en configurer",
    "Add external storage" : "Ajouter un stockage externe",
    "Global credentials saved" : "Informations d'identification globales enregistrées",
    "Could not save global credentials" : "Impossible d'enregistrer les informations d'identification globales",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Les identifiants globaux peuvent être utilisés pour s'authentifier auprès de multiples stockages externes qui ont les mêmes identifiants.",
    "Saving …" : "Enregistrement  …",
    "Save" : "Enregistrer",
    "Unable to update this external storage config. {statusMessage}" : "Impossible de mettre à jour la configuration de ce stockage externe. {statusMessage}",
    "New configuration successfully saved" : "Nouvelle configuration sauvegardée avec succès",
    "Enter missing credentials" : "Saisissez les identifiants de connexion manquants",
    "Credentials successfully set" : "Identifiants enregistrés avec succès",
    "Error while setting credentials: {error}" : "Erreur lors de l'envoi des identifiants : {error}",
    "Checking storage …" : "Vérification du stockage …",
    "There was an error with this external storage." : "Il y a eu une erreur avec ce stockage externe.",
    "We were unable to check the external storage {basename}" : "Nous n'avons pas pu vérifier le stockage externe {basename}",
    "Examine this faulty external storage configuration" : "Examiner la configuration de ce stockage externe défectueuse",
    "Open in Files" : "Ouvrir dans Fichiers",
    "External mount error" : "Erreur montage externe",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Une erreur est survenue avec ce stockage externe. Voulez-vous vérifier la configuration de ce point de montage dans la page des paramètres ?",
    "Open settings" : "Ouvrir les paramètres",
    "Ignore" : "Ignorer",
    "List of external storage." : "Liste des périphériques de stockage externes.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Aucun stockage externe n'est configuré. Vous pouvez le configurer dans vos Paramètres personnels.",
    "There is no external storage configured and you don't have the permission to configure them." : "Il n'y a aucun stockage externe configuré et vous n'avez pas l'autorisation pour les configurer.",
    "No external storage" : "Aucun stockage externe",
    "Storage type" : "Type de stockage",
    "Unknown" : "Inconnu",
    "Scope" : "Portée",
    "Personal" : "Personnel",
    "System" : "Système",
    "Connected" : "Connecté",
    "Error" : "Erreur",
    "Indeterminate" : "Indéterminé",
    "Incomplete configuration" : "Configuration incomplète",
    "Unauthorized" : "Non autorisé",
    "Network error" : "Erreur réseau",
    "Grant access" : "Autoriser l’accès",
    "Error configuring OAuth2" : "Erreur lors de la configuration de OAuth2",
    "%s" : "%s",
    "Access key" : "Clé d'accès",
    "Secret key" : "Clé secrète",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Client",
    "Client secret" : "Secret client",
    "S3 Storage" : "Stockage S3",
    "Enable SSL" : "Activer SSL",
    "Enable Path Style" : "Activer Path Style",
    "Legacy (v2) authentication" : "Authentification héritée (v2)",
    "FTP" : "FTP",
    "Local" : "Local",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP avec identification par clé",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS utilisant la connexion OC",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Le support cURL dans PHP n'est pas activé ou installé. Le montage de %s n'est pas possible. Veuillez demander à votre administrateur système de l'installer.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Le support FTP dans PHP n'est pas activé ou installé. Le montage de %s n'est pas possible. Merci de demander à votre administrateur de l'installer.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" n'est pas installé. Le montage de %2$s n'est pas possible. Merci de demander à l'administrateur système de l'installer.",
    "Checking storage …" : "Vérification du stockage...",
    "Type to select account or group." : "Tapez pour sélectionner un compte ou un groupe.",
    "(Group)" : "(Groupe)",
    "Check for changes" : "Rechercher les modifications",
    "Disconnect" : "Se déconnecter",
    "Unknown backend: {backendName}" : "Service inconnu: {backendName}",
    "Admin defined" : "Défini par l'administrateur",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "La vérification automatique du statut est désactivée en raison du grand nombre de stockages configurés. Cliquez pour vérifier l'état.",
    "Are you sure you want to disconnect this external storage?" : "Êtes-vous sûr de vouloir déconnecter ce stockage externe ?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Cela rendra ce stockage indisponible dans {instanceName} et entraînera la suppression de ces fichiers et dossiers sur tous les clients actuellement connectés, mais ne supprimera aucun fichier ni dossier du stockage externe lui-même.",
    "Delete storage?" : "Supprimer le stockage ?",
    "Click to recheck the configuration" : "Cliquer pour revérifier la configuration",
    "Saving …" : "Enregistrement ...",
    "Failed to save global credentials" : "Impossible d'enregistrer les identifiants globaux",
    "Failed to save global credentials: {message}" : "Impossible d'enregistrer les identifiants globaux : {message}",
    "No external storage configured or you don't have the permission to configure them" : "Aucun stockage externe configuré ou vous n'avez pas l'autorisation de les configurer",
    "Open documentation" : "Voir la documentation",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "Le stockage externe vous permet de monter des périphériques et services externes en tant que périphériques de stockage secondaires dans Nextcloud. Vous pouvez aussi autoriser les personnes à monter leurs propres services de stockage externes.",
    "Configuration" : "Configuration",
    "Available for" : "Disponible pour",
    "All people" : "Tout le monde",
    "Advanced settings" : "Paramètres avancés",
    "Use presigned S3 url" : "Utiliser une URL S3 pré-signée"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
