OC.L10N.register(
    "support",
    {
    "Link:" : "Връзка:",
    "Password:" : "Парола:",
    "Generating system report failed." : "Генерирането на системния отчет не беше успешно.",
    "Could not create folder \"System information\" to store generated report." : "Не можа да се създаде папка „Системна информация“ за съхраняване на генерирания отчет.",
    "Could not create file \"%s\" to store generated report." : "Не можа да се създаде файл „%s“ за съхраняване на генерирания отчет.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Файлът „%s“ не можа да се сподели. Въпреки това можете да го намерите в папка „Системна информация“.",
    "Subscription notifications" : "Известия за абонамент",
    "Nextcloud Subscription" : "Абонамент за Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Вашият сървър няма абонамент за Nextcloud или вашият абонамент е изтекъл.",
    "Your Nextcloud server subscription does not cover your number of users." : "Вашият абонамент за сървър на Nextcloud не покрива вашия брой потребители.",
    "Your Nextcloud Subscription has expired!" : "Абонаменът ви за Nextcloud е изтекъл!",
    "Your server has no Nextcloud Subscription" : "Вашият сървър няма абонамент за Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Вашият Nextcloud сървър не обезпечен с абонамент за Nextcloud Enterprise.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Ако настройката на сървъра ви прекъсне и служителите не могат да работят повече, не е нужно да разчитате на търсене в онлайн форуми за решение. Имате директен достъп до нашите опитни инженери!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Имате договор с доставчика, предоставящ ранна информация за защита, смекчаване, корекции и актуализации.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Ако трябва да останете по-дълго на текущата си версия без прекъсвания, не е нужно да стартирате софтуер без актуализации на защитата.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Разполагате с най-добрия опит за справяне с проблеми с производителността и мащабируемостта.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Имате достъп до правилната документация и експертен опит, за да отговорите бързо на въпроси относно съответствие или да изпълните GDPR, HIPAA и други регулаторни изисквания.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Можем също така да предоставим интеграция с Outlook, онлайн офис, мащабируема, интегрирана аудио-видео и чат комуникация и други функции, достъпни само в ограничена форма безплатно или да разработим допълнителни интеграции и възможности според вашите нужди.",
    "A subscription helps you get the most out of Nextcloud!" : "Абонаментът ви помага да извлечете максимума от Nextcloud!",
    "Learn more now" : "Научете повече",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Този имейл беше изпратен до всички администратори от приложението за поддръжка на вашия екземпляр Nextcloud на %1$s, защото имате над %2$s регистрирани потребители.",
    "Your Nextcloud server Subscription is over limit" : "Вашият абонамент за Nextcloud сървър е над лимита",
    "Dear admin," : "Уважаеми администратор,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Абонаменът ви за Nextcloud не покрива броя на потребителите, които в момента са активни на този сървър. Моля, свържете се с вашия мениджър на профил в Nextcloud, за да актуализирате абонамента си!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$sе мениджърът на вашия профил и можете да се свържете с него по имейл чрез %2$s или по телефона чрез %3$s.",
    "Thank you," : "Благодарим Ви,",
    "Your Nextcloud team" : "Вашият Nextcloud екип",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Този имейл беше изпратен до всички администратори от приложението за поддръжка на вашия екземпляр Nextcloud на %s, защото имате повече потребители, отколкото покрива абонаментът ви.",
    "Your Nextcloud server Subscription is expired" : "Абонаменът ви за Nextcloud сървър е изтекъл",
    "Your Nextcloud server Subscription is expired!" : "Абонаменът ви за Nextcloud сървър е изтекъл!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Абонаменът ви за Nextcloud сървър е изтекъл! Моля, свържете се с вашия мениджър на профил в Nextcloud, за да актуализирате абонамента си!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Този имейл беше изпратен до всички администратори от приложението за поддръжка на вашия екземпляр Nextcloud на %s, тъй като абонаментът ви е изтекъл.",
    "Support" : "Поддръжка",
    "Getting support and help for your Nextcloud" : "Получаване на поддръжка и помощ за вашия Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Приложението за поддръжка ви осигурява директен достъп до ресурси за помощ и консултации, специални опции за контакт с вашия мениджър на профил и преглед на вашия корпоративен абонамент.",
    "Basic subscription" : "Основен абонамент",
    "Standard subscription" : "Стандартен абонамент",
    "Premium subscription" : "Премиум абонамент",
    "Géant subscription" : "Géant абонамент",
    "Silver partner subscription" : "Сребърен партньорски абонамент",
    "Gold partner subscription" : "Златен партньорски абонамент",
    "Subscription" : "Абонамент",
    "Over subscription limit" : "Превишаване на лимит за абонамент",
    "Valid subscription" : "Валиден абонамент",
    "Expired subscription" : "Изтекъл абонамент",
    "Subscription key:" : "Абонаментен ключ:",
    "Expires in: " : "Изтича след:",
    "_%n year_::_%n years_" : ["%n години","%n години "],
    "_%n month_::_%n months_" : ["%n месеци","%n месеци"],
    "_%n week_::_%n weeks_" : ["%n седмици ","%n седмици"],
    "_%n day_::_%n days_" : ["%n ","%n дни"],
    "For an unlimited amount of users" : "За неограничен брой потребители",
    "_For %n active users_::_For %n active users_" : ["За %n активни потребители","За %n активни потребители"],
    "_For %n users_::_For %n users_" : ["За %n потребители","За %n активни потребители"],
    "_currently at %n user_::_currently at %n users_" : ["в момента при %n потребители","в момента при %n потребители"],
    "Includes support for %s" : "Включва поддръжка за %s",
    "Includes support for %1$s & %2$s" : "Включва поддръжка за %1$s и %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Включва поддръжка за %1$s, %2$s и %3$s",
    "Extended maintenance life cycle" : "Удължен жизнен цикъл на поддръжка",
    "Update subscription key" : "Актуализиране на ключа за абонамент",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s е мениджърът на вашия профил. Не се колебайте да се свържете с нас, ако имате въпроси относно вашия абонамент.",
    "You can find answers to common question in our portal and also file support requests there." : "Можете да намерите отговори на често задавани въпроси в нашия портал, както и да подадете заявки за поддръжка там.",
    "Access Nextcloud portal" : "Достъп до портала на Nextcloud ",
    "System information" : "Информация за системата",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Събирайте системна информация за случаи на поддръжка. Долният бутон генерира текстов файл в папка „Системна информация“ и го споделя като защитена с парола публична връзка. Връзката е валидна 2 седмици.",
    "Generate system report" : "Генериране на системен отчет",
    "Enterprise subscription recommended" : "Препоръчва се професионален абонамент",
    "No active enterprise subscription" : "Няма активен професионален абонамент",
    "Unsupported" : "Не се поддържа",
    "This Nextcloud server has no Enterprise Subscription." : "Този Nextcloud сървър няма професионален абонамент.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Абонаментът за Nextcloud Enterprise/професионален/ ви помага да извлечете максимума от вашия Nextcloud, да поддържате данните си защитени и сървърът ви да работи надеждно по всяко време.",
    "Advantages" : "Предимства",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Достъп до техническата експертиза на разработчиците на Nextcloud чрез документация и поддръжка",
    "Access to additional capabilities like Outlook integration, online office and more" : "Достъп до допълнителни възможности като интеграция с Outlook, онлайн офис и др",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Достъп до експертен опит за мащабируемост и възможности за мащабируемост за Files and Talk",
    "Optional branding, consulting, architecture advice" : "По избор брандиране, консултации, архитектурни съвети",
    "Confidential security notification service, mitigations, patches and advice" : "Поверителна услуга за известяване за сигурност, смекчаване, корекции и съвети",
    "Compliance certification, advice and documentation" : "Сертификация за съответствие, съвети и документация",
    "Get a quote" : "Получете оферта",
    "More information" : "Допълнителна информация",
    "Subscription benefits" : "Предимства на абонамента",
    "Pricing" : "Ценообразуване",
    "Community support" : "Подкрепа от общността",
    "Forum" : "Форум",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud е безплатен софтуер, който се поддържа от много активна общност. Моля, регистрирайте се във форума, за да задавате въпроси и да обсъждате с други.",
    "Nextcloud forum" : "Форум на Nextcloud",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud използва GitHub като платформа за съвместна работа. Можете да подавате доклади за грешки директно там.",
    "Nextcloud at GitHub" : "Nextcloud в GitHub",
    "Subscription key" : "Абонаментен ключ",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Ако имате активен абонамент за Nextcloud, моля, въведете своя ключ за абонамент тук.",
    "Learn more about an enterprise subscription." : "Научете повече за професионален абонамент.",
    "Set subscription key" : "Задаване на абонаментен ключ",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Информацията за абонамента не можа да бъде извлечена правилно в момента. Насрочен е повторен опит. Моля, проверете отново по-късно.",
    "The subscription key was invalid." : "Абонаментният ключ е невалиден.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Абонаментният ключ не можа да бъде потвърден, тъй като този сървър няма интернет връзка. Моля, свържете се с екипа за поддръжка, за да разрешите това.",
    "The subscription key had an invalid format." : "Абонаментният ключ имаше невалиден формат.",
    "While fetching the subscription information an error happened." : "Възникна грешка при извличане на информацията за абонамента.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Долният бутон генерира текстов файл в папка „Системна информация“ и го споделя като защитена с парола публична връзка. Връзката е валидна 2 седмици.",
    "News" : "Новини",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "За да получите актуална информация какво се случва в Nextcloud, регистрирайте се за бюлетина и ни последвайте в нашите профили в социалните медии.",
    "Like our Facebook page" : "Харесайте страницата ни във Фейсбук",
    "Follow us on Twitter" : "Следвайте ни в Twitter",
    "Check out our blog" : "Посетете блога ни",
    "Subscribe to our newsletter" : "Абонирайте се за нашия имейл бюлетин"
},
"nplurals=2; plural=(n != 1);");
