<?php
/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
?>

<input type="hidden" id="isPublic" name="isPublic" value="1">
<div id="content"></div>
