import{g as f}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as g}from"./delphi-Be3ql3j1.chunk.mjs";function c(e,a){for(var n=0;n<a.length;n++){const t=a[n];if(typeof t!="string"&&!Array.isArray(t)){for(const r in t)if(r!=="default"&&!(r in e)){const i=Object.getOwnPropertyDescriptor(t,r);i&&Object.defineProperty(e,r,i.get?i:{enumerable:!0,get:()=>t[r]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,l;function u(){if(l)return o;l=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/delphi" instead of "highlight.js/lib/languages/delphi.js"'))}return e(),o=g(),o}var s=u();const p=f(s),b=c({__proto__:null,default:p},[s]);export{b as d};
//# sourceMappingURL=delphi.js-L7QxuO26.chunk.mjs.map
