OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Nextcloud 公告",
    "Nextcloud announcement" : "Nextcloud 公告",
    "Read more" : "阅读更多",
    "Disable announcements" : "禁用公告",
    "(These announcements are only shown to administrators)" : "（这些公告只对管理员可见）",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Nextcloud 公告会将 Nextcloud 的最新信息带入您的通知中。"
},
"nplurals=1; plural=0;");
