OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : " ব্যক্তিগত ক্রিয়াকলাপের জন্য%s",
    "Your feed URL is invalid" : "আপনার ফিড URL টি অবৈধ",
    "Activity feed" : "সক্রিয়তা বারতা",
    "Your settings have been updated." : "আপনার সেটিং নবায়ন করা হয়েছে৷",
    "Settings have been updated." : "সেটিংস আপডেট করা হয়েছে।",
    "Recent activity" : "সাম্প্রতিক কার্জক্রম ",
    "More activities" : "বাড়তি কার্জক্রম ",
    "Daily activity summary for %s" : "এর জন্য প্রতিদিনের ক্রিয়াকলাপের সংক্ষিপ্তসার %s",
    "All activities" : "সমস্ত কার্যক্রম",
    "By others" : "অন্যদের দ্বারা",
    "By you" : "তোমার দ্বারা ",
    "Activity at %s" : "কার্যক্রম  %s",
    "Hello %s" : "হ্যালো %s",
    "Hello %s," : "হেলো %s,",
    "There was some activity at %s" : "এখানে কিছু ক্রিয়াকলাপ ছিল %s",
    "Mail" : "মেইল",
    "Push" : "ঠেলা",
    "Activity" : "সক্রিয়তা",
    "Notifications" : "বার্তাসমূহ",
    "This application enables people to view a log of activities about them, their files or other data." : "এই অ্যাপ্লিকেশান ইউজারের সকল কার্জক্রম(তাদের ফাইল এবং অন্য সব ডাটা) সক্রিয় করে ",
    "Send email" : "ইমেইল পাঠান ",
    "Send push notification" : "পুশ নোটিফিকেশন পাঠান ",
    "Today" : "আজ",
    "Yesterday" : "গতকাল",
    "You need to set up your email address before you can receive notification emails." : "ইমেইল বারতা পাওয়ার আগে আপনাকে নিজের ইমেইল ঠিকানা নিরধারন করতে হবে৷",
    "Send activity emails" : "ক্রিয়াকলাপ ইমেল প্রেরণ করুন",
    "As soon as possible" : "যত দ্রুত সম্ভব ",
    "Hourly" : "ঘনটাভিততিক",
    "Daily" : "দৈনিক",
    "Weekly" : "সাপ্তাহিক",
    "in {path}" : "{পথে}",
    "Home" : "বাড়ি",
    "This stream will show events like additions, changes & shares" : "এই স্ট্রিমটি সংযোজন, পরিবর্তন এবং ভাগের মতো ইভেন্টগুলি প্রদর্শন করবে",
    "No activity yet" : "এখনও কোন কার্যকলাপ নেই",
    "Activity settings" : "কার্যক্রম অবস্থা",
    "Enable RSS feed" : "RSS feed উপযোগী ক኉ন",
    "RSS feed" : "আরএসএস ফিড ",
    "Personal notification settings" : "ব্যক্তিগত বিজ্ঞপ্তি অবস্থা",
    "Choose for which activities you want to get an email or push notification." : "আপনি কোন ক্রিয়াকলাপের জন্য ইমেল পেতে চান বা বিজ্ঞপ্তি চাপুন তা চয়ন করুন।",
    "Choose for which activities you want to get a push notification." : "আপনি কোন ধরণের বিজ্ঞপ্তি পেতে চান তা বেছে নিন।",
    "Notification" : "নোটিফিকেশন ",
    "Enable notification emails" : "বিজ্ঞপ্তি ইমেলগুলি সক্ষম করুন",
    "Send daily activity summary in the morning" : "সকালে প্রতিদিনের ক্রিয়াকলাপের সারাংশ পাঠান",
    "Default settings" : "ডিফল্ট সেটিংস",
    "No more events to load" : "লোড করার কোন ইভেন্ট খুঁজে পাওয়া গেল না।"
},
"nplurals=2; plural=(n != 1);");
