OC.L10N.register(
    "circles",
    {
    "Teams" : "Jamoalar",
    "Personal" : "Personal",
    "System" : "Tizim",
    "Open" : "Ochish",
    "Invite" : "Taklif qiling",
    "Password protected" : "Parol bilan himoyalangan",
    "Hidden" : "Yashirin",
    "Local" : "Lokal",
    "Email address" : "E-pochta manzili",
    "Contact" : "Aloqa",
    "Team" : "Jamoa",
    "Member" : "A'zo",
    "Admin" : "Administrator",
    "Owner" : "Egasi",
    "Open »%s«" : "ochish »%s«",
    "Files" : "Fayllar",
    "Accept" : "Qabul qiling",
    "%s" : "%s",
    "Open %s" : "Ochiq %s",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Jamg'arma sizga jamoalarni boshqa ishonchli serverlar bilan baham ko'rish va ularni turli holatlarda ko'rinadigan qilish imkonini beradi.",
    "https://…" : "https://…",
    "Loading…" : "Yuklanmoqda...",
    "No files in here" : "No files in hereBu erda fayl mavjud emas",
    "No entries found in this folder" : "Ushbu papkada hech qanday yozuv topilmadi",
    "Name" : "Nomi",
    "Size" : "O'lchami",
    "Modified" : "O'zgartirilgan"
},
"nplurals=1; plural=0;");
