OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Fitxategi partekatzeak",
    "Downloaded via public link" : "Esteka publikoaren bidez deskargatuta",
    "Downloaded by {email}" : "{email} erabiltzaileak deskargatua",
    "{file} downloaded via public link" : "{file} fitxategia esteka publikoaren bidez deskargatuta",
    "{email} downloaded {file}" : "{email} erabiltzaileak {file} fitxategia deskargatu du",
    "Shared with group {group}" : "{group} taldearekin partekatua",
    "Removed share for group {group}" : "{group} taldearekiko partekatzea kendu da",
    "{actor} shared with group {group}" : "{actor} erabiltzaileak {group} taldearekin partekatua",
    "{actor} removed share for group {group}" : "{actor} erabiltzaileak {group} taldearekiko partekatzea kendu du",
    "Share for group {group} expired" : "{group} taldearekin partekatzea iraungi da",
    "You shared {file} with group {group}" : " {file} fitxategia {group} taldearekin partekatu duzu",
    "You removed group {group} from {file}" : "{group} taldea {file} fitxategitik kendu duzu",
    "{actor} shared {file} with group {group}" : "{actor} erabiltzaileak {file} fitxategia {group} taldearekin partekatu du",
    "{actor} removed group {group} from {file}" : "{actor} erabiltzaileak {group} taldea {file} fitxategitik kendu du",
    "Share for file {file} with group {group} expired" : "{file} fitxategia {group} taldearekin partekatzea iraungi da",
    "Shared as public link" : "Esteka publiko bezala partekatua",
    "Removed public link" : "Esteka publikoa kenduta",
    "Public link expired" : "Esteka publikoa iraungita",
    "{actor} shared as public link" : "{actor} erabiltzaileak esteka publiko bezala partekatu du",
    "{actor} removed public link" : "{actor} erabiltzaileak esteka publikoa kendu du",
    "Public link of {actor} expired" : "{actor} erabiltzailearen esteka publikoa iraungi da",
    "You shared {file} as public link" : "{file} fitxategia esteka publiko bezala partekatu duzu",
    "You removed public link for {file}" : "{file} fitxategiaren esteka publikoa kendu duzu",
    "Public link expired for {file}" : "{file} fitxategiaren esteka publikoa iraungi da",
    "{actor} shared {file} as public link" : "{actor} erabiltzaileak {file} fitxategia esteka publiko bezala partekatu du",
    "{actor} removed public link for {file}" : "{actor} erabiltzaileak {file} fitxategiaren esteka publikoa kendu du",
    "Public link of {actor} for {file} expired" : "{file} fitxategirako {actor} erabiltzailearen esteka publikoa iraungi da",
    "{user} accepted the remote share" : "{user} erabiltzaileak urruneko partekatzea onartu du",
    "{user} declined the remote share" : "{user} erabiltzaileak urruneko partekatzea ukatu du",
    "You received a new remote share {file} from {user}" : "Urruneko {file} partekatze berria jaso duzu {user} erabiltzailearengandik",
    "{user} accepted the remote share of {file}" : "{user} erabiltzaileak {file} fitxategiaren urruneko partekatzea onartu du",
    "{user} declined the remote share of {file}" : "{user} erabiltzaileak {file} fitxategiaren urruneko partekatze bat ukatu du",
    "{user} unshared {file} from you" : "{user} erabiltzaileak {file} fitxategia zurekin partekatzeari utzi dio",
    "Shared with {user}" : "{user} erabiltzailearekin partekatua",
    "Removed share for {user}" : "{user} erabiltzailearekin partekatzea kenduta",
    "You removed yourself" : "Zure burua kendu duzu",
    "{actor} removed themselves" : "{actor} erabiltzaileak bere burua kendu du",
    "{actor} shared with {user}" : "{actor} erabiltzaileak {user} erabiltzailearekin partekatu du",
    "{actor} removed share for {user}" : "{actor} erabiltzaileak {user} erabiltzailearekin partekatzea kendu du",
    "Shared by {actor}" : "{actor} erabiltzaileak partekatua",
    "{actor} removed share" : "{actor} erabiltzaileak partekatzea kendu du",
    "Share for {user} expired" : "{user} erabiltzailearekin partekatzea iraungi da",
    "Share expired" : "Partekatzea iraungi da",
    "You shared {file} with {user}" : "{file} fitxategia {user} erabiltzailearekin partekatu duzu",
    "You removed {user} from {file}" : "{user} erabiltzailea {file} fitxategik kendu duzu",
    "You removed yourself from {file}" : "Zure burua kendu duzu {file} fitxategitik",
    "{actor} removed themselves from {file}" : "{actor} erabiltzaileak bere burua kendu du {file} fitxategitik",
    "{actor} shared {file} with {user}" : "{actor} erabiltzaileak {file} fitxategia partekatu du {user} erabiltzailearekin",
    "{actor} removed {user} from {file}" : "{actor} erabiltzaileak {user} erabiltzailea kendu du {file} fitxategitik",
    "{actor} shared {file} with you" : "{actor} erabiltzaileak {file} zurekin partekatu du",
    "{actor} removed you from the share named {file}" : "{actor} erabiltzaileak {file} izeneko partekatzetik kendu zaitu",
    "Share for file {file} with {user} expired" : "{file} fitxategia {user} erabiltzailearekin partekatzea iraungi da",
    "Share for file {file} expired" : "{file} fitxategia partekatzea iraungi da",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Posta elektronikoz edo esteka publiko bidez partekatutako fitxategi edo karpeta bat <strong>deskargatu</strong> da",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Fitxategiak postaz edo esteka publikoz partekatutako karpeta batera  <strong>igo</strong> dira",
    "A file or folder was shared from <strong>another server</strong>" : "Fitxategia edo karpeta bat partekatu da <strong>beste zerbitzari batetik</strong>",
    "Sharing" : "Partekatzea",
    "A file or folder has been <strong>shared</strong>" : "Fitxategia edo karpeta bat <strong>partekatu</strong> da",
    "Shared link" : "Partekatutako esteka",
    "Wrong share ID, share does not exist" : "Partekatzeko ID okerra, partekatzea ez dago",
    "Could not delete share" : "Ezin izan da partekatzea ezabatu",
    "Please specify a file or folder path" : "Zehaztu fitxategi edo karpetaren bide bat",
    "Wrong path, file/folder does not exist" : "Bide okerra, fitxategia/karpeta ez da existitzen",
    "Could not create share" : "Ezin izan da partekatzea sortu",
    "Please specify a valid account to share with" : "Zehaztu baliozko kontu bat partekatzeko",
    "Group sharing is disabled by the administrator" : "Administratzaileak taldeekin partekatzea desgaitu du",
    "Please specify a valid group" : "Zehaztu baliozko talde bat",
    "Public link sharing is disabled by the administrator" : "Administratzaileak estekak publikoki partekatzea desgaitu du",
    "Please specify a valid email address" : "Zehaztu baliozko helbide elektroniko bat",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : " %s Nextcloud Talk-etik pasahitza bidaliz partekatzeak huts egin du, Nextcloud Talk ez dagoelako gaituta",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : " %1$s partekatzeak huts egin du, atzealdeak %2$s motako partekatzeak ez dituelako onartzen",
    "Please specify a valid federated account ID" : "Zehaztu baliozko federatutako kontu ID bat",
    "Please specify a valid federated group ID" : "Mesedez, zehaztu baliozko talde federatu baten id-a",
    "You cannot share to a Team if the app is not enabled" : "Ezin duzu talde batekin partekatu aplikazioa gaituta ez badago",
    "Please specify a valid team" : "Zehaztu baliozko lantalde bat",
    "Sharing %s failed because the back end does not support room shares" : "%s partekatzeak huts egin du, atzealdeak ez duelako gelak partekatzea onartzen",
    "Unknown share type" : "Partekatze mota ezezaguna",
    "Not a directory" : "Ez da direktorio bat",
    "Could not lock node" : "Ezin izan da nodoa blokeatu",
    "Public upload is only possible for publicly shared folders" : "Igoera publikoa publikoki partekatutako karpetetan egin daiteke soilik",
    "Share must at least have READ or CREATE permissions" : "Partekatzeak gutxienez IRAKURRI edo SORTU egiteko baimenak behar ditu",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Partekatzeak IRAKURRI egiteko baimenak behar ditu, EGUNERATU edo EZABATU baimenak baldin badauzka",
    "Public upload disabled by the administrator" : "Administratzaileak igoera publikoak desgaitu ditu",
    "Could not lock path" : "Ezin izan da bidea blokeatu",
    "no sharing rights on this item" : "Ez dago baimenik fitxategi hau partekatzeko",
    "You are not allowed to edit incoming shares" : "Ez duzu baimenik zuri partekaturikoak editatzeko",
    "Wrong or no update parameter given" : "Eguneraketa parametrorik ez da eman edo okerra da",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Nextcloud Talk-ek pasahitza bidaltzeak\" huts egin du ez dagoelako Nextcloud Talk gaituta fitxategi edo karpeta bat partekatzeko.",
    "Custom share link tokens have been disabled by the administrator" : "Administratzaileak esteka pertsonalizatuen tokenak sortzeko aukera ezgaitu du",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Tokenek gutxienez karaktere 1 izan behar dute, eta letrak, zenbakiak edo marratxo bat baino ezin dituzte eduki",
    "Invalid date. Format must be YYYY-MM-DD" : "Data baliogabea. UUU-HH-EE gisako formatua izan behar du",
    "No sharing rights on this item" : "Ez dago baimenik fitxategi hau partekatzeko",
    "Invalid share attributes provided: \"%s\"" : "Baliogabeko partekatze atributuak eman dira: \"%s\"",
    "You are not allowed to send mail notifications" : "Ezin dituzu email bidezko jakinarazpenak bidali",
    "No mail notification configured for this share type" : "Partekatze mota honentzat ez dago email jakinarazpenik konfiguratuta",
    "Wrong password" : "Pasahitz okerra",
    "Error while sending mail notification" : "Errorea email jakinarazpena bidaltzean",
    "Failed to generate a unique token" : "Ezin izan da token bakar bat sortu",
    "This share does not exist or is no longer available" : "Partekatze hau ez dago edo jada ez dago erabilgarri",
    "shared by %s" : "%s erabiltzaileak partekatua",
    "Download" : "Deskargatu",
    "Add to your %s" : "Gehitu zure %s-era",
    "Direct link" : "Esteka zuzena",
    "Share API is disabled" : "Partekatze API-a desgaituta dago",
    "File sharing" : "Fitxategien partekatzea",
    "Share will expire tomorrow" : "Partekatzea bihar iraungiko da",
    "Your share of {node} will expire tomorrow" : "{node} nodoaren zure partekatzea bihar iraungiko da",
    "You received {share} as a share by {user}" : "{share} partekatzea jaso duzu {user} erabiltzailearengandik",
    "You received {share} to group {group} as a share by {user}" : "{share} {group} taldearekin partekatzea jaso duzu {user} erabiltzailearengandik",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "Remember to upload the files to %s" : "Gogoratu fitxategiak %s(e)ra igo behar dituzula",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Atsegin handiz gogorarazi nahi dizugu oraindik ez duzula fitxategirik igo partekatutako karpetara.",
    "Open \"%s\"" : "Ireki «%s»",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Aplikazio honek Nextcloud-en fitxategiak partekatzeko aukera ematen du. Gaituta badago, administratzaileak aukeratu dezake zein taldek parteka ditzaketen fitxategiak. Ondoren, baimendutako pertsonek fitxategiak eta karpetak parteka ditzakete Nextcloud-eko beste kontu eta talde batzuekin. Gainera, administratzaileak partekatzeko estekaren funtzioa gaitzen badu, kanpoko esteka bat erabil daiteke fitxategiak Nextcloud-etik kanpoko beste pertsonekin partekatzeko. Administratzaileek ere ezar ditzakete pasahitzak eta iraungitze-datak, bai eta gaitu zerbitzaritik zerbitzarira fitxategiak esteken bidez partekatzea, baita gailu mugikorretatik partekatzea ere.\nFuntzioa desaktibatuz gero, zerbitzarian partekatutako fitxategiak eta karpetak kentzen dira partekatutako hartzaile guztientzat, baita sinkronizazio-bezeroetan eta mugikorreko aplikazioetan ere. Informazio gehiago eskuragarri dago Nextcloud Dokumentazioan.",
    "Filter accounts" : "Iragazi kontuak",
    "you" : "zu",
    "The request will expire on {date} at midnight and will be password protected." : "Eskaera {date} egunean iraungiko da gauerdian eta pasahitzez babestuta egongo da.",
    "The request will expire on {date} at midnight." : "Eskaera {date} egunean iraungiko da gauerdian.",
    "The request will be password protected." : "Eskaera pasahitzez babestuta egongo da.",
    "When should the request expire?" : "Noiz iraungi beharko luke eskaerak?",
    "Set a submission expiration date" : "Ezarri bidalketaren iraungitze-data",
    "Expiration date" : "Iraungitze-data",
    "Select a date" : "Hautatu data bat",
    "Your administrator has enforced a {count} days expiration policy." : "Zure administratzaileak {count} eguneko iraungitze-politika ezarri du. ",
    "What password should be used for the request?" : "Zein pasahitz erabili behar litzateke eskaera honetarako?",
    "Set a password" : "Ezarri pasahitz bat",
    "Password" : "Pasahitza",
    "Enter a valid password" : "Sartu baliozko pasahitz bat",
    "Generate a new password" : "Sortu pasahitz berria",
    "Your administrator has enforced a password protection." : "Zure administratzaileak pasahitzez babestu behar dela ezarri du.",
    "Automatically copying failed, please copy the share link manually" : "Autimatikoki kopiatzeak huts egin du, kopiatu eskuz partekatze esteka",
    "Link copied" : "Esteka kopiatu da",
    "Email already added" : "Helbide elektronikoa dagoeneko gehituta dago",
    "Invalid email address" : "Baliogabeko helbide elektronikoa",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Ondorengo helbide elektronikoa ez da baliozkoa: {emails}","Ondorengo helbide elektronikoak ez dira baliozkoak: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["Helbide elektroniko {count} gehitu da dagoeneko","{count} helbide elektroniko gehitu dira dagoeneko"],
    "_{count} email address added_::_{count} email addresses added_" : ["Helbide elektroniko {count} gehitu da","{count} helbide elektroniko gehitu dira"],
    "You can now share the link below to allow people to upload files to your directory." : "Orain beheko esteka parteka dezakezu jendeak zure direktoriora fitxategiak igo ditzan.",
    "Share link" : "Partekatu esteka",
    "Copy" : "Kopiatu",
    "Send link via email" : "Bidali esteka posta elektronikoz",
    "Enter an email address or paste a list" : "Sartu helbide elektroniko bat edo itsatsi zerrenda bat",
    "Remove email" : "Kendu helbide elektronikoa",
    "Select a destination" : "Hautatu helmuga bat",
    "Select" : "Hautatu",
    "What are you requesting?" : "Zer eskatu nahi duzu?",
    "Request subject" : "Eskaeraren gaia",
    "Birthday party photos, History assignment…" : "Urtebetetze festako argazkiak, Historiako apunteak...",
    "Where should these files go?" : "Nora joan behar lukete fitxategi hauek?",
    "Upload destination" : "Igo helmuga",
    "Revert to default" : "Itzuli aukera lehenetsira",
    "The uploaded files are visible only to you unless you choose to share them." : "Igotzen diren fitxategiak zeuk bakarrik ikus ditzakezu, partekatzea erabakitzen duzun artean.",
    "Add a note" : "Gehitu oharra",
    "Note for recipient" : "Hartzailearentzako oharra",
    "Add a note to help people understand what you are requesting." : "Gehitu ohar bat jendeak uler dezan zer eskatzen ari zaren.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Hartzaileari eskatzen ari zarena ulertzen lagunduko dion estekak, data edo beste edozein informazio gehi ditzakezu.",
    "Close" : "Itxi",
    "_Send email and close_::_Send {count} emails and close_" : ["Bidali mezu elektronikoa eta itxi","Bidali {count} mezu elektroniko eta itxi"],
    "Please select a folder, you cannot share the root directory." : "Aukeratu karpeta bat, ezin duzu erro karpeta partekatu.",
    "File request created" : "Fitxategi eskaera ondo sortu da",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Fitxategi eskaera sortu da eta mezu elektronikoa bidali da","Fitxategi eskaera sortu da eta  {count} mezu elektronikoak bidali dira"],
    "Error creating the share: {errorMessage}" : "Errorea partekatzea sortzean: {errorMessage}",
    "Error creating the share" : "Errorea partekatzea sortzean",
    "Error sending emails: {errorMessage}" : "Errorea mezu elektronikoak bidaltzean: {errorMessage}",
    "Error sending emails" : "Errorea mezu elektronikoak bidaltzean",
    "Create a file request" : "Sortu fitxategi eskaera",
    "Collect files from others even if they do not have an account." : "Bildu beste pertsona batzuen fitxategiak, nahiz eta beraiek kontua ez izan.",
    "To ensure you can receive files, verify you have enough storage available." : "Fitxategiak jaso ditzakezula bermatzeko, ziurta ezazu badaukazula nahikoa biltegiratze leku.",
    "File request" : "Fitxategi eskaera",
    "Previous step" : "Aurreko urratsa",
    "Cancel" : "Utzi",
    "Cancel the file request creation" : "Utzi bertan behera fitxategi eskaera sortzea",
    "Close without sending emails" : "Itxi mezu elektronikoak bidali gabe",
    "Continue" : "Jarraitu",
    "Error while toggling options" : "Errorea aukerak aldatzean",
    "Accept shares from other accounts and groups by default" : "Onartu beste kontu eta talde batzuetako partekatzeak modu lehenetsian",
    "Choose a default folder for accepted shares" : "Aukeratu karpeta lehenetsia onartutako akzioetarako",
    "Invalid path selected" : "Bide baliogabea hautatu da",
    "Unknown error" : "Errore ezezaguna",
    "Set default folder for accepted shares" : "Ezarri onartutako partekatzeen karpeta lehenetsia",
    "Reset" : "Berrezarri",
    "Reset folder to system default" : "Berrezarri karpeta sistemaren balio lehenetsietara",
    "Share expiration: {date}" : "Partekatzearen iraungitze-data: {date}",
    "Share Expiration" : "Partekatzearen iraungitze-data",
    "group" : "taldea",
    "conversation" : "elkarrizketa",
    "remote" : "urrunekoa",
    "remote group" : "urruneko taldea",
    "guest" : "gonbidatua",
    "by {initiator}" : "{initiator}(e)k",
    "Shared with the group {user} by {owner}" : "{owner} jabeak {user} taldearekin partekatua",
    "Shared with the conversation {user} by {owner}" : "{owner} jabeak {user} elkarrizketarekin partekatua",
    "Shared with {user} by {owner}" : "{owner} jabeak {user} erabiltzailearekin partekatua",
    "Open Sharing Details" : "Ireki partekatzearen xehetasunak",
    "Added by {initiator}" : "Honek gehitua: {initiator}",
    "Via “{folder}”" : "“{folder}” bidez",
    "Unshare" : "Ez partekatu",
    "Cannot copy, please copy the link manually" : "Ezin izan da kopiatu. Kopiatu esteka eskuz",
    "Copy internal link" : "Kopiatu barne-esteka",
    "For people who already have access" : "Dagoeneko sarbidea duten pertsonentzat",
    "Internal link" : "Barneko esteka",
    "{shareWith} by {initiator}" : "{initiator} erabiltzaileak {shareWith} ",
    "Shared via link by {initiator}" : "{initiator} erabiltzaileak esteka bidez partekatua",
    "File request ({label})" : "Fitxategi eskaera ({label})",
    "Mail share ({label})" : "Posta partekatzea ({label})",
    "Share link ({label})" : "Partekatu ({label}) eskeka",
    "Mail share" : "Posta partekatzea",
    "Share link ({index})" : "Partekatu ({index}) esteka",
    "Create public link" : "Sortu esteka publikoa",
    "Actions for \"{title}\"" : "\"{title}\"-ren ekintzak",
    "Copy public link of \"{title}\"" : "Kopiatu \"{title}\"-ren esteka publikoa",
    "Error, please enter proper password and/or expiration date" : "Errorea, sartu dagokion pasahitza edo/eta iraungitze-data",
    "Link share created" : "Esteka partekatzea sortu da",
    "Error while creating the share" : "Errore bat gertatu da partekatzea sortzean",
    "Your browser does not support copying, please copy the link manually:" : "Zure nabigatzaileak ez du onartzen kopiatzea, beraz, kopiatu esteka eskuz:",
    "Successfully copied public link" : "Esteka publikoa behar bezala kopiatu da",
    "Please enter the following required information before creating the share" : "Sartu ondorengo beharrezko informazioa partekatzea sortu aurretik",
    "Password protection (enforced)" : "Pasahitz bidez babestua (betearazita)",
    "Password protection" : "Pasahitz bidezko babesa",
    "Enter a password" : "Sartu pasahitz bat",
    "Enable link expiration (enforced)" : "Gaitu esteken iraungitzea (betearazia)",
    "Enable link expiration" : "Gaitu esteken iraungitzea",
    "Enter expiration date (enforced)" : "Sartu esteken iraungitzea (betearazia)",
    "Enter expiration date" : "Gaitu esteken iraungitzea",
    "Create share" : "Sortu partekatzea",
    "Customize link" : "Pertsonalizatu esteka",
    "Generate QR code" : "Sortu QR kodea",
    "Add another link" : "Gehitu beste esteka bat",
    "Create a new share link" : "Sortu partekatze esteka berria",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Partekatzeko aukera bizkorrak, une honetan hautatutakoa \"{selectedOption}\" da",
    "View only" : "Ikustea soilik",
    "Can edit" : "Editatu dezake",
    "Custom permissions" : "Baimen pertsonalizatuak",
    "Resharing is not allowed" : "Birpartekatzea ez da onartzen",
    "Name or email …" : "Izena edo posta elektronikoa …",
    "Name, email, or Federated Cloud ID …" : "Izena, posta elektronikoa edo federatutako hodiaren identifikazioa …",
    "Searching …" : "Bilatzen …",
    "No elements found." : "Ez da elementurik aurkitu.",
    "Search everywhere" : "Bilatu nonahi",
    "Guest" : "Gonbidatua",
    "Group" : "Taldea",
    "Email" : "Posta elektronikoa",
    "Team" : "Lantaldea",
    "Talk conversation" : "Talk elkarrizketa",
    "Deck board" : "Deck mahaia",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "{server} zerbitzarian",
    "Enter external recipients" : "Sartu kanpoko hartzaileak",
    "Search for internal recipients" : "Bilatu barruko hartzaileak",
    "Note from" : "Oharra bidali du",
    "Note:" : "Oharra:",
    "File drop" : "Fitxategiak jaregin",
    "Upload files to {foldername}." : "Igo fitxategiak {foldername}(e)ra.",
    "By uploading files, you agree to the terms of service." : "Fitxategiak igotzean, zerbitzu-baldintzak onartzen dituzu.",
    "Successfully uploaded files" : "Fitxategiak ongi igo dira",
    "View terms of service" : "Ikusi zerbitzu-balditzak",
    "Terms of service" : "Erabilera baldintzak",
    "Share with {user}" : "Partekatu {user}-ekin",
    "Share with email {email}" : "Partekatu helbide elektronikoarekin {email}",
    "Share with group" : "Partekatu taldearekin",
    "Share in conversation" : "Partekatu elkarrizketan",
    "Share with {user} on remote server {server}" : "Partekatu {user}-rekin urruneko zerbitzarian {server}",
    "Share with remote group" : "Partekatu urruneko taldearekin",
    "Share with guest" : "Partekatu gonbidatuarekin",
    "Update share" : "Eguneratu partekatzea",
    "Save share" : "Gorde partekatzea",
    "Read" : "Irakurri",
    "Create" : "Sortu",
    "Edit" : "Aldatu",
    "Share" : "Partekatu",
    "Delete" : "Ezabatu",
    "Password field cannot be empty" : "Pasahitz-eremua ezin da hutsik egon",
    "Replace current password" : "Aldatu uneko pasahitza",
    "Failed to generate a new token" : "Ezin izan da token berri bat sortu",
    "Allow upload and editing" : "Onartu igotzea eta editatzea",
    "Allow editing" : "Baimendu editatzea",
    "Upload only" : "Igoera soilik",
    "Advanced settings" : "Ezarpen aurreratuak",
    "Share label" : "Partekatu etiketa",
    "Share link token" : "Partekatzeko esteka-tokena",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Ezarri partekatze-estekaren token publikoa gogoratzeko erraza den zerbait, edo sortu token berria. Ez da gomendagarria informazio sentikorra duten partekatzeetako tokenak asma daitezkeenak erabiltzea.",
    "Generating…" : "Sortzen...",
    "Generate new token" : "Sortu token berria",
    "Set password" : "Pasahitza ezarri",
    "Password expires {passwordExpirationTime}" : "Pasahitza {passwordExpirationTime} iraungiko da",
    "Password expired" : "Pasahitza iraungi da",
    "Video verification" : "Bideo egiaztapena",
    "Expiration date (enforced)" : "Iraungitze-data (betearazita)",
    "Set expiration date" : "Ezarri iraungitze-data",
    "Hide download" : "Ezkutatu deskarga",
    "Allow download and sync" : "Baimendu deskargatu eta sinkronizatzea",
    "Note to recipient" : "Oharra hartzailearentzat",
    "Enter a note for the share recipient" : "Sartu ohar bat partekatzearen hartzailearentzat",
    "Show files in grid view" : "Erakutsi fitxategiak sareta ikuspegian",
    "Delete share" : "Ezabatu partekatzea",
    "Others with access" : "Sarbidea duten beste erabiltzaileak",
    "No other accounts with access found" : "Ez da aurkitu sarbidea duen beste konturik",
    "Toggle list of others with access to this directory" : "Txandakatu direktorio honetara sarbidea duten beste erabiltzaileen zerrenda",
    "Toggle list of others with access to this file" : "Txandakatu fitxategi honetara sarbidea duten beste erabiltzaileen zerrenda",
    "Unable to fetch inherited shares" : "Ezin izan dira heredatutako partekatzeak eskuratu",
    "Link shares" : "Lotu partekatzeak",
    "Shares" : "Partekatzeak",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Partekatu fitxategiak zure erakundean. Fitxategia dagoeneko ikus dezaketen hartzaileek esteka hau ere erabil dezakete erraz atzitzeko.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Partekatu fitxategiak zure erakundetik kanpoko beste batzuekin esteka publikoen eta posta elektronikoen bidez. Beste instantzia batzuetako {productName} kontuekin ere parteka dezakezu haien federatutako hodeiaren identifikazioa erabiliz.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Barneko edo kanpoko partekatzeetan sartzen ez diren aplikazio edo beste iturri batzuetako partekatzeak.",
    "Type names, teams, federated cloud IDs" : "Idatzi izenak, lantaldeak, federatutako hodeien iDak",
    "Type names or teams" : "Idatzi izenak edo lantaldeak",
    "Type a federated cloud ID" : "Idatzi federatutako hodei baten IDa",
    "Type an email" : "Idatzi posta elektroniko bat",
    "Type an email or federated cloud ID" : "Idatzi posta elektroniko edo federatutako hodei baten IDa",
    "Unable to load the shares list" : "Ezin izan da partekatzeen zerrenda kargatu",
    "Expires {relativetime}" : "Iraungitzea: {relativetime}",
    "this share just expired." : "partekatze hau oraintxe iraungi da.",
    "Shared with you by {owner}" : "{owner} erabiltzaileak zurekin partekatua",
    "Internal shares" : "Barneko partekatzeak",
    "Internal shares explanation" : "Barneko partekatzeen azalpena ",
    "External shares" : "Kanpoko sareak",
    "External shares explanation" : "Kanpoko partekatzeen azalpena",
    "Additional shares" : "Partekatze gehigarriak",
    "Additional shares explanation" : "Partekatze gehigarrien azalpena",
    "Link to a file" : "Esteka fitxategi batera",
    "_Accept share_::_Accept shares_" : ["Onartu partekatzea","Onartu partekatzeak"],
    "Open in Files" : "Ireki Fitxategiak aplikazioan",
    "_Reject share_::_Reject shares_" : ["Ukatu partekatzea","Ukatu partekatzeak"],
    "_Restore share_::_Restore shares_" : ["Berrezarri partekatzea","Berrezarri partekatzeak"],
    "Shared" : "Partekatuta",
    "Shared by {ownerDisplayName}" : "{ownerDisplayName}-(e)k partekatuta",
    "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
    "Sharing options" : "Partekatze aukerak",
    "Shared with others" : "Beste batzuekin partekatua",
    "You do not have enough permissions to share this file." : "Ez daukazu baimenik fitxategi hau partekatzeko",
    "People" : "Jendea",
    "Create file request" : "Sortu fitxategi eskaera",
    "Upload files to {foldername}" : "Igo fitxategiak {foldername}(e)ra",
    "Public file share" : "Fitxategi partekatze publikoa",
    "Publicly shared file." : "Partekatutako fitxategi publikoa.",
    "No file" : "Fitxategirik ez",
    "The file shared with you will show up here" : "Zurekin partekatutako fitxategia hemen agertuko da",
    "Public share" : "Partekatze publikoa",
    "Publicly shared files." : "Partekatutako fitxategi publikoak.",
    "No files" : "Fitxategirik ez",
    "Files and folders shared with you will show up here" : "Zurekin partekatutako fitxategi eta karpetak hemen agertuko dira",
    "Overview of shared files." : "Partekatutako fitxategien ikuspegia.",
    "No shares" : "Partekatzerik ez",
    "Files and folders you shared or have been shared with you will show up here" : "Partekatu dituzun eta zurekin partekatutako fitxategi eta karpetak hemen agertuko dira",
    "Shared with you" : "Zurekin partekatua",
    "List of files that are shared with you." : "Zurekin partekatuta dauden fitxategien zerrenda.",
    "Nothing shared with you yet" : "Oraindik ez da ezer partekatu zurekin",
    "Files and folders others shared with you will show up here" : "Zurekin partekatutako fitxategi eta karpetak hemen agertuko dira",
    "List of files that you shared with others." : "Besteekin partekatu dituzun fitxategien zerrenda.",
    "Nothing shared yet" : "Oraindik ez da ezer partekatu",
    "Files and folders you shared will show up here" : "Partekatu dituzun fitxategi eta karpetak hemen agertuko dira",
    "Shared by link" : "Esteka bidez partekatua",
    "List of files that are shared by link." : "Esteka bidez partekatutako fitxategien zerrenda.",
    "No shared links" : "Ez dago partekatutako estekarik",
    "Files and folders you shared by link will show up here" : "Esteka bidez partekatutako fitxategi eta karpetak hemen agertuko dira",
    "File requests" : "Fitxategi eskaerak",
    "List of file requests." : "Fitxategi eskaeren zerrenda",
    "No file requests" : "Ez da fitxategirik eskatu",
    "File requests you have created will show up here" : "Sortu dituzun fitxategi-eskaerak hemen agertuko dira",
    "Deleted shares" : "Ezabatutako partekatzeak",
    "List of shares you left." : "Utzi dituzun partekatzeen zerrenda.",
    "No deleted shares" : "Ezabatutako partekatzerik ez",
    "Shares you have left will show up here" : "Utzi dituzun partekatzeak hemen agertuko dira",
    "Pending shares" : "Zain dauden partekatzeak",
    "List of unapproved shares." : "Onartu gabeko partekatzeen zerrenda.",
    "No pending shares" : "Ez dago zain dagoen partekatzerik",
    "Shares you have received but not approved will show up here" : "Jaso dituzun baina berretsi gabe dauden partekatzeak hemen agertukon dira",
    "Error deleting the share" : "Errorea partekatzea ezabatzean",
    "Error updating the share" : "Errorea partekatzea eguneratzen",
    "File \"{path}\" has been unshared" : "\"{path}\" fitxategiaren partekatzea eten da",
    "Folder \"{path}\" has been unshared" : "\"{path}\" karpetaren partekatzea eten da",
    "Could not update share" : "Ezin izan da partekatzea eguneratu",
    "Share saved" : "Partekatzea gordeta",
    "Share expiry date saved" : "Partekatzearen iraungitze data gordeta",
    "Share hide-download state saved" : "Partekatzearen ezkutatze-deskarga egoera gorde da",
    "Share label saved" : "Partekatu etiketa gorde da",
    "Share note for recipient saved" : "Partekatutako oharra hartzailearentzat gordeta",
    "Share password saved" : "Partekatu pasahitza gorde da",
    "Share permissions saved" : "Partekatze baimenak gordeta",
    "To upload files to {folder}, you need to provide your name first." : "{folder}karpetara fitxategiak igotzeko, aurretik izena eman behar duzu.",
    "Upload files to {folder}" : "Igo fitxategiak {folder}(e)ra",
    "Please confirm your name to upload files to {folder}" : "Berretsi zure izena fitxategiak {folder} karpetara igotzeko",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName}-k zurekin karpeta bat partekatu du.",
    "Names must not be empty." : "Izenak ez dira hutsik egon behar.",
    "Names must not start with a dot." : "Izenek ezin dute hasi puntu batez.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" karakterea ezin da egon izenean",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" erreserbatutako izena da eta ezin da erabili",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" ez da onartzen izen gisa.",
    "Names must not end with \"{extension}\"." : "Izenek ezin dute bukatu \"{extension}\" batez",
    "Invalid name." : "Izen baliogabea.",
    "Password created successfully" : "Pasahitza ongi sortu da",
    "Error generating password from password policy" : "Errorea pasahitz-gidalerrotik pasahitza sortzean",
    "Shared with you and the group {group} by {owner}" : "{owner} erabiltzaileak zu eta {group} taldearekin partekatuta",
    "Shared with you and {circle} by {owner}" : " {owner} erabiltzaileak zurekin eta {circle} zirkuluarekin partekatua",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} erabiltzaileak zu eta {conversation} elkarrizketarekin partekatua",
    "Shared with you in a conversation by {owner}" : "{owner} erabiltzaileak zurekin partekatua elkarrizketa batean",
    "Share not found" : "Partekatzea ez da aurkitu",
    "Back to %s" : "Itzuli %s(e)ra",
    "Add to your Nextcloud" : "Gehitu zure Nextclouden",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "%s partekatzeak huts egin du atzealdeak ez dituelako ScienceMesh parteatzeak onartzen",
    "Name or email …" : "Izena edo posta ...",
    "Name, email, or Federated Cloud ID …" : "Izena, posta, edo federatutako hodei IDa...",
    "Searching …" : "Bilatzen…"
},
"nplurals=2; plural=(n != 1);");
