OC.L10N.register(
    "app_api",
    {
    "Error starting install of ExApp" : "Errore bat gertatu da ExApp instalatzen hastean",
    "ExApp not found, failed to get status" : "Ez da ExApp aurkitu, ezin izan da lortu egoera",
    "Could not perform installation of ExApp" : "Ezin izan da ExApp-ren instalazioa egin",
    "Failed to enable ExApp" : "Ezin izan da ExApp gaitu",
    "Failed to disable ExApp" : "Ezin izan da ExApp desgaitu",
    "Could not update ExApp" : "Ezin izan da ExApp eguneratu.",
    "Error starting update of ExApp" : "Errore bat gertatu da ExApp eguneratzean",
    "Could not perform update of ExApp" : "Ezin izan da ExApp-ren eguneraketa egin",
    "ExApp not found, failed to get logs" : "Ez da ExApp aurkitu, ezin izan dira erregistroak lortu",
    "AppAPI authentication failed" : "AppAPI autentifikazioak huts egin du",
    "AppAPI ExApp notifier" : "AppAPI ExApp jakinarazlea",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "AA integrazio taldea",
    "ExApps Settings" : "ExApp-ren ezarpenak",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "Cancel" : "Utzi",
    "Delete" : "Ezabatu",
    "Password confirmation failed" : "Pasahitzaren berrespenak huts egin du",
    "Default" : "Lehenetsia",
    "Edit" : "Aldatu",
    "Unlimited" : "Mugagabea",
    "ExApps installed" : "ExApp-ak instalatuta",
    "Name" : "Izena",
    "Protocol" : "Protokoloa",
    "Host" : "Ostalaria",
    "Docker network" : "Docker sarea",
    "Nextcloud URL" : "Nextcloud URLa",
    "HaProxy password" : "HaProxy pasahitza",
    "Memory limit" : "Memoria muga",
    "Additional options" : "Aukera gehiago",
    "Check connection" : "Egiaztatu konexioa",
    "Heartbeat" : "Taupadak",
    "Enabled" : "Gaituta",
    "More information" : "Informazio gehiago",
    "Remove" : "Kendu",
    "From" : "Nork",
    "To" : "Nori",
    "Add" : "Gehitu",
    "Display name" : "Erakusteko izena",
    "Deployment method" : "Zabalketa metodoa",
    "Daemon host" : "Daimonaren ostalaria",
    "Compute device" : "Konputazio gailua",
    "Option value" : "Aukeraren balioa",
    "Confirm" : "Berretsi",
    "Save" : "Gorde",
    "Register" : "Erregistratu",
    "External Apps" : "Kanpoko aplikazioak",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "AppAPI Proiektua Nextcloud-erako aplikazioak garatzeko modua iraultzea helburu duen ekimen zirraragarria da.",
    "Deploy Daemons" : "Zabaldu daimonak",
    "{license}-licensed" : "{license}-lizentziaduna",
    "Update to {version}" : "Eguneratu {version} bertsiora",
    "Delete data on remove" : "Ezabatu datuak kentzean",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will be an error in the future.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will be an error in the future.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aplikazioa ezin da instalatu hurrengo menpekotasunak betetzen ez direlako:",
    "View in store" : "Dendan ikusi",
    "Visit website" : "Web orria ikusi",
    "Report a bug" : "Jakinarazi errore bat",
    "User documentation" : "Erabiltzaile dokumentazioa",
    "Admin documentation" : "Admin dokumentazioa",
    "Developer documentation" : "Garatzaile dokumentazioa",
    "This app is supported via your current Nextcloud subscription." : "Aplikazio hau zure Nextcloud harpidetzaren bitartez ahalbidetua dago.",
    "Supported" : "Onartuta",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Nabarmendutako aplikazioak, komunitateak eta komunitatean garatutakoak dira. Funtzionalitate orokorrak eskaintzen dituzte eta produkzioan erabiltzeko prest daude.",
    "Featured" : "Nabarmendua",
    "Update to {update}" : "Eguneratu {update} bertsiora",
    "Default Deploy daemon is not accessible" : "Zabalpen lehenetsia ez dago eskuragarri",
    "Icon" : "Ikonoa",
    "Version" : "Bertsioa",
    "Daemon" : "Daemona",
    "Level" : "Maila",
    "Actions" : "Ekintzak",
    "Results from other categories" : "Beste kategoriatako emaitzak",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["Aplikazio %nek eguneraketa dauka prest","%n aplikaziok eguneraketa daukate prest."],
    "_Update_::_Update all_" : ["Eguneratu","Eguneratu denak"],
    "Deploy Daemon" : "Zabaldu daimona",
    "Type" : "Mota",
    "Display Name" : "Izena erakutsi",
    "GPUs support" : "GPUen bateragarritasuna",
    "Deploy config" : "Zabaldu konfigurazioa",
    "Verify connection" : "Egiaztatu konexioa",
    "Register Daemon" : "Erregistratu daimona",
    "More info" : "Informazio gehiago",
    "Enable https" : "Gaitu https",
    "Network" : "Sarea",
    "Additional option" : "Aukera gehiago",
    "by {author}\n{license}" : "{autor}-(e)k egina\n{license}",
    "Your apps" : "Zure aplikazioak",
    "Documentation" : "Dokumentazioa",
    "Details" : "Xehetasunak",
    "Changelog" : "Aldaketak",
    "Active apps" : "Aplikazio aktiboak",
    "Disabled apps" : "Gaitu gabeko aplikazioak",
    "Updates" : "Eguneraketak",
    "Featured apps" : "Aplikazio nabarmenduak",
    "Supported apps" : "Onartutako aplikazioak",
    "manual-install apps cannot be updated" : "eskuz instalatutako aplikazioak ezin dira eguneratu",
    "{progress}% Deploying" : "{progress}% zabaltzen",
    "{progress}% Initializing" : "{progress}% hasieratzen",
    "Healthchecking" : "Osasun-kontrola",
    "Deploy and Enable" : "Zabaldu eta gaitu",
    "Enable" : "Aktibatu",
    "Disable" : "Desaktibatu",
    "Allow untested app" : "Baimendu probatu gabeko aplikazioa",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikazio hau ez dago zure Nextcloud bertsioarekin bateragarri bezala markatuta. Jarraitzen baduzu aplikazioa instalatu egingo duzu. Kontuan izan agian aplikazioak ez duela ondo funtzionatuko.",
    "Your ExApps" : "Zure ExApp-ak",
    "An error occurred during the request. Unable to proceed." : "Errorea gertatu da eskaeran. Ezin da jarraitu.",
    "The app has been enabled but needs to be updated." : "Aplikazioa gaitu da baina eguneratzea behar du.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Errorea: aplikazio hau ezin da gaitu zerbitzaria ezegonkorra izatea eragiten duelako",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Bultzatu zure Nextcloud AppAPI eta bereziki diseinatutako aplikazioak.\n\n\nAppAPI Nextcloud ekosistemaren barruan dagoen proiektu bat da, diseinatua\naplikazioen garapena, hedapena eta kudeaketa prozesua arintzeko eta hobetzeko .\n\nGaratzaileei sortzeko aukera ematen dien metodologia berri bat aurkezten du\nProgramazio-lengoaia ezberdinak erabiltzen dituzten aplikazioak, PHPra mugatu gabe, tradizionalki Nextcloud garapenean erabiltzen zena.\n\n\n### AppAPI behar duten aplikazioen zerrenda:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Aplikazio bat garatu nahi baduzu, atsegin handiz lagunduko dizugu eta lagunduko dizugu._\n\n### Laguntza\n\nProiektu honen laguntza eskertzen dugu:\n\n- ⭐Ezarri izarra gure lanari GitHub-en\n- ❗Eman  arazo baten berri edo eskatu eginbide bat\n- 💁 Ebatzi arazo bat eta sortu Pull Request bat\n- 🧑‍💻 Garatu zure aplikazioa AppAPI erabiliz\n\nBenetan hunkituta gaude AppAPI proiektuaren etorkizunaz eta\n eraldatzeko ahalmenarekin Nextcloud-en aplikazioak garatzeko\n eta esperimentatzeko modua.\n\nBidaia honi ekiten diogun heinean, gonbidatzen zaituztegu\n -garatzaileak, pentsalariak, sortzaileak eta ikusleak- gurekin\n batera aplikazioen panorama polifazetikoa, egonkorra eta\n seguruagoa osatzen.\n\n*Zure iritziak, iradokizunak eta ekarpenak oso baliotsuak dira guretzat.*"
},
"nplurals=2; plural=(n != 1);");
