OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Último reporte enviado el: {on}",
    "An error occurred while sending your report." : "Se presentó un error al enviar tu reporte.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicaciones <em>(para cada aplicacion: nombre, versión, estado de activación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente de la base de datos <em>(tipo, versión, tamaño de la base de datos) </em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información de encripción <em>(¿Está habilitada? ¿Cuál es el módulo predeterminado?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de elementos compartidos <em>(por tipo y configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente de PHP <em>(versión, límite de memoria, tiempo max. de ejecución, tamaño max. de archivos)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles de la instancia del servidor <em>(versión, memcache usado, estado de bloqueo/previsualización/avatares)</em>",
    "Usage survey" : "Encuesta de uso",
    "Help improve Nextcloud" : "Ayúdanos a mejorar a Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "¿Quieres ayudarnos a mejorar a Nextcloud  proporcionándonos datos anónimos acerca de tu configuración y uso? Puedes deshabilitarlo en cualquier momento en la configuración de administración.",
    "Send usage" : "Enviar uso",
    "Not now" : "No ahora",
    "Never" : "Nunca",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Puedes ayudar a mejorar Nextcloud enviándonos algunos datos de tu configuración actual y uso.",
    "Send new report now" : "Enviar un nuevo reporte ahora",
    "Send usage survey monthly" : "Enviar la encuesta de uso mensual",
    "Data to send" : "Datos a enviar",
    "Last report" : "Último reporte",
    "Last report sent on: %s" : "Último reporte enviado el: %s"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
