OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Príobháideacht",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Taispeánann an t-ionad príobháideachta duit an áit a bhfuil do shonraí stóráilte agus cé atá in ann rochtain a fháil orthu, de bharr gur roinn tú leo nó toisc gur riarthóirí iad.",
    "Error loading additional administrator." : "Earráid agus riarthóir breise á lódáil.",
    "Error adding new administrator." : "Earráid agus riarthóir nua á chur leis.",
    "Error deleting new administrator." : "Earráid agus riarthóir nua á scriosadh.",
    "Administrators" : "Riarthóirí",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Is riarthóirí ainmnithe iad na cuntais seo a leanas agus d'fhéadfadh rochtain a bheith acu ar do shonraí trí stóráil córais nó trí chúltacaí. Mar sin féin, níl rochtain éasca acu ar do shonraí tríd an gcomhéadan gréasáin nó trí fheidhmchláir na gcliant.",
    "Loading administrators …" : "Riarthóirí á lódáil …",
    "Remove external {propertyName} admin" : "Bain riarthóir seachtrach {propertyName}",
    "Add external admin" : "Cuir riarthóir seachtrach leis",
    "Cancel" : "Cealaigh",
    "Add" : "Cuir",
    "Name of external admin" : "Ainm an riarthóra sheachtraigh",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Tá do stóras baile criptithe trí úsáid a bhaint as {linkopen}criptiúchán ar thaobh an fhreastalaí ↗{linkclose} le máistireochair. Ciallaíonn sé gur féidir le riarthóirí rochtain a fháil ar do chuid comhad, ach gan a n-ábhar a léamh.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Is féidir do chomhaid ar stórais sheachtracha a chriptiú le {linkopen}criptiúchán ar thaobh an fhreastalaí ↗{linkclose} le máistireochair bunaithe ar a gcumraíocht.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Tá do stóras baile criptithe le {linkopen}criptiúchán taobh an fhreastalaí ↗{linkclose} le heochair úsáideora aonair. Ciallaíonn sé gur féidir le riarthóirí rochtain a fháil ar do chuid comhad, ach gan a n-ábhar a léamh.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Is féidir do chomhaid ar stórais sheachtracha a chriptiú le {linkopen}criptiúchán ar thaobh an fhreastalaí ↗{linkclose} le heochair aonair bunaithe ar a gcumraíocht.",
    "Additionally, this server is protected with full-disk-encryption." : "Ina theannta sin, tá an freastalaí seo cosanta le lán-diosca-criptithe.",
    "This server is protected with full-disk-encryption." : "Tá an freastalaí seo cosanta le lán-diosca-criptithe.",
    "Your files are not protected by encryption." : "Níl do chuid comhad cosanta ag criptiú.",
    "Error saving new state of full-disk-encryption" : "Earráid agus staid nua criptithe diosca iomlán á sábháil",
    "Encryption" : "Criptiú",
    "Edit encryption" : "Cuir criptiú in eagar",
    "Edit" : "Cuir in eagar",
    "This server is using full-disk-encryption." : "Tá an freastalaí seo ag baint úsáide as criptiúchán lán-diosca.",
    "Privacy policy" : "Beartas Príobháideachais",
    "Read the privacy policy ↗" : "Léigh an polasaí príobháideachta ↗",
    "Error loading information about shares." : "Earráid agus faisnéis faoi scaireanna á lódáil.",
    "People you've shared with" : "Daoine a roinn tú leo",
    "Loading people you've shared with …" : "Ag lódáil daoine ar roinn tú leo …",
    "You do not have any shares with individual users." : "Níl aon scaireanna agat le húsáideoirí aonair.",
    "Your {serverName} account" : "Do chuntas {serverName}",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Léiríonn do shonraí cé tú féin agus is furasta mí-úsáid a bhaint astu. Creidimid ag Nextcloud go bhfuil sé de cheart agat cinneadh a dhéanamh cad a tharlóidh le do shonraí. Cosnaíonn Nextcloud do chearta mar atá sainmhínithe sa Manifesto Sonraí Úsáideora!",
    "Who has access to your data?" : "Cé aige a bhfuil rochtain ar do shonraí?",
    "Error saving new location of the server" : "Earráid agus suíomh nua an fhreastalaí á shábháil",
    "Where is your data?" : "Cá bhfuil do shonraí?",
    "Your data is located in:" : "Tá do shonraí lonnaithe i:",
    "An admin has not selected the location of the server yet." : "Níl suíomh an fhreastalaí roghnaithe ag riarthóir fós.",
    "Change data location" : "Athraigh suíomh sonraí",
    "Region" : "Réigiún",
    "Please select a region" : "Roghnaigh réigiún le do thoil",
    "{bold}Control{/bold} over user data access" : "{bold}Rialú{/bold} ar rochtain sonraí úsáideoirí",
    "{bold}Knowledge{/bold} of how the data is stored" : "{bold}Eolas{/bold} ar an gcaoi a stóráiltear na sonraí",
    "{bold}Freedom{/bold} to choose a platform" : "{bold}Saoirse{/bold} chun ardán a roghnú",
    "User Data Manifesto 2.0" : "Manifesto Sonraí Úsáideora 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Bunchearta a shainiú do dhaoine chun a gcuid sonraí féin a rialú san aois idirlín.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Ba cheart go mbeadh sonraí arna uaslódáil go sainráite agus go toilteanach ag úsáideoir faoi smacht deiridh an úsáideora. Ba cheart go mbeadh úsáideoirí in ann cinneadh a dhéanamh cé dó a dtabharfaidh siad rochtain dhíreach ar a gcuid sonraí agus cé na ceadanna agus na ceadúnais ar cheart rochtain den sórt sin a thabhairt dóibh.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Nuair a dhéantar na sonraí a uaslódáil chuig soláthraí seirbhíse sonrach, ba cheart úsáideoirí a chur ar an eolas faoin áit a stórálann an soláthraí seirbhíse sonrach sin na sonraí, cé chomh fada, cén dlínse a oibríonn an soláthraí seirbhíse sonrach, agus cé na dlíthe a bhfuil feidhm acu.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Ba cheart go mbeadh úsáideoirí in ann a gcuid sonraí a bhaint as an tseirbhís am ar bith i gcónaí gan aon ghlasáil isteach ón díoltóir a fheiceáil. Tá caighdeáin oscailte le haghaidh formáidí agus prótacail riachtanach chun é seo a ráthú.",
    "Learn more ↗" : "Tuilleadh eolais ↗",
    "Somaliland" : "Somáilis",
    "Andorra" : "Andóra",
    "United Arab Emirates" : "Aontas na nÉimíríochtaí Arabacha",
    "Afghanistan" : "an Afganastáin",
    "Antigua and Barbuda" : "Antigua agus Barbúda",
    "Anguilla" : "Anguilla",
    "Albania" : "an Albáin",
    "Armenia" : "Airméin",
    "Angola" : "Angóla",
    "Antarctica" : "Antartaice",
    "Argentina" : "an Airgintín",
    "American Samoa" : "Samó Meiriceánach",
    "Austria" : "Ostair",
    "Australia" : "an Astráil",
    "Aruba" : "Aruba",
    "Åland Islands" : "Oileáin Åland",
    "Azerbaijan" : "Asarbaiseáin",
    "Bosnia and Herzegovina" : "An Bhoisnia agus an Heirseagaivéin",
    "Barbados" : "Barbadós",
    "Bangladesh" : "Bhanglaidéis",
    "Belgium" : "an Bheilg",
    "Burkina Faso" : "Buircíne Fasó",
    "Bulgaria" : "an Bhulgáir",
    "Bahrain" : "Bairéin",
    "Burundi" : "An Bhurúin",
    "Benin" : "Beinin",
    "Saint Barthélemy" : "Naomh Barthélemy",
    "Bermuda" : "Beirmiúda",
    "Brunei" : "Brúiné",
    "Bolivia" : "An Bholaiv",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius agus Saba",
    "Brazil" : "an Bhrasaíl",
    "Bahamas" : "Bahámaí",
    "Bhutan" : "an Bhutáin",
    "Bouvet Island" : "Oileán Bouvet",
    "Botswana" : "an Bhotsuáin",
    "Belarus" : "Bhealarúis",
    "Belize" : "Bheilís",
    "Canada" : "Ceanada",
    "Cocos (Keeling) Islands" : "Oileáin Cocos (Keeling).",
    "Democratic Republic of the Congo" : "Poblacht Dhaonlathach an Chongó",
    "Central African Republic" : "Poblacht na hAfraice Láir",
    "Congo" : "Chongó",
    "Switzerland" : "Eilvéis",
    "Cote d'Ivoire" : "Cósta Eabhair",
    "Cook Islands" : "Oileáin Cook",
    "Chile" : "an tSile",
    "Cameroon" : "Camarún",
    "China" : "an tSín ",
    "Colombia" : "an Cholóim",
    "Costa Rica" : "Cósta Ríce",
    "Cuba" : "Cúba",
    "Cabo Verde" : "Rinn Verde",
    "Curaçao" : "Curacao",
    "Christmas Island" : "Oileán na Nollag",
    "Cyprus" : "an Chipir",
    "Czech" : "Seiceach",
    "Germany" : "an Ghearmáin",
    "Djibouti" : "Djibútí",
    "Denmark" : "an Danmhairg",
    "Dominican Republic" : "An Phoblacht Dhoiminiceach",
    "Algeria" : "an Ailgéir",
    "Ecuador" : "Eacuadór",
    "Estonia" : "an Eastóin",
    "Egypt" : "an Éigipt",
    "West Sahara" : "an Sahára Thiar",
    "Eritrea" : "Eiritré",
    "Spain" : "an Spáinn",
    "Ethiopia" : "an Aetóip",
    "Finland" : "an Fhionlainn",
    "Fiji" : "Fidsí",
    "Falkland Islands" : "Oileáin Fháclainne",
    "Micronesia" : "Micrinéise",
    "Faroe Islands" : "Oileáin Fharó",
    "France" : "an Fhrainc",
    "Gabon" : "Ghabúin",
    "United Kingdom" : "an Ríocht Aontaithe",
    "Grenada" : "Greanáda",
    "Georgia" : "An tSeoirsia",
    "French Guiana" : "Guáin na Fraince",
    "Guernsey" : "Geansaí",
    "Ghana" : "Gána",
    "Gibraltar" : "Giobráltar",
    "Greenland" : "Ghraonlainn",
    "Gambia" : "An Ghaimbia",
    "Guinea" : "Ghuine",
    "Guadeloupe" : "Guadalúip",
    "Equatorial Guinea" : "An Ghuine Mheánchriosach",
    "Greece" : "an Ghréig",
    "South Georgia and the South Sandwich Islands" : "An tSeoirsia Theas agus na hOileáin Sandwich Theas",
    "Guatemala" : "Guatamala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guine Bhissau",
    "Guyana" : "Ghuáin",
    "Hong Kong" : "Hong Cong",
    "Heard Island and McDonald Islands" : "Oileán Heard agus Oileáin McDonald",
    "Honduras" : "Hondúras",
    "Croatia" : "an Chróit",
    "Haiti" : "Háití",
    "Hungary" : "an Ungáir",
    "Indonesia" : "Indinéis",
    "Ireland" : "Éire",
    "Israel" : "Iosrael",
    "Isle of Man" : "Oileán Mhanann",
    "India" : "India",
    "British Indian Ocean Territory" : "Críoch Aigéan Indiach na Breataine",
    "Iraq" : "an Iaráic",
    "Iran" : "an Iaráin",
    "Iceland" : "Íoslainn",
    "Italy" : "an Iodáil",
    "Jamaica" : "Iamáice",
    "Jordan" : "an Iordáin",
    "Japan" : "an tSeapáin",
    "Kenya" : "an Chéinia",
    "Kyrgyzstan" : "Chirgeastáin",
    "Cambodia" : "an Chambóid",
    "Kiribati" : "Ciribeas",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "San Críostóir-Nimheas",
    "North Korea" : "An Chóiré Thuaidh",
    "South Korea" : "An Chóiré Theas",
    "Kuwait" : "Cuáit",
    "Cayman Islands" : "Oileáin Cayman",
    "Kazakhstan" : "Chasacstáin",
    "Laos" : "Laos",
    "Lebanon" : "an Liobáin",
    "Saint Lucia" : "Naomh Lucia",
    "Liechtenstein" : "Lichtinstéin",
    "Sri Lanka" : "Srí Lanca",
    "Liberia" : "Libéir",
    "Lesotho" : "Leosóta",
    "Lithuania" : "an Liotuáin",
    "Luxembourg" : "Lucsamburg",
    "Latvia" : "an Laitvia",
    "Libya" : "Libia",
    "Morocco" : "Maracó",
    "Monaco" : "Monacó",
    "Moldova" : "Mholdóiv",
    "Montenegro" : "Montainéagró",
    "Saint Martin" : "Naomh Máirtín",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Oileáin Mharshall",
    "Macedonia" : "an Mhacadóin",
    "Mali" : "Mailí",
    "Myanmar" : "Maenmar",
    "Mongolia" : "an Mhongóil",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Oileáin Mariana Thuaidh",
    "Mauritania" : "Mháratáin",
    "Montserrat" : "Montsarat",
    "Malta" : "an Mhálta",
    "Mauritius" : "Oileán Mhuirís",
    "Maldives" : "Oileáin Mhaildíve",
    "Malawi" : "an Mhaláiv",
    "Mexico" : "Meicsiceo",
    "Malaysia" : "Mhalaeisia",
    "Mozambique" : "Mósaimbíc",
    "Namibia" : "Namaib",
    "New Caledonia" : "An Nua-Chaladóin",
    "Niger" : "Nígir",
    "Norfolk Island" : "Oileán Norfolk",
    "Nigeria" : "Nigéir",
    "Nicaragua" : "Nicearagua",
    "Netherlands" : "an Ísiltír",
    "Norway" : "an Iorua",
    "Nepal" : "Neipeal",
    "Nauru" : "Nárú",
    "Niue" : "Niue",
    "New Zealand" : "An Nua-Shéalainn",
    "Oman" : "Óman",
    "Panama" : "Panama",
    "Peru" : "Peiriú",
    "French Polynesia" : "Polainéis na Fraince",
    "Papua New Guinea" : "Nua-Ghuine Phapua",
    "Philippines" : "hOileáin Fhilipíneacha",
    "Pakistan" : "an Phacastáin",
    "Poland" : "an Pholainn",
    "Saint Pierre and Miquelon" : "Naomh Pierre agus Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Pórtó Ríce",
    "Palestine" : "Phalaistín",
    "Portugal" : "an Phortaingéil",
    "Palau" : "Palau",
    "Paraguay" : "Paragua",
    "Qatar" : "Catar",
    "Réunion" : "Réunion",
    "Romania" : " an Rómáin",
    "Serbia" : "an tSeirbia",
    "Russia" : "an Rúis",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "An Araib Shádach",
    "Solomon Islands" : "Oileáin Sholamón",
    "Seychelles" : "Na Séiséil",
    "Sudan" : "an tSúdáin",
    "Sweden" : "an tSualainn",
    "Singapore" : "Singeapór",
    "Saint Helena, Ascension and Tristan da Cunha" : "San Héilin, Ascension agus Tristan da Cunha",
    "Slovenia" : "an tSlóivéin",
    "Svalbard and Jan Mayen" : "Svalbard agus Jan Mayen",
    "Slovakia" : "an tSlóvaic",
    "Sierra Leone" : "Siarra Leon",
    "San Marino" : "San Mairíne",
    "Senegal" : "an tSeineagáil",
    "Somalia" : "an tSomáil",
    "Suriname" : "Suranam",
    "South Sudan" : "an tSúdáin Theas",
    "Sao Tome and Principe" : "Sao Tome agus Principe",
    "El Salvador" : "an tSalvadóir",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "an tSiria",
    "Swaziland" : "an tSuasalainn",
    "Turks and Caicos Islands" : "Oileáin na dTurcach agus na Caicos",
    "Chad" : "Sead",
    "Fr. S. Antarctic Lands" : "Bhí an tAth. S. Tailte Antartach",
    "Togo" : "Tóga",
    "Thailand" : "an Téalainn",
    "Tajikistan" : "Táidsíceastáin",
    "Tokelau" : "Tócalainn",
    "Timor-Leste" : "Tíomór-Leste",
    "Turkmenistan" : "Tuircméanastáin",
    "Tunisia" : "an Túinéis",
    "Tonga" : "Tonga",
    "Turkey" : "n Tuirc",
    "Trinidad and Tobago" : "Oileán na Tríonóide agus Tobága",
    "Tuvalu" : "Túvalú",
    "Taiwan" : "an Téaváin",
    "Tanzania" : "Tansáin",
    "Ukraine" : "an Úcráin",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Mionoileáin Imeallacha na Stát Aontaithe",
    "United States" : "an Stát Aontaithe",
    "Uruguay" : "Uragua",
    "Uzbekistan" : "Úisbéiceastáin",
    "Holy See" : "Suí Naofa",
    "Saint Vincent and the Grenadines" : "San Uinseann agus na Greanáidíní",
    "Venezuela" : "Veiniséala",
    "Virgin Islands (British)" : "Oileáin na Maighdean (British)",
    "Virgin Islands (U.S.)" : "Oileáin na Maighdean (S.A.)",
    "Vietnam" : "Vítneam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis agus Futúna",
    "Samoa" : "Samó",
    "Yemen" : "Éimin",
    "Mayotte" : "Maigh Eo",
    "South Africa" : "an Afraic Theas",
    "Zambia" : "an tSaimbia",
    "Zimbabwe" : "An tSiombáib",
    "Loading administrators …" : "Riarthóirí á lódáil…",
    "Loading people you've shared with …" : "Ag lódáil na ndaoine a roinn tú leo…",
    "Control" : "Smacht",
    "over user data access" : "thar rochtain ar shonraí úsáideora",
    "Knowledge" : "Eolas",
    "of how the data is stored" : "ar an gcaoi a stóráiltear na sonraí",
    "Freedom" : "Saoirse",
    "to choose a platform" : "ardán a roghnú"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
