OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Shiriki za faili",
    "Downloaded via public link" : "Pakua kupitia kiungo cha umma",
    "Downloaded by {email}" : "Imepakuliwa na {email}",
    "{file} downloaded via public link" : "{file} imepakuliwa kupitia kiungo cha umma",
    "{email} downloaded {file}" : "{email}imepakua {file}",
    "Shared with group {group}" : "Imeshirikishwa na kundi {group}",
    "Removed share for group {group}" : "Imeondoa ushiriki kwa kundi {group}",
    "{actor} shared with group {group}" : "{actor}imeshirikishwa na kundi {group}",
    "{actor} removed share for group {group}" : "{actor}imeondoa ushiriki kwa kundi {group}",
    "Share for group {group} expired" : "Ushiriki kwa kundi {group}umeisha wakati",
    "You shared {file} with group {group}" : "Umeshirikisha {file}na kundi {group}",
    "You removed group {group} from {file}" : "Umeondoa kundi {group} kutoka {file}",
    "{actor} shared {file} with group {group}" : "{actor} imeshirikisha {file} na kundi {group}",
    "{actor} removed group {group} from {file}" : "{actor}imeondoa kundi {group} kutoka {file}",
    "Share for file {file} with group {group} expired" : "Shiriki kwa faili {file} na kundi {group} umeisha wakati",
    "Shared as public link" : "Imeshirikiwa kama kiungo cha umma",
    "Removed public link" : "Imeondoa kiungo cha umma",
    "Public link expired" : "Kiungo cha umma kimeisha wakati wake",
    "{actor} shared as public link" : "{actor}imeshirikiwa kama kiungo cha umma",
    "{actor} removed public link" : "{actor}imeondoa kiungo cha umma",
    "Public link of {actor} expired" : "Kiungo cha umma cha {actor} kimeisha wakati",
    "You shared {file} as public link" : "Umeshirikisha kiungo cha {file} kama kiungo cha umma",
    "You removed public link for {file}" : "Umeondoa kiungo cha umma kwa {file}",
    "Public link expired for {file}" : "Kiungo cha umma kimeisha wakati kwa {file}",
    "{actor} shared {file} as public link" : "{actor} imeshirikisha {file} kama kiungo cha umma",
    "{actor} removed public link for {file}" : "{actor} imeondoa kiungo cha umma kwa {file}",
    "Public link of {actor} for {file} expired" : "Kiungo cha umma cha {actor}kwa {file} kimeisha wakati",
    "{user} accepted the remote share" : "{user} amekubali ushirikishaji wa mbali",
    "{user} declined the remote share" : "{user} amekataa ushirikishaji wa mbali",
    "You received a new remote share {file} from {user}" : "Umepokea ushirikishaji mpya wa mbali{file} kutoka {user}",
    "{user} accepted the remote share of {file}" : "{user} amekubali ushirikishaji wa mbali wa {file}",
    "{user} declined the remote share of {file}" : "{user}amepunguza ushirikishaji wa mbali wa {file}",
    "{user} unshared {file} from you" : "{user}haijashirikisha {file}kwako",
    "Shared with {user}" : "Imeshirikishwa na {user}",
    "Removed share for {user}" : "Imeondoa ushiriki kwa {user}",
    "You removed yourself" : "Umeondoa wewe mwenyewe",
    "{actor} removed themselves" : "{actor}wamejiondoa wenyewe",
    "{actor} shared with {user}" : "{actor} ameshirikishwa na {user}",
    "{actor} removed share for {user}" : "{actor}ameondoa ushiriki kwa {user}",
    "Shared by {actor}" : "Imeshirikishwa na{actor}",
    "{actor} removed share" : "{actor}imeondoa ushiriki",
    "Share for {user} expired" : "Ushiriki kwa {user} umeisha wakati",
    "Share expired" : "Ushirikishaji umeisha wakati",
    "You shared {file} with {user}" : "Umeshirikisha {file} na {user}",
    "You removed {user} from {file}" : "Umeondoa {user} kutoka {file}",
    "You removed yourself from {file}" : "Umejiondoa mwenyewe kutoka {file}",
    "{actor} removed themselves from {file}" : "{actor} wamejiondoa wenyewe kutoka {file}",
    "{actor} shared {file} with {user}" : "{actor} ameshirikisha {file} na {user}",
    "{actor} removed {user} from {file}" : "{actor} amemwondoa {user} kutoka {file}",
    "{actor} shared {file} with you" : "{actor} ameshirikisha {file} na wewe",
    "{actor} removed you from the share named {file}" : "{actor} amekuondoa kutoka ushiriki wenye jina {file}",
    "Share for file {file} with {user} expired" : "Ushiriki kwa faili {file} na {user} umeisha wakati",
    "Share for file {file} expired" : "Ushiriki kwa faili {file} umeisha wakati",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Faili au folda lililoshirikishwa kwa barua pepe au kiungo cha umma <strong> lilipakuliwa</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Faili<strong> limepakiwa</strong>kwenye folda lililoshirikishwa kwa barua pepe au kiungo cha umma",
    "A file or folder was shared from <strong>another server</strong>" : "Faili au folda ilishirikishwa kutoka<strong> seva nyingine</strong>",
    "Sharing" : "inashirikisha",
    "A file or folder has been <strong>shared</strong>" : "Faili au folda<strong> imeshirikishwa</strong>",
    "Shared link" : "Kiungo kilichoshirikishwa",
    "Wrong share ID, share does not exist" : "Kitambulisho cha kushiriki kibaya, ushirikishaji haupo",
    "Could not delete share" : "Haikuweza kufuta kushiriki",
    "Please specify a file or folder path" : "Tafadhali bainisha njia ya faili au folda",
    "Wrong path, file/folder does not exist" : "Njia mbaya, faili/folda haipo",
    "Could not create share" : "Haikuweza kuunda kushiriki",
    "Please specify a valid account to share with" : "Tafadhali bainisha akaunti halali ya kushiriki nayo",
    "Group sharing is disabled by the administrator" : "Kushiriki kwa kikundi kumezimwa na msimamizi",
    "Please specify a valid group" : "Tafadhali bainisha kikundi halali",
    "Public link sharing is disabled by the administrator" : "Kushiriki kiungo kwa umma kumezimwa na msimamizi",
    "Please specify a valid email address" : "Tafadhali bainisha barua pepe halali",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Ushirikishaji %s kutuma nenosiri kwa Nextcloud Talk kumeshindwa kwa sababu Nextcloud Talk haijawashwa",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Ushirikishaji %1$s kumeshindwa kwa sababu sehemu ya nyuma hairuhusu kushiriki kutoka kwa aina %2$s",
    "Please specify a valid federated account ID" : "Tafadhali bainisha kitambulisho halali cha akaunti iliyoshirikishwa",
    "Please specify a valid federated group ID" : "Tafadhali bainisha kitambulisho halali cha kikundi kilichoshirikishwa",
    "You cannot share to a Team if the app is not enabled" : "Huwezi kushirikisha kwa Timu ikiwa programu haijawashwa",
    "Please specify a valid team" : "Tafadhali bainisha timu halali",
    "Sharing %s failed because the back end does not support room shares" : "Ushirikishaji %s kumeshindwa kwa sababu sehemu ya nyuma haitumii ushiriki wa vyumba",
    "Unknown share type" : "Aina ya ushirikishaji isiyojulikana",
    "Not a directory" : "Sio saraka",
    "Could not lock node" : "Haikuweza kufunga nodi",
    "Public upload is only possible for publicly shared folders" : "Upakiaji wa umma unawezekana kwa folda zinazoshirikiwa hadharani pekee",
    "Share must at least have READ or CREATE permissions" : "Ushiriki lazima angalau uwe na ruhusa za READ au CREATE",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Shiriki lazima iwe na ruhusa ya SOMA ikiwa ruhusa ya UPDATE au FETA imewekwa",
    "Public upload disabled by the administrator" : "Upakiaji wa umma umezimwa na msimamizi",
    "Could not lock path" : "Haikuweza kufunga njia",
    "no sharing rights on this item" : "Hakuna haki za kushiriki kwenye kipengee hiki",
    "You are not allowed to edit incoming shares" : " Huruhusiwi kuhariri shiriki zinazoingia",
    "Wrong or no update parameter given" : "Kigezo cha sasisho kibaya au hakuna",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Kutuma nenosiri kupitia Nextcloud Talk kwa kushiriki faili au folda kumeharibika kwa sababu Nextcloud Talk haijawezeshwa.",
    "Custom share link tokens have been disabled by the administrator" : "Tokeni za kipekee za viungo vya kushiriki zimezimwa na msimamizi.",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Tokeni lazima ziwe na angalau herufi moja 1 na zinaweza kuwa na herufi, nambari, au alama ya mkato pekee.",
    "Invalid date. Format must be YYYY-MM-DD" : "Tarehe si sahihi. Muundo lazima uwe YYYY-MM-DD.",
    "No sharing rights on this item" : "Huna ruhusa ya kushiriki kipengee hiki.",
    "Invalid share attributes provided: \"%s\"" : " Sifa za kushiriki zilizotolewa si sahihi: \"%s\"",
    "You are not allowed to send mail notifications" : "Huruhusiwi kutuma arifa za barua pepe.",
    "No mail notification configured for this share type" : "Hakuna arifa ya barua pepe iliyopangwa kwa aina hii ya kushiriki.",
    "Wrong password" : "Nenosiri si sahihi",
    "Error while sending mail notification" : "Kosa lilitokea wakati wa kutuma arifa ya barua pepe.",
    "Failed to generate a unique token" : "Imeshindikana kuunda tokeni ya kipekee.",
    "This share does not exist or is no longer available" : "Ushiriki huu haupo au haupatikani tena.",
    "shared by %s" : "Imeshirikiwa na %s",
    "Download" : "Pakua",
    "Add to your %s" : "Ongeza kwenye yako %s",
    "Direct link" : "Kiungo cha moja kwa moja",
    "Share API is disabled" : "API ya kushiriki imezimwa",
    "File sharing" : "Kushiriki faili",
    "Share will expire tomorrow" : "Shiriki itaisha muda wake kesho",
    "Your share of {node} will expire tomorrow" : "Shiriki yako ya {node}itaisha muda wake kesho ",
    "You received {share} as a share by {user}" : "Umepokea {share} kama imeshirikiwa na {user}",
    "You received {share} to group {group} as a share by {user}" : "Umepokea {share} kwenye kundi {group} kama imeshirikiwa na  {user}",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "Remember to upload the files to %s" : "Kumbuka kupakia faili kwa %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Tungependa kukukumbusha kwa unyenyekevu kwamba bado hujaweka faili yoyote kwenye folda iliyoshirikiwa.",
    "Open \"%s\"" : "Fungua \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Programu hii inawawezesha watu kushiriki faili ndani ya Nextcloud. Ikiwezeshwa, msimamizi anaweza kuchagua makundi gani yanaweza kushiriki faili. Watu walioko kwenye makundi husika wanaweza kisha kushiriki faili na folda na akaunti na makundi mengine ndani ya Nextcloud. Zaidi ya hayo, ikiwa msimamizi atawezeshwa kipengele cha kiungo cha kushiriki, kiungo cha nje kinaweza kutumika kushiriki faili na watu wengine wasioko ndani ya Nextcloud. Wasimamizi pia wanaweza kuweka nywila, tarehe za kumalizika kwa kiungo, na kuwezesha kushirikiana kati ya seva kupitia viungo vya kushiriki, pamoja na kushiriki kutoka kwa vifaa vya simu.\n\nKuzima kipengele hiki hufuta faili na folda zilizoshirikiwa kwenye seva kwa wateja wote wa kushiriki, na pia kwenye wateja wa kusawazisha (sync clients) na programu za simu. Taarifa zaidi zinapatikana kwenye Nyaraka za Nextcloud.",
    "Filter accounts" : "Chuja akaunti",
    "you" : "wewe",
    "The request will expire on {date} at midnight and will be password protected." : "Ombi litaisha muda wake tarehe {date} saa sita usiku na litakuwa limehifadhiwa kwa nenosiri.",
    "The request will expire on {date} at midnight." : "Ombi litatoweka tarehe {date} saa sita usiku.",
    "The request will be password protected." : "Ombi litakuwa limehifadhiwa kwa nenosiri.",
    "When should the request expire?" : "Ombi linafaa litoweke lini?",
    "Set a submission expiration date" : "Weka tarehe ya kumalizika kwa kuwasilisha",
    "Expiration date" : "Tarehe ya kumalizika",
    "Select a date" : "Chagua tarehe",
    "Your administrator has enforced a {count} days expiration policy." : "Msimamizi wako ameweka sera ya kumalizika baada ya siku {count}.",
    "What password should be used for the request?" : "Nenosiri gani linapaswa kutumika kwa ombi hili?",
    "Set a password" : "Weka nenosiri",
    "Password" : "Nenosiri",
    "Enter a valid password" : "Ingiza nenosiri halali",
    "Generate a new password" : "Zalisha nenosiri mpya",
    "Your administrator has enforced a password protection." : "Msimamizi wako ameweka ulinzi wa nenosiri.",
    "Automatically copying failed, please copy the share link manually" : "Kunakili kwa otomatiki kulishindikana, tafadhali nakili kiungo cha kushiriki kwa mkono.",
    "Link copied" : "Kiungo kimenakiliwa",
    "Email already added" : "Barua pepe imeshaongezwa",
    "Invalid email address" : "Anwani ya barua pepe si sahihi",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["The following email address is not valid: {emails}","Anwani zifuatazo za barua pepe si sahihi: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} email address already added","{count} Anwani za barua pepe tayari zimeongezwa"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} email address added","{count} Anwani za barua pepe zimeongezwa "],
    "You can now share the link below to allow people to upload files to your directory." : "Sasa unaweza kushiriki kiungo kilicho hapa chini ili kuruhusu watu kupakia faili kwenye saraka yako.",
    "Share link" : "Shirikisha kiungo",
    "Copy" : "Nakili",
    "Send link via email" : "Tuma kiungo kupitia barua pepe",
    "Enter an email address or paste a list" : "Ingiza anwani ya barua pepe au bandika orodha",
    "Remove email" : "Ondoa barua pepe",
    "Select a destination" : "Chagua mahali pa kwenda",
    "Select" : "Chagua",
    "What are you requesting?" : "Unaomba nini?",
    "Request subject" : "Omba mada",
    "Birthday party photos, History assignment…" : "Picha za sherehe ya siku ya kuzaliwa, kazi ya Historia...",
    "Where should these files go?" : "Faili hizi zinapaswa kwenda wapi?",
    "Upload destination" : "Pakia  katika eneo lengwa",
    "Revert to default" : "Rudi kwa chaguomsingi",
    "The uploaded files are visible only to you unless you choose to share them." : "Faili zilizopakiwa zinaonekana kwako tu isipokuwa utachagua kuzishiriki.",
    "Add a note" : "Ongeza maelezo",
    "Note for recipient" : "Maelezo kwa mpokeaji",
    "Add a note to help people understand what you are requesting." : "Ongeza maelezo kusaidia watu kuelewa unachokiomba.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Unaweza kuongeza viungo, tarehe, au taarifa nyingine yoyote itakayomsaidia mpokeaji kuelewa unachokiomba.",
    "Close" : "Funga",
    "_Send email and close_::_Send {count} emails and close_" : ["Send email and close","Tuma barua pepe {count}na ufunge"],
    "Please select a folder, you cannot share the root directory." : "Tafadhali chagua folda, huwezi kushiriki saraka ya mizizi.",
    "File request created" : "Ombi la faili limeundwa",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["File request created and email sent","Ombi la faili limeundwa na barua pepe {count} zikatumwa"],
    "Error creating the share: {errorMessage}" : "Hitilafu katika kuunda ushiriki: {errorMessage}",
    "Error creating the share" : "Hitilafu katika kutengeneza ushiriki",
    "Error sending emails: {errorMessage}" : "Hitilafu wakati wa kutuma barua pepe: {errorMessage}",
    "Error sending emails" : "Hitilafu wakati wa kutuma barua pepe",
    "Create a file request" : "Tengeneza ombi la faili",
    "Collect files from others even if they do not have an account." : "Kusanya faili kutoka kwa wengine hata kama hawana akaunti.",
    "To ensure you can receive files, verify you have enough storage available." : "Ili kuhakikisha kuwa unaweza kupokea faili, thibitisha kuwa una hifadhi ya kutosha.",
    "File request" : "Ombi la faili",
    "Previous step" : "Hatua ya awali",
    "Cancel" : "Sitisha",
    "Cancel the file request creation" : "Sitisha ombi la utengenezaji wa faili",
    "Close without sending emails" : "Funga bila kutuma barua pepe",
    "Continue" : "Endelea",
    "Error while toggling options" : "Hitilafu wakati wa kugeuza chaguo",
    "Accept shares from other accounts and groups by default" : "Kubali kushirikiwa kutoka kwa akaunti na vikundi vingine kwa chaguomsingi",
    "Choose a default folder for accepted shares" : "Chagua folda chaguo-msingi kwa shiriki zinazokubalika",
    "Invalid path selected" : "Njia iliyochaguliwa si halali",
    "Unknown error" : "Hitilafu isiyojulikana",
    "Set default folder for accepted shares" : "Weka folda chaguo-msingi kwa shiriki zinazokubaliwa",
    "Reset" : "Pangilia upya",
    "Reset folder to system default" : "Weka upya folda iwe chaguomsingi ya mfumo",
    "Share expiration: {date}" : "Ukomo wa shiriki: {date}",
    "Share Expiration" : "Ukomo wa shiriki",
    "group" : "kundi",
    "conversation" : "mazungumzo",
    "remote" : "mbali",
    "remote group" : "kundi la mbali",
    "guest" : "mgeni",
    "by {initiator}" : "kwa {initiator}",
    "Shared with the group {user} by {owner}" : "Imeshirikiwa na kundi {user} kwa {owner}",
    "Shared with the conversation {user} by {owner}" : "Imeshirikiwa na mazungumzo {user} kwa {owner}",
    "Shared with {user} by {owner}" : "Imeshirikiwa na {user} kwa {owner}",
    "Open Sharing Details" : "Fungua maelezo ya ushiriki",
    "Added by {initiator}" : "Imeongezwa na {initiator}",
    "Via “{folder}”" : "Kupitia \"{folder}\"",
    "Unshare" : "Usishirikishe",
    "Cannot copy, please copy the link manually" : "Haiwezi kunakili, tafadhali nakili kiungio kwa njia za kawaida",
    "Copy internal link" : "Nakili kiungo cha ndani",
    "For people who already have access" : "Kwa watu ambao tayari wana ufikiaji",
    "Internal link" : "Kiungo cha ndani",
    "{shareWith} by {initiator}" : "{shareWith} kwa {initiator}",
    "Shared via link by {initiator}" : "Imeshirikiwa kupitia kiungo na {initiator}",
    "File request ({label})" : "Ombi la faili ({label})",
    "Mail share ({label})" : "Shiriki barua ({label})",
    "Share link ({label})" : "Shiriki kiungo ({label})",
    "Mail share" : "Shiriki barua",
    "Share link ({index})" : "Shiriki kiungo ({index})",
    "Create public link" : "Tengeneza kiungo cha umma",
    "Actions for \"{title}\"" : "Matendo kwa \"{title}\"",
    "Copy public link of \"{title}\"" : "Nakili kiungo cha umma cha \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Hitilafu, tafadhali weka nenosiri sahihi na/au tarehe ya mwisho wa matumizi",
    "Link share created" : "Ushiriki wa kiungo umeundwa",
    "Error while creating the share" : "Hitilafu wakati wa kuunda kushiriki",
    "Your browser does not support copying, please copy the link manually:" : "Kivinjari chako hakiungi mkono kunakili, tafadhali nakili kiungo kikawaida:",
    "Successfully copied public link" : "Kiungo cha umma kimenakiliwa kwa mafanikio",
    "Please enter the following required information before creating the share" : "Tafadhali weka maelezo yafuatayo yanayohitajika kabla ya kuunda kushiriki",
    "Password protection (enforced)" : "Ulinzi wa nenosiri (umetekelezwa)",
    "Password protection" : "Ulinzi wa nenosiri",
    "Enter a password" : "Ingiza nenosiri",
    "Enable link expiration (enforced)" : "Washa muda wa kuisha kwa kiungo (imetekelezwa)",
    "Enable link expiration" : " Washa muda wa kuisha kwa kiungo",
    "Enter expiration date (enforced)" : "Weka tarehe ya mwisho wa matumizi (imetekelezwa)",
    "Enter expiration date" : "Weka tarehe ya mwisho wa matumizi",
    "Create share" : "Tengeneza ushirikishaji",
    "Customize link" : "Tengeneza kiungo kwa matakwa ya mteja",
    "Generate QR code" : "Tengeneza msimbo wa QR",
    "Add another link" : "Ongeza kiungo kingine",
    "Create a new share link" : "Unda kiungo kipya cha kushiriki",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Chaguzi za haraka za kushiriki, zilizochaguliwa sasa ni \"{selectedOption}\"",
    "View only" : "Utazamaji pekee",
    "Can edit" : "Inaweza kuhariri",
    "Custom permissions" : "Ruhusa maalum",
    "Resharing is not allowed" : "Kushiriki upya hakuruhusiwi",
    "Name or email …" : "Jina au barua pepe …",
    "Name, email, or Federated Cloud ID …" : "Jina, barua pepe au Kitambulisho cha Cloud iliyoshirikishwa  …",
    "Searching …" : "Inatafuta …",
    "No elements found." : "Hakuna vipengele vilivyopatikana",
    "Search everywhere" : "Tafuta kila mahali",
    "Guest" : "Mgeni",
    "Group" : "Kundi",
    "Email" : "Barua pepe",
    "Team" : "Timu",
    "Talk conversation" : "Mazungumzo ya Talk",
    "Deck board" : "Bodi ya deck",
    "ScienceMesh" : "SayansiMesh",
    "on {server}" : "juu ya {server}",
    "Enter external recipients" : "Ingiza wapokeaji wa nje",
    "Search for internal recipients" : "Tafuta wapokeaji wa ndani",
    "Note from" : "Kumbuka kutoka",
    "Note:" : "Kumbuka:",
    "File drop" : "Kuacha faili",
    "Upload files to {foldername}." : "Pakia faili kwenye {foldername}",
    "By uploading files, you agree to the terms of service." : "Kwa kupakia faili, unakubali sheria na masharti.",
    "Successfully uploaded files" : " Faili zimepakiwa kikamilifu",
    "View terms of service" : "Tazama masharti ya huduma",
    "Terms of service" : "Masharti ya huduma",
    "Share with {user}" : "Shiriki na {user}",
    "Share with email {email}" : "Shiriki na barua pepe {email}",
    "Share with group" : "Shiriki na kundi",
    "Share in conversation" : "Shiriki katika mazungumzo",
    "Share with {user} on remote server {server}" : "Shiriki na {user}kwenye seva ya mbali {server}",
    "Share with remote group" : "Shiriki na kundi la mbali",
    "Share with guest" : "Shiriki na mgeni",
    "Update share" : "Sasisha ushiriki",
    "Save share" : "Hifadhi ushiriki",
    "Read" : "Soma",
    "Create" : "Tengeneza",
    "Edit" : "Hariri",
    "Share" : "Shirikisha",
    "Delete" : "Futa",
    "Password field cannot be empty" : "Sehemu ya nenosiri haiwezi kuwa tupu",
    "Replace current password" : "Badilisha nenosiri la sasa",
    "Failed to generate a new token" : "Imeshindwa kutengeneza tokeni mpya",
    "Allow upload and editing" : "Ruhusu upakiaji na uhariri",
    "Allow editing" : "Ruhusu uhariri",
    "Upload only" : "Pakua tu",
    "Advanced settings" : "Mipangilio ya kiwango cha juu",
    "Share label" : "Shiriki lebo",
    "Share link token" : "Shiriki tokeni ya kiungo",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Weka tokeni ya kiungo cha kushiriki hadharani iwe kitu ambacho ni rahisi kukumbuka au kutengeneza tokeni mpya. Haipendekezi kutumia tokeni inayoweza kukisiwa kwa hisa ambazo zina taarifa nyeti.",
    "Generating…" : "Inazalisha...",
    "Generate new token" : "Tengeneza tokeni mpya",
    "Set password" : " Weka nenosiri",
    "Password expires {passwordExpirationTime}" : "Nenosiri linaisha muda {passwordExpirationTime}",
    "Password expired" : "Nenosiri limekwisha muda wake",
    "Video verification" : "Uthibitishaji wa video",
    "Expiration date (enforced)" : "Tarehe ya mwisho wa matumizi (imetekelezwa)",
    "Set expiration date" : "Panga tarehe ya mwisho wa matumizi",
    "Hide download" : "Ficha upakuaji",
    "Allow download and sync" : "Ruhusu upakuaji na usawazishe",
    "Note to recipient" : "Kumbuka kwa mpokeaji",
    "Enter a note for the share recipient" : "Andika dokezo kwa mpokeaji kushiriki",
    "Show files in grid view" : "Show files in grid view",
    "Delete share" : "Futa shiriki",
    "Others with access" : "Wengine wenye ufikiaji",
    "No other accounts with access found" : "Hakuna akaunti nyingine zenye ufikiaji zilizopatikana",
    "Toggle list of others with access to this directory" : "Geuza orodha ya wengine na ufikiaji wa saraka hii",
    "Toggle list of others with access to this file" : "Geuza orodha ya wengine na ufikiaji wa faili hii",
    "Unable to fetch inherited shares" : "Imeshindwa kuleta shiriki zilizorithiwa",
    "Link shares" : "Unganisha shiriki",
    "Shares" : "Shiriki",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Shiriki faili ndani ya shirika lako. Wapokeaji ambao tayari wanaweza kutazama faili wanaweza pia kutumia kiungo hiki kwa ufikiaji rahisi.",
    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "Shiriki faili na wengine nje ya shirika lako kupitia viungo vya umma na anwani za barua pepe. Unaweza pia kushiriki kwenye akaunti za {productName} katika matukio mengine kwa kutumia kitambulisho chao cha wingu kilichoshirikishwa.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Shiriki kutoka kwa programu au vyanzo vingine ambavyo hazijajumuishwa katika ushiriki wa ndani au nje.",
    "Type names, teams, federated cloud IDs" : "Andika majina, timu, vitambulisho vya cloud vilivyoshirikishwa",
    "Type names or teams" : "Andika majina au timu",
    "Type a federated cloud ID" : "Andika kitambulisho cha cloud kilichoshirikishwa",
    "Type an email" : "Andika barua pepe",
    "Type an email or federated cloud ID" : "Andika barua pepe au kitambulisho cha cloud kilichoshirikishwa",
    "Unable to load the shares list" : "Imeshindwa kupakia orodha ya shiriki",
    "Expires {relativetime}" : "Inaisha wakati {relativetime}",
    "this share just expired." : "Shiriki hii imeisha muda wake",
    "Shared with you by {owner}" : "Imeshirikiwa na wewe kwa {owner}",
    "Internal shares" : "Shiriki za ndani",
    "Internal shares explanation" : "Maelezo ya shiriki za ndani",
    "External shares" : "Shiriki za nje",
    "External shares explanation" : "Maelezo ya shiriki za nje",
    "Additional shares" : "Shiriki za nyongeza",
    "Additional shares explanation" : "Maelezo ya shiriki za nyongeza",
    "Link to a file" : "Unga kwenye faili",
    "_Accept share_::_Accept shares_" : ["Accept share","Kubali shiriki"],
    "Open in Files" : "Fungua ndani ya faili",
    "_Reject share_::_Reject shares_" : ["Reject share","Kataa shiriki"],
    "_Restore share_::_Restore shares_" : ["Restore share","Rejesha shiriki"],
    "Shared" : "Imeshirikishwa",
    "Shared by {ownerDisplayName}" : "Imeshirikishwa na{ownerDisplayName}",
    "Shared multiple times with different people" : "Imeshirikiwa mara nyingi na watu tofauti",
    "Sharing options" : "Kushiriki chaguzi",
    "Shared with others" : "Imeshirikiwa na wengine",
    "You do not have enough permissions to share this file." : "Huna vibali vya kutosha kushiriki faili hii.",
    "People" : "Watu",
    "Create file request" : "Unda ombi la faili",
    "Upload files to {foldername}" : "Pakia faili kwa {foldername}",
    "Public file share" : "Shiriki faili za umma",
    "Publicly shared file." : "Faili iliyoshirikiwa hadharani.",
    "No file" : "Hakuna faili",
    "The file shared with you will show up here" : "Faili iliyoshirikiwa nawe itaonekana hapa",
    "Public share" : "Shiriki ya umma",
    "Publicly shared files." : "Faili zilizoshirikiwa hadharani.",
    "No files" : "Hakuna faili",
    "Files and folders shared with you will show up here" : "Faili na folda zilizoshirikiwa nawe zitaonekana hapa",
    "Overview of shared files." : "Muhtasari wa faili zilizoshirikiwa.",
    "No shares" : "Hakuna shiriki",
    "Files and folders you shared or have been shared with you will show up here" : "Faili na folda ulizoshiriki au ambazo umeshirikiwa nawe zitaonekana hapa",
    "Shared with you" : "Imeshirikiwa na wewe",
    "List of files that are shared with you." : "Orodha ya faili ambazo zimeshirikiwa nawe.",
    "Nothing shared with you yet" : "Bado hakuna kilichoshirikiwa nawe",
    "Files and folders others shared with you will show up here" : "Faili na folda ambazo wengine wameshiriki nawe zitaonekana hapa",
    "List of files that you shared with others." : "Orodha ya faili ulizoshiriki na wengine.",
    "Nothing shared yet" : "Bado hakuna kitu kilichoshirikiwa",
    "Files and folders you shared will show up here" : "Faili na folda ulizoshiriki zitaonekana hapa",
    "Shared by link" : "Imeshirikishwa na kiungio",
    "List of files that are shared by link." : "Orodha ya faili zinazoshirikiwa na kiungo.",
    "No shared links" : "Hakuna viungo vilivyoshirikiwa",
    "Files and folders you shared by link will show up here" : "Faili na folda ulizoshiriki kwa kutumia kiungo zitaonekana hapa",
    "File requests" : "Maombi ya faili",
    "List of file requests." : "Orodha ya maombi ya faili",
    "No file requests" : "Hakuna maombi ya faili",
    "File requests you have created will show up here" : "Maombi ya faili uliyounda yataonekana hapa",
    "Deleted shares" : "Shiriki zilizofutwa",
    "List of shares you left." : "Orodha ya shiriki ulizoacha.",
    "No deleted shares" : "Hakuna shiriki zilizofutwa",
    "Shares you have left will show up here" : "Shiriki  ulizobakisha zitaonekana hapa",
    "Pending shares" : "Shiriki zinazosubiri",
    "List of unapproved shares." : "Orodha ya shiriki ambazo hazijaidhinishwa.",
    "No pending shares" : "Hakuna shiriki zinazosubiri",
    "Shares you have received but not approved will show up here" : "Shiriki ambazo umepokea lakini hazijaidhinishwa zitaonekana hapa",
    "Error deleting the share" : "Hitilafu katika kufuta kushiriki",
    "Error updating the share" : "Hitilafu katika kusasisha ushiriki",
    "File \"{path}\" has been unshared" : "Faili \"{path}\" haijashirikiwa",
    "Folder \"{path}\" has been unshared" : "Folda \"{path}\" haijashirikiwa",
    "Could not update share" : "Haikuweza kusasisha kushiriki",
    "Share saved" : "Shiriki imehifadhiwa",
    "Share expiry date saved" : "Shiriki tarehe ya kumalizika kwa kushiriki iliyohifadhiwa",
    "Share hide-download state saved" : "Shiriki hali ya upakuaji fiche iliyohifadhiwa",
    "Share label saved" : "Lebo ya kushiriki imehifadhiwa",
    "Share note for recipient saved" : "Dokezo la shiriki kwa mpokeaji aliyehifadhiwa",
    "Share password saved" : "Nenosiri la shiriki lililohifadhiwa",
    "Share permissions saved" : "Ruhusa za kushiriki zimehifadhiwa",
    "To upload files to {folder}, you need to provide your name first." : "Ili kupakia faili kwenye {folder}, unahitaji kutoa jina lako kwanza.",
    "Upload files to {folder}" : "Pakia faili kwa {folder}",
    "Please confirm your name to upload files to {folder}" : "Tafadhali thibitisha jina lako ili kupakia faili {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} ameshiriki folda nawe.",
    "Names must not be empty." : "Majina lazima yasiwe tupu.",
    "Names must not start with a dot." : "Majina lazima yasianze na nukta.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" hairuhusiwi ndani ya jina.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" ni jina lililohifadhiwa na lisiloruhusiwa",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" si jina linaloruhusiwa.",
    "Names must not end with \"{extension}\"." : "Majina lazima yasiishie na \"{extension}\".",
    "Invalid name." : "Jina batili.",
    "Password created successfully" : "Nenosiri limeundwa kwa mafanikio",
    "Error generating password from password policy" : "Hitilafu katika kuzalisha nenosiri kutoka kwa sera ya nenosiri",
    "Shared with you and the group {group} by {owner}" : "Imeshirikiwa nawe na kikundi {group} kwa {owner}",
    "Shared with you and {circle} by {owner}" : " Imeshirikiwa na wewe na{circle} kwa {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Imeshirikiwa nawe na mazungumzo {conversation} kwa {owner}",
    "Shared with you in a conversation by {owner}" : " Imeshirikiwa nawe kwenye mazungumzo na{owner}",
    "Share not found" : "Ushirikishaji haupo",
    "Back to %s" : "Rudi kwenye %s",
    "Add to your Nextcloud" : "Ongeza kwenye Nextcloud yako",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Ushirikishaji %s kumeshindwa kwa sababu sehemu ya nyuma haitumii hisa za ScienceMesh",
    "Name or email …" : "Jina au barua pepe",
    "Name, email, or Federated Cloud ID …" : "Jina, barua pepe au kitambulisho cha Cloudi kilichoshirikishwa...",
    "Searching …" : "Inatafuta"
},
"nplurals=2; plural=(n != 1);");
