import{g}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as l}from"./dart-CL8zQ6ub.chunk.mjs";function c(e,s){for(var n=0;n<s.length;n++){const t=s[n];if(typeof t!="string"&&!Array.isArray(t)){for(const r in t)if(r!=="default"&&!(r in e)){const i=Object.getOwnPropertyDescriptor(t,r);i&&Object.defineProperty(e,r,i.get?i:{enumerable:!0,get:()=>t[r]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,a;function u(){if(a)return o;a=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/dart" instead of "highlight.js/lib/languages/dart.js"'))}return e(),o=l(),o}var f=u();const d=g(f),j=c({__proto__:null,default:d},[f]);export{j as d};
//# sourceMappingURL=dart.js-BilW9S4q.chunk.mjs.map
