OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Сэргээх түлхүүр хамгаалах нууц үг алга",
    "Please repeat the recovery key password" : "Сэргээх түлхүүр үгээ давтана уу",
    "Repeated recovery key password does not match the provided recovery key password" : "Давтан оруулсан нөхөн сэргээх түлхүүрийн нууц үг таарахгүй байна",
    "Recovery key successfully enabled" : "Сэргээх түлхүүр амжилттай идэвхжсэн",
    "Could not enable recovery key. Please check your recovery key password!" : "Сэргээх түлхүүрийг идэвхжүүлж чадсангүй. Сэргээх түлхүүрийн нууц үгээ шалгана уу!",
    "Recovery key successfully disabled" : "Сэргээх түлхүүр амжилттай идэвхгүй болсон",
    "Could not disable recovery key. Please check your recovery key password!" : "Сэргээх түлхүүрийг идэвхгүй болгож чадсангүй. Сэргээх түлхүүрийн нууц үгээ шалгана уу!",
    "Please provide the old recovery password" : "Хуучин сэргээх нууц үгийг оруулна уу",
    "Please provide a new recovery password" : "Шинэ сэргээх нууц үг оруулна уу",
    "Please repeat the new recovery password" : "Шинэ сэргээх нууц үгийг давтана уу",
    "Password successfully changed." : "нууц үг амжилттай солигдлоо",
    "Could not change the password. Maybe the old password was not correct." : "Нууц үгийг өөрчилж чадсангүй. Хуучин нууц үг буруу байсан байж магадгүй.",
    "Recovery Key disabled" : "Сэргээх түлхүүр идэвхгүй",
    "Recovery Key enabled" : "Сэргээх түлхүүр идэвхтэй",
    "Could not enable the recovery key, please try again or contact your administrator" : "Нөхөн сэргээх түлхүүрийг идэвхжүүлэх боломжгүй байна. Дахин оролдож үзнэ үү эсвэл администраторт хандана уу",
    "Could not update the private key password." : "Хувийн түлхүүрийн нууц үгийг шинэчилж чадсангүй.",
    "The old password was not correct, please try again." : "Хуучин нууц үг буруу байсан, дахин оролдоно уу.",
    "The current log-in password was not correct, please try again." : "Одоогийн нэвтрэх нууц үг буруу байсан, дахин оролдоно уу.",
    "Private key password successfully updated." : "Хувийн түлхүүрийн нууц үг амжилттай шинэчлэгдсэн.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Шифрлэлтийн програмд зориулсан хувийн түлхүүр хүчингүй байна. Шифрлэгдсэн файлуудад нэвтрэх эрхээ сэргээхийн тулд хувийн тохиргоодоо хувийн түлхүүрийн нууц үгээ шинэчилнэ үү.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Шифрлэлтийн програм идэвхтэй байна, гэхдээ таны түлхүүрүүд эхлүүлэгдээгүй байна. Гарч дахин нэвтэрнэ үү.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Шифрлэлтийн модулийг ашиглахын тулд администраторын тохиргоонд серверийн талын шифрлэлтийг идэвхжүүлнэ үү.",
    "Encryption app is enabled and ready" : "Шифрлэлтийн апп идэвхтэй бөгөөд бэлэн",
    "Bad Signature" : "Буруу гарын үсэг",
    "Missing Signature" : "Гарын үсэг байхгүй",
    "one-time password for server-side-encryption" : "серверийн шифрлэлтийн нэг удаагийн нууц үг",
    "Encryption password" : "Шифрлэлтийн нууц үг",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "Администратор серверийн талын шифрлэлтийг идэвхжүүллээ. Таны файлууд <strong>%s</strong> нууц үгийг ашиглан шифрлэгдлээ.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "Администратор серверийн талын шифрлэлтийг идэвхжүүллээ. Таны файлууд \"%s\" нууц үгийг ашиглан шифрлэгдлээ.",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Веб интерфэйст нэвтэрч, хувийн тохиргооны \"Аюулгүй байдал\" хэсэгт очоод \"Хуучин нэвтрэх нууц үг\" талбарт энэ нууц үгийг болон одоогийн нэвтрэх нууц үгээ оруулж шифрлэлтийн нууц үгээ шинэчилнэ үү.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Энэ файлыг тайлах боломжгүй байна. Магадгүй энэ нь хуваалцсан файл байж болно. Файлын эзэмшигчээс файлыг дахин хуваалцахыг хүснэ үү.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Энэ файлыг унших боломжгүй байна. Магадгүй энэ нь хуваалцсан файл байж болно. Файлын эзэмшигчээс файлыг дахин хуваалцахыг хүснэ үү.",
    "Default Encryption Module" : "Анхдагч шифрлэлтийн модуль",
    "Default encryption module for Nextcloud Server-side Encryption (SSE)" : "Nextcloud серверийн шифрлэлтийн (SSE) анхдагч шифрлэлтийн модуль",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to\n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Энэ програм нь Nextcloud-ын серверийн талын шифрлэлт (SSE) функцийн (өгөгдмөл) криптографийн хэрэгжүүлэлтийг хангадаг.\n\n\t\t\t**Шифрлэлтийн дэлгэрэнгүй**\n\t\t\t*   **Шифрийн горим:** AES-256-CTR (өгөгдмөл)\n\t\t\t*   **Баталгаажуулалт:** HMAC-SHA256\n\n\t\t\t**Чухал анхааруулгууд**\n\t\t\t*   **АЮУЛ:** Бүх файлыг тайлах хүртэл (`occ encryption:decrypt-all`) энэ програмыг идэвхгүй болгож болохгүй.\n\t\t\t*   **АНХААРУУЛГА:** Идэвхжүүлсний дараа шифрлэлтгүй файл хадгалалтад буцаах нь командын мөрийн хандалт шаарддаг. Web UI-аар хийсэн үйлдэл нь байнгын шинж чанартай байна.\"\n\n\t\t\t**Одоо байгаа файлуудын талаарх тэмдэглэл**\n\t\t\t*   Өгөгдмөл байдлаар SSE идэвхжүүлэх нь одоо байгаа файлуудыг шифрлэхгүй; зөвхөн шинэ файлууд шифрлэгдэнэ.\n\t\t\t*   Бүх одоо байгаа файлуудыг шифрлэхийн тулд `occ encryption:encrypt-all` тушаалыг ашиглана уу.\n\n\t\t\t**Эхлэхийн өмнө**\n\t\t\t*   **Баримт бичгийг уншина уу:** SSE идэвхжүүлэх, одоо байгаа файлуудыг шифрлэх буюу SSE идэвхгүй болгохын өмнө өгөгдөл алдахаас зайлсхийхийн тулд нөлөөллийг болон зохих журмыг ойлгохын тулд баримт бичгийг унших нь маш чухал.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Энэ сонголтыг идэвхжүүлэх нь үндсэн хадгалалт дээрх бүх файлуудыг шифрлэнэ, эс тэгвэл зөвхөн гадаад хадгалалт дээрх файлууд шифрлэгдэнэ",
    "Encrypt the home storage" : "Гэрийн санах ойг шифрлэх",
    "Disable recovery key" : "Сэргээх түлхүүрийг идэвхгүй болгох",
    "Enable recovery key" : "Сэргээх түлхүүрийг идэвхжүүлэх",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "Нөхөн сэргээх түлхүүр нь файлуудыг шифрлэхэд ашигладаг нэмэлт шифрлэлтийн түлхүүр юм. Нууц үгийг мартсан тохиолдолд бүртгэлийн файлуудыг сэргээхэд ашиглагддаг.",
    "Recovery key password" : "Сэргээх түлхүүрийн нууц үг",
    "Passwords fields do not match" : "Нууц үгнүүд таарахгүй байна",
    "Repeat recovery key password" : "Сэргээх түлхүүрийн нууц үгийг давтах",
    "An error occurred while updating the recovery key settings. Please try again." : "Нөхөн сэргээх түлхүүрийн тохиргоог шинэчлэх явцад алдаа гарлаа. Дахин оролдоно уу.",
    "Change recovery key password" : "Нөөцлөлтийн түлхүүрийн нууц үг өөрчлөх",
    "Old recovery key password" : "Хуучин сэргээх түлхүүрийн нууц үг",
    "New recovery key password" : "Шинэ сэргээх түлхүүрийн нууц үг",
    "Repeat new recovery key password" : "Шинэ сэргээх түлхүүрийн нууц үгийг давтах",
    "An error occurred while changing the recovery key password. Please try again." : "Нөхөн сэргээх түлхүүрийн нууц үгийг өөрчлөх явцад алдаа гарлаа. Дахин оролдоно уу.",
    "Update private key password" : "Хувийн түлхүүрийн нууц үг шинэчлэх",
    "Your private key password no longer matches your log-in password. Set your old private key password to your current log-in password." : "Таны хувийн түлхүүрийн нууц үг одоогийн нэвтрэх нууц үгтэй таарахгүй байна. Хуучин хувийн түлхүүрийн нууц үгийг одоогийн нэвтрэх нууц үгтэй тохируулна уу.",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Хэрэв та хуучин нууц үгээ санахгүй байвал администраторт хандаж файлуудаа сэргээлгэж болно.",
    "Old log-in password" : "Хуучин нэвтрэх нууц үг",
    "Current log-in password" : "Одоогийн нэвтрэх нууц үг",
    "Update" : "Шинэчлэх",
    "Updating recovery keys. This can take some time…" : "Нөөцлөлтийн түлхүүрүүдийг шинэчилж байна. Энэ хэсэг хугацаа шаардана…",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Энэ сонголтыг идэвхжүүлснээр нууц үгээ алдсан тохиолдолд шифрлэгдсэн файлуудад нэвтрэх эрхийг дахин олж авах боломжтой болно",
    "Enable password recovery" : "Нууц үг сэргээлтийг идэвхжүүлэх",
    "Default encryption module" : "Анхдагч шифрлэлтийн модуль",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Шифрлэлтийн програм идэвхтэй байна гэхдээ таны түлхүүрүүд эхлүүлэгдээгүй байна. Гарч дахин нэвтэрнэ үү",
    "Basic encryption module" : "Үндсэн шифрлэлтийн модуль",
    "Missing parameters" : "параметр байхгүй",
    "Default encryption module for server-side encryption" : "Серверийн шифрлэлтийн анхдагч шифрлэлтийн модуль",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Энэ шифрлэлтийн модулийг ашиглахын тулд администраторын тохиргоонд серверийн талын шифрлэлтийг идэвхжүүлэх шаардлагатай. Идэвхжүүлсний дараа энэ модуль бүх файлуудыг ил тод байдлаар шифрлэнэ. Шифрлэлт нь AES 256 түлхүүрт суурилдаг.\nМодуль нь одоо байгаа файлуудад нөлөөлөхгүй; серверийн талын шифрлэлт идэвхжүүлэгдсэний дараа зөвхөн шинэ файлууд шифрлэгдэнэ. Шифрлэлтийг дахин идэвхгүй болгож шифрлэлтгүй систем рүү буцах боломжгүй.\nСерверийн талын шифрлэлтийг идэвхжүүлэхээр шийдэхийн өмнө бүх нөлөөллийг ойлгохын тулд баримт бичгийг уншина уу.",
    "Change recovery key password:" : "Сэргээх түлхүүрийн нууц үгийг өөрчлөх:",
    "Change Password" : "нууц үг өөрчлөх",
    "Your private key password no longer matches your log-in password." : "Таны хувийн түлхүүрийн нууц үг нэвтрэх нууц үгтэй таарахгүй байна.",
    "Set your old private key password to your current log-in password:" : "Хуучин хувийн түлхүүрийн нууц үгээ одоогийн нэвтрэх нууц үгтэй тааруулах:",
    "Update Private Key Password" : "Хувийн түлхүүрийн нууц үгийг шинэчлэх",
    "Enable password recovery:" : "Нууц үг сэргээхийг идэвхжүүлэх:",
    "Enabled" : "Идэвхижүүлэх",
    "Disabled" : "идэвхигүй",
    "This app provides the (default) cryptography implementation for Nextcloud's Server-side Encryption (SSE) feature.\n\n\t\t\t**Encryption Details**\n\t\t\t*   **Cipher Mode:** AES-256-CTR (default)\n\t\t\t*   **Authentication:** HMAC-SHA256\n\n\t\t\t**Important Warnings**\n\t\t\t*   **DANGER:** Do not disable this application until all files have been decrypted (`occ encryption:decrypt-all`).\n\t\t\t*   **WARNING**: Reverting to non-encrypted file storage after activation requires command-line access. The action is permanent via the Web UI.\"\n\n\t\t\t**Notes for Existing Files**\n\t\t\t*   By default, enabling SSE does not encrypt existing files; only new files will be encrypted.\n\t\t\t*   To encrypt all existing files, use the command `occ encryption:encrypt-all`.\n\n\t\t\t**Before You Begin**\n\t\t\t*   **Read the Documentation:** Before you enable SSE, encrypt existing files, or disable SSE, it is critical to \n\t\t\t\tread the documentation to understand implications and the appropriate procedures to avoid data loss." : "Энэ програм нь Nextcloud-ын серверийн талын шифрлэлт (SSE) функцийн (өгөгдмөл) криптографийн хэрэгжүүлэлтийг хангадаг.\n\n\t\t\t**Шифрлэлтийн дэлгэрэнгүй**\n\t\t\t*   **Шифрийн горим:** AES-256-CTR (өгөгдмөл)\n\t\t\t*   **Баталгаажуулалт:** HMAC-SHA256\n\n\t\t\t**Чухал анхааруулгууд**\n\t\t\t*   **АЮУЛ:** Бүх файлыг тайлах хүртэл (`occ encryption:decrypt-all`) энэ програмыг идэвхгүй болгож болохгүй.\n\t\t\t*   **АНХААРУУЛГА:** Идэвхжүүлсний дараа шифрлэлтгүй файл хадгалалтад буцаах нь командын мөрийн хандалт шаарддаг. Web UI-аар хийсэн үйлдэл нь байнгын шинж чанартай байна.\"\n\n\t\t\t**Одоо байгаа файлуудын талаарх тэмдэглэл**\n\t\t\t*   Өгөгдмөл байдлаар SSE идэвхжүүлэх нь одоо байгаа файлуудыг шифрлэхгүй; зөвхөн шинэ файлууд шифрлэгдэнэ.\n\t\t\t*   Бүх одоо байгаа файлуудыг шифрлэхийн тулд `occ encryption:encrypt-all` тушаалыг ашиглана уу.\n\n\t\t\t**Эхлэхийн өмнө**\n\t\t\t*   **Баримт бичгийг уншина уу:** SSE идэвхжүүлэх, одоо байгаа файлуудыг шифрлэх буюу SSE идэвхгүй болгохын өмнө өгөгдөл алдахаас зайлсхийхийн тулд нөлөөллийг болон зохих журмыг ойлгохын тулд баримт бичгийг унших нь маш чухал."
},
"nplurals=2; plural=(n != 1);");
