OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Soukromí",
    "-" : "–",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum soukromí ukazuje, kde jsou vaše data fyzicky uložena a kdo k nim může přistupovat, buď protože jste jim je nasdíleli nebo protože jsou správci.",
    "Error loading additional administrator." : "Chyba při načítání dalšího správce.",
    "Error adding new administrator." : "Chyba při přidávání nového správce.",
    "Error deleting new administrator." : "Chyba při mazání nového správce.",
    "Administrators" : "Správci",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Následující účty jsou pověřenými správci a mohou mít případně přístup k vašim datům prostřednictvím systémového úložiště či záloh. Nicméně, nemají snadný přístup k vašim datům prostřednictvím webového rozhraní nebo klientských aplikací.",
    "Loading administrators …" : "Načítání správců …",
    "Remove external {propertyName} admin" : "Odebrat externí správu {propertyName}",
    "Add external admin" : "Přidat správce zvenčí",
    "Cancel" : "Storno",
    "Add" : "Přidat",
    "Name of external admin" : "Jméno externího správce",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Vaše domovské úložiště je šifrováno pomocí {linkopen}šifrování na straně serveru ↗{linkclose} s využitím hlavního klíče. To znamená, že správci sice mohou přistupovat k vašim souborům, ale už ne číst jejich obsah.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Vaše soubory na externích úložištích mohou být šifrovány pomocí {linkopen}šifrování na straně serveru ↗{linkclose} s hlavním klíčem založeným na jejich nastavení.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Vaše domovské úložiště je šifrováno pomocí {linkopen}šifrování na straně serveru ↗{linkclose} s využitím klíče konkrétního uživatele. To znamená, že správci sice mohou přistupovat k vašim souborům, ale už ne číst jejich obsah.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Vaše soubory na externích úložištích mohou být šifrovány pomocí {linkopen}šifrování na straně serveru ↗{linkclose} s individuálním klíčem založeným na jejich nastavení.",
    "Additionally, this server is protected with full-disk-encryption." : "Dále, tento server je chráněn šifrováním celého úložiště.",
    "This server is protected with full-disk-encryption." : "Tento server je chráněn šifrováním celého úložiště.",
    "Your files are not protected by encryption." : "Vaše soubory nejsou chráněny šifrováním.",
    "Error saving new state of full-disk-encryption" : "Chyba při ukládání nového stavu celodiskového šifrování",
    "Encryption" : "Šifrování",
    "Edit encryption" : "Upravit šifrování",
    "Edit" : "Upravit",
    "This server is using full-disk-encryption." : "Tento server používá šifrování celého úložiště.",
    "Privacy policy" : "Zásada ochrany osobních údajů",
    "Read the privacy policy ↗" : "Přečíst si zásady ochrany osobních údajů ↗",
    "Error loading information about shares." : "Chyba při načítání informací o sdílení.",
    "People you've shared with" : "Lidé, kterým jste nasdíleli",
    "You do not have any shares with individual users." : "Nemáte žádná sdílení s jednotlivými uživateli.",
    "Your {serverName} account" : "Váš účet na {serverName}",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaše data představují to, kdo jste a mohou být snadno zneužita. My v Nextcloud věříme, že máte právo rozhodovat, co se s vašimi daty děje. Nextcloud chrání vaše práva, definovaná v manifestu o datech uživatelů!",
    "Who has access to your data?" : "Kdo má přístup k vašim datům?",
    "Error saving new location of the server" : "Chyba při ukládání nového umístění serveru",
    "Where is your data?" : "Kde se vaše data nacházejí?",
    "Your data is located in:" : "Vaše data se nacházejí v:",
    "An admin has not selected the location of the server yet." : "Správce doposud nezadal umístění serveru.",
    "Change data location" : "Změnit umístění dat",
    "Region" : "Oblast",
    "Please select a region" : "Vyberte oblast",
    "User Data Manifesto 2.0" : "Manifest o datech uživatelů, verze 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Definující základní práva lidí na kontrolu nad svými daty v éře Internetu.",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Data výslovně a úmyslně nahraná uživatelem by měla být pod jeho nezpochybnitelnou kontrolou. Uživatelé by měli být schopní rozhodovat, komu udělit přímý přístup k jejich datům a jaká oprávnění a licence má takový přístup poskytovat.",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Když jsou data nahrávána ke konkrétnímu poskytovateli služby, uživatelé by měli být informováni kde konkrétní poskytovatel služby uchovává data, po jak dlouhou dobu, pod čí jurisdikcí konkrétní poskytovatel služby funguje a které zákony se na toto vztahují.",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Uživatelé by vždy měli být schopní kdykoli vyzískat svá data ze služby nazpět, aniž by přitom narazili na nepostradatelnost jejího dodavatele. Pro zajištění tohoto je nezbytné používání otevřených standardů pro formáty dat a komunikační protokoly.",
    "Learn more ↗" : "Zjistit víc ↗",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Spojené Arabské Emiráty",
    "Afghanistan" : "Afgánistán",
    "Antigua and Barbuda" : "Antigua a Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albánie",
    "Armenia" : "Arménie",
    "Angola" : "Angola",
    "Antarctica" : "Antarktida",
    "Argentina" : "Argentina",
    "American Samoa" : "Americká Samoa",
    "Austria" : "Rakousko",
    "Australia" : "Austrálie",
    "Aruba" : "Aruba",
    "Åland Islands" : "Alandy",
    "Azerbaijan" : "Ázerbájdžán",
    "Bosnia and Herzegovina" : "Bosna a Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladéš",
    "Belgium" : "Belgie",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulharsko",
    "Bahrain" : "Bahrajn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Svatý Bartoloměj",
    "Bermuda" : "Bermudy",
    "Brunei" : "Brunej",
    "Bolivia" : "Bolívie",
    "Bonaire, Sint Eustatius and Saba" : "Karibské Nizozemsko",
    "Brazil" : "Brazílie",
    "Bahamas" : "Bahamy",
    "Bhutan" : "Bhútán",
    "Bouvet Island" : "Bouvetův ostrov",
    "Botswana" : "Botswana",
    "Belarus" : "Bělorusko",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosové ostrovy",
    "Democratic Republic of the Congo" : "Kongo",
    "Central African Republic" : "Středoafrická republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švýcarsko",
    "Cote d'Ivoire" : "Pobřeží slonoviny",
    "Cook Islands" : "Cookovy ostrovy",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Čína",
    "Colombia" : "Kolumbie",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kapverdy",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Vánoční ostrov",
    "Cyprus" : "Kypr",
    "Czech" : "Česko",
    "Germany" : "Německo",
    "Djibouti" : "Džibutsko",
    "Denmark" : "Dánsko",
    "Dominican Republic" : "Dominikánská republika",
    "Algeria" : "Alžír",
    "Ecuador" : "Ekvádor",
    "Estonia" : "Estonsko",
    "Egypt" : "Egypt",
    "West Sahara" : "Západní Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Španělsko",
    "Ethiopia" : "Etiopie",
    "Finland" : "Finsko",
    "Fiji" : "Fidži",
    "Falkland Islands" : "Falklandské ostrovy",
    "Micronesia" : "Mikronésie",
    "Faroe Islands" : "Faerské ostrovy",
    "France" : "Francie",
    "Gabon" : "Gabon",
    "United Kingdom" : "Spojené království",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzie",
    "French Guiana" : "Francouzská Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grónsko",
    "Gambia" : "Gambie",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Rovníková Guinea",
    "Greece" : "Řecko",
    "South Georgia and the South Sandwich Islands" : "Jižní Georgie a Jižní Sandwichovy ostrovy",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heardův ostrov a McDonaldovy ostrovy",
    "Honduras" : "Honduras",
    "Croatia" : "Chorvatsko",
    "Haiti" : "Haiti",
    "Hungary" : "Maďarsko",
    "Indonesia" : "Indonézie",
    "Ireland" : "Irsko",
    "Israel" : "Izrael",
    "Isle of Man" : "Man",
    "India" : "Indie",
    "British Indian Ocean Territory" : "Britské indickooceánské území",
    "Iraq" : "Irák",
    "Iran" : "Irán",
    "Iceland" : "Island",
    "Italy" : "Itálie",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordánsko",
    "Japan" : "Japonsko",
    "Kenya" : "Keňa",
    "Kyrgyzstan" : "Kyrgyzstán",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comores" : "Komory",
    "Saint Kitts and Nevis" : "Svatý Kryštof a Nevis",
    "North Korea" : "Severní Korea",
    "South Korea" : "Jižní Korea",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmanské ostrovy",
    "Kazakhstan" : "Kazachstán",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Svatá Lucie",
    "Liechtenstein" : "Lichnštejnsko",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Libérie",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litva",
    "Luxembourg" : "Lucembursko",
    "Latvia" : "Lotyšsko",
    "Libya" : "Libye",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldavsko",
    "Montenegro" : "Černá Hora",
    "Saint Martin" : "Svatý Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovy ostrovy",
    "Macedonia" : "Makedonie",
    "Mali" : "Mali",
    "Myanmar" : "Barma",
    "Mongolia" : "Mongolsko",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Severní Mariany",
    "Mauritania" : "Mauritánie",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurícius",
    "Maldives" : "Maledivy",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malajsie",
    "Mozambique" : "Mozambik",
    "Namibia" : "Nambie",
    "New Caledonia" : "Nová Kaledonie",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk",
    "Nigeria" : "Nigérie",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Nizozemí",
    "Norway" : "Norsko",
    "Nepal" : "Nepál",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nový Zéland",
    "Oman" : "Omán",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francouzská Polynésie",
    "Papua New Guinea" : "Papua-Nová Guinea",
    "Philippines" : "Filipíny",
    "Pakistan" : "Pakistán",
    "Poland" : "Polsko",
    "Saint Pierre and Miquelon" : "Saint-Pierre a Miquelon",
    "Pitcairn" : "Pitcairnovy ostrovy",
    "Puerto Rico" : "Portoriko",
    "Palestine" : "Palestina",
    "Portugal" : "Portugalsko",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumunsko",
    "Serbia" : "Srbsko",
    "Russia" : "Rusko",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudská Arábie",
    "Solomon Islands" : "Šalamounovy ostrovy",
    "Seychelles" : "Seychely",
    "Sudan" : "Súdán",
    "Sweden" : "Švédsko",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Svatá Helena",
    "Slovenia" : "Slovinsko",
    "Svalbard and Jan Mayen" : "Špicberky a Jan Mayen",
    "Slovakia" : "Slovensko",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somálsko",
    "Suriname" : "Surinam",
    "South Sudan" : "Jižní Súdán",
    "Sao Tome and Principe" : "Svatý Tomáš a Princův ostrov",
    "El Salvador" : "Salvador",
    "Sint Maarten" : "Svatý Martin (nizozemská část)",
    "Syria" : "Sýrie",
    "Swaziland" : "Swazijsko",
    "Turks and Caicos Islands" : "Turks a Caicos",
    "Chad" : "Čad",
    "Fr. S. Antarctic Lands" : "Francouzská jižní a antarktická území",
    "Togo" : "Togo",
    "Thailand" : "Thajsko",
    "Tajikistan" : "Tádžikistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Východní Timor",
    "Turkmenistan" : "Turkmenistán",
    "Tunisia" : "Tunisko",
    "Tonga" : "Tonga",
    "Turkey" : "Turecko",
    "Trinidad and Tobago" : "Trinidad a Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tchaj-wan",
    "Tanzania" : "Tanzanie",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Menší odlehlé ostrovy Spojených států amerických",
    "United States" : "Spojené státy",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistán",
    "Holy See" : "Svatý stolec",
    "Saint Vincent and the Grenadines" : "Svatý Vincenc a Grenadiny",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Britské Panenské ostrovy",
    "Virgin Islands (U.S.)" : "Americké Panenské ostrovy",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis a Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Jihoafrická republika",
    "Zambia" : "Zambie",
    "Zimbabwe" : "Zimbabwe",
    "Loading administrators …" : "Načítání správců",
    "Loading people you've shared with …" : "Načítání lidí, kterým jste nasdíleli …",
    "Control" : "Kontrola",
    "over user data access" : "nad přístupem k datům uživatele",
    "Knowledge" : "Znalost",
    "of how the data is stored" : "toho, jak jsou data ukládána",
    "Freedom" : "Svoboda",
    "to choose a platform" : "volby platformy"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
