OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Configuração do daemon não encontrada",
    "Error starting install of ExApp" : "Erro ao iniciar a instalação do ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp falhou ao registrar, verifique os logs do NC",
    "ExApp not found, failed to get status" : "ExApp não encontrado, falha ao obter status",
    "Error adding Docker registry" : "Erro ao adicionar o registro do Docker",
    "Error removing Docker registry" : "Erro ao remover o registro do Docker",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Este aplicativo não está instalado da Loja de Aplicativos. Sem informações extras disponíveis. Somente ações de ativar/desativar e remover são permitidas.",
    "Could not perform installation of ExApp" : "Não foi possível realizar a instalação do ExApp",
    "Failed to enable ExApp" : "Falha ao habilitar ExApp",
    "Failed to disable ExApp" : "Falha ao desativar ExApp",
    "Could not update ExApp" : "Não foi possível atualizar ExApp",
    "Error starting update of ExApp" : "Erro ao iniciar a atualização do ExApp",
    "Could not perform update of ExApp" : "Não foi possível realizar a atualização do ExApp",
    "ExApp not found, failed to get logs" : "ExApp não encontrado, falha ao obter logs",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Falha ao obter logs de contêiner. Observação: O download de um contêiner do Docker funciona apenas para contêineres com arquivo json ou driver de registro do journald. Erro: %s",
    "ExApp not found, failed to get deploy options" : "ExApp não encontrado, falha ao obter opções de implantação",
    "AppAPI authentication failed" : "Falha na autenticação AppAPI",
    "AppAPI ExApp notifier" : "Notificador AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Equipe de Integração de IA",
    "ExApps Settings" : "Configurações de ExApps",
    "AppAPI deploy daemon" : "Deploy daemon de AppAPI",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "O deploy daemon padrão de AppAPI não está definido. Por favor, registre um deploy daemon padrão nas configurações para instalar Aplicativos Externos (Ex-Apps).",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "O deploy daemon padrão de AppAPI \"%s\" não está acessível. Verifique a configuração do daemon.",
    "The AppAPI default deploy daemon is not using HaRP. Please consider switching to HaRP for better performance." : "O deploy daemon padrão do AppAPI não está usando o HaRP. Considere mudar para o HaRP para obter melhor desempenho.",
    "AppAPI HaRP version check" : "Verificação da versão do AppAPI HaRP",
    "Could not retrieve HaRP version from daemon \"%s\"" : "Não foi possível recuperar a versão do HaRP do daemon \"%s\"",
    "HaRP version for daemon \"%s\" is \"%s\", which is too old. The minimum required version is \"%s\". Please update the daemon to the latest version." : "A versão do HaRP para o daemon \"%s\" é \"%s\", que é muito antiga. A versão mínima necessária é \"%s\". Atualize o daemon para a versão mais recente.",
    "Failed to check HaRP version for daemon \"%s\": %s" : "Falha ao verificar a versão do HaRP para o daemon \"%s\": %s",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "External Apps management" : "Gerenciamento de Aplicativos Externos",
    "Admin options saved" : "Opções de administrador salvas",
    "Failed to save admin options" : "Falha ao salvar as opções do administrador",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "O Projeto AppAPI é uma iniciativa empolgante que visa revolucionar a forma como os aplicativos são desenvolvidos para o Nextcloud por meio do uso de contêineres Docker. Isso permite uma maior escolha de linguagens de programação e permite que tarefas computacionalmente custosas sejam transferidas para um servidor diferente.",
    "Deploy daemons" : "Deploy daemons",
    "A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Um Deploy Daemon (DaemonConfig) é um daemon de orquestração de ExApps.",
    "Deploy daemons. A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy daemons. Um deploy daemon (DaemonConfig) é um daemon de orquestração de ExApps.",
    "Default deploy daemon is not accessible. Please check its configuration" : "O deploy daemon padrão não está acessível. Por favor, verifique a configuração",
    "ExApp init timeout (minutes)" : "Tempo limite de inicialização do ExApp (minutos)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Tempo limite do processo de inicialização do ExApp após o qual o AppAPI o marcará como com falha",
    "ExApp init timeout" : "Tempo limite de inicialização do ExApp",
    "ExApp container restart policy" : "Política de reinicialização do contêiner ExApp",
    "Choose the container restart policy, e.g. 'always' to ensure ExApps will be running after a daemon server reboot" : "Escolha a política de reinicialização do contêiner, p. ex., 'sempre' para garantir que o ExApps continuará em execução após a reinicialização do servidor do daemon.",
    "This settings changes are effective only for newly created containers" : "Estas alterações nas configurações são válidas apenas para contêineres criados depois",
    "Deploy daemon deletion confirmation" : "Confirmação da exclusão do deploy daemon",
    "Are you sure you want delete the \"{name}\" deploy daemon?" : "Tem certeza de que deseja excluir o deploy daemon \"{name}\"?",
    "Remove all ExApps installed on this daemon" : "Remover todos os ExApps instalados neste daemon",
    "Cancel" : "Cancelar",
    "Delete" : "Excluir",
    "A \"manual-install\" deploy daemon cannot be set as default" : "Um deploy daemon de \"instalação manual\" não pode ser definido como padrão",
    "Failed to save admin settings. Check the logs" : "Falha ao salvar as configurações administrativas. Verifique os registros",
    "Password confirmation failed" : "Falha na confirmação da senha",
    "Default" : "Padrão",
    "Set as default" : "Definir como padrão",
    "Test deploy" : "Implantação de teste",
    "Docker registries" : "Registros do Docker",
    "Edit" : "Editar",
    "Daemon connection successful" : "Conexão do daemon bem-sucedida",
    "Failed to connect to the daemon. Check the logs" : "Falha ao conectar ao daemon. Verifique os registros",
    "Failed to check connection to the daemon. Check the logs" : "Falha ao verificar a conexão com o daemon. Verifique os registros",
    "Unlimited" : "Ilimitado",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} CPU","{n} de CPUs","{n} CPUs"],
    "Deploy daemon configuration" : "Configuração do deploy daemon",
    "Deploy daemon configuration details" : "Detalhes da configuração do deploy daemon",
    "Deploy daemon" : "Deploy daemon",
    "Default daemon. ExApps will be installed on it" : "Daemon padrão. ExApps serão instalados nele.",
    "The \"Manual install\" daemon is usually used for development. It cannot be set as the default daemon." : "O daemon \"Instalação manual\" é normalmente utilizado para desenvolvimento. Não pode ser definido como o daemon padrão.",
    "ExApps installed" : "ExApps instalados",
    "Name" : "Nome",
    "Protocol" : "Protocolo",
    "Host" : "Host",
    "ExApp direct communication (FRP disabled)" : "Comunicação direta ExApp (FRP desativado)",
    "Deploy options" : "Opções de implantação",
    "Docker network" : "Rede Docker",
    "Nextcloud URL" : "URL Nextcloud",
    "HaProxy password" : "Senha do HaProxy",
    "GPU support" : "Suporte a GPU",
    "Computation device" : "Dispositivo de computação",
    "Memory limit" : "Limite de memória",
    "CPU limit" : "Limite da CPU",
    "Additional options" : "Opções adicionais",
    "Check connection" : "Verificar conexão",
    "Registered Deploy daemons list" : "Lista de Deploy daemons registrados",
    "No Deploy daemons are registered" : "Nenhum deploy daemon está registrado",
    "Register a custom one or configure one from the available templates" : "Registre um personalizado ou configure um a partir dos modelos disponíveis",
    "Register daemon" : "Registrar daemon",
    "Register ExApp in Nextcloud" : "Registrar ExApp no ​​Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Verificar se o ExApp está registrado no Nextcloud antes da implantação",
    "Image pull" : "Image pull",
    "Check if the image is successfully pulled" : "Verifique se o pull da imagem terminou com sucesso",
    "Container started" : "Contêiner iniciado",
    "Check if the image successfully pulled and container is created and started" : "Verifique se o pull da imagem terminou com sucesso e o contêiner foi criado e iniciado",
    "Heartbeat" : "Heartbeat",
    "Check for the heartbeat is finished and healthy" : "Verifique se o heartbeat está finalizado e saudável",
    "Init step" : "Etapa de inicialização",
    "Wait for initialization step to finish" : "Aguardar a conclusão da etapa de inicialização",
    "Enabled" : "Ativado",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Verifique se o ExApp tratou com sucesso o evento ativado e registrou tudo corretamente",
    "Only if ExApp container is preset" : "Somente se o contêiner ExApp estiver predefinido",
    "Deploy test passed successfully!" : "O teste de implantação foi concluído com êxito!",
    "Deploy test failed at step \"{step}\"" : "O teste de implantação falhou na etapa \"{step}\"",
    "AppAPI will try to install small skeleton ExApp to check that the daemon is configured correctly and the deployment steps are successful." : "O AppAPI tentará instalar um pequeno esqueleto ExApp para verificar se o daemon está configurado corretamente e se as etapas de implantação foram bem-sucedidas.",
    "The following deploy test checks must succeed:" : "As seguintes verificações de teste de implantação devem ser bem-sucedidas:",
    "More information" : "Mais informações",
    "Download ExApp logs" : "Baixar logs do ExApp",
    "Remove the test ExApp" : "Remover o ExApp de teste",
    "Start the deploy test" : "Iniciar o teste de implantação",
    "Stop the deploy test" : "Interromper o teste de implantação",
    "The test ExApp is unregistered and its container is removed on \"Stop the deploy test\"" : "O ExApp de teste não está registrado e seu contêiner é removido em \"Interromper o teste de implantação\".",
    "Please enter a registry domain" : "Por favor, digite um domínio de registro",
    "\"From\" cannot be \"local\"" : "\"De\" não pode ser \"local\"",
    "This registry mapping already exists" : "Esse mapeamento de registro já existe",
    "\"From\" and \"To\" cannot be the same" : "\"De\" e \"Para\" não podem ser iguais",
    "Docker registry mapping added" : "Adicionado o mapeamento do registro do Docker",
    "Error adding Docker registry mapping" : "Erro ao adicionar o mapeamento do registro do Docker",
    "Docker registry mapping removed" : "Removido o mapeamento do registro do Docker",
    "Error removing Docker registry mapping" : "Erro ao remover o mapeamento do registro do Docker",
    "Override Docker registries" : "Substituir os registros do Docker",
    "Configure Docker registry override mappings for the selected daemon." : "Configure os mapeamentos de substituição do registro Docker para o daemon selecionado.",
    "The matching source registry in ExApp info.xml will be overwritten during deployment (image pull step)." : "O registro de origem correspondente no ExApp info.xml será substituído durante a implantação (etapa do pull da imagem).",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "Isso é útil se você quiser usar um registro personalizado do Docker, por exemplo, para usar um registro privado do Docker ou para usar um registro diferente do Docker para testes.",
    "Image pull will be skipped" : "O image pull será pulado",
    "Remove" : "Remover",
    "No custom Docker registries are registered" : "Nenhum registro Docker personalizado está registrado",
    "Add registry override mapping" : "Adicionar mapeamento de substituição de registro",
    "From" : "De",
    "registry URL (e.g. ghcr.io)" : "URL do registro (p. ex., ghcr.io)",
    "To" : "Para",
    "registry URL (e.g. docker.io)" : "URL do registro (p. ex., docker.io)",
    "Add" : "Adicionar",
    "Hostname used by Nextcloud to access the ExApps" : "Nome do host usado pelo Nextcloud para acessar os ExApps",
    "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}." : "O nome do host (e porta) no qual o {name} está disponível. Não precisa ser um host público, apenas um host acessível pelo servidor Nextcloud, p. ex., {host}.",
    "The hostname (and port) or path at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server. It can also be the path to the Docker socket. (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "O nome do host (e porta) ou caminho em que o {name} está disponível. Não precisa ser um host público, apenas um host acessível pelo servidor Nextcloud. Também pode ser o caminho para o soquete Docker (p. ex., nextcloud-appapi-dsp:2375, /var/run/docker.sock).",
    "A daemon with this name already exists" : "Um daemon com este nome já existe",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "A chave secreta para a comunicação do contêiner HaRP (HP_SHARED_KEY).",
    "AppAPI Docker Socket Proxy authentication password" : "Senha de autenticação AppAPI Docker Socket Proxy",
    "Changes are only effective for newly installed ExApps. For existing ExApps, the Docker containers should be recreated to apply the new settings values." : "As alterações só entram em vigor para ExApps instalados posteriormente. Para ExApps existentes, os contêineres Docker devem ser recriados para aplicar os novos valores de configuração.",
    "The Docker network that the deployed ExApps will use." : "A rede Docker que os ExApps implantados usarão.",
    "The URL should start with http:// or https://" : "O URL deve começar com http:// ou https://",
    "For a HTTPS daemon, the Nextcloud URL should be HTTPS" : "Para um daemon HTTPS, o URL do Nextcloud deve ser HTTPS",
    "All available GPU devices on the daemon host need to be enabled in ExApp containers by Docker." : "Todos os dispositivos GPU disponíveis no host do daemon precisam ser habilitados nos contêineres ExApp pelo Docker.",
    "DaemonConfig successfully registered" : "DaemonConfig registrado com sucesso",
    "Failed to register DaemonConfig. Check the logs" : "Falha ao registrar o DaemonConfig. Verifique os logs.",
    "DaemonConfig successfully updated" : "DaemonConfig atualizado com sucesso",
    "Failed to update DaemonConfig. Check the logs" : "Falha ao atualizar o DaemonConfig. Verifique os logs",
    "Failed to connect to Daemon. Check the logs" : "Falha ao conectar ao Daemon. Verifique os logs.",
    "Failed to check connection to Daemon. Check the logs" : "Falha ao verificar a conexão com o Daemon. Verifique os logs.",
    "Edit the deploy daemon" : "Editar o deploy daemon",
    "Register a new deploy daemon" : "Registrar um novo deploy daemon",
    "Daemon configuration template" : "Modelo de configuração do daemon",
    "Select a daemon configuration template" : "Selecione um modelo de configuração de daemon",
    "Daemon registration form" : "Formulário de registro do Daemon",
    "Unique deploy daemon name" : "Nome exclusivo do deploy daemon",
    "Unique deploy Daemon name" : "Nome exclusivo do Deploy daemon",
    "Display name" : "Nome de exibição",
    "Deployment method" : "Método de implantação",
    "Select the daemon deploy method" : "Selecione o método de implantação do daemon",
    "HaRP host" : "Host HaRP",
    "Daemon host" : "Host do daemon",
    "HaRP shared key" : "Chave compartilhada HaRP",
    "The password must be at least 12 characters long" : "A senha deve ter pelo menos 12 caracteres",
    "Set this daemon as the default one" : "Definir este daemon como padrão",
    "Set as the default daemon" : "Definir como daemon padrão",
    "Enable HTTPS" : "Ativar HTTPS",
    "Show deploy options" : "Mostrar opções de implantação",
    "Hide deploy options" : "Ocultar opções de implantação",
    "Enable HaRP" : "Ativar HaRP",
    "FRP server address" : "Endereço do servidor FRP",
    "The address (host:port) of the FRP server that should be reachable by the ExApp in the network defined in the 'Docker network' section." : "O endereço (host:porta) do servidor FRP que deve estar acessível pelo ExApp na rede definida na seção 'Rede Docker'.",
    "Docker socket proxy port" : "Porta de proxy de soquete de Docker",
    "The port in HaRP which the Docker socket proxy connects to. This should be exposed but for the in-built one, it is not required to be exposed or changed." : "A porta no HaRP à qual o proxy do soquete Docker se conecta. Ela deve ser exposta, mas, no caso da porta embutida, não é necessário expô-la ou alterá-la.",
    "Disable FRP" : "Desativar FRP",
    "Flag for advanced setups only. Disables the FRP tunnel between ExApps and HaRP." : "Sinalizador apenas para configurações avançadas. Desativa o túnel FRP entre o ExApps e o HaRP.",
    "Docker network for ex-app deployment must be defined" : "A rede de Docker para implantação de ex-app deve ser definida",
    "Compute device" : "Dispositivo de computação",
    "Memory limit (in MiB)" : "Limite de memória (em MiB)",
    "Must be a positive integer" : "Deve ser um número inteiro positivo",
    "Maximum amount of memory that the ExApp container can use in mebibytes" : "Quantidade máxima de memória que o contêiner ExApp pode usar em mebibytes",
    "CPU limit as decimal value" : "Limite da CPU como valor decimal",
    "Must be a positive number" : "Deve ser um número positivo",
    "Maximum number of CPU cores that the ExApp container can use (e.g. 0.5 for half a core, 2 for two cores)" : "Número máximo de núcleos de CPU que o contêiner ExApp pode usar (p. ex., 0.5 para meio núcleo, 2 para dois núcleos)",
    "Add additional option" : "Adicionar opção adicional",
    "Option key (unique)" : "Chave da opção (exclusiva)",
    "Option key (unique, e.g. my_key)" : "Chave da opção (exclusiva, p. ex., my_key)",
    "Option key is required" : "A chave da opção é obrigatória",
    "Option value" : "Valor da opção",
    "Option value is required" : "O valor da opção é obrigatório",
    "Confirm" : "Confirmar",
    "Save" : "Salvar",
    "Register" : "Registrar",
    "External Apps" : "Aplicativos Externos",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Impulsione seu Nextcloud com o AppAPI e seus aplicativos especialmente projetados.\n\n\nO AppAPI é um projeto dentro do ecossistema Nextcloud desenvolvido para simplificar e aprimorar o processo de\ndesenvolvimento, implementação e gerenciamento de aplicativos.\n\nEle introduz uma nova metodologia que permite que os desenvolvedores criem\naplicativos usando uma variedade de linguagens de programação, não se limitando ao PHP, que era tradicionalmente usado no desenvolvimento do Nextcloud.\n\n### Aplicativo incluído no pacote\n\n**A partir do Nextcloud 30.0.1, este aplicativo está incluído no pacote padrão do Nextcloud.**\n\n### Suporte\n\nAgradecemos qualquer apoio a este projeto:\n\n- ⭐ Dê uma estrela ao nosso trabalho no GitHub\n- ❗ Crie um problema ou uma solicitação de recurso\n- 💁 Resolva um problema e crie uma solicitação pull\n- 🧑‍💻 Desenvolva seu próprio aplicativo usando o AppAPI\n\nEstamos genuinamente entusiasmados com o futuro do projeto AppAPI e seu potencial para transformar\na forma como os aplicativos são desenvolvidos e experimentados no Nextcloud.\n\nAo embarcarmos nesta jornada, convidamos vocês - desenvolvedores, pensadores, criadores e visionários -\npara se juntar a nós na criação de um cenário de aplicativos mais versátil, estável e seguro.\n\n*Suas percepções, sugestões e contribuições são inestimáveis para nós.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "O Projeto AppAPI é uma iniciativa empolgante que tem como objetivo revolucionar a forma como os aplicativos são desenvolvidos para o Nextcloud.",
    "Deploy Daemons" : "Deploy Daemons",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemon (DaemonConfig) é um daemon de orquestração de ExApps",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemons. Deploy Daemon (DaemonConfig) é um daemon de orquestração de ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "O Deploy Daemon padrão não está acessível. Por favor, verifique sua configuração.",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Especifique a política de reinicialização do contêiner, p. ex., 'sempre' para garantir que o ExApp seja executado após a reinicialização do servidor daemon",
    "This settings changes are reflected only for newly created containers" : "Estas alterações nas configurações são refletidas apenas para contêineres recém-criados",
    "{license}-licensed" : "Licenciado por {license}",
    "Update to {version}" : "Atualizar para {version}",
    "Delete data on remove" : "Excluir dados ao remover",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Este aplicativo não tem uma versão mínima do Nextcloud atribuída. Isso será um erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Este aplicativo não tem uma versão máxima do Nextcloud atribuída. Isso será um erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Este aplicativo não pode ser instalado porque as seguintes dependências não foram atendidas:",
    "View in store" : "Ver na loja",
    "Visit website" : "Visitar site",
    "Report a bug" : "Relatar um problema",
    "User documentation" : "Documentação do usuário",
    "Admin documentation" : "Documentação do administrador",
    "Developer documentation" : "Documentação do desenvolvedor",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Este aplicativo não está registrado na Loja de Aplicativos. Nenhuma informação extra disponível. Somente ações de ativar/desativar e remover são permitidas.",
    "This app is supported via your current Nextcloud subscription." : "Este aplicativo é suportado por sua assinatura atual do Nextcloud.",
    "Supported" : "Suportado",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Os aplicativos em destaque são desenvolvidos pela comunidade. Eles oferecem funcionalidade central e estão prontos para uso em produção.",
    "Featured" : "Destaques",
    "Update to {update}" : "Atualizar para {update}",
    "All ExApps are up-to-date." : "Todos os ExApps estão na versão mais recente.",
    "Default Deploy daemon is not accessible" : "O Deploy daemon padrão não está acessível",
    "Icon" : "Ícone",
    "Version" : "Versão",
    "Daemon" : "Daemon",
    "Level" : "Nível",
    "Actions" : "Ações",
    "Results from other categories" : "Resultados de outras categorias",
    "No apps found" : "Nenhum aplicativo encontrado",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp tem uma atualização disponível.","%n aplicativos têm uma atualização disponível","%n aplicativos têm uma atualização disponível"],
    "_Update_::_Update all_" : ["Atualizar","Atualizar todos","Atualizar todos"],
    "Deploy Daemon" : "Deploy Daemon",
    "Type" : "Tipo",
    "Display Name" : "Nome de Exibição",
    "GPUs support" : "Suporte a GPUs",
    "Are you sure you want delete Deploy Daemon" : "Tem certeza de que deseja excluir o Deploy Daemon",
    "All ExApps on this daemon will be removed" : "Todos os ExApps neste daemon serão removidos",
    "All ExApps installed on this daemon will be removed" : "Todos os ExApps instalados neste daemon serão removidos",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "O Deploy Daemon \"manual-install\" (instalação manual) não pode ser definido como padrão",
    "Failed to save admin options. Check the logs" : "Falha ao salvar as opções do administrador. Verifique os logs.",
    "Deploy daemon config details" : "Detalhes da configuração do Deploy daemon",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "O daemon de instalação manual é geralmente usado para desenvolvimento. Não pode ser definido como daemon padrão.",
    "Deploy config" : "Configuração de implantação",
    "Verify connection" : "Verificar conexão",
    "No Deploy daemons configured" : "Nenhum Deploy daemon configurado",
    "Register a custom one or setup from available templates" : "Registre um personalizado ou configure a partir dos modelos disponíveis",
    "Register Daemon" : "Registrar Daemon",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI tentará instalar o esqueleto pequeno do ExApp para verificar se o Daemon está configurado corretamente e se as etapas de implantação estão funcionando.",
    "The following Deploy test checks must be passed to succeed:" : "As seguintes verificações de teste de implantação devem ser concluídas para sucesso:",
    "More info" : "Mais informações",
    "Remove test ExApp" : "Remover ExApp de teste",
    "Start Deploy test" : "Iniciar teste de Implantação",
    "Stop Deploy test" : "Parar teste de Implantação",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp está desregistrado e o contêiner é removido em \"Parar teste de implantação\"",
    "Hostname to access ExApps" : "Nome do host para acessar ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nome do host ou caminho para acessar o daemon do Docker (p. ex., nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Daemon com este nome já existe",
    "Password must be at least 12 characters long" : "A senha deve ter pelo menos 12 caracteres",
    "With https enabled network is set to host" : "Com https habilitado, a rede é definida como host",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "As alterações seriam aplicadas somente para ExApps recém-instalados. Para ExApps existentes, os contêineres Docker devem ser recriados.",
    "URL should start with http:// or https://" : "O URL deve começar com http:// ou https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Para o daemon HTTPS, o URL do Nextcloud deve ser HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Todos os dispositivos GPU disponíveis no host do daemon serão solicitados a serem habilitados em contêineres ExApp pelo Docker.",
    "Edit Deploy Daemon" : "Editar Deploy Daemon",
    "Register Deploy Daemon" : "Registrar Deploy Daemon",
    "Select daemon configuration template" : "Selecione o modelo de configuração do daemon",
    "Unique Deploy Daemon Name" : "Nome Exclusivo do Deploy Daemon",
    "Select daemon deploy method" : "Selecione o método de implantação do daemon",
    "Set daemon as default" : "Definir daemon como padrão",
    "Set as default daemon" : "Definir como daemon padrão",
    "Enable https" : "Ativar https",
    "Show deploy config" : "Mostrar configuração de deploy",
    "Hide deploy config" : "Ocultar configuração de deploy",
    "Network" : "Rede",
    "Docker network name" : "Nome da rede do Docker",
    "Additional option" : "Opção adicional",
    "by {author}\n{license}" : "por {author}\n{license}",
    "Your apps" : "Seus aplicativos",
    "Documentation" : "Documentação",
    "Details" : "Detalhes",
    "Changelog" : "Registro de alterações",
    "Active apps" : "Aplicativos ativados",
    "Disabled apps" : "Aplicativos desativados",
    "Updates" : "Atualizações",
    "Featured apps" : "Aplicativos em destaque",
    "Supported apps" : "Aplicativos compatíveis",
    "manual-install apps cannot be updated" : "aplicativos de instalação manual não podem ser atualizados",
    "{progress}% Deploying" : "{progress}% Implantando",
    "{progress}% Initializing" : "{progress}% Inicializando",
    "Healthchecking" : "Verificação de saúde",
    "Deploy and Enable" : "Implantar e Ativar",
    "Enable" : "Ativar",
    "Disable" : "Desativar",
    "Allow untested app" : "Permitir aplicativo não testado",
    "Default Deploy daemon is not accessible. Please verify configuration" : "O Deploy daemon padrão não está acessível. Por favor, verifique a configuração.",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "O aplicativo será baixado da Loja de Aplicativos e implantado no Deploy Daemon padrão.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Este aplicativo não está marcado como compatível com sua versão do Nextcloud. Se você continuar, ainda poderá instalar o aplicativo. Observe que o aplicativo poderá não funcionar como esperado.",
    "Your ExApps" : "Seus ExApps",
    "An error occurred during the request. Unable to proceed." : "Ocorreu um erro durante a solicitação. Não foi possível prosseguir.",
    "The app has been enabled but needs to be updated." : "O aplicativo foi ativado, mas precisa ser atualizado.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erro: Este aplicativo não pode ser ativado porque torna o servidor instável.",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Impulsione seu Nextcloud com o AppAPI e seus aplicativos especialmente projetados.\n\n\nO AppAPI é um projeto dentro do ecossistema Nextcloud desenvolvido para simplificar e aprimorar o processo de\ndesenvolvimento, implementação e gerenciamento de aplicativos.\n\nEle introduz uma nova metodologia que permite que os desenvolvedores criem\naplicativos usando uma variedade de linguagens de programação, não se limitando ao PHP, que era tradicionalmente usado no desenvolvimento do Nextcloud.\n\n\n### Lista de aplicativos que requerem o AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Se você deseja desenvolver um aplicativo, teremos prazer em ajudá-lo e auxiliá-lo._\n\n### Suporte\n\nAgradecemos qualquer apoio a este projeto:\n\n- ⭐ Dê uma estrela ao nosso trabalho no GitHub\n- ❗ Crie um problema ou uma solicitação de recurso\n- 💁 Resolva um problema e crie uma solicitação pull\n- 🧑‍💻 Desenvolva seu próprio aplicativo usando o AppAPI\n\nEstamos genuinamente entusiasmados com o futuro do projeto AppAPI e seu potencial para transformar\na forma como os aplicativos são desenvolvidos e experimentados no Nextcloud.\n\nAo embarcarmos nesta jornada, convidamos vocês - desenvolvedores, pensadores, criadores e visionários -\npara se juntar a nós na criação de um cenário de aplicativos mais versátil, estável e seguro.\n\n*Suas percepções, sugestões e contribuições são inestimáveis para nós.*"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
