import{d as i}from"./preload-helper-DadE4qT2.chunk.mjs";const r=i({name:"FilesByMonthMixin",computed:{fileIdsByMonth(){const t={};for(const s of this.fetchedFileIds){const e=this.files[s];e&&(t[e.attributes.month]=t[e.attributes.month]??[],t[e.attributes.month].push(e.fileid))}return Object.keys(t).forEach(s=>t[s].sort(this.sortFilesByTimestamp)),t},monthsList(){return Object.keys(this.fileIdsByMonth).sort((t,s)=>t>s?-1:1)}},methods:{sortFilesByTimestamp(t,s){return this.files[t].attributes.timestamp>this.files[s].attributes.timestamp?-1:1}}});export{r as F};
//# sourceMappingURL=FilesByMonthMixin-BLjMI05j.chunk.mjs.map
