OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "Notifications" : "Meldingar",
    "Dismiss" : "Forkast",
    "in {path}" : "i {spor}",
    "Never" : "Aldri",
    "Your settings have been updated." : "Innstillingane dine har blitt oppdaterte.",
    "None" : "Ingen",
    "You need to set up your email address before you can receive notification emails." : "Du må skriva inn e-postadressa di før du kan få e-postvarsel."
},
"nplurals=2; plural=(n != 1);");
