import{g as f}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as g}from"./python-repl-BtwP6BTX.chunk.mjs";function c(e,a){for(var n=0;n<a.length;n++){const t=a[n];if(typeof t!="string"&&!Array.isArray(t)){for(const r in t)if(r!=="default"&&!(r in e)){const o=Object.getOwnPropertyDescriptor(t,r);o&&Object.defineProperty(e,r,o.get?o:{enumerable:!0,get:()=>t[r]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var i,s;function p(){if(s)return i;s=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/python-repl" instead of "highlight.js/lib/languages/python-repl.js"'))}return e(),i=g(),i}var l=p();const u=f(l),y=c({__proto__:null,default:u},[l]);export{y as p};
//# sourceMappingURL=python-repl.js-D2nE_2eV.chunk.mjs.map
