OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Версии",
    "This application automatically maintains older versions of files that are changed." : "Това приложение автоматично поддържа по-стари версии на файлове, които са променени.",
    "Current version" : "Текуща версия",
    "You" : "Вие",
    "Name this version" : "Наименуване на тази версия",
    "Edit version name" : "Редактиране на името на версия",
    "Restore version" : "Възстановяване на версия",
    "Download version" : "Изтегляне на версия",
    "Delete version" : "Изтриване на версия",
    "Cancel" : "Отказ",
    "Remove version name" : "Премахване на име на версия",
    "Save version name" : "Записване на име на версия",
    "Version name" : "Име на версия",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Именуваните версии се запазват и се изключват от автоматичните почиствания, когато квотата за хранилище е пълна.",
    "Initial version restored" : "Възстановяване на първоначалната версия",
    "Version restored" : "Версията е възстановена",
    "Could not restore version" : "Версията не можа да се възстанови",
    "Could not delete version" : "Версията не можа да се изтрие"
},
"nplurals=2; plural=(n != 1);");
