OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Berbagi dengan {email}",
    "Shared with {email} by {actor}" : "Berbagi dengan {email} oleh {actor}",
    "Unshared from {email}" : "Berhenti membagikan dari {email}",
    "Unshared from {email} by {actor}" : "Berhenti membagikan dari {email} oleh {actor}",
    "Password for mail share sent to {email}" : "Kata sandi untuk berbagi melalui email dikirim ke {email}",
    "Password for mail share sent to you" : "Kata sandi untuk berbagi melalui email dikirim kepada Anda",
    "You shared {file} with {email} by mail" : "Anda membagikan {file} dengan {email} lewat email",
    "{actor} shared {file} with {email} by mail" : "{actor} membagikan {file} dengan {email} lewat email",
    "You unshared {file} from {email} by mail" : "Anda berhenti membagikan {file} dari {email} melalui email",
    "{actor} unshared {file} from {email} by mail" : "{actor} berhenti membagikan {file} dari {email} melalui email",
    "Password to access {file} was sent to {email}" : "Kata sandi untuk mengakses {file} telah dikirim ke {email}",
    "Password to access {file} was sent to you" : "Kata sandi untuk mengakses {file} telah dikirim kepada Anda",
    "Share by mail" : "Berbagi melalui email",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Berbagi %1$s gagal, karena item ini sudah dibagikan dengan akun %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Kami tidak dapat mengirimkan kepada Anda kata sandi yang dibuat otomatis. Harap tetapkan alamat email yang valid di pengaturan pribadi Anda dan coba lagi.",
    "Failed to send share by email. Got an invalid email address" : "Gagal mengirim berbagi melalui email. Mendapatkan alamat email yang tidak valid",
    "Failed to send share by email" : "Gagal mengirim berbagi melalui email",
    "%1$s shared %2$s with you" : "%1$s membagikan %2$s kepada Anda",
    "Note:" : "Catatan:",
    "This share is valid until %s at midnight" : "Berbagi ini berlaku hingga %s pada tengah malam",
    "Expiration:" : "Kedaluwarsa:",
    "%1$s via %2$s" : "%1$s melalui %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s membagikan %2$s kepada Anda. Anda seharusnya sudah menerima email terpisah dengan tautan untuk mengaksesnya.",
    "Password to access %1$s shared to you by %2$s" : "Kata sandi untuk mengakses %1$s yang dibagikan kepada Anda oleh %2$s",
    "Password to access %s" : "Kata sandi untuk mengakses %s",
    "It is protected with the following password:" : "Item tersebut dilindungi dengan kata sandi berikut:",
    "This password will expire at %s" : "Kata sandi ini akan kedaluwarsa pada %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s membagikan %2$s kepada Anda dan ingin menambahkan:",
    "%1$s shared %2$s with you and wants to add" : "%1$s membagikan %2$s kepada Anda dan ingin menambahkan",
    "%s added a note to a file shared with you" : "%s menambahkan catatan pada file yang dibagikan kepada Anda",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Anda baru saja membagikan %1$s kepada %2$s. Berbagi tersebut sudah dikirim kepada penerima. Karena kebijakan keamanan yang ditetapkan oleh administrator %3$s, setiap berbagi harus dilindungi dengan kata sandi dan tidak diperbolehkan mengirimkan kata sandi secara langsung kepada penerima. Oleh karena itu Anda perlu meneruskan kata sandi tersebut secara manual kepada penerima.",
    "Password to access %1$s shared by you with %2$s" : "Kata sandi untuk mengakses %1$s yang Anda bagikan kepada %2$s",
    "This is the password:" : "Ini kata sandinya:",
    "You can choose a different password at any time in the share dialog." : "Anda dapat memilih kata sandi yang berbeda kapan saja di dialog berbagi.",
    "Could not find share" : "Tidak menemukan berbagi",
    "Share provider which allows you to share files by mail" : "Penyedia berbagi yang memungkinkan Anda membagikan file melalui email",
    "Unable to update share by mail config" : "Tidak dapat memperbarui konfigurasi berbagi melalui email",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Memungkinkan orang membagikan tautan yang dipersonalisasi ke file atau folder dengan memasukkan alamat email.",
    "Send password by mail" : "Kirim kata sandi melalui email",
    "Reply to initiator" : "Balas kepada penginisiasi"
},
"nplurals=1; plural=0;");
