<?php

declare(strict_types=1);

namespace WoltLab\WebpExif\Exception;

use Throwable;

/**
 * Every exception triggered by the webp-exif component MUST implement this interface.
 *
 * @author      Alexander Ebert
 * @copyright   2025 WoltLab GmbH
 * @license     The MIT License <https://opensource.org/license/mit>
 */
interface WebpExifException extends Throwable {}
