import{a,F as r,b as i}from"./FaceCover-JWnrrp4x.chunk.mjs";import{n}from"./icons-CFZwNZD8.chunk.mjs";const c={name:"FaceMergeForm",components:{FaceCover:i},mixins:[a,r],props:{firstFace:{type:String,required:!0}},data(){return{loading:!1}},computed:{files(){return this.$store.state.files.files},faces(){return this.$store.state.faces.faces},facesFiles(){return this.$store.getters.facesFiles},filteredFaces(){return Object.values(this.faces).filter(e=>e.basename!==this.firstFace).sort((e,s)=>e.attributes.nbItems&&s.attributes.nbItems?s.attributes.nbItems-e.attributes.nbItems:!this.facesFiles[s.basename]||!this.facesFiles[e.basename]?0:this.facesFiles[s.basename].length-this.facesFiles[e.basename].length)}},methods:{handleSelect(e){this.$emit("select",e),this.loading=!0}}};var l=function(){var e=this,s=e._self._c;return s("div",{staticClass:"merge-form face-list"},e._l(e.filteredFaces,function(t){return s("FaceCover",{key:t.basename,attrs:{"base-name":t.basename,small:""},on:{click:function(m){return e.handleSelect(t.basename)}}})}),1)},o=[],f=n(c,l,o,!1,null,"b48e014f");const h=f.exports;export{h as F};
//# sourceMappingURL=FaceMergeForm-VGyH05ZM.chunk.mjs.map
