OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU мэдээлэл боломжгүй",
    "CPU Usage:" : "CPU ашиглалт:",
    "Load average: {percentage} % ({load}) last minute" : "Дундаж ачаалал: {percentage} % ({load}) сүүлийн минут",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) сүүлийн 1 минут\n{last5MinutesPercentage} % ({last5Minutes}) сүүлийн 5 минут\n{last15MinutesPercentage} % ({last15Minutes}) сүүлийн 15 минут",
    "RAM Usage:" : "RAM ашиглалт:",
    "SWAP Usage:" : "SWAP ашиглалт:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Нийт: {memTotalBytes}/Одоогийн ашиглалт: {memUsageBytes}",
    "RAM info not available" : "RAM мэдээлэл боломжгүй",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Нийт: {swapTotalBytes}/Одоогийн ашиглалт: {swapUsageBytes}",
    "SWAP info not available" : "SWAP мэдээлэл боломжгүй",
    "Copied!" : "Хуулсан!",
    "Not supported!" : "Дэмжигдэхгүй",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "Unknown" : "Үл танигдах зүйл",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d өдөр, %2$d цаг, %3$d минут, %4$d секунд",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d цаг, %2$d минут, %3$d секунд",
    "System" : "сисмем",
    "Monitoring" : "Хяналт",
    "Monitoring app with useful server information" : "Ашигтай серверийн мэдээлэл бүхий хяналтын апп",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU-ийн ачаалал, RAM-ийн хэрэглээ, дискний хэрэглээ, хэрэглэгчдийн тоо гэх мэт серверийн хэрэгтэй мэдээллийг харуулдаг.",
    "Operating System:" : "Үйлдлийн систем:",
    "CPU:" : "CPU:",
    "threads" : "thread-ууд",
    "Memory:" : "Санах ой:",
    "Server time:" : "Серверийн цаг:",
    "Uptime:" : "Ажилласан хугацаа:",
    "Temperature" : "Температур",
    "Load" : "Ачаалал",
    "Memory" : "Санах ой",
    "Disk" : "Диск",
    "Mount:" : "Холболт:",
    "Filesystem:" : "Файлын систем:",
    "Size:" : "Хэмжээ:",
    "Available:" : "Боломжтой:",
    "Used:" : "Ашигласан:",
    "Files:" : "Файлууд:",
    "Storages:" : "Санах ойнууд:",
    "Free Space:" : "Чөлөөт зай:",
    "Network" : "Сүлжээ",
    "Hostname:" : "Хостын нэр:",
    "Gateway:" : "Гарц:",
    "Status:" : "Төлөв:",
    "Speed:" : "Хурд:",
    "Duplex:" : "Дуплекс:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Идэвхтэй хэрэглэгчид",
    "Last hour" : "Сүүлийн цаг",
    "%s%% of all users" : "Бүх хэрэглэгчдийн %s%%",
    "Last 24 Hours" : "Сүүлийн 24 цаг",
    "Last 7 Days" : "Сүүлийн 7 өдөр",
    "Last 30 Days" : "Сүүлийн 30 өдөр",
    "Shares" : "Түгээлтүүд",
    "Users:" : "Хэрэглэгчид:",
    "Groups:" : "Бүлгүүд:",
    "Links:" : "Холбоосууд:",
    "Emails:" : "Имэйлүүд:",
    "Federated sent:" : "Холбогдсон илгээсэн:",
    "Federated received:" : "Холбогдсон хүлээн авсан:",
    "Talk conversations:" : "Talk яриа:",
    "PHP" : "PHP",
    "Version:" : "Хувилбар:",
    "Memory limit:" : "Санах ойн хязгаар:",
    "MB" : "МБ",
    "Max execution time:" : "Хамгийн их гүйцэтгэх хугацаа:",
    "seconds" : "секунд",
    "Upload max size:" : "Байршуулах дээд хэмжээ:",
    "OPcache Revalidate Frequency:" : "OPcache дахин баталгаажуулах давтамж:",
    "Extensions:" : "Өргөтгөлүүд:",
    "Unable to list extensions" : "Өргөтгөлүүдийг жагсааж чадсангүй",
    "PHP Info:" : "PHP мэдээлэл:",
    "Show phpinfo" : "phpinfo харуулах",
    "FPM worker pool" : "FPM ажилчдын сан",
    "Pool name:" : "Сангийн нэр:",
    "Pool type:" : "Сангийн төрөл:",
    "Start time:" : "Эхлэх цаг:",
    "Accepted connections:" : "Хүлээн авсан холболтууд:",
    "Total processes:" : "Нийт процессууд:",
    "Active processes:" : "Идэвхтэй процессууд:",
    "Idle processes:" : "Сул процессууд:",
    "Listen queue:" : "Сонсох дараалал:",
    "Slow requests:" : "Удаан хүсэлтүүд:",
    "Max listen queue:" : "Сонсох дарааллын дээд хэмжээ:",
    "Max active processes:" : "Идэвхтэй процессуудын дээд хэмжээ:",
    "Max children reached:" : "Дээд хүүхдүүдэд хүрсэн:",
    "Database" : "Өгөгдлийн сан",
    "Type:" : "Төрөл:",
    "External monitoring tool" : "Гадаад хяналтын хэрэгсэл",
    "Use this end point to connect an external monitoring tool:" : "Гадаад хяналтын хэрэгсэл холбоход энэ төгсгөлийн цэгийг ашиглана уу:",
    "Copy" : "Хуулах",
    "Output in JSON" : "JSON гаралт",
    "Skip apps section (including apps section will send an external request to the app store)" : "Аппуудын хэсгийг алгасах (аппуудын хэсгийг оруулахад апп дэлгүүр рүү гадаад хүсэлт илгээнэ)",
    "Skip server update" : "Серверийн шинэчлэлтийг алгасах",
    "To use an access token, please generate one then set it using the following command:" : "Хандалтын токен ашиглахын тулд эхлээд токен үүсгэж, дараахь командын тусламжтайгаар тохируулна уу:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Дараа нь дээрх URL-д хүсэлт илгээхдээ токеноо \"NC-Token\" толгойн мэдээллээр дамжуулна уу."
},
"nplurals=2; plural=(n != 1);");
