OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendár",
    "Tasks" : "Úlohy",
    "Personal" : "Osobné",
    "{actor} created calendar {calendar}" : "[actor] vytvoril kalendár [calendar]",
    "You created calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
    "{actor} deleted calendar {calendar}" : "[actor] zmazal kalendár [calendar]",
    "You deleted calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
    "{actor} updated calendar {calendar}" : "[actor] upravil kalendár [calendar]",
    "You updated calendar {calendar}" : "Upravili ste kalendár {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} obnovil kalendár {calendar}",
    "You restored calendar {calendar}" : "Obnovili ste kalendár {calendar}",
    "You shared calendar {calendar} as public link" : "Sprístupnili ste kalendár {calendar}  ako verejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstránili ste verejný odkaz pre kalendár {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} vám sprístupnil kalendár {calendar}",
    "You shared calendar {calendar} with {user}" : "Sprístupnili ste kalendár {calendar} s {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} sprístupnil kalendár {calendar} s {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} vám prestal sprístupňovať kalendár {calendar}",
    "You unshared calendar {calendar} from {user}" : "Prestali ste sprístupňovať kalendár {calendar} od používateľa {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zrušil zdieľanie kalendára {calendar} s používateľom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zrušil zdieľanie kalendára {calendar} so sebou samým",
    "You shared calendar {calendar} with group {group}" : "Sprístupnili ste kalendár {calendar} so skupinou {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} vyzdieľal kalendár {calendar} so skupinou {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili ste zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  zrušil zdieľanie kalendára {calendar} so skupinou {group}",
    "Untitled event" : "Udalosť bez názvu",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvoril udalosť {event} v kalendári {calendar}",
    "You created event {event} in calendar {calendar}" : "Vytvorili ste udalosť {event} v kalendári {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} zmazal udalosť {event} from z kalendára {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Zmazali ste udalosť {event} z kalendára {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}  aktualizoval udalosť {event} v kalendári {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizovali ste udalosť {event} v kalendári {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} presunul udalosť {event} z kalendára {sourceCalendar} do kalendára {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Presunuli ste udalosť {event} z kalendára {sourceCalendar} do kalendára {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} obnovil udalosť {event} v kalendári {calendar}",
    "You restored event {event} of calendar {calendar}" : "Obnovili ste udalosť {event} v kalendári {calendar}",
    "Busy" : "Zaneprázdnený",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} vytvoril úlohu {todo} v zozname {calendar}",
    "You created to-do {todo} in list {calendar}" : "Vytvorili ste úlohu {todo} v zozname {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} zmazal úlohu {todo} zo zoznamu {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Zmazali ste úlohu {todo} zo zoznamu {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} upravil úlohu {todo} v zozname {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Upravili ste úlohu {todo} v zozname {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} vyriešil úlohu {todo} v zozname {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Vyriešili ste úlohu {todo} v zozname {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} znovu otvoril úlohu {todo} v zozname {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Otvorili ste znovu úlohu {todo} v zozname {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} presunul udalosť {todo} zo zoznamu {sourceCalendar} do zoznamu {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Presunuli ste udalosť {todo} zo zoznamu {sourceCalendar} do zoznamu {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalendár, kontakty a úlohy",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendár</strong> bol upravený",
    "A calendar <strong>event</strong> was modified" : "<strong>Udalosť</strong> v kalendári bola upravená",
    "A calendar <strong>to-do</strong> was modified" : "Kalendár <strong>úloh</strong> bol upravený",
    "Contact birthdays" : "Narodeniny kontaktu",
    "Death of %s" : "Dátum úmrtia %s",
    "Untitled calendar" : "Kalendár bez názvu",
    "Calendar:" : "Kalendár:",
    "Date:" : "Dátum:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "_%n year_::_%n years_" : ["%n rokov","%n rokov","%n rokov","%n rokov"],
    "_%n month_::_%n months_" : ["%n mesiac","%n mesiace","%n mesiacov","%n mesiacov"],
    "_%n day_::_%n days_" : ["%n deň","%n dni","%n dní","%n dní"],
    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodín","%n hodín"],
    "_%n minute_::_%n minutes_" : ["%n minúta","%n minúty","%n minút","%n minút"],
    "%s (in %s)" : "%s (v %s)",
    "%s (%s ago)" : "%s (pred %s)",
    "Calendar: %s" : "Kalendár: %s",
    "Date: %s" : "Dátum: %s",
    "Description: %s" : "Popis: %s",
    "Where: %s" : "Kde: %s",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "In the past on %1$s for the entire day" : "V minulosti %1$s na celý deň",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Za %n minútu %1$s na celý deň","Za %n minúty %1$s na celý deň","Za %n minút %1$s na celý deň","Za %n minút %1$s na celý deň"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Za %n hodinu %1$s na celý deň","Za %n hodiny %1$s na celý deň","Za %n hodín %1$s na celý deň","Za %n hodín %1$s na celý deň"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Za %n deň %1$s na celý deň","Za %n dni %1$s na celý deň","Za %n dní %1$s na celý deň","Za %n dní %1$s na celý deň"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Za %n týždeň %1$s na celý deň","Za %n týždne %1$s na celý deň","Za %n týždňov %1$s na celý deň","Za %n týždňov %1$s na celý deň"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Za %n mesiac %1$s na celý deň","Za %n mesiace %1$s na celý deň","Za %n mesiacov %1$s na celý deň","Za %n mesiacov %1$s na celý deň"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Za %n rok %1$s na celý deň","Za %n roky %1$s na celý deň","Za %n rokov %1$s na celý deň","Za %n rokov %1$s na celý deň"],
    "In the past on %1$s between %2$s - %3$s" : "V minulosti %1$s medzi %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Za %n minútu %1$s %2$s medzi %2$s - %3$s","Za %n minúty %1$s %2$s medzi %2$s - %3$s","Za %n minút %1$s %2$s medzi %2$s - %3$s","Za %n minút %1$s %2$s medzi %2$s - %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Za %n hodinu %1$s %2$s medzi %2$s - %3$s","Za %n hodiny %1$s %2$s medzi %2$s - %3$s","Za %n hodín %1$s %2$s medzi %2$s - %3$s","Za %n hodín %1$s %2$s medzi %2$s - %3$s"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Za %n deň %1$s %2$s medzi %2$s - %3$s","Za %n dni %1$s %2$s medzi %2$s - %3$s","Za %n dní %1$s %2$s medzi %2$s - %3$s","Za %n dní %1$s %2$s medzi %2$s - %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Za %n týždeň %1$s %2$s medzi %2$s - %3$s","Za %n týždne %1$s %2$s medzi %2$s - %3$s","Za %n týždňov %1$s %2$s medzi %2$s - %3$s","Za %n týždňov %1$s %2$s medzi %2$s - %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Za %n mesiac %1$s %2$s medzi %2$s - %3$s","Za %n mesiace %1$s %2$s medzi %2$s - %3$s","Za %n mesiacov %1$s %2$s medzi %2$s - %3$s","Za %n mesiacov %1$s %2$s medzi %2$s - %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Za %n rok %1$s %2$s medzi %2$s - %3$s","Za %n roky %1$s %2$s medzi %2$s - %3$s","Za %n rokov %1$s %2$s medzi %2$s - %3$s","Za %n rokov %1$s %2$s medzi %2$s - %3$s"],
    "Could not generate when statement" : "Nepodarilo sa vygenerovať vyhlásenie kedy",
    "Every Day for the entire day" : "Každý deň, na celý deň",
    "Every Day for the entire day until %1$s" : "Každý deň, na celý deň, do %1$s",
    "Every Day between %1$s - %2$s" : "Každý deň medzi %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Každý deň medzi %1$s - %2$s do %3$s",
    "Every %1$d Days for the entire day" : "Každých %1$d dní, na celý deň",
    "Every %1$d Days for the entire day until %2$s" : "Každých %1$d dní, na celý deň, do %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Každých %1$d dní, medzi %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Každých %1$d dní, medzi %2$s - %3$s do %4$s",
    "Could not generate event recurrence statement" : "Nepodarilo sa vygenerovať vyhlásenie o opakovaní udalosti",
    "Every Week on %1$s for the entire day" : "Každý týždeň %1$s na celý deň",
    "Every Week on %1$s for the entire day until %2$s" : "Každý týždeň %1$s na celý deň do %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Každý týždeň %1$s medzi %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Každý týždeň %1$s medzi %2$s - %3$s do %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Každých %1$d týždňov %2$s, na celý deň",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Každých %1$d týždňov od %2$s na celý deň do %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Každých %1$d týždňov od %2$s na celý deň medzi %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Každých %1$d týždňov od %2$s na celý deň medzi %3$s - %4$s do %5$s",
    "Every Month on the %1$s for the entire day" : "Každý mesiac od %1$s na celý deň",
    "Every Month on the %1$s for the entire day until %2$s" : "Každý mesiac od %1$s na celý deň do %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Každý mesiac od %1$s medzi %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Každý mesiac od %1$s medzi %2$s - %3$s do %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Každých %1$d mesiacov od %2$s na celý deň",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Každých %1$d mesiacov od %2$s na celý deň do %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Každých %1$d mesiacov od %2$s medzi %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Každých %1$d mesiacov od %2$s medzi %3$s - %4$s do %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Každý rok v %1$s od %2$s na celý deň",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Každý rok v %1$s od %2$s na celý deň do %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Každý rok v %1$s od %2$s medzi %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Každý rok v %1$s od %2$s medzi %3$s - %4$s do %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Každé %1$d roky v %2$s od %3$s na celý deň",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Každé %1$d roky v %2$s od %3$s na celý deň do %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Každé %1$d roky v %2$s od %3$s medzi %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Každé %1$d roky v %2$s od %3$s medzi %4$s - %5$s do %6$s",
    "On specific dates for the entire day until %1$s" : "V konkrétnych dátumoch na celý deň %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "V konkrétnych dátumoch medzi %1$s - %2$s do %3$s",
    "In the past on %1$s" : "V minulosti %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["Za %n minútu na %1$s","Za %n minúty na %1$s","Za %n minút na %1$s","Za %n minút na %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["Za %n hodinu na %1$s","Za %n hodiny na %1$s","Za %n hodín na %1$s","Za %n hodín na%1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["Za %n deň na %1$s","Za %n dni na %1$s","Za %n dní na %1$s","Za %n dní na %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["Za %n týždeň %1$s","Za %n týždne na %1$s","Za %n týždňov na %1$s","Za %n týždňov na %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["Za %n mesiac na%1$s","Za %n mesiace na%1$s","Za %n mesiacov na%1$s","Za %n mesiacov na %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["Za %n rok na %1$s","Za %n roky na %1$s","Za %n rokov na %1$s","Za %n rokov na %1$s"],
    "In the past on %1$s then on %2$s" : "V minulosti %1$s a potom %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Za %n minútu %1$s a potom %2$s","Za %n minúty %1$s a potom %2$s","Za %n minút %1$s a potom %2$s","Za %n minút %1$s a potom %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Za %n hodinu %1$s a potom %2$s","Za %n hodiny %1$s a potom %2$s","Za %n hodín %1$s a potom %2$s","Za %n hodín %1$s a potom %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Za %n deň %1$s a potom %2$s","Za %n dni %1$s a potom %2$s","Za %n dní %1$s a potom %2$s","Za %n dní %1$s a potom %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Za %n týždeň %1$s a potom %2$s","Za %n týždne %1$s a potom %2$s","Za %n týždňov %1$s a potom %2$s","Za %n týždňov %1$s a potom %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Za %n mesiac %1$s a potom %2$s","Za %n mesiace %1$s a potom %2$s","Za %n mesiacov %1$s a potom %2$s","Za %n mesiacov %1$s a potom %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Za %n rok %1$s a potom %2$s","Za %n roky %1$s a potom %2$s","Za %n rokov %1$s a potom %2$s","Za %n rokov %1$s a potom %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "V minulosti %1$s potom %2$s a %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Za %n minútu %1$s potom %2$s a %3$s","Za %n minúty %1$s potom %2$s a %3$s","Za %n minút %1$s potom %2$s a %3$s","Za %n minút %1$s potom %2$s a %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Za %n hodinu %1$s potom %2$s a %3$s","Za %n hodiny %1$s potom %2$s a %3$s","Za %n hodín %1$s potom %2$s a %3$s","Za %nhodín %1$s potom %2$s a %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Za %n deň %1$s potom %2$s a %3$s","Za %n dni %1$s potom %2$s a %3$s","Za %n dní %1$s potom %2$s a %3$s","Za %n dní %1$s potom %2$s a %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Za %n týždeň %1$s potom %2$s a %3$s","Za %n týždne %1$s potom %2$s a %3$s","Za %n týždňov %1$s potom %2$s a %3$s","Za %n týždňov %1$s potom %2$s a %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Za %n mesiac %1$s potom %2$s a %3$s","Za %n mesiace %1$s potom %2$s a %3$s","Za %n mesiacov %1$s potom %2$s a %3$s","Za %n mesiacov %1$s potom %2$s a %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Za %n rok %1$s potom %2$s a %3$s","Za %n roky %1$s potom %2$s a %3$s","Za %n rokov %1$s potom %2$s a %3$s","Za %n rokov %1$s potom %2$s a %3$s"],
    "Could not generate next recurrence statement" : "Nepodarilo sa vygenerovať ďalšie opakovanie",
    "Cancelled: %1$s" : "Zrušené: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" bolo zrušené",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s prijal/a vaše pozvanie",
    "%1$s has tentatively accepted your invitation" : "%1$s predbežne prijal vaše pozvanie.",
    "%1$s has declined your invitation" : "%1$s odmietol/a vaše pozvanie",
    "%1$s has responded to your invitation" : "%1$s zareagoval/a na vašu pozvánku",
    "Invitation updated: %1$s" : "Pozvánka aktualizovaná: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s aktualizoval udalosť \"%2$s\"",
    "Invitation: %1$s" : "Pozvánka: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s by vás chcel/a pozvať na \"%2$s\"",
    "Organizer:" : "Organizátor:",
    "Attendees:" : "Účastníci:",
    "Title:" : "Názov:",
    "When:" : "Kedy:",
    "Location:" : "Miesto:",
    "Link:" : "Odkaz:",
    "Occurring:" : "Výskyt:",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "More options …" : "Ďalšie nastavenia ...",
    "More options at %s" : "Ďalšie nastavenia %s",
    "Monday" : "Pondelok",
    "Tuesday" : "Utorok",
    "Wednesday" : "Streda",
    "Thursday" : "Štvrtok",
    "Friday" : "Piatok",
    "Saturday" : "Sobota",
    "Sunday" : "Nedeľa",
    "January" : "Január",
    "February" : "Február",
    "March" : "Marec",
    "April" : "Apríl",
    "May" : "Máj",
    "June" : "Jún",
    "July" : "Júl",
    "August" : "August",
    "September" : "September",
    "October" : "Október",
    "November" : "November",
    "December" : "December",
    "First" : "Prvé",
    "Second" : "Druhý",
    "Third" : "Tretí",
    "Fourth" : "Štvrtý",
    "Fifth" : "Piate",
    "Last" : "Posledné",
    "Second Last" : "Predposledný",
    "Third Last" : "Tretí odzadu",
    "Fourth Last" : "Štvrtý odzadu",
    "Fifth Last" : "Piatu odzadu",
    "Contacts" : "Kontakty",
    "{actor} created address book {addressbook}" : "{actor} vytvoril adresár {addressbook}",
    "You created address book {addressbook}" : "Vytvorili ste adresár {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} zmazal adresár {addressbook}",
    "You deleted address book {addressbook}" : "Zmazali ste adresár {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} upravil adresár {addressbook}",
    "You updated address book {addressbook}" : "Upravili ste adresár {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} zdieľal adresár {addressbook} with you",
    "You shared address book {addressbook} with {user}" : "Zdieľate adresár {addressbook} with {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} zdieľa adresár {addressbook} s {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} prestal zdieľať adresár {addressbook} s vami",
    "You unshared address book {addressbook} from {user}" : "Nezdieľate adresár {addressbook} od {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} nezdieľa adresár {addressbook} od {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} nezdieľa adresár {addressbook} od samého seba",
    "You shared address book {addressbook} with group {group}" : "Zdieľate adresár {addressbook} so skupinou {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} zdieľa adresár {addressbook} so skupinou {group}",
    "You unshared address book {addressbook} from group {group}" : "Nezdieľate adresár {addressbook} od skupiny {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} nezdieľa adresár {addressbook} od skupiny {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} vytvoril kontakt {card} v adresári {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Vytvorili ste kontakt {card} v adresári {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} zmazal kontakt {card} z adresára {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Zmazali ste kontakt {card} z adresára {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} upravil kontakt {card} v adresári {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Upravili ste kontakt {card} v adresári {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>kontakt</strong> alebo <strong>adresár</strong> bol upravený",
    "System address book disabled" : "Systémový adresár je vypnutý",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Systémový adresár kontaktov bol automaticky vypnutý počas aktualizácie. To znamená, že adresár kontaktov už nebude dostupný pre používateľov v aplikácii Kontakty ani v iných klientoch. Systémový adresár kontaktov bol vypnutý, pretože počet kontaktov v adresári prekročil maximálny odporúčaný počet kontaktov. Tento limit je nastavený na prevenciu problémov s výkonom. Systémový adresár kontaktov môžete znovu povoliť pomocou nasledujúcej príkazu {command}.",
    "Accounts" : "Účty",
    "System address book which holds all accounts" : "Systémový adresár, ktorý obsahuje všetky účty.",
    "File is not updatable: %1$s" : "Súbor nie je možné aktualizovať: %1$s",
    "Failed to get storage for file" : "Nepodarilo sa získať miesto pre súbor",
    "Could not write to final file, canceled by hook" : "Nepodarilo sa zapísať do konečného súboru, zrušené háčikom (hook)",
    "Could not write file contents" : "Nepodarilo sa zapísať obsah súboru",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Chyba pri kopírovaní súboru do cieľovej lokácie (skopírovaných %1$s, predpokladaná veľkosť: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Očakávaná veľkosť súboru je %1$s, ale prečítalo sa (z klienta Nextcloud) a zapísalo sa (do úložiska Nextcloud) %2$s. Môže ísť o problém so sieťou na strane odosielania alebo problém so zápisom do úložiska na strane servera.",
    "Could not rename part file to final file, canceled by hook" : "Nepodarilo sa premenovať dočasný súbor na finálny, zrušené háčikom (hook)",
    "Could not rename part file to final file" : "Nepodarilo sa premenovať dočasný súbor na finálny.",
    "Failed to check file size: %1$s" : "Kontrola veľkosti súboru zlyhala: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Nie je možné otvoriť súbor: %1$s (%2$d), zdá sa že súbor existuje",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Nie je možné otvoriť súbor: %1$s (%2$d), nezdá sa že súbor existuje",
    "Failed to get size for : %1$s" : "Nepodarilo sa získať veľkosť pre: %1$s",
    "Encryption not ready: %1$s" : "Šifrovanie nie je dostupné: %1$s",
    "Failed to open file: %1$s" : "Otvorenie súboru zlyhalo: %1$s",
    "Failed to unlink: %1$s" : "Odpojenie zlyhalo: %1$s",
    "Failed to write file contents: %1$s" : "Zapisovanie obsahu súboru zlyhalo: %1$s",
    "File not found: %1$s" : "Súbor nebol nájdený: %1$s",
    "Invalid target path" : "Neplatná cesta cieľa",
    "System is in maintenance mode." : "Systém je v režime údržby.",
    "Upgrade needed" : "Je potrebná aktualizácia",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ak chcete používať CalDAV alebo CardDAV v iOS alebo macOS, musí byť %s nakonfigurovaný na používanie HTTPS.",
    "Configures a CalDAV account" : "Nakonfiguruje účet CalDAV",
    "Configures a CardDAV account" : "Nakonfiguruje účet CardDAV",
    "Events" : "Udalosti",
    "Untitled task" : "Úloha bez názvu",
    "Completed on %s" : "Dokončené %s",
    "Due on %s by %s" : "Termín od %s do %s",
    "Due on %s" : "Termín do %s",
    "This is an example contact" : "Toto je príklad kontaktu",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Vitajte v Nextcloud Calendar!\n\nToto je ukážková udalosť – preskúmajte flexibilitu plánovania s Nextcloud Calendar tým, že vykonáte akékoľvek úpravy, ktoré chcete!\n\nS Nextcloud Calendar môžete:\n- Jednoducho vytvárať, upravovať a spravovať udalosti.\n- Vytvárať viacero kalendárov a zdieľať ich s tímom, priateľmi alebo rodinou.\n- Skontrolovať dostupnosť a zobraziť svoje zaneprázdnené časy pre ostatných.\n- Bezproblémovo integrovať s aplikáciami a zariadeniami cez CalDAV.\n- Prispôsobiť si skúsenosti: naplánovať opakujúce sa udalosti, nastaviť notifikácie a iné nastavenia.",
    "Example event - open me!" : "Príklad udalosti - otvorte ma!",
    "System Address Book" : "Systémový Adresár",
    "The system address book contains contact information for all users in your instance." : "Systémový adresár obsahuje kontaktné informácie o všetkých užívateľov vo vašej inštancii.",
    "Enable System Address Book" : "Povoliť systémový Adresár",
    "DAV system address book" : "Systémový DAV adresár",
    "No outstanding DAV system address book sync." : "Žiadna zostávajúca synchronizácia adresára systému DAV.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV synchronizácia systémového adresára ešte nebola spustená, pretože vaša inštancia má viac ako 1000 užívateľov alebo sa vyskytla chyba. Prosím, spustite ju manuálne volaním \"occ dav:sync-system-addressbook\".",
    "DAV system address book size" : "Veľkosť adresára systému DAV",
    "The system address book is disabled" : "Systémový adresár je zakázaný",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Adresár systému je povolený, ale obsahuje viac kontaktov, než je nastavený limit %dkontaktov.",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Adresár systému je povolený a obsahuje menej kontaktov, než je nastavený limit %dkontaktov.",
    "WebDAV endpoint" : "Koncový bod WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Nepodarilo sa skontrolovať, či je váš webový server správne nastavený tak, aby umožňoval synchronizáciu súborov cez WebDAV. Skontrolujte prosím manuálne.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Váš webový server nie je zatiaľ správne nastavený, aby umožnil synchronizáciu súborov, pretože rozhranie WebDAV sa zdá byť nefunkčné.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Váš webový server je správne nastavený tak, aby umožňoval synchronizáciu súborov cez WebDAV.",
    "Calendars including events, details and attendees" : "Kalendáre vrátane udalostí, podrobností a účastníkov",
    "Migrated calendar (%1$s)" : "Migrovaný kalendár (%1$s)",
    "Contacts and groups" : "Kontakty a skupiny",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Neprítomnosť uložená",
    "Failed to save your absence settings" : "Nepodarilo sa uložiť vaše nastavenia neprítomnosti.",
    "Absence cleared" : "Neprítomnosť odstránená",
    "Failed to clear your absence settings" : "Nepodarilo sa vymazať vaše nastavenia neprítomnosti.",
    "First day" : "Prvý deň",
    "Last day (inclusive)" : "Posledný deň (vrátane)",
    "Out of office replacement (optional)" : "Zástup keď je mimo kancelárie (voliteľné)",
    "Name of the replacement" : "Názov náhrady",
    "Short absence status" : "Status pre Krátku neprítomnosť",
    "Long absence Message" : "Správa pri Dlhej neprítomnosti",
    "Save" : "Uložiť",
    "Disable absence" : "Zakázať neprítomnosť",
    "Failed to load availability" : "Nepodarilo sa načítať dostupnosť",
    "Saved availability" : "Dostupnosť bola uložená",
    "Failed to save availability" : "Nepodarilo sa uložiť dostupnosť",
    "to" : "do",
    "Delete slot" : "Odstrániť slot",
    "No working hours set" : "Nenastavená pracovná doba",
    "Add slot" : "Pridať slot",
    "Weekdays" : "Pracovné dni",
    "Pick a start time for {dayName}" : "Vyberte začiatočný čas pre {dayName}",
    "Pick a end time for {dayName}" : "Vyberte koncový čas pre {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Automaticky nastaviť stav používateľa na „Nerušiť“ ak nie ste dostupný,  pre stlmenie všetkých upozornení.",
    "Cancel" : "Zrušiť",
    "Import" : "Import",
    "Error while saving settings" : "Chyba pri ukladaní nastavení",
    "Contact reset successfully" : "Kontakt bol úspešne resetovaný",
    "Error while resetting contact" : "Chyba počas resetovania kontaktu ",
    "Contact imported successfully" : "Kontakt bol úspešne importovaný",
    "Error while importing contact" : "Chyba pri importovaní kontaktu",
    "Import contact" : "Importovať kontakt",
    "Reset to default" : "Nastaviť predvolené",
    "Import contacts" : "Importovať kontakty",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importovaním nového súboru .vcf sa vymaže existujúci predvolený kontakt a nahradí sa novým. Chcete pokračovať?",
    "Failed to save example event creation setting" : "Nepodarilo sa uložiť nastavenie vytvorenia príkladu udalosti",
    "Failed to upload the example event" : "Nezvládlo sa nahrať príklad udalosti",
    "Custom example event was saved successfully" : "Vlastný príklad udalosti bol úspešne uložený",
    "Failed to delete the custom example event" : "Nepodarilo sa odstrániť vlastnú ukážkovú udalosť",
    "Custom example event was deleted successfully" : "Vlastný príklad udalosti bol úspešne odstránený",
    "Import calendar event" : "Importovať udalosť kalendára",
    "Uploading a new event will overwrite the existing one." : "Nahrávanie novej udalosti prepíše existujúcu.",
    "Upload event" : "Nahratie udalosti",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Tiež nainštalujte {calendarappstoreopen}apku Kalendár{linkclose} alebo {calendardocopen}pripojte svoj počítač a smartfón pre synchronizáciu ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Uistite sa, že ste správne nastavili {emailopen}e-mailový server{linkclose}.",
    "Calendar server" : "Kalendárový server",
    "Send invitations to attendees" : "Odoslanie pozvánok účastníkom",
    "Automatically generate a birthday calendar" : "Automaticky generovať narodeninový kalendár",
    "Birthday calendars will be generated by a background job." : "Narodeninové kalendáre budú generované úlohou na pozadí.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Preto nebudú dostupné hneď po povolení, ale zobrazia sa po určitom čase",
    "Send notifications for events" : "Zasielať upozornenia na udalosti",
    "Notifications are sent via background jobs, so these must occur often enough." : "Upozornenia sa odosielajú prostredníctvom úloh na pozadí - preto je potrebné, aby tieto prebiehali dostatočne často.",
    "Send reminder notifications to calendar sharees as well" : "Posielať upozornenia na pripomienky aj zdieľaným osobám v kalendári",
    "Reminders are always sent to organizers and attendees." : "Upozornenia sa vždy posielajú organizátorom a účastníkom.",
    "Enable notifications for events via push" : "Zapnúť oznámenia o udalostiach prostredníctvom technológie push.",
    "Example content" : "Príklad obsahu",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Príklad obsahu slúži na predvedenie funkcií Nextcloud. Predvolený obsah je dodávaný s Nextcloudom a môže byť nahradený vlastným obsahom.",
    "Availability" : "Dostupnosť",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ak nakonfigurujete svoj pracovný čas, ostatní užívatelia vás uvidia ako neprítomného, keď si rezervujete schôdzku",
    "Absence" : "Neprítomnosť",
    "Configure your next absence period." : "Nastavte si ďalšie obdobie svojej neprítomnosti.",
    "There was an error updating your attendance status." : "Nastal problém pri aktualizácii Vašej účasti.",
    "Please contact the organizer directly." : "Prosím kontaktujte priamo organizátora.",
    "Are you accepting the invitation?" : "Príjmate pozvánku?",
    "Tentative" : "Neistý",
    "Your attendance was updated successfully." : "Vaša účasť bola aktualizovaná úspešne.",
    "No results." : "Žiadne výsledky.",
    "Start typing." : "Začnite písať."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
