OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "최근 연락함",
    "Contacts Interaction" : "Contacts Interaction",
    "Manages interaction between accounts and contacts" : "계정 및 연락처 간 상호작용을 관리합니다",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "계정 및 연락처 간 상호작용에 관한 데이터를 수집하고, 데이터 주소록을 제공합니다"
},
"nplurals=1; plural=0;");
