OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Недавно контактирани",
    "Contacts Interaction" : "Интеракција контаката",
    "Manages interaction between accounts and contacts" : "Управља интеракцијом између налога и контаката",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Прикупља податке о интеракцији налога и контаката и обезбеђује адресар за податке"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
