import{g as a}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as c}from"./gams-ja02EC4u.chunk.mjs";function g(r,f){for(var o=0;o<f.length;o++){const t=f[o];if(typeof t!="string"&&!Array.isArray(t)){for(const e in t)if(e!=="default"&&!(e in r)){const n=Object.getOwnPropertyDescriptor(t,e);n&&Object.defineProperty(r,e,n.get?n:{enumerable:!0,get:()=>t[e]})}}}return Object.freeze(Object.defineProperty(r,Symbol.toStringTag,{value:"Module"}))}var i=c();const p=a(i),u=g({__proto__:null,default:p},[i]);export{u as g};
//# sourceMappingURL=gams-DjKa17CG.chunk.mjs.map
