OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Vantar endurheimtulykilorð",
    "Please repeat the recovery key password" : "Endurtaktu endurheimtulykilorð",
    "Repeated recovery key password does not match the provided recovery key password" : "Endurtekna endurheimtulykilorðið samsvarar ekki uppgefnu endurheimtulykilorði",
    "Recovery key successfully enabled" : "Tókst að virkja endurheimtulykil",
    "Could not enable recovery key. Please check your recovery key password!" : "Tókst ekki að virkja endurheimtulykil. Athugaðu endurheimtulykilorðið þitt!",
    "Recovery key successfully disabled" : "Tókst að gera endurheimtulykil óvirkan",
    "Could not disable recovery key. Please check your recovery key password!" : "Tókst ekki að gera endurheimtulykil óvirkan. Athugaðu endurheimtulykilorðið þitt!",
    "Please provide the old recovery password" : "Settu inn gamla endurheimtulykilorðið",
    "Please provide a new recovery password" : "Settu inn nýja endurheimtulykilorðið",
    "Please repeat the new recovery password" : "Endurtaktu nýja endurheimtulykilorðið",
    "Password successfully changed." : "Lykilorðinu hefur verið breytt.",
    "Could not change the password. Maybe the old password was not correct." : "Tókst ekki að breyta lykilorðinu. Kannski var gamla lykilorðið ekki rétt.",
    "Recovery Key disabled" : "Endurheimtulykilorð óvirkt",
    "Recovery Key enabled" : "Endurheimtulykilorð virkt",
    "Could not enable the recovery key, please try again or contact your administrator" : "Gat ekki virkjað endurheimtulykilinn, reyndu aftur eða hafðu samband við kerfisstjóra",
    "Could not update the private key password." : "Tókst ekki að uppfæra lykilorð einkalykils.",
    "The old password was not correct, please try again." : "Gamla lykilorðið var ekki rétt, reyndu aftur.",
    "The current log-in password was not correct, please try again." : "Núgildandi innskráningarlykilorð var ekki rétt, reyndu aftur.",
    "Private key password successfully updated." : "Tókst að uppfæra lykilorð einkalykils.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Ógildur einkalykill fyrir dulritunarforrit. Uppfærðu einkalykilorðið í stillingunum þínum til að fá aftur aðgang að dulrituðu skránum þínum.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Dulritunarforritið er virkt en dulritunarlyklarnir þínir eru ekki tilbúnir til notkunar, skráðu þig út og svo aftur inn.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Virkjaðu dulritun á vefþjóninum í kerfisstjórnunarstillingunum svo hægt sé að nota dulritunareininguna.",
    "Encryption app is enabled and ready" : "Dulritunarforrit er virkt og tilbúið til notkunar",
    "Bad Signature" : "Ógild undirritun",
    "Missing Signature" : "Vantar undirritun",
    "one-time password for server-side-encryption" : "eins-skiptis lykilorð fyrir dulritun á þjóni",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ef þessi kostur er virkur verða allar skrár í aðalgeymslu dulritaðar, annars verða einungis skrár í ytri gagnageymslum dulritaðar",
    "Encrypt the home storage" : "Dulrita heimamöppuna",
    "Disable recovery key" : "Gera endurheimtingarlykil óvirkan",
    "Enable recovery key" : "Virkja endurheimtingarlykil",
    "Recovery key password" : "Endurheimtulykilorð",
    "Repeat recovery key password" : "Endurtaktu endurheimtulykilorðið",
    "Old recovery key password" : "Gamla endurheimtulykilorðið",
    "New recovery key password" : "Nýtt endurheimtulykilorð",
    "Repeat new recovery key password" : "Endurtaktu nýja endurheimtulykilorðið",
    "Old log-in password" : "Gamla innskráningarlykilorðið",
    "Current log-in password" : "Núgildandi innskráningarlykilorð",
    "Update" : "Uppfæra",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ef þessi kostur er virkur gerir það þér kleift að endurheimta aðgang að skránum þínum ef þú tapar lykilorðinu",
    "Default encryption module" : "Sjálfgefin dulritunareining",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Dulritunarforritið er virkt en dulritunarlyklarnir þínir eru ekki tilbúnir til notkunar, skráðu þig út og svo aftur inn",
    "Basic encryption module" : "Grunn-dulritunareining",
    "Missing parameters" : "Vantar breytur",
    "Default encryption module for server-side encryption" : "Sjálfgefin dulritunareining fyrir dulritun á vefþjóni",
    "Change recovery key password:" : "Breyta endurheimtulykilorði:",
    "Change Password" : "Breyta lykilorði",
    "Your private key password no longer matches your log-in password." : "Lykilorð einkalykilsins þíns samsvarar ekki lengur innskráningarlykilorðinu þínu.",
    "Set your old private key password to your current log-in password:" : "Settu eldra lykilorð einkalykilsins þíns á að vera það sama og núgildandi innskráningarlykilorðið þitt:",
    "Update Private Key Password" : "Uppfæra lykilorð einkalykils:",
    "Enable password recovery:" : "Virkja endurheimtingu lykilorðs:",
    "Enabled" : "Virkt",
    "Disabled" : "Óvirkt"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
