import{d as t}from"./preload-helper-DadE4qT2.chunk.mjs";const a=t({name:"AbortControllerMixin",data(){return{abortController:new AbortController}},methods:{abortPendingRequest(){this.abortController.abort(),this.abortController=new AbortController}},beforeDestroy(){this.abortController.abort()},beforeRouteLeave(r,e,o){this.abortPendingRequest(),o()}});export{a as A};
//# sourceMappingURL=AbortControllerMixin-Bb5X6Yae.chunk.mjs.map
