OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Zjištěno nové místo přihlášení",
    "More info about the suspicious IP address available on %s" : "Další informace o podezřelé IP adrese jsou k dispozici na %s",
    "Open %s ↗" : "Otevřít %s ↗",
    "Suspicious Login" : "Podezřelé přihlášení",
    "New login detected" : "Zjištěno nové přihlášení",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Zjišťovat a varovat o podezřelých IP adresách přihlašujících se k Nextcloud\n\t",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Bylo zaznamenáno nové přihlášení k vašemu účtu. IP adresa %s byla vyhodnocena jako podezřelá. Pokud jste to byli vy, tuto zprávu ignorujte. Pokud ne, měli byste si změnit heslo."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
