OC.L10N.register(
    "photos",
    {
    "Videos" : "Videothan",
    "Favorites" : "Annsachdan",
    "Tags" : "Tagaichean",
    "Back" : "Air ais",
    "Save" : "Sàbhail",
    "Favorite" : "Annsachd",
    "Home" : "Dachaigh",
    "General" : "Coitcheann",
    "Last week" : "An t-seachdain seo chaidh",
    "Details" : "Mion-fhiosrachadh",
    "Cancel" : "Cancel"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
