OC.L10N.register(
    "files_external",
    {
    "You are not logged in" : "Nincs bejelentkezve",
    "Permission denied" : "Jogosultság megtagadva",
    "Forbidden to manage local mounts" : "A helyi csatolt kötetek kezelése tiltott",
    "Storage with ID \"%d\" not found" : "A(z) „%d” azonosítójú tároló nem található",
    "Invalid backend or authentication mechanism class" : "Érvénytelen háttérszolgáltatási vagy hitelesítési mechanizmust tartalmazó osztály",
    "Invalid mount point" : "Érvénytelen csatolási pont",
    "Objectstore forbidden" : "Az objektumtár tiltott",
    "Invalid storage backend \"%s\"" : "Érvénytelen háttértárkezelő: „%s”",
    "Not permitted to use backend \"%s\"" : "A(z) „%s” háttérszolgáltatás használata nem engedélyezett",
    "Not permitted to use authentication mechanism \"%s\"" : "A(z) „%s” hitelesítési mechanizmus használata nem engedélyezett",
    "Unsatisfied backend parameters" : "Elégtelen paraméterek a háttérszolgáltatáshoz",
    "Unsatisfied authentication mechanism parameters" : "Elégtelen paraméterek a hitelesítési mechanizmushoz",
    "Insufficient data: %s" : "Elégtelen adatok: %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "A(z) „%d” azonosítójú tárolót csak rendszergazdák szerkeszthetik",
    "Static credentials" : "Statikus hitelesítő adatok",
    "Access key ID" : "Hozzáférés kulcs azonosítója",
    "Secret access key" : "Titkos hozzáférési kulcs",
    "Builtin" : "Beépített",
    "None" : "Egyik sem",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Bejelentkezés",
    "Password" : "Jelszó",
    "Tenant name" : "Ügyfél neve",
    "Identity endpoint URL" : "Személyazonossági végpont webcíme",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domain",
    "Rackspace" : "Rackspace",
    "API key" : "API-kulcs",
    "Global credentials" : "Globális hitelesítő adatok",
    "Log-in credentials, save in database" : "Bejelentkezési hitelesítő adatok, mentés adatbázisban",
    "Login and password" : "Bejelentkezés és jelszó",
    "Log-in credentials, save in session" : "Bejelentkezési hitelesítő adatok, mentés a munkamenetben",
    "Global credentials, manually entered" : "Globális hitelesítő adatok, kézileg megadva",
    "Manually entered, store in database" : "Kézileg megadva, tárolás adatbázisban",
    "RSA public key" : "RSA nyilvános kulcs",
    "Public key" : "Nyilvános kulcs",
    "RSA private key" : "RSA titkos kulcs",
    "Private key" : "Titkos kulcs",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Az alapértelmezett Kerberos tartomány, alapértelmezetten „WORKGROUP”",
    "Kerberos ticket Apache mode" : "Kerberos-jegy Apache módja",
    "Kerberos ticket" : "Kerberos-jegy",
    "Bucket" : "Bucket",
    "Hostname" : "Gépnév",
    "Port" : "Port",
    "Proxy" : "Proxy",
    "Region" : "Régió",
    "Storage Class" : "Tárolóosztály",
    "Use Legacy S3 signing (v2)" : "Örökölt S3 aláírás (v2) használata",
    "Enable multipart copy" : "Többrészes másolás engedélyezése",
    "SSE-C encryption key" : "SSE-C titkosítási kulcsa",
    "WebDAV" : "WebDAV",
    "URL" : "Webcím",
    "Remote subfolder" : "Távoli almappa",
    "Secure https://" : "Biztonságos https://",
    "Host" : "Kiszolgáló",
    "Secure ftps://" : "Biztonságos ftps://",
    "Location" : "Hely",
    "Root" : "Gyökér",
    "Share" : "Megosztás",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "Case sensitive file system" : "Kis- és nagybetűket megkülönböztető fájlrendszer",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "A letiltása lehetővé teszi a kis- és nagybetűket nem megkülönböztető fájlrendszerek használatát, de ez teljesítményvesztést okoz",
    "Verify ACL access when listing files" : "ACL hozzáférés ellenőrzése a fájlok listázásakor",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Egy könyvtárban szereplő összes fájl vagy mappa ACL-jének ellenőrzése azon elemek kiszűréséhez, melyeken a fióknak nincs olvasási engedélye; teljesítménycsökkenéssel jár",
    "Timeout" : "Időtúllépés",
    "Login as share" : "Bejelentkezés megosztásként",
    "Service name" : "Szolgáltatás neve",
    "Request timeout (seconds)" : "Kérés időtúllépése (másodpercben)",
    "External storage" : "Külső tároló",
    "External storage support" : "Külső tároló támogatása",
    "Adds basic external storage support" : "Alapvető támogatást ad a külső tárolókhoz",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Ez az alkalmazás lehetővé teszi a rendszergazdák számára, hogy beállítsák a kapcsolatokat a külső tárhelyszolgáltatókkal, például FTP-kiszolgálókkal, S3 vagy SWIFT objektumtárolókkal, más Nextcloud-kiszolgálókkal, WebDAV-kiszolgálókkal és egyebekkel. A rendszergazdák kiválaszthatják, hogy milyen típusú tárolókat engedélyeznek, és csatolhatják ezeket a tárhelyeket egy fiók, egy csoport vagy az egész rendszer számára. A felhasználók látni fogják, hogy egy új mappa jelenik meg a Nextcloud gyökérkönyvtárában, amelyet minden más Nextcloud mappához hasonlóan elérhetnek és használhatnak. A külső tárhely lehetővé teszi az emberek számára a külső helyeken tárolt fájlok megosztását is. Ezekben az esetekben a fájl tulajdonosának hitelesítő adatait akkor használják, amikor a címzett a fájlt külső tárhelyről kéri, ezáltal biztosítva, hogy a címzett hozzáférjen a megosztott fájlhoz.\n\nA külső tároló grafikus felületen vagy a parancssorból állítható be. Ez a második lehetőség nagyobb rugalmasságot biztosít a rendszergazdák számára a tömeges külső tárolók beállításához, és a csatolási prioritások beállításához. További információ a külső tároló GUI dokumentációjában, és a külső tároló konfigurációs fájljának dokumentációjában található.",
    "Edit storage" : "Tároló szerkesztése",
    "Add storage" : "Tároló hozzáadása",
    "Folder name" : "Mappa neve",
    "Authentication" : "Hitelesítés",
    "Cancel" : "Mégse",
    "Edit" : "Szerkesztés",
    "Create" : "Létrehozás",
    "Restrict to" : "Korlátozás erre:",
    "Storage configuration" : "Tárolóbeállítás",
    "Never" : "Soha",
    "Once every direct access" : "Minden közvetlen elérésnél",
    "Always" : "Mindig",
    "Mount options" : "Csatolási beállítások",
    "Check filesystem changes" : "Fájlrendszer-módosítások ellenőrzése",
    "Read only" : "Csak olvasható",
    "Enable previews" : "Előnézet engedélyezése",
    "Enable sharing" : "Megosztás engedélyezése",
    "Enable encryption" : "Titkosítás engedélyezése",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitás a Mac NFD kódolással (lassú)",
    "External storages" : "Külső tárolók",
    "Status" : "Állapot",
    "Restricted to" : "Korlátozva erre:",
    "Actions" : "Műveletek",
    "Checking …" : "Ellenőrzés…",
    "Recheck status" : "Állapot újraellenőrzése",
    "Delete" : "Törlés",
    "System provided storage" : "Rendszer által biztosított tároló",
    "Saved" : "Mentve",
    "Error while saving" : "Hiba a mentés során",
    "Saved allowed backends" : "Az engedélyezett háttérszolgáltatások mentve",
    "Failed to save allowed backends" : "Nem sikerült az engedélyezett háttérszolgáltatások mentése",
    "Advanced options for external storage mounts" : "Speciális beállítások a külső tárolók csatolásaihoz",
    "Allow people to mount external storage" : "Külső tárolók csatolásának engedélyezése az emberek számára",
    "External storage backends people are allowed to mount" : "Külső tároló-háttérszolgáltatások, melyeket az emberek csatolhatnak",
    "Error generating key pair" : "Hiba történt a kulcspár előállítása során",
    "Key size" : "Kulcsméret",
    "Generate keys" : "Kulcsok előállítása",
    "Confirm" : "Megerősítés",
    "Storage credentials" : "Tároló hitelesítő adatai",
    "To access the storage, you need to provide the authentication credentials." : "A tároló eléréséhez meg kell adnia a hitelesítő adatokat.",
    "Enter the storage login" : "Adja meg a tároló bejelentkezését",
    "Enter the storage password" : "Adja meg a tároló jelszavát",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices." : "A külső tárolók lehetővé teszik a külső tárolószolgáltatások és -eszközök másodlagos Nextcloud-tárolóeszközként való csatolását.",
    "You may also allow people to mount their own external storage services." : "Engedélyezheti, hogy az emberek csatolják a saját külső tárolószolgáltatásaikat is.",
    "The cURL support in PHP is not enabled or installed." : "A PHP cURL-támogatása nincs engedélyezve vagy telepítve.",
    "The FTP support in PHP is not enabled or installed." : "A PHP FTP-támogatása nincs engedélyezve vagy telepítve.",
    "{module} is not installed." : "A(z) {module} nincs telepítve.",
    "Dependant backends" : "Függő háttérszolgáltatások",
    "No external storage configured or you do not have the permission to configure them" : "Nincs külső tároló beállítva, vagy nincs elegendő jogosultsága a beállításukhoz",
    "Add external storage" : "Külső tároló hozzáadása",
    "Global credentials saved" : "Globális hitelesítő adatok mentve",
    "Could not save global credentials" : "Nem sikerült a globális hitelesítő adatok mentése",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "A globális hitelesítő adatokkal azonos külső hitelesítő adatokkal rendelkező külső tárhelyek hitelesíthetők.",
    "Saving …" : "Mentés…",
    "Save" : "Mentés",
    "Unable to update this external storage config. {statusMessage}" : "Nem sikerült a külső tároló beállításainak frissítése. {statusMessage}",
    "New configuration successfully saved" : "Az új konfiguráció sikeresen elmentve",
    "Enter missing credentials" : "Adja meg a hiányzó hitelesítési adatokat",
    "Credentials successfully set" : "Hitelesítő adatok sikeresen beállítva",
    "Error while setting credentials: {error}" : "Hiba a hitelesítő adatok beállításakor: {error}",
    "Checking storage …" : "Tároló ellenőrzése…",
    "There was an error with this external storage." : "Hiba történt ezzel a külső tárolóval.",
    "We were unable to check the external storage {basename}" : "Nem sikerült a(z) {basename} külső tároló ellenőrzése",
    "Examine this faulty external storage configuration" : "Vizsgálja meg a külső tároló hibás konfigurációját",
    "Open in Files" : "Megnyitás a Fájlokban",
    "External mount error" : "Külső csatolási hiba",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Hiba történt ezzel a külső tárolóval. Átnézi a csatolási pont konfigurációját a beállítások oldalon?",
    "Open settings" : "Beállítások megnyitása",
    "Ignore" : "Mellőzés",
    "List of external storage." : "Külső tárolók felsorolása.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Nincs külső tároló konfigurálva. Beállíthatja őket a Személyes beállításokban.",
    "There is no external storage configured and you don't have the permission to configure them." : "Nincs külső tároló konfigurálva, és nincs jogosultsága beállítani őket.",
    "No external storage" : "Nincs külső tároló",
    "Storage type" : "Tároló típusa",
    "Unknown" : "Ismeretlen",
    "Scope" : "Hatókör",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Connected" : "Csatlakozva",
    "Error" : "Hiba",
    "Indeterminate" : "Meghatározatlan",
    "Incomplete configuration" : "Hiányos konfiguráció",
    "Unauthorized" : "Jogosulatlan",
    "Network error" : "Hálózati hiba",
    "Grant access" : "Hozzáférés megadása",
    "Error configuring OAuth2" : "OAuth2 beállítási hiba",
    "%s" : "%s",
    "Access key" : "Hozzáférési kulcs",
    "Secret key" : "Titkos kulcs",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliensazonosító",
    "Client secret" : "Klienstitok",
    "S3 Storage" : "S3-tároló",
    "Enable SSL" : "SSL engedélyezése",
    "Enable Path Style" : "Útvonalstílus engedélyezés",
    "Legacy (v2) authentication" : "Örökölt (v2) hitelesítés",
    "FTP" : "FTP",
    "Local" : "Helyi",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP titkos kulcsos belépéssel",
    "SMB/CIFS" : "SMB/CIFS",
    "SMB/CIFS using OC login" : "SMB/CIFS OC bejelentkezéssel",
    "OpenStack Object Storage" : "OpenStack objektumtároló",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A PHP cURL támogatása nincs engedélyezve vagy telepítve.  A(z) %s csatolása nem lehetséges. Kérje meg a rendszergazdát, hogy telepítse.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A PHP FTP támogatása nincs engedélyezve vagy telepítve. A(z)%s csatolása nem lehetséges. Kérje meg a rendszergazdát, hogy telepítse.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "A(z) „%1$s” nincs telepítve. A(z) %2$s csatolása nem lehetséges. Kérje meg a rendszergazdát, hogy telepítse.",
    "Checking storage …" : "Tároló ellenőrzése…",
    "Type to select account or group." : "Gépeljen a fiók vagy a csoport kiválasztásához.",
    "(Group)" : "(Csoport)",
    "Check for changes" : "Változások keresése",
    "Disconnect" : "Kapcsolat bontása",
    "Unknown backend: {backendName}" : "Ismeretlen háttérszolgáltatás: {backendName}",
    "Admin defined" : "Rendszergazda által definiálva",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Az automatikus állapotellenőrzés a beállított tárolók nagy száma miatt ki van kapcsolva, kattintson az állapot ellenőrzéséhez",
    "Are you sure you want to disconnect this external storage?" : "Biztos, hogy bontja a kapcsolatot ezzel a külső tárolóval?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "A tároló nem lesz elérhető a(z) {instanceName} számára, és a szinkronizálási kliensek is törölni fogják azokat a fájlokat, amelyek jelenleg kapcsolatban vannak, viszont magáról a külső tárolóról nem fogja törölni a fájlokat és mappákat.",
    "Delete storage?" : "Tároló törlése?",
    "Click to recheck the configuration" : "Kattintson ide a konfiguráció újraellenőrzéséhez",
    "Saving …" : "Mentés…",
    "Failed to save global credentials" : "A globális hitelesítő adatok mentése sikertelen",
    "Failed to save global credentials: {message}" : "A globális hitelesítő adatok mentése sikertelen: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Nincsenek külső tárolók beállítva, vagy nincs hozzáférése a beállításaikhoz",
    "Open documentation" : "Dokumentáció megnyitása",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "A külső tárhely lehetővé teszi külső tárolási szolgáltatások és eszközök másodlagos Nextcloud-tárolóeszközként történő csatlakoztatását. Lehetővé teheti az emberek számára, hogy saját külső tárolószolgáltatásukat is csatlakoztassák.",
    "Configuration" : "Beállítások",
    "Available for" : "Számukra érhető el:",
    "All people" : "Mindenki",
    "Advanced settings" : "Speciális beállítások",
    "Use presigned S3 url" : "Előre aláírt S3 webcím használata"
},
"nplurals=2; plural=(n != 1);");
