OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Favorites" : "Favoriten",
    "Shared with you" : "Mat dir gedeelt",
    "Tags" : "Tags",
    "Back" : "Zeréck",
    "Save" : "Späicheren",
    "Shared by" : "Gedeelt vun",
    "Favorite" : "Favorit",
    "Go back" : "Zeréckgoen",
    "Home" : "Doheem",
    "General" : "Allgemeng",
    "Remove from favorites" : "Remove from favorites",
    "Details" : "Detailer",
    "Cancel" : "Cancel",
    "Confirm" : "Konfirméieren",
    "Group" : "Grupp"
},
"nplurals=2; plural=(n != 1);");
