OC.L10N.register(
    "files",
    {
    "Added to favorites" : "تمت إضافته إلى المفضلة",
    "Removed from favorites" : "تمت إزالته مِن المفضلة",
    "You added {file} to your favorites" : "أنت اضفت {file} إلى مفضلتك",
    "You removed {file} from your favorites" : "تم ازالت {file} من مفضلتك",
    "Favorites" : "المفضلة ",
    "File changes" : "تغيير في ملف",
    "Created by {user}" : "انشاء جديد من قبل {user}",
    "Changed by {user}" : "تغيير من قبل {user}",
    "Deleted by {user}" : "حذف من قبل {user}",
    "Restored by {user}" : "استعادة من قبل {user}",
    "Renamed by {user}" : "اعادة تسمية من قبل {user}",
    "Moved by {user}" : "نقل من قبل {user}",
    "\"remote account\"" : "\"حساب بعيد\"",
    "You created {file}" : "أنشأتَ {file}",
    "You created an encrypted file in {file}" : "انشأت ملف مشفر في {file}",
    "{user} created {file}" : "{user} قام بإنشاء ملف {file}",
    "{user} created an encrypted file in {file}" : "{user} قام بإنشاء ملف مشفر {file}",
    "{file} was created in a public folder" : "{file} تم إنشاءه في مجلد عام",
    "You changed {file}" : "أنت قمت بتغيير {file}",
    "You changed an encrypted file in {file}" : "أنت قمت بتغيير ملف مشفر {file}",
    "{user} changed {file}" : "{user} قام بتغيير {file}",
    "{user} changed an encrypted file in {file}" : "{user} قام بتغيير ملف مشفر {file}",
    "You deleted {file}" : "أنت حذفت ملف {file}",
    "You deleted an encrypted file in {file}" : "أنت حذفت ملف مشفر {file}",
    "{user} deleted {file}" : "{user} قام بحذف {file}",
    "{user} deleted an encrypted file in {file}" : "{user} قام بحذف ملف مشفر {file}",
    "You restored {file}" : "أنت قمت باستعادة {file}",
    "{user} restored {file}" : "{user} استعادة ملف {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "لقد أعدت تسمية {oldfile} (مخفي) إلى {newfile} (مخفي)",
    "You renamed {oldfile} (hidden) to {newfile}" : "لقد أعدت تسمية {oldfile} (مخفي) إلى {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "لقد أعدت تسمية {oldfile} إلى {newfile} (مخفي)",
    "You renamed {oldfile} to {newfile}" : "أنت أعدت تسمية {oldfile} إلى {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "أعاد {user} تسمية {oldfile} (مخفي) إلى {newfile} (مخفي)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "أعاد {user} تسمية {oldfile} (مخفي) إلى {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "أعاد {user} تسمية {oldfile} إلى {newfile} (مخفي)",
    "{user} renamed {oldfile} to {newfile}" : "{user} اعادة تسمية {oldfile} إلى {newfile}",
    "You moved {oldfile} to {newfile}" : "أنت نقلت {oldfile} إلى {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} نقل {oldfile} إلى {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "ملف اضيف إلى او تم ازالته من <strong> مفضلتك </strong>",
    "Files" : "الملفات",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A favorite file or folder has been <strong>changed</strong>" : "ملف في المفضلة تم <strong>تم تغييره</strong>",
    "Failed to authorize" : "فشل في التخويل",
    "Invalid folder path" : "مسار المجلد غير صحيح",
    "Folder not found" : "المجلد غير موجود",
    "The file cannot be found" : "تعذّر العثور على الملف",
    "The destination path does not exist: %1$s" : "مسار المَقصِد غير موجود: %1$s",
    "You do not have permission to create a file at the specified location" : "ليس لديك صلاحية لإنشاء ملف في الموقع المحدد",
    "The file could not be converted." : "لايمكن تحويل الملف.",
    "Could not get relative path to converted file" : "تعذّر الحصول على المسار النسبي للملف المُتحوِّل",
    "Favorite files" : "الملفات المُفضَّلة",
    "No favorites" : "لا يوجد مفضلات ",
    "More favorites" : "مزيد من المُفضَّلة",
    "Accept" : "قبول",
    "Reject" : "رفض",
    "Incoming ownership transfer from {user}" : "تم تحويل ملكية الملف إليك من قبل {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "هل تريد الموافقة {path}?\n\nملاحظة: عملية موافقة على النقل قد تستغرق إلى 1 ساعة.",
    "Ownership transfer denied" : "تمّ رفض نقل الملكية",
    "Your ownership transfer of {path} was denied by {user}." : "تمّ رفض نقل ملكية الملفات في {path} من قِبَل المستخدِم {user}.",
    "Ownership transfer failed" : "فشل نقل ملكية الملفات",
    "Your ownership transfer of {path} to {user} failed." : "فشلت عمليتك لنقل الـ {path} إلى {user}",
    "The ownership transfer of {path} from {user} failed." : "فشل عملية النقل لـ {path} من قبل {user}",
    "Ownership transfer done" : "تم نقل ملكية الملفات بنجاح",
    "Your ownership transfer of {path} to {user} has completed." : "عمليتك لنقل الـ {path} إلى {user} تمت بنجاح.",
    "The ownership transfer of {path} from {user} has completed." : "نقل ملكية الملفات لـ {path} من قبل {user} تمت بنجاح.",
    "in %s" : "في %s",
    "Transferred from %1$s on %2$s" : "تم النقل من %1$s في%2$s",
    "File Management" : "إدارة الملفات",
    "Home" : "الرئيسية",
    "Target folder does not exist any more" : "المجلد المراد غير موجود بعد الان",
    "Reload current directory" : "إعادة تحميل المجلد الحالي",
    "Go to the \"{dir}\" directory" : "إنتقل إلى المجلد \"{dir}\"",
    "Current directory path" : "مسار المجلد الحالي",
    "Share" : "مشاركة",
    "Your have used your space quota and cannot upload files anymore" : "لقد استنفذت حصتك التخزينية و لم يعد بإمكانك رفع أي ملفات الآن",
    "You do not have permission to upload or create files here." : "أنت ليس لديك إذنٌ برفع أو إنشاء الملفات هنا.",
    "Drag and drop files here to upload" : "إسحب وأفلت الملفات هنا لرفعها",
    "Favorite" : "المفضلة",
    "Back" : "عودة",
    "Toggle selection for file \"{displayName}\"" : "تبديل الاختيار للملف \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "تبديل الاختيار للمجلد \"{displayName}\"",
    "File is loading" : "يتم تحميل الملف...",
    "Folder is loading" : "يتم تحميل المجلد...",
    "Filename" : "اسم الملف",
    "Folder name" : "اسم المجلد",
    "This node is unavailable" : "هذه العُقْدَة node غير متوفرة ",
    "Another entry with the same name already exists." : "توجد سلفاً إدخالية أخرى بنفس هذا الاسم.",
    "Invalid filename." : "اسم ملف غير صحيح.",
    "Rename file" : "إعادة تسمية الملف",
    "Folder" : "مجلد",
    "Unknown file type" : "نوع ملف غير معروف",
    "Pending" : "قيد الانتظار",
    "Unknown date" : "تاريخ غير معروف",
    "Active filters" : "فلاتر نشطة",
    "Remove filter" : "إزالة عامل التصفية ",
    "Today" : "اليوم",
    "Last 7 days" : "آخر 7 أيام",
    "Last 30 days" : "آخر 30 يوماً",
    "This year ({year})" : "هذا العام ({year})",
    "Last year ({year})" : "العام الماضي ({year})",
    "Custom date range" : "نطاق زمني مخصص",
    "Search everywhere" : "البحث الشامل",
    "Documents" : "المستندات",
    "Spreadsheets" : "الجداول الالكترونية",
    "Presentations" : "العروض",
    "PDFs" : "ملفات PDF",
    "Folders" : "المجلدات",
    "Audio" : "صوت",
    "Images" : "الصِّوَر",
    "Videos" : "مقاطع فيديو",
    "Filters" : "فلاتر",
    "Appearance" : "المظهر",
    "Show hidden files" : "عرض الملفات المخفية",
    "Show file type column" : "عرض عمود نوع الملف",
    "Crop image previews" : "اقتصاص صورة العروض",
    "General" : "عامٌّ",
    "Sort favorites first" : "فرز المفضلة أولا",
    "Sort folders before files" : "فرز المجلدات قبل الملفات",
    "All files" : "كل الملفات",
    "Personal files" : "ملفات شخصية",
    "Additional settings" : "الإعدادات المتقدمة",
    "Actions" : "الإجراءات",
    "File actions" : "إجراءات الملفات",
    "Selection" : "اختيار",
    "Select all files" : "تحديد كل الملفات",
    "Deselect all" : "إلغاء تحديد الكل",
    "Navigation" : "التنقل",
    "View" : "عرض",
    "Toggle grid view" : "تفعيل/تعطيل وضع القائمة",
    "Show those shortcuts" : "أعرُض تلك الاختصارات",
    "Warnings" : "تحذيرات",
    "WebDAV URL" : "عنوان URL لـ WebDAV",
    "Total rows summary" : "ملخص مجموع الأسطر",
    "Toggle selection for all files and folders" : "تبديل الاختيار لكل الملفات و المجلدات",
    "Name" : "الاسم",
    "File type" : "نوع الملف",
    "Size" : "الحجم",
    "Modified" : "التعديل",
    "(selected)" : "(تم اختياره)",
    "List of files and folders." : "قائمة الملفات والمجلدات",
    "You have used your space quota and cannot upload files anymore." : "لقد قمت باستنفاذ كامل حصتك التخزينية و لايمكنك تحميل المزيد من الملفات.",
    "Column headers with buttons are sortable." : "ترويسات الأعمدة ذات الأزرار قابلة للترتيب.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "لم يتم عرض هذه القائمة بالكامل لأسباب تتعلق بالأداء. سيتم عرض الملفات تباعاً أثناء التنقل عبر القائمة.",
    "File not found" : "تعذر العثور على الملف",
    "_{count} selected_::_{count} selected_" : ["{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده"],
    "Views" : "مشاهدات",
    "Owner" : "المالك",
    "{usedQuotaByte} used" : "{usedQuotaByte} مستخدمة",
    "{used} of {quota} used" : "{used} من {quota} مستخدم",
    "{relative}% used" : "{relative}% مستخدمة",
    "Could not refresh storage stats" : "تعذر تحديث حالة التخزين",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Storage information" : "معلومات التخزين",
    "Storage quota" : "حصة التخزين",
    "New folder" : "مجلد جديد",
    "Create new folder" : "إنشاء مجلد جديد",
    "This name is already in use." : "هذا الاسم سبق استعماله.",
    "Create" : "إنشاء",
    "Refresh" : "إنعاش",
    "Limit" : "الحد",
    "Fill template fields" : "قُم بملء حقول القالب",
    "Submit" : "إرسال ",
    "Choose a file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
    "Transfer" : "نقل ملكية",
    "Transfer {path} to {userid}" : "نقل ملكية {path} إلى {userid}",
    "Error while searching for users" : "خطأ وقع أثناء البحث عن مستخدمين",
    "Ownership transfer request sent" : "طلب نقل الملكية أرسل بنجاح",
    "Cannot transfer ownership of a file or folder you do not own" : "لايمكنك نقل ملكية ملف أو مجلد لا تملكه",
    "Transfer ownership of a file or folder" : "تحويل ملكية ملف أو مجلد",
    "New owner" : "مالك جديد",
    "Keep {old}" : "إحتَفِظ بـ {old}",
    "Keep without extension" : "إحتَفِظ بدون امتداد",
    "Use {new}" : "إستَعمِل {new}",
    "Remove extension" : "أزِل الامتداد",
    "Change file extension" : "تغيير امتداد الملف",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "تغيير امتداد اسم الملف من \"{old}\" إلى \"{new}\" يمكن أن يتسبب في جعله غير قابل للعرض.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "إزالة الامتداد \"{old}\" من اسم الملف يمكن أن يتسبب في تغيير طريقة تناول و عرض الملف أو يجعله غير قابل للعرض.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "إضافة الامتداد \"{new}\" لاسم الملف يمكن أن يتسبب في تغيير طريقة تناول و عرض الملف أو أن يجعله غير قابل للعرض.",
    "Do not show this dialog again." : "لا تُظهِر هذه النافذة مرة أخرى",
    "Cancel" : "إلغاء",
    "Rename" : "إعادة التسمية",
    "Select file or folder to link to" : "اختر ملف أو مجلد للربط معه",
    "Choose {file}" : "إختر {file}",
    "Files settings" : "إعدادات الملفات",
    "Switch to list view" : "التبديل إلى عرض القائمة",
    "Switch to grid view" : "تبديل إلى العرض الشبكي",
    "The file could not be found" : "تعذّر إيجاد الملف",
    "Upload was cancelled by user" : "عملية الرفع تمّ إلغاؤها من المستخدم",
    "Not enough free space" : "لا يوجد مساحة تخزينية كافية",
    "Operation is blocked by access control" : "العمليات حظرت الوصول لهذه الخدمة",
    "Error during upload: {message}" : "حدث خطأ أثناء الرفع: {message}",
    "Error during upload, status code {status}" : "حدث خطأ أثناء الرفع. رمز الحالة {status}",
    "Unknown error during upload" : "خطأ غير محدد حدث أثناء الرفع",
    "Loading current folder" : "تحميل المجلد الحالي",
    "Retry" : "أعِدِ المحاولة",
    "No files in here" : "لا توجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوى أو قم بالمزامنة مع أجهزتك!",
    "Go back" : "العودة",
    "Your files" : "ملفاتك",
    "Open in files" : "فتح في تطبيق الملفات",
    "File cannot be accessed" : "الملف لم يمكن الوصول إليه",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "إمّا أن الملف غير موجود أو أنك لا تمتلك الصلاحية لعرضه. أُطلُب من المُرسل أن يتشاركه معك.",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "السماح بتقييد أسماء الملفات لضمان إمكانية مزامنة الملفات مع جميع العملاء. بشكل افتراضي، يُسمح بجميع أسماء الملفات الصالحة على POSIX (مثل Linux أو macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "بعد تمكين أسماء الملفات المتوافقة مع نظام التشغيل Windows، لا يمكن تعديل الملفات الموجودة بعد الآن ولكن يمكن إعادة تسميتها بأسماء جديدة صالحة بواسطة مالكها.",
    "Files compatibility" : "توافقية الملفات",
    "Enforce Windows compatibility" : "فرض التوافق مع ويندوز",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "سيؤدي هذا إلى حظر أسماء الملفات غير الصالحة على أنظمة Windows؛ مثل استخدام الأسماء المحجوزة أو الأحرف الخاصة. لكن هذا لن يفرض توافق حساسية الحالة.",
    "Blank" : "فارغ",
    "Unable to create new file from template" : "تعذر إنشاء الملف الجديد من القالب",
    "Pick a template for {name}" : "اختر قالبا لـ {name}",
    "Create a new file with the selected template" : "إنشاء ملف جديد بإستخدام القالب المحدد",
    "Creating file" : "إنشاء ملف",
    "Save as {displayName}" : "حفظ باسم {displayName}",
    "Failed to convert files: {message}" : "تعذّر تحويل الملفات: {message}",
    "All files failed to be converted" : "تعذّر تحويل كل الملفات",
    "One file could not be converted: {message}" : "تعذّر تحويل الملف : {message}",
    "Failed to convert files" : "تعذّر تحويل الملفات",
    "File successfully converted" : "تمّ تحويل الملفات بنجاحٍ",
    "Failed to convert file: {message}" : "تعذّر تحويل الملف: {message}",
    "Failed to convert file" : "تعذّر تحويل ملف",
    "Delete" : "حذف ",
    "Leave this share" : "مغادرة هذه المشاركة",
    "Leave these shares" : "مغادرة هاتين المشاركتين",
    "Disconnect storage" : "قطع اتصال التخزين",
    "Disconnect storages" : "فصل وحدات تخزين",
    "Delete permanently" : "حذف بشكل دائم",
    "Delete and unshare" : "حذف وإلغاء المشاركة",
    "Delete file" : "حذف الملف",
    "Delete files" : "حذف الملفات",
    "Delete folder" : "حذف مجلد",
    "Delete folders" : "حذف مجلدين",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عنصراً","أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك حذف {count} عنصر بشكل نهائي "],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عنصراً"],
    "Confirm deletion" : "تأكيد الحذف",
    "Download" : "تنزيل",
    "Add to favorites" : "إضافة إلى المفضلة",
    "Remove from favorites" : "إزالة من المفضلة",
    "Move" : "نقل",
    "Copy" : "نسخ",
    "Move or copy" : "نقل أو نسخ",
    "Destination is not a folder" : "الوجهة ليست مجلد",
    "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
    "A file or folder with that name already exists in this folder" : "ملف أو مجلد بنفس ذاك الاسم موجود سلفاً في هذا المجلد",
    "The files are locked" : "الملفات مقفلة",
    "The file does not exist anymore" : "الملف لم يعد موجوداً",
    "Choose destination" : "تحديد الوجهة",
    "Copy to {target}" : "نسخ إلى {target}",
    "Move to {target}" : "نقل إلى {target}",
    "Move or copy operation failed" : "عملية النسخ أو النقل فشلت",
    "Open folder" : "فتح المجلد",
    "Open folder {displayName}" : "فتح المجلد {displayName}",
    "Open in Files" : "فتح في \"الملفات\"",
    "Open locally" : "الفتح محلّيّاً",
    "Failed to redirect to client" : "فشل في التحويل الى العميل",
    "Open file locally" : "فتح الملف محلّيّاً",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "يجب أن يفتح الملف الآن على جهازك. إذا لم يحدث ذلك، فيرجى التأكد من تثبيت تطبيق سطح المكتب.",
    "Retry and close" : "أعِد المحاولة ثم أغلِق",
    "Open online" : "إفتَح مُتَّصِلاً بالإنترنت",
    "Details" : "التفاصيل",
    "Unfavorite" : "إبعادٌ من المُفضّلة",
    "View in folder" : "عرض في المجلد",
    "Type" : "النوع",
    "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
    "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
    "Create templates folder" : "إنشاء مجلد للقوالب",
    "Templates" : "القوالب",
    "New template folder" : "مجلد القوالب الجديد",
    "In folder" : "في المجلد",
    "Search in folder: {folder}" : "البحث في المجلد:  {folder}",
    "One of the dropped files could not be processed" : "أحد الملفات المُفلَتة لا يمكن معالجته",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "مُستعرِضُك لا يدعم واجهة تطبيق نظام الملفات Filesystem API. لذا، لن يُمكن رفع المجلدات",
    "No files to upload" : "لا توجد ملفات لرفعها",
    "Unable to create the directory {directory}" : "تعذّر إنشاء الدليل {directory}",
    "Some files could not be uploaded" : "بعض الملفات لم يمكن رفعها",
    "Files uploaded successfully" : "تمّ رفع الملفات بنجاح",
    "No files to process" : "لا توجد ملفات لمعالجتها",
    "Files copied successfully" : "تمّ نسخ الملفات بنجاح",
    "Files moved successfully" : "تمّ نقل الملفات بنجاح",
    "Some files could not be copied" : "بعض الملفات لا يمكن نسخها",
    "Some files could not be moved" : "تعذر نقل بعض الملفات",
    "Conflicts resolution skipped" : "تمّ تخطّي حلّ التعارضات",
    "Upload cancelled" : "تمّ إلغاء الرفع",
    "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{newName}\" مستعمل سلفاً في المجلد\"{dir}\". إختر اسماً آخر رجاءً.",
    "Could not rename \"{oldName}\"" : "تعذرت إعادة تسمية \"{oldName}\"",
    "This operation is forbidden" : "هذه العملية ممنوعة ",
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
    "Unexpected error: {error}" : "خطأ غير متوقع: {error}",
    "Unknown error" : "خطأ غير معروف",
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","%n ملف","ملفان","%n ملفات","%n ملف","%n ملفات"],
    "_%n folder_::_%n folders_" : ["لا توجد مجلدات","مجلد واحد","مجلدان","%n مجلدات","%n مجلد","%n مجلدات"],
    "Filename must not be empty." : "يجب ألّا يكون اسم الملف فارغاً.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" غير مسموح به في اسم الملف.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" هو اسم محجوز و لا يجوز استعماله كاسم لملف.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" غير مسموح به كنوع لملف.",
    "Filenames must not end with \"{extension}\"." : "أسماء الملفات يجب ألّا تنتهي بـ \"{extension}\".",
    "List of favorite files and folders." : "قائمة بالملفات و المجلدات المُفضّلة.",
    "No favorites yet" : "ليس لديك ملفات مفضلة",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كمفضلة سوف تظهر هنا ",
    "List of your files and folders." : "قائمة بملفاتك و مجلداتك",
    "List of your files and folders that are not shared." : "قائمة بالملفات و المجلدات التي لم تتم مشاركتها.",
    "No personal files found" : "لا توجد أي ملفات شخصية",
    "Files that are not shared will show up here." : "الملفات التي لم تتم مشاركتها يتم عرضها هنا",
    "Recent" : "آخر الملفات",
    "List of recently modified files and folders." : "قائمة بالملفات والمجلدات التي تمّ تعديلها مؤخراً.",
    "No recently modified files" : "لا توجد أي ملفات تمّ تعديلها مؤخراً",
    "Files and folders you recently modified will show up here." : "الملفات و المجلدات التي تمّ تعديلها مؤخراً ستظهر هنا.",
    "Search" : "بحث",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الرفع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد رفعها أعلى من المسموح على الخادم.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "تمت إعادة تسمية \"{oldName}\" إلى \"{newName}\"",
    "Clear filter" : "إزالة التصفية",
    "Submitting fields …" : "إرسال الحقول ...",
    "Invalid path selected" : "المسار او الملف غير صحيح",
    "Choose file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
    "Change" : "تغير",
    "Shared by link" : "شاركته باستخدام رابط مشاركة",
    "Shared" : "مشاركة",
    "You" : "أنت",
    "Shared multiple times with different people" : "تمّت مشاركته عدة مرات مع أشخاص متعددين",
    "Unable to change the favorite state of the file" : "تعذّر تغيير حالة المُفضَّلة للملف",
    "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
    "Tags" : "الوسوم",
    "Save as …" : "حفظ باسم ...",
    "Converting files …" : "تحويل الملفات ...",
    "Converting file …" : "تحويل الملف ..."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
