.settings__field[data-v-e84629db]{max-width:500px;margin-top:calc(3 * var(--default-grid-baseline))!important}.settings__placeholder[data-v-e84629db]{height:calc(var(--default-clickable-area) + 3 * var(--default-grid-baseline))}
