<?php

/**
 * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */


namespace OCA\Circles\Exceptions;

/**
 * Class FederatedEventException
 *
 * @package OCA\Circles\Exceptions
 */
class InvalidIdException extends FederatedItemServerException {
}
