OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Kata sandi telah kedaluwarsa, silakan gunakan metode lupa kata sandi untuk mereset",
    "Password must not have been used recently before." : "Kata sandi tidak boleh sudah pernah digunakan baru-baru ini.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Kata sandi termasuk dalam 1.000.000 kata sandi yang paling umum. Harap buat yang unik.",
    "Password is present in compromised password list. Please choose a different password." : "Kata sandi ada dalam daftar kata sandi yang telah disusupi. Harap pilih kata sandi yang berbeda.",
    "Password needs to be at least %s characters long." : "Panjang kata sandi minimal harus %s karakter.",
    "Password needs to contain at least one numeric character." : "Kata sandi harus mengandung setidaknya satu karakter numerik.",
    "Password needs to contain at least one special character." : "Kata sandi harus mengandung setidaknya satu karakter khusus.",
    "Password needs to contain at least one lower and one upper case character." : "Kata sandi harus mengandung setidaknya satu karakter huruf kecil dan satu huruf besar.",
    "Password policy" : "Ketentuan kata sandi",
    "Allows admins to configure a password policy" : "Memungkinkan admin untuk mengonfigurasi kebijakan kata sandi",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Memungkinkan admin untuk menentukan prasyarat tertentu untuk kata sandi, misalnya mewajibkan panjang minimum",
    "General password policies" : "Kebijakan kata sandi umum",
    "Add policy set" : "Tambah set kebijakan",
    "Login policies" : "Kebijakan login",
    "Password history size" : "Ukuran riwayat kata sandi",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Jumlah kata sandi yang disimpan (dalam bentuk hash yang aman) untuk mencegah pengguna menggunakan kembali kata sandi yang pernah digunakan sebelumnya.",
    "Maximum login attempts" : "Upaya login maksimum",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Jumlah upaya login sebelum akun pengguna dinonaktifkan hingga tindakan manual diambil. (0 untuk tanpa batas)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Harap dicatat, opsi ini dimaksudkan untuk melindungi akun yang diserang. Akun yang dinonaktifkan harus diaktifkan kembali secara manual oleh administrasi. Penyerang yang mencoba menebak kata sandi akun akan diblokir alamat IP-nya oleh perlindungan brute force terlepas dari pengaturan ini.",
    "Number of days until user password expires" : "Jumlah hari hingga kata sandi pengguna kedaluwarsa",
    "Password expiration" : "Kedaluwarsa kata sandi",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Peringatan: mengaktifkan kedaluwarsa kata sandi saat ini dianggap sebagai risiko keamanan oleh beberapa lembaga keamanan.",
    "Remove policy" : "Hapus kebijakan",
    "Minimum password length" : "Panjang kata sandi minimum",
    "Forbid common passwords" : "Larang kata sandi  yang sering digunakan",
    "Enforce upper and lower case characters" : "Berlakukan pemakaian huruf besar dan huruf kecil",
    "Enforce numeric characters" : "Berlakukan karakter numerik",
    "Enforce special characters" : "Berlakukan karakter spesial",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Periksa kata sandi terhadap daftar kata sandi yang bocor dari haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Pemeriksaan ini membuat hash dari kata sandi dan mengirimkan 5 karakter pertama dari hash tersebut ke API haveibeenpwned.com untuk mengambil daftar semua hash yang dimulai dengan karakter tersebut. Kemudian ia memeriksa pada instans Nextcloud apakah hash kata sandi ada dalam set hasil tersebut.",
    "Account password policies" : "Kebijakan kata sandi akun",
    "Share password policies" : "Kebijakan kata sandi berbagi"
},
"nplurals=1; plural=0;");
