OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Tệp chia sẻ",
    "Downloaded via public link" : "Tải xuống qua liên kết",
    "Downloaded by {email}" : "Tải xuống bởi {email}",
    "{file} downloaded via public link" : "{file} được tải xuống qua liên kết công khai",
    "{email} downloaded {file}" : "{email} đã tải xuống {file}",
    "Shared with group {group}" : "Đã chia sẻ với nhóm {group}",
    "Removed share for group {group}" : "Đã xóa chia sẻ cho nhóm {group}",
    "{actor} shared with group {group}" : "{actor} đã chia sẻ với nhóm {group}",
    "{actor} removed share for group {group}" : "{actor} đã xóa lượt chia sẻ cho nhóm {group}",
    "Share for group {group} expired" : "Chia sẻ cho nhóm {group} đã hết hạn",
    "You shared {file} with group {group}" : "Bạn đã chia sẻ {file} với nhóm {group}",
    "You removed group {group} from {file}" : "Bạn đã xóa nhóm {group} khỏi {file}",
    "{actor} shared {file} with group {group}" : "{actor} đã chia sẻ {file} với nhóm {group}",
    "{actor} removed group {group} from {file}" : "{actor} đã xóa nhóm {group} khỏi {file}",
    "Share for file {file} with group {group} expired" : "Chia sẻ tệp {file} với nhóm {group} đã hết hạn",
    "Shared as public link" : "Được chia sẻ dưới dạng liên kết công khai",
    "Removed public link" : "Đã xóa liên kết công khai",
    "Public link expired" : "Liên kết công khai đã hết hạn",
    "{actor} shared as public link" : "{actor} được chia sẻ dưới dạng liên kết công khai",
    "{actor} removed public link" : "{actor} đã xóa liên kết công khai",
    "Public link of {actor} expired" : "Liên kết công khai của {actor} đã hết hạn",
    "You shared {file} as public link" : "Bạn đã chia sẻ {file} dưới dạng liên kết công khai",
    "You removed public link for {file}" : "Bạn đã xóa liên kết công khai cho {file}",
    "Public link expired for {file}" : "Liên kết công khai đã hết hạn cho {file}",
    "{actor} shared {file} as public link" : "{actor} đã chia sẻ {file} dưới dạng liên kết công khai",
    "{actor} removed public link for {file}" : "{actor} đã xóa liên kết công khai cho {file}",
    "Public link of {actor} for {file} expired" : "Liên kết công khai của {actor} cho {file} đã hết hạn",
    "{user} accepted the remote share" : "{user} đã chấp nhận chia sẻ từ xa",
    "{user} declined the remote share" : "{user} đã từ chối chia sẻ từ xa",
    "You received a new remote share {file} from {user}" : "Bạn đã nhận được một {file} chia sẻ từ xa mới từ {user}",
    "{user} accepted the remote share of {file}" : "{user} đã chấp nhận chia sẻ từ xa của {file}",
    "{user} declined the remote share of {file}" : "{user} đã từ chối chia sẻ từ xa của {file}",
    "{user} unshared {file} from you" : "{user} đã hủy chia sẻ {file} với bạn",
    "Shared with {user}" : "Đã chia sẻ với {user}",
    "Removed share for {user}" : "Đã xóa chia sẻ cho {user}",
    "You removed yourself" : "Bạn đã xóa chính mình",
    "{actor} removed themselves" : "{actor} đã tự xóa mình",
    "{actor} shared with {user}" : "{actor} đã chia sẻ với {user}",
    "{actor} removed share for {user}" : "{actor} đã xóa lượt chia sẻ cho {user}",
    "Shared by {actor}" : "Được chia sẻ bởi {actor}",
    "{actor} removed share" : "{actor} đã xóa lượt chia sẻ",
    "Share for {user} expired" : "Chia sẻ cho {user} đã hết hạn",
    "Share expired" : "Chia sẻ đã hết hạn",
    "You shared {file} with {user}" : "Bạn đã chia sẻ {file} với {user}",
    "You removed {user} from {file}" : "Bạn đã xóa {user} khỏi {file}",
    "You removed yourself from {file}" : "Bạn đã xóa chính mình khỏi {file}",
    "{actor} removed themselves from {file}" : "{actor} đã tự xóa mình khỏi {file}",
    "{actor} shared {file} with {user}" : "{actor} đã chia sẻ {file} với {user}",
    "{actor} removed {user} from {file}" : "{actor} đã xóa {user} khỏi {file}",
    "{actor} shared {file} with you" : "{actor} đã chia sẻ {file} với bạ",
    "{actor} removed you from the share named {file}" : "{actor} đã xóa bạn khỏi phần chia sẻ có tên {file}",
    "Share for file {file} with {user} expired" : "Chia sẻ tệp {file} với {user} đã hết hạn",
    "Share for file {file} expired" : "Chia sẻ cho tệp {file} đã hết hạn",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Một tệp hoặc thư mục được chia sẻ qua thư hoặc bằng liên kết công khai đã được tải xuống 1",
    "A file or folder was shared from <strong>another server</strong>" : "Một tập tin hoặc thư mục đã được chia sẻ từ 1 máy chủ khác 1",
    "Sharing" : "Chia sẻ",
    "A file or folder has been <strong>shared</strong>" : "Một tập tin hoặc thư mục đã được shared",
    "Shared link" : "Liên kết được chia sẻ",
    "Wrong share ID, share does not exist" : "ID chia sẻ sai, chia sẻ không tồn tại",
    "Could not delete share" : "Không thể xoá chia sẻ",
    "Please specify a file or folder path" : "Vui lòng chỉ định đường dẫn tệp hoặc thư mục",
    "Wrong path, file/folder does not exist" : "Đường dẫn sai, tập tin/thư mục không tồn tại",
    "Could not create share" : "Không thể tạo chia sẻ",
    "Group sharing is disabled by the administrator" : "Chia sẻ nhóm bị quản trị viên vô hiệu hóa",
    "Please specify a valid group" : "Vui lòng chỉ định một nhóm hợp lệ",
    "Public link sharing is disabled by the administrator" : "Chia sẻ liên kết công khai bị quản trị viên vô hiệu hóa",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Chia sẻ %s gửi mật khẩu bằng Nextcloud Talk không thành công do Nextcloud Talk chưa được bật",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Chia sẻ %1$s không thành công vì phần phụ trợ không cho phép chia sẻ từ loại %2$s",
    "Please specify a valid federated group ID" : "Vui lòng chỉ định ID nhóm liên kết hợp lệ",
    "Sharing %s failed because the back end does not support room shares" : "Chia sẻ %s không thành công vì phần sau không hỗ trợ chia sẻ phòng",
    "Unknown share type" : "Loại chia sẻ không xác định",
    "Not a directory" : "Không phải là thư mục",
    "Could not lock node" : "Không thể khóa nút",
    "Public upload is only possible for publicly shared folders" : "Chỉ có thể tải lên công khai đối với các thư mục được chia sẻ công khai",
    "Share must at least have READ or CREATE permissions" : "Chia sẻ ít nhất phải có quyền ĐỌC hoặc TẠO",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Chia sẻ phải có quyền ĐỌC nếu quyền CẬP NHẬT hoặc XÓA được đặt",
    "Public upload disabled by the administrator" : "Tải lên công khai bị quản trị viên vô hiệu hóa",
    "Could not lock path" : "Không thể khóa đường dẫn",
    "Wrong or no update parameter given" : "Sai hoặc không có tham số cập nhật nào được đưa ra",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Gửi mật khẩu bằng Nextcloud Talk\" để chia sẻ tệp hoặc thư mục không thành công do Nextcloud Talk chưa được bật.",
    "Wrong password" : "Mật khẩu không chính xác",
    "shared by %s" : "Được chia sẻ bởi %s",
    "Download" : "Tải về",
    "Add to your %s" : "Thêm vào %s của bạn",
    "Direct link" : "Liên kết trực tiêp",
    "Share API is disabled" : "API chia sẻ bị tắt",
    "File sharing" : "Chia sẻ file",
    "Share will expire tomorrow" : "Chia sẻ sẽ hết hạn vào ngày mai",
    "Your share of {node} will expire tomorrow" : "Phần chia sẻ {node} của bạn sẽ hết hạn vào ngày mai",
    "You received {share} as a share by {user}" : "Bạn đã nhận được {share} dưới dạng lượt chia sẻ của {user}",
    "You received {share} to group {group} as a share by {user}" : "Bạn đã nhận được {share} để nhóm {group} dưới dạng lượt chia sẻ của {user}",
    "Accept" : "Chấp nhận",
    "Decline" : "Từ chối",
    "Expiration date" : "Ngày kết thúc",
    "Set a password" : "Đặt mật khẩu",
    "Password" : "Mật khẩu",
    "Link copied" : "Đã sao chép liên kết",
    "Share link" : "Chia sẽ liên kết",
    "Select" : "Chọn",
    "Close" : "Đóng",
    "Error creating the share: {errorMessage}" : "Lỗi khi tạo chia sẻ: {errorMessage}",
    "Error creating the share" : "Lỗi khi tạo chia sẻ",
    "Cancel" : "Hủy bỏ",
    "Continue" : "Tiếp tục",
    "Error while toggling options" : "Lỗi khi chuyển đổi tùy chọn",
    "Choose a default folder for accepted shares" : "Chọn thư mục mặc định cho các chia sẻ được chấp nhận",
    "Invalid path selected" : "Đường dẫn không hợp lệ được chọn",
    "Unknown error" : "Lỗi không xác định",
    "Set default folder for accepted shares" : "Đặt thư mục mặc định cho các chia sẻ được chấp nhận",
    "Reset" : "Đặt lại",
    "Reset folder to system default" : "Đặt lại thư mục về mặc định của hệ thống",
    "group" : "nhóm",
    "conversation" : "đàm thoại",
    "remote" : "Từ xa",
    "remote group" : "nhóm từ xa",
    "guest" : "khách",
    "Shared with the group {user} by {owner}" : "Được chia sẻ với nhóm {user} bởi {owner}",
    "Shared with the conversation {user} by {owner}" : "Được chia sẻ với cuộc trò chuyện {user} bởi {owner}",
    "Shared with {user} by {owner}" : "Được chia sẻ với {user} bởi {owner}",
    "Open Sharing Details" : "Mở chi tiết chia sẻ",
    "Added by {initiator}" : "Được thêm bởi {initiator}",
    "Via “{folder}”" : "Thông qua “{folder}”",
    "Unshare" : "Bỏ chia sẽ",
    "Cannot copy, please copy the link manually" : "Không thể sao chép, vui lòng sao chép liên kết bằng tay",
    "Internal link" : "Liên kết nội bộ",
    "{shareWith} by {initiator}" : "{shareWith} bởi {initiator}",
    "Shared via link by {initiator}" : "Được chia sẻ qua liên kết bởi {initiator}",
    "Mail share ({label})" : "Chia sẻ thư ({label})",
    "Share link ({label})" : "Chia sẻ liên kết ({label})",
    "Share link ({index})" : "Chia sẻ liên kết ({index})",
    "Actions for \"{title}\"" : "Hành động cho \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Lỗi, vui lòng nhập đúng mật khẩu và/hoặc ngày hết hạn",
    "Link share created" : "Đã tạo liên kết chia sẻ",
    "Error while creating the share" : "Lỗi khi tạo chia sẻ",
    "Please enter the following required information before creating the share" : "Vui lòng nhập các thông tin bắt buộc sau trước khi tạo chia sẻ",
    "Password protection (enforced)" : "Bảo vệ bằng mật khẩu (bắt buộc)",
    "Password protection" : "Password protection",
    "Enter a password" : "Nhập mật khẩu",
    "Create share" : "Tạo chia sẻ",
    "Customize link" : "Tùy chỉnh liên kết",
    "Add another link" : "Thêm một liên kết khác",
    "Create a new share link" : "Tạo liên kết chia sẻ mới",
    "View only" : "Chỉ xem",
    "Can edit" : "Có thể chỉnh sửa",
    "Custom permissions" : "Quyền tùy chỉnh",
    "Resharing is not allowed" : "Chia sẻ lại không được cho phép",
    "No elements found." : "Không tìm thấy phần tử nào.",
    "Search everywhere" : "Tìm ở bất kì đâu",
    "Guest" : "Khách",
    "Group" : "Nhóm",
    "Email" : "Thư điện tử",
    "Team" : "Đội",
    "Talk conversation" : "Nói chuyện",
    "Deck board" : "Dự án Deck",
    "ScienceMesh" : "Khoa học Mesh",
    "on {server}" : "trên {server}",
    "File drop" : "Thả file",
    "Terms of service" : "Điều khoản dịch vụ",
    "Update share" : "Cập nhật chia sẻ",
    "Save share" : "Lưu chia sẻ",
    "Read" : "Đọc",
    "Create" : "Tạo",
    "Edit" : "Chỉnh sửa",
    "Share" : "Chia sẻ",
    "Delete" : "Xóa",
    "Allow upload and editing" : "Cho phép tải lên và chỉnh sửa",
    "Allow editing" : "Cho phép chỉnh sửa",
    "Upload only" : "Chỉ tải lên",
    "Advanced settings" : "Cài đặt nâng cao",
    "Share label" : "Chia sẻ nhãn",
    "Set password" : "Đặt mật khẩu",
    "Password expires {passwordExpirationTime}" : "Mật khẩu hết hạn {passwordExpirationTime}",
    "Password expired" : "Mật khẩu quá hạn",
    "Video verification" : "Xác minh video",
    "Expiration date (enforced)" : "Ngày hết hạn (bắt buộc)",
    "Set expiration date" : "Đặt ngày hết hạn",
    "Hide download" : "Ẩn tải xuống",
    "Note to recipient" : "Ghi chú cho người nhận",
    "Enter a note for the share recipient" : "Nhập ghi chú cho người nhận chia sẻ",
    "Delete share" : "Xóa chia sẻ",
    "Others with access" : "Những người khác có quyền truy cập",
    "Toggle list of others with access to this directory" : "Chuyển đổi danh sách những người khác có quyền truy cập vào thư mục này",
    "Toggle list of others with access to this file" : "Chuyển đổi danh sách những người khác có quyền truy cập vào tệp này",
    "Unable to fetch inherited shares" : "Không thể tìm nạp cổ phần được kế thừa",
    "Shares" : "Chia sẻ",
    "Unable to load the shares list" : "Không thể tải danh sách chia sẻ",
    "Expires {relativetime}" : "Hết hạn {relativetime}",
    "this share just expired." : "chia sẻ này vừa hết hạn.",
    "Shared with you by {owner}" : "Đã được chia sẽ bởi {owner}",
    "Link to a file" : "Liên kết đến một tập tin",
    "_Accept share_::_Accept shares_" : ["Chấp nhận chia sẻ"],
    "Open in Files" : "Mở trong Tệp",
    "_Reject share_::_Reject shares_" : ["Từ chối chia sẻ"],
    "_Restore share_::_Restore shares_" : ["Khôi phục lượt chia sẻ"],
    "Shared" : "Chia sẻ",
    "Shared by {ownerDisplayName}" : "Được chia sẻ bởi {ownerDisplayName}",
    "Shared multiple times with different people" : "Shared multiple times with different people",
    "Shared with others" : "Chia sẻ với người khác",
    "People" : "Mọi người",
    "Overview of shared files." : "Tổng quan về các tập tin được chia sẻ.",
    "No shares" : "Không có lượt chia sẻ",
    "Files and folders you shared or have been shared with you will show up here" : "Các tệp và thư mục bạn đã chia sẻ hoặc đã được chia sẻ với bạn sẽ hiển thị ở đây",
    "Shared with you" : "Chia sẻ với bạn",
    "List of files that are shared with you." : "Danh sách các tập tin được chia sẻ với bạn.",
    "Nothing shared with you yet" : "Bạn chưa được chia sẻ gì cả",
    "Files and folders others shared with you will show up here" : "Các tệp và thư mục mà người khác chia sẻ với bạn sẽ hiển thị ở đây",
    "List of files that you shared with others." : "Danh sách các tập tin mà bạn đã chia sẻ với người khác.",
    "Nothing shared yet" : "Chưa có gì được chia sẻ",
    "Files and folders you shared will show up here" : "Các tệp và thư mục bạn đã chia sẻ sẽ hiển thị ở đây",
    "Shared by link" : "Chia sẻ theo liên kết",
    "List of files that are shared by link." : "Danh sách các tập tin được chia sẻ theo liên kết.",
    "No shared links" : "Chưa có liên kết chia sẻ",
    "Files and folders you shared by link will show up here" : "Các tệp và thư mục bạn chia sẻ bằng liên kết sẽ hiển thị ở đây",
    "Deleted shares" : "Chia sẻ đã xóa",
    "List of shares you left." : "Danh sách chia sẻ bạn để lại.",
    "No deleted shares" : "Không có chia sẻ bị xóa",
    "Shares you have left will show up here" : "Những chia sẻ bạn để lại sẽ hiển thị ở đây",
    "Pending shares" : "Chia sẻ đang chờ xử lý",
    "List of unapproved shares." : "Danh sách cổ phiếu không được phê duyệt",
    "No pending shares" : "Không có cổ phiếu đang chờ xử lý",
    "Shares you have received but not approved will show up here" : "Những chia sẻ bạn đã nhận được nhưng không được duyệt sẽ hiển thị ở đây",
    "Error updating the share" : "Lỗi cập nhật chia sẻ",
    "File \"{path}\" has been unshared" : "Tệp \"{path}\" đã không được chia sẻ",
    "Folder \"{path}\" has been unshared" : "Thư mục \"{path}\" đã không được chia sẻ",
    "Password created successfully" : "Đã tạo mật khẩu thành công",
    "Error generating password from password policy" : "Lỗi tạo mật khẩu từ chính sách mật khẩu",
    "Shared with you and the group {group} by {owner}" : "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
    "Shared with you and {circle} by {owner}" : "Được chia sẻ với bạn và {circle} bởi {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Được chia sẻ với bạn và cuộc trò chuyện {conversation} của {owner}",
    "Shared with you in a conversation by {owner}" : "Được chia sẻ với bạn trong cuộc trò chuyện bởi {owner}",
    "Share not found" : "Không tìm thấy chia sẻ.",
    "Back to %s" : "Quay lại %s",
    "Add to your Nextcloud" : "Thêm vào Nextcloud của bạn",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Chia sẻ %s không thành công vì phần sau không hỗ trợ chia sẻ ScienceMesh",
    "Name or email …" : "Tên hoặc email…",
    "Name, email, or Federated Cloud ID …" : "Tên, email hoặc ID đám mây liên kết…",
    "Searching …" : "Đang tìm kiếm ..."
},
"nplurals=1; plural=0;");
