OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Λείπει ο κωδικός κλειδιού ανάκτησης",
    "Please repeat the recovery key password" : "Παρακαλούμε επαναλάβετε τον κωδικό κλειδιού ανάκτησης",
    "Repeated recovery key password does not match the provided recovery key password" : "Ο επαναλαμβανόμενος κωδικός κλειδιού ανάκτησης δεν ταιριάζει με τον παρεχόμενο κωδικό κλειδιού ανάκτησης",
    "Recovery key successfully enabled" : "Επιτυχής ενεργοποίηση κλειδιού ανάκτησης",
    "Could not enable recovery key. Please check your recovery key password!" : "Αποτυχία ενεργοποίησης κλειδιού ανάκτησης. Παρακαλούμε ελέγξτε τον κωδικό του κλειδιού ανάκτησής σας!",
    "Recovery key successfully disabled" : "Επιτυχής απενεργοποίηση κλειδιού ανάκτησης",
    "Could not disable recovery key. Please check your recovery key password!" : "Αποτυχία απενεργοποίησης κλειδιού ανάκτησης. Παρακαλούμε ελέγξτε τον κωδικό του κλειδιού ανάκτησής σας!",
    "Please provide the old recovery password" : "Παρακαλούμε παρέχετε τον παλιό κωδικό ανάκτησης",
    "Please provide a new recovery password" : "Παρακαλούμε παρέχετε ένα νέο κωδικό ανάκτησης",
    "Please repeat the new recovery password" : "Παρακαλούμε επαναλάβετε το νέο κωδικό ανάκτησης",
    "Password successfully changed." : "Ο κωδικός πρόσβασης άλλαξε επιτυχώς.",
    "Could not change the password. Maybe the old password was not correct." : "Αποτυχία αλλαγής κωδικού. Ίσως ο παλιός κωδικός δεν ήταν σωστός.",
    "Recovery Key disabled" : "Κλειδί ανάκτησης απενεργοποιημένο",
    "Recovery Key enabled" : "Κλειδί ανάκτησης ενεργοποιημένο",
    "Could not enable the recovery key, please try again or contact your administrator" : "Αδυναμία ενεργοποίησης κλειδιού ανάκτησης, παρακαλούμε προσπαθήστε ξανά ή επικοινωνήστε με το διαχειριστή σας",
    "Could not update the private key password." : "Αποτυχία ενημέρωσης του κωδικού ιδιωτικού κλειδιού.",
    "The old password was not correct, please try again." : "Ο παλιός κωδικός δεν ήταν σωστός, παρακαλούμε δοκιμάστε ξανά.",
    "The current log-in password was not correct, please try again." : "Ο τρέχων κωδικός σύνδεσης δεν ήταν σωστός, παρακαλούμε δοκιμάστε ξανά.",
    "Private key password successfully updated." : "Ο κωδικός ιδιωτικού κλειδιού ενημερώθηκε επιτυχώς.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Άκυρο ιδιωτικό κλειδί για την εφαρμογή κρυπτογράφησης. Παρακαλώ ενημερώστε τον κωδικό του ιδιωτικού κλειδιού σας στις προσωπικές ρυθμίσεις για να επανακτήσετε πρόσβαση στα κρυπτογραφημένα σας αρχεία.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Η εφαρμογή κρυπτογράφησης είναι ενεργοποιημένη αλλά τα κλειδιά σας δεν έχουν αρχικοποιηθεί. Παρακαλούμε αποσυνδεθείτε και συνδεθείτε ξανά.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Παρακαλούμε ενεργοποιήστε την κρυπτογράφηση στον διακομιστή στις ρυθμίσεις διαχειριστή για να χρησιμοποιήσετε τη μονάδα κρυπτογράφησης.",
    "Encryption app is enabled and ready" : "Η εφαρμογή κρυπτογράφησης είναι ενεργοποιημένη και έτοιμη",
    "Bad Signature" : "Κακή υπογραφή",
    "Missing Signature" : "Ελλιπής υπογραφή",
    "one-time password for server-side-encryption" : "κωδικός μιας χρήσης για κρυπτογράφηση στο διακομιστή",
    "Encryption password" : "Κωδικός κρυπτογράφησης",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "Η διαχείριση ενεργοποίησε την κρυπτογράφηση στον διακομιστή. Τα αρχεία σας κρυπτογραφήθηκαν χρησιμοποιώντας τον κωδικό <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "Η διαχείριση ενεργοποίησε την κρυπτογράφηση στον διακομιστή. Τα αρχεία σας κρυπτογραφήθηκαν χρησιμοποιώντας τον κωδικό \"%s\".",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Παρακαλούμε συνδεθείτε στη διαδικτυακή διεπαφή, μεταβείτε στην ενότητα \"Ασφάλεια\" των προσωπικών σας ρυθμίσεων και ενημερώστε τον κωδικό κρυπτογράφησής σας εισάγοντας αυτόν τον κωδικό στο πεδίο \"Παλιός κωδικός σύνδεσης\" και τον τρέχοντα κωδικό σύνδεσής σας.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Δεν ήταν δυνατό να αποκρυπτογραφηθεί αυτό το αρχείο, πιθανόν πρόκειται για κοινόχρηστο αρχείο. Παρακαλούμε ζητήστε από τον κάτοχο του αρχείου να το ξαναμοιραστεί μαζί σας.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Δεν ήταν δυνατό να διαβαστεί αυτό το αρχείο, πιθανόν πρόκειται για κοινόχρηστο αρχείο. Παρακαλούμε ζητήστε από τον κάτοχο του αρχείου να το ξαναμοιραστεί μαζί σας.",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Η ενεργοποίηση αυτής της επιλογής κρυπτογραφεί όλα τα αρχεία που είναι αποθηκευμένα στον κύριο αποθηκευτικό χώρο, αλλιώς μόνο τα αρχεία σε εξωτερικούς αποθηκευτικούς χώρους θα κρυπτογραφηθούν",
    "Encrypt the home storage" : "Κρυπτογράφηση του κεντρικού χώρου αποθήκευσης",
    "Disable recovery key" : "Απενεργοποίηση κλειδιού ανάκτησης",
    "Enable recovery key" : "Ενεργοποίηση κλειδιού ανάκτησης",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "Το κλειδί ανάκτησης είναι ένα πρόσθετο κλειδί κρυπτογράφησης που χρησιμοποιείται για την κρυπτογράφηση αρχείων. Χρησιμοποιείται για την ανάκτηση αρχείων από έναν λογαριασμό εάν ξεχαστεί το συνθηματικό.",
    "Recovery key password" : "Συνθηματικό κλειδιού ανάκτησης",
    "Repeat recovery key password" : "Επαναλάβετε το συνθηματικό κλειδιού ανάκτησης",
    "Old recovery key password" : "Παλιό συνθηματικό κλειδιού ανάκτησης",
    "New recovery key password" : "Νέο συνθηματικό κλειδιού ανάκτησης",
    "Repeat new recovery key password" : "Επαναλάβετε το νέο συνθηματικό κλειδιού ανάκτησης",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Εάν δεν θυμάστε τον παλιό σας συνθηματικό, μπορείτε να ζητήσετε από το διαχειριστή σας να ανακτήσει τα αρχεία σας.",
    "Old log-in password" : "Παλαιό συνθηματικό σύνδεσης",
    "Current log-in password" : "Τρέχων συνθηματικό σύνδεσης",
    "Update" : "Ενημέρωση",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Η ενεργοποίηση αυτής της επιλογής θα σας επιτρέψει να επανακτήσετε πρόσβαση στα κρυπτογραφημένα σας αρχεία σε περίπτωση απώλειας του κωδικού σας",
    "Default encryption module" : "Προεπιλεγμένη μονάδα κρυπτογράφησης",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Η εφαρμογή κρυπτογράφησης είναι ενεργοποιημένη αλλά τα κλειδιά σας δεν έχουν αρχικοποιηθεί, παρακαλώ αποσυνδεθείτε και συνδεθείτε ξανά",
    "Basic encryption module" : "Βασική μονάδα κρυπτογράφησης",
    "Missing parameters" : "Ελλιπείς παράμετροι",
    "Default encryption module for server-side encryption" : "Προεπιλεγμένη μονάδα κρυπτογράφησης για κρυπτογράφηση στον διακομιστή",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Για να χρησιμοποιήσετε αυτή τη μονάδα κρυπτογράφησης, πρέπει να ενεργοποιήσετε την κρυπτογράφηση στον διακομιστή στις ρυθμίσεις διαχειριστή. Μόλις ενεργοποιηθεί, αυτή η μονάδα θα κρυπτογραφεί όλα τα αρχεία σας διαφανώς. Η κρυπτογράφηση βασίζεται σε κλειδιά AES 256.\nΗ μονάδα δεν θα αγγίξει τα υπάρχοντα αρχεία, μόνο τα νέα αρχεία θα κρυπτογραφηθούν αφού ενεργοποιηθεί η κρυπτογράφηση στον διακομιστή. Επίσης, δεν είναι δυνατό να απενεργοποιήσετε ξανά την κρυπτογράφηση και να επιστρέψετε σε ένα μη κρυπτογραφημένο σύστημα.\nΠαρακαλούμε διαβάστε την τεκμηρίωση για να γνωρίζετε όλες τις επιπτώσεις πριν αποφασίσετε να ενεργοποιήσετε την κρυπτογράφηση στον διακομιστή.",
    "Change recovery key password:" : "Αλλαγή συνθηματικού κλειδιού ανάκτησης:",
    "Change Password" : "Αλλαγή συνθηματικό",
    "Your private key password no longer matches your log-in password." : "Το συνθηματικό του ιδιωτικού κλειδιού σας δεν ταιριάζει πλέον με τον κωδικό σύνδεσής σας.",
    "Set your old private key password to your current log-in password:" : "Ορίστε τον παλιό σας συνθηματικό ιδιωτικού κλειδιού στον τρέχοντα κωδικό σύνδεσης:",
    "Update Private Key Password" : "Ενημέρωση Κωδικού Ιδιωτικού Κλειδιού",
    "Enable password recovery:" : "Ενεργοποίηση ανάκτησης συνθηματικού:",
    "Enabled" : "Ενεργοποιημένο",
    "Disabled" : "Απενεργοποιημένο"
},
"nplurals=2; plural=(n != 1);");
