OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Persona aktivaĵa fluo por %s",
    "Your feed URL is invalid" : "Via fluo-adreso ne validas",
    "Activity feed for %1$s" : "Aktivaĵa fluo por %1$s",
    "Activity feed" : "Aktivaĵa fluo",
    "Your settings have been updated." : "Viaj agordoj ĝisdatiĝis.",
    "Settings have been updated." : "Agordoj estis ĝisdatigitaj.",
    "remote user" : "fora uzanto",
    "Recent activity" : "Lastatempa aktiveco",
    "No activities" : "Neniu aktivaĵo",
    "More activities" : "Pli da aktivecoj",
    "Daily activity summary for %s" : "Taga resumo de aktiveco por %s",
    "_and %n more…_::_and %n more…_" : ["kaj %n pli…","kaj %n pli…"],
    "All activities" : "Ĉiuj aktivaĵoj",
    "By others" : "De aliuloj",
    "By you" : "De vi",
    "Activity at %s" : "Aktiveco ĉe %s",
    "Hello %s" : "Saluton %s",
    "Hello %s," : "Saluton %s,",
    "There was some activity at %s" : "Okazis kelkaj aktivaĵoj en %s",
    "_and %n more _::_and %n more _" : ["kaj %n aliaj ","kaj %n aliaj "],
    "Mail" : "Retpoŝto",
    "Push" : "Puŝi",
    "Activity" : "Aktivaĵoj",
    "Notifications" : "Atentigoj",
    "This application enables people to view a log of activities about them, their files or other data." : "Tiu ĉi aplikaĵo ebligas al homoj vidi protokolon de agoj pri si, siaj dosieroj aŭ aliaj datumoj.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Tiu programo ebligas al homoj vidi agojn ligitajn al siaj dosieroj kaj datumoj en Nextcloud.\n\t\tĈiu persono povas agordi siajn individuajn agadajn agordojn en la personaj agordoj,\n\t\tpor elekti, kian agadon oni devas puŝi al poŝtelefonoj, sendi per retpoŝto\n\t\taŭ ĉu ĉiutaga resumo estu sendita ĉiumatene.\n\t\tPli detalaj informoj troveblas en Aktivaĵo dokumentado.",
    "Send email" : "Sendi retpoŝtmesaĝon",
    "Send push notification" : "Sendi puŝan atentigon",
    "Activity notification configuration" : "Agordoj de aktivaĵaj atentigoj",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "You need to set up your email address before you can receive notification emails." : "Vi devas agordi vian retpoŝtadreson por povi ricevi sciigojn retmesaĝe.",
    "Send activity emails" : "Sendi aktivaĵajn retmesaĝojn",
    "As soon as possible" : "Kiel eble plej baldaŭ",
    "Hourly" : "Ĉiuhore",
    "Daily" : "Ĉiutage",
    "Weekly" : "Ĉiusemajne",
    "You commented" : "Vi komentis",
    "Message deleted by author" : "Mesaĝo estas forigita de aǔtoro",
    "Open {filename}" : "Malfermi {filename}",
    "in {path}" : "ene de {path}",
    "Home" : "Hejmo",
    "Could not load activities" : "Ne eblas ŝargi aktivaĵojn",
    "Loading activities" : "Ŝargante aktivaĵojn",
    "This stream will show events like additions, changes & shares" : "Tiu ĉi fluo montros eventojn kiel aldonojn, ŝanĝojn kaj kunhavigojn",
    "No activity yet" : "Ankoraŭ neniu aktivaĵo",
    "Loading more activities" : "Ŝargante pli da aktivaĵoj",
    "No more activities." : "Ne estas pli da aktivaĵoj",
    "Could not enable RSS link" : "Ne eblis ebligi RSS-ligilon",
    "RSS link copied to clipboard" : "RSS ligilo estas kopiita al tondujo",
    "Could not copy the RSS link, please copy manually:" : "Ne eblis kopii la aplikaĵan pasvorton. Bv kopii ĝin permane.",
    "Activity settings" : "Agordoj de aktivaĵoj",
    "Enable RSS feed" : "Aktivigi RSS-fluon",
    "RSS feed" : "RSS-fluo",
    "Copy RSS feed link" : "Kopii RSS-fluan ligilon",
    "Personal notification settings" : "Agordoj de persona sciigo",
    "Unable to load the activity list" : "Ne eblis ŝargi la liston de aktivaĵoj",
    "Choose for which activities you want to get an email or push notification." : "Elektu pri kiuj aktivaĵoj vi volas ricevi retpoŝton aŭ puŝan sciigon.",
    "Choose for which activities you want to get a push notification." : "Elektu por kiuj aktivaĵoj vi volas ricevi puŝan sciigon.",
    "Notification" : "Atentigo",
    "Enable notification emails" : "Ebligi atentigajn retmesaĝojn",
    "Daily activity summary" : "Ĉiutaga resumo de aktivaĵoj",
    "Send daily activity summary in the morning" : "Sendi ĉiutagan aktivaĵan resumon matene",
    "Default settings" : "Defaŭltaj agordoj",
    "Configure the default notification settings for new accounts." : "Agordi la defaŭltajn sciigajn agordojn por novaj kontoj.",
    "Unable to save the settings" : "Ne eblis konservi la agordojn",
    "No more events to load" : "Ne plu ŝargeblaj eventoj"
},
"nplurals=2; plural=(n != 1);");
