OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikkje støtta!",
    "Press ⌘-C to copy." : "Trykk  ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "Unknown" : "Ukjend",
    "System" : "System",
    "Monitoring" : "Overvåker",
    "Size:" : "Storleik:",
    "Files:" : "Filar:",
    "Active users" : "Aktive brukarare",
    "Shares" : "Delingar",
    "Users:" : "Brukarare:",
    "Upload max size:" : "Maks opplastning storleik:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Eksternt monoitor verktøy",
    "Copy" : "Kopier"
},
"nplurals=2; plural=(n != 1);");
