OC.L10N.register(
    "comments",
    {
    "Comments" : "კომენტარები",
    "You commented" : "თქვენი კომენტარი",
    "{author} commented" : "{author}-ის კომენტარი",
    "You commented on %1$s" : "თქვენი კომენტარი %1$s-ზე",
    "You commented on {file}" : "თქვენი კომენტარი {file}-ზე",
    "%1$s commented on %2$s" : "%1$s-მა დატოვა კომენტარი %2$s-ზე",
    "{author} commented on {file}" : "{author}-მა დატოვა კომენტარი {file}-ზე",
    "<strong>Comments</strong> for files" : "<strong>კომენტარები</strong> ფაილებისთვის",
    "Files" : "ფაილები",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "თქვენ გახსენეს \"{file}\"-ის კომენტარში ანგარიშიდან, რომელიც მის შემდეგ წაიშალა",
    "{user} mentioned you in a comment on \"{file}\"" : "{user}-მა გახსენათ კომენტარში ფაილზე \"{file}\"",
    "Files app plugin to add comments to files" : "Files აპის დამატება ფაილებზე კომენტარების დასამატებლად",
    "Edit comment" : "კომენტარის ჩასწორება",
    "Delete comment" : "კომენტარის წაშლა",
    "Cancel edit" : "ჩასწორების გაუქმება",
    "New comment" : "ახალი კომენტარი",
    "Write a comment …" : "კომენტარის დაწერა …",
    "Post comment" : "კომენტარის დაპოსტვა",
    "@ for mentions, : for emoji, / for smart picker" : "@ ხსენებისთვის, : ემოჯისთვის, / ჭკვიანი ამრჩევისთვის",
    "Could not reload comments" : "კომენტარების თავიდან ჩატვირთვა შეუძლებელია",
    "Failed to mark comments as read" : "კომენტარების წაკითხულად მონიშვნა ჩავარდა",
    "Unable to load the comments list" : "კომენტარების სიის ჩატვირთვა ჩავარდა",
    "No comments yet, start the conversation!" : "ჯერ კომენტარები არაა. დაიწყეთ საუბარი!",
    "No more messages" : "მეტი შეტყობინება აღარაა",
    "Retry" : "თავიდან ცდა",
    "_1 new comment_::_{unread} new comments_" : ["1 ახალი კომენტარი","{unread} ახალი კომენტარი"],
    "Comment" : "კომენტარი",
    "An error occurred while trying to edit the comment" : "კომენტარის ჩასწორებისას აღმოჩენილია შეცდომა",
    "Comment deleted" : "კომენტარი წაიშალა",
    "An error occurred while trying to delete the comment" : "კომენტარის წაშლისას აღმოჩენილია შეცდომა",
    "An error occurred while trying to create the comment" : "კომენტარის შექმნისას აღმოჩენილია შეცდომა",
    "Write a comment …" : "კომენტარის დაწერა …"
},
"nplurals=2; plural=(n!=1);");
