OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "مشاركات الملفات",
    "Downloaded via public link" : "تمّ تنزيله عبر رابط عام",
    "Downloaded by {email}" : "تمّ التنزيل بواسطة {email}",
    "{file} downloaded via public link" : "تمّ تنزيل {file} عبر رابط عام",
    "{email} downloaded {file}" : "{email} قام بتنزيل {file}",
    "Shared with group {group}" : "تمت مشاركته مع المجموعة {group}",
    "Removed share for group {group}" : "تمت إزالة مشاركة المجموعة {group}",
    "{actor} shared with group {group}" : "قام {actor} بالمشاركة مع المجموعة {group}",
    "{actor} removed share for group {group}" : "أزال {actor} المشاركة مع المجموعة {group}",
    "Share for group {group} expired" : "إنتَهت صلاحية المشاركة مع المجموعة {group}",
    "You shared {file} with group {group}" : "لقد شاركت أنت {file} مع المجموعة {group}",
    "You removed group {group} from {file}" : "لقد أزلت المجموعة {group} من {file}",
    "{actor} shared {file} with group {group}" : "{actor} شارك {file} مع المجموعة {group}",
    "{actor} removed group {group} from {file}" : "قام {actor} بإزالة المجموعة {group} من {file}",
    "Share for file {file} with group {group} expired" : "إنتَهَت صلاحية مشاركة الملف {file} مع المجموعة {group}",
    "Shared as public link" : "تمّت مشاركته كرابط عام",
    "Removed public link" : "تمّت إزالة الرابط العام",
    "Public link expired" : "انتهت صلاحية الرابط العام",
    "{actor} shared as public link" : "قام {actor} بالمشاركة كرابط عام",
    "{actor} removed public link" : "{actor} قام بإزالة الرابط العام",
    "Public link of {actor} expired" : "إنتَهَت صلاحية الرابط العام لـ {actor}",
    "You shared {file} as public link" : "لقد شاركت أنت {file} كرابط عام",
    "You removed public link for {file}" : "لقد أزلت الرابط العام لـ {file}",
    "Public link expired for {file}" : "إنتهت صلاحية الرابط العام لـ {file}",
    "{actor} shared {file} as public link" : "قام {actor} بمشاركة {file} كرابط عام",
    "{actor} removed public link for {file}" : "قام {actor} بإزالة الرابط العام لـ {file}",
    "Public link of {actor} for {file} expired" : "انتهت صلاحية الرابط العام لـ {actor} لـ {file}",
    "{user} accepted the remote share" : "وافق {user} على المشاركة البعيدة remote",
    "{user} declined the remote share" : "رفض {user} المشاركة البعيدة remote",
    "You received a new remote share {file} from {user}" : "لقد تلقيت أنت مشاركة بعيدة remote جديدة {file} من {user}",
    "{user} accepted the remote share of {file}" : "وافق {user} على المشاركة البعيدة لـ {file} ",
    "{user} declined the remote share of {file}" : "رفض {user} المشاركة البعيدة لـ {file}",
    "{user} unshared {file} from you" : "ألغى {user} مشاركة {file} معك",
    "Shared with {user}" : "تمّت المشاركة مع {user}",
    "Removed share for {user}" : "تمّت إزالة المشاركة لـ {user}",
    "You removed yourself" : "قمت بإزالة نفسك",
    "{actor} removed themselves" : "أزال {actor} أنفسهم",
    "{actor} shared with {user}" : "قام {actor} بالمشاركة مع {user}",
    "{actor} removed share for {user}" : "أزال {actor} المشاركة مع {user}",
    "Shared by {actor}" : "تمّت مشاركته بواسطة {actor}",
    "{actor} removed share" : "قام {actor} بإزالة المشاركة",
    "Share for {user} expired" : "إنتَهَت صلاحية المشاركة مع {user}",
    "Share expired" : "إنتَهَت صلاحية المشاركة",
    "You shared {file} with {user}" : "لقد شاركت أنت {file} مع {user}",
    "You removed {user} from {file}" : "لقد أزلت أنت مشاركة {user} من {file}",
    "You removed yourself from {file}" : "لقد أزلت نفسك من {file}",
    "{actor} removed themselves from {file}" : "أزال {actor} نفسه من {file}",
    "{actor} shared {file} with {user}" : "قام {actor} بمشاركة {file} مع {user}",
    "{actor} removed {user} from {file}" : "قام {actor} بإزالة {user} من {file}",
    "{actor} shared {file} with you" : "قام {actor} بمشاركة {file} معك",
    "{actor} removed you from the share named {file}" : "أزالك {actor} من مشاركة الملف {file}",
    "Share for file {file} with {user} expired" : "إنتَهَت صلاحية مشاركة الملف {file} مع {user}",
    "Share for file {file} expired" : "إنتَهَت صلاحية المشاركة للملف {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "تمّ <strong>تنزيل</strong> ملف أو مجلد مشترك عن طريق البريد أو الرابط العام",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "تمّ رفع <strong>ملفات</strong> إلى مجلد مشترك عبر الإيميل أو عبر رابط عمومي",
    "A file or folder was shared from <strong>another server</strong>" : "تمّت مشاركة ملف أو مجلد من خادم آخر</strong>",
    "Sharing" : "المشاركة",
    "A file or folder has been <strong>shared</strong>" : "تمّت <strong>مشاركة </strong> ملف أو مجلد",
    "Shared link" : "رابط المشاركة",
    "Wrong share ID, share does not exist" : "خطأ في مُعرِّف المشاركة sahre ID. المشاركة غير موجودة",
    "Could not delete share" : "لا يمكن حذف المشاركة",
    "Please specify a file or folder path" : "يرجى تحديد مسار ملف أو مجلد",
    "Wrong path, file/folder does not exist" : "مسار الملف أو المجلد غير موجود",
    "Could not create share" : "لا يمكن انشاء مشاركة",
    "Please specify a valid account to share with" : "رجاءً، قم بتحديد حساب صحيح للمشاركة معه",
    "Group sharing is disabled by the administrator" : "مشاركة المجموعة معطّلة من قِبَل مسؤول النظام",
    "Please specify a valid group" : "يرجى تحديد مجموعة صحيحة",
    "Public link sharing is disabled by the administrator" : "المشاركة عن طريق الروابط العامة معطّلة من قِبَل مسؤول النظام",
    "Please specify a valid email address" : "من فضلك، عيٍّن عنواناً صحيحاً للبريد الإلكتروني",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "مشاركة %s لارسال كلمة المرور من قبل تطبيق \"المحادثة Talk\" نكست كلاود فشلت بسبب عدم تفعيل التطبيق.",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "فشلت مشاركة %1$s لأن الخادم لا يسمح بالمشاركة من النوع %2$s",
    "Please specify a valid federated account ID" : "يرجى تحديد معرف صحيح لحساب السحابة الموحدة",
    "Please specify a valid federated group ID" : "يرجى تعيين معرف صحيح لمجموعة السحابة الموحدة",
    "You cannot share to a Team if the app is not enabled" : "لا يمكنك المشاركة مع فريق إذا لم يكن التطبيق مُمكّناً",
    "Please specify a valid team" : "من فضلك، قم بتحديد فريق صحيح",
    "Sharing %s failed because the back end does not support room shares" : "فشلت مشاركة %s لأن الخلفية back end لا تدعم مشاركات الغُرَف room shares",
    "Unknown share type" : "نوع مشاركة غير معروف",
    "Not a directory" : "ليس مُجلّداً صحيحاً",
    "Could not lock node" : "تعذّر قَفْل lock النقطة node",
    "Public upload is only possible for publicly shared folders" : "عمليات الرفع العامة مسموحة فقط في المجلدات المشاركة",
    "Share must at least have READ or CREATE permissions" : "يجب أن تمتلك المشاركة أذونات الإنشاء CREATE و القراءة READ على الأقل",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "يجب أن تمتلك المشاركة إذن القراءة READ إذا كانت أذونات UPDATE أو DELETE مُعيّنة  ",
    "Public upload disabled by the administrator" : "عمليات الرفع العامة معطّلة من قِبَل مسؤول النظام",
    "Could not lock path" : "تعذّر قَفْل lock المسار path",
    "no sharing rights on this item" : "لا توجد حقوق مشاركة في هذا العنصر",
    "You are not allowed to edit incoming shares" : "أنت غير مسموحٍ لك بتعديل المشاركات الواردة",
    "Wrong or no update parameter given" : "خطأ أو لم يتم تقديم مدخلات التحديث update paramete",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"عملية إرسال كلمة المرور بواسطة تطبيق نكست كلاود للمحادثة Talk\" من أجل مشاركة ملف أو مُجلّد لم تُنفّذ بسبب أن التطبيق غير مُفعّل",
    "Custom share link tokens have been disabled by the administrator" : "أَمَارَات روابط المشاركة المخصصة تمّ تعطيلها من قِبَل المشرف",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "الأَمَارَات يجب أن تحوي حرفاً واحداً 1 على الأقل ويجب أن تحوي فقط حروفاً أو أرقاماً أو شَرْطَات.",
    "Invalid date. Format must be YYYY-MM-DD" : "التاريخ غير صحيح. يجب أن يكون على الصيغة YYYY-MM-DD",
    "No sharing rights on this item" : "لا توجد حقوق مشاركة في هذا العنصر",
    "Invalid share attributes provided: \"%s\"" : "خصائص المشاركة المعطاة غير صحيحة: \"%s\"",
    "You are not allowed to send mail notifications" : "أنت غير مسموحٍ لك بإرسال إشعارات الإيميل",
    "No mail notification configured for this share type" : "لا توجد إشعارات بريد مهيّأة لهذا النوع من المشاركات ",
    "Wrong password" : "كلمة المرور غير صحيحة",
    "Error while sending mail notification" : "حدث خطأ أثناء إرسال إشعار بإيميل",
    "Failed to generate a unique token" : "تعذّر توليد أَمَارَة مُميّزة",
    "This share does not exist or is no longer available" : "هذه المشاركة غير موجودة أو لم تعد متاحة الآن",
    "shared by %s" : "تمّت مشاركته مِن قبل %s",
    "Download" : "تنزيل",
    "Add to your %s" : "أضاف إليك %s",
    "Direct link" : "رابط مباشر",
    "Share API is disabled" : "المشاركة عبر واجهة برمجة التطبيقات API مُعطّلة",
    "File sharing" : "مشاركة الملفات",
    "Share will expire tomorrow" : "المشاركة ستنتهي صلاحيتها غداً",
    "Your share of {node} will expire tomorrow" : "مشاركتك لـ {node} ستنتهي صلاحيتها غدًا",
    "You received {share} as a share by {user}" : "لقد تلقيت أنت {share} كمشاركة من قِبَل {user}",
    "You received {share} to group {group} as a share by {user}" : "لقد تلقيت أنت {share} كمشاركة ضمن المجموعة {group} من قِبَل {user}",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Remember to upload the files to %s" : "لا تنس رفع الملفات إلى %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "نود أن نذكرك بأنك لم تقم حتى الآن بتحميل أيّ ملفات إلى المجلد المشترك.",
    "Open \"%s\"" : "إفتَح \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "يُمكِّن هذا التطبيق الأشخاص من مشاركة الملفات داخل نكست كلاود. عند تمكينه، يُمكِّن المدير تحديد المجموعات التي يمكنها مشاركة الملفات. يمكن للأشخاص المعنيين بعد ذلك مشاركة الملفات والمجلدات مع حسابات ومجموعات أخرى داخل نكست كلاود. بالإضافة إلى ذلك، إذا قام المدير بتمكين ميزة رابط المشاركة، فيمكن استخدام رابط خارجي لمشاركة الملفات مع أشخاص آخرين خارج نكست كلاود. يمكن للمديرين أيضًا فرض كلمات المرور و تواريخ انتهاء الصلاحية و تمكين المشاركة من خادم إلى خادم عبر روابط المشاركة؛ بالإضافة إلى المشاركة من الأجهزة المحمولة. بالمقابل، يؤدي تعطيل التطبيق إلى إزالة الملفات والمجلدات المشتركة على الخادم لدي جميع مستلمي المشاركة، و كذلك على عملاء المزامنة و تطبيقات الأجهزة المحمولة. \nللمزيد من المعلومات، أنظُر توثيق نكست كلاود.",
    "Filter accounts" : "تصفية الحسابات",
    "you" : "أنت",
    "The request will expire on {date} at midnight and will be password protected." : "سوف تنتهي صلاحية الطلب في {date} عند منتصف الليل، و سيكون محميّاً بكلمة مرور.",
    "The request will expire on {date} at midnight." : "سوف تنتهي صلاحية الطلب في {date} عند منتصف الليل.",
    "The request will be password protected." : "سوف يكون الطلب محميّاً بكلمة مرور.",
    "When should the request expire?" : "متى يجب أن تنتهي صلاحية الطلب؟",
    "Set a submission expiration date" : "تعيين وقت انتهاء صلاحية الإرسال",
    "Expiration date" : "تاريخ إنتهاء صلاحية المشاركة",
    "Select a date" : "إختر تاريخاً",
    "Your administrator has enforced a {count} days expiration policy." : "قام مسؤول النظام بفرض سياسة {count} أيام لانتهاء الصلاحية.",
    "What password should be used for the request?" : "هل يجب استعمال كلمة مرور لهذا الطلب؟",
    "Set a password" : "تعيين كلمة المرور",
    "Password" : "كلمة المرور",
    "Enter a valid password" : "أدخِل كلمة مرور صحيحة",
    "Generate a new password" : "توليد كلمة مرور جديدة",
    "Your administrator has enforced a password protection." : "مسؤول النظام قام بفرض الحماية عن طريق كلمة المرور.",
    "Automatically copying failed, please copy the share link manually" : "تعذّر النسخ التلقائي. قم رجاءً بنسخ رابط المشاركة يدويّاً",
    "Link copied" : "تمّ نسخ الرابط",
    "Email already added" : "الإيميل سبقت إضافته سلفاً",
    "Invalid email address" : "عنوان الإيميل غير صحيح",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["عنوان الإيميل التالي غير صحيح: {emails}","عنوان الإيميل التالي غير صحيح: {emails}","عنوان الإيميل التالي غير صحيح: {emails}","عناوين الإيميل التالية غير صحيحة: {emails}","عناوين الإيميل التالية غير صحيحة: {emails}","عناوين الإيميل التالية غير صحيحة: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} عنوان بريد إلكتروني مضاف مسبقاً","{count} عنوان بريد إلكتروني مضاف مسبقاً","{count} عناوين بريد إلكتروني مضافة مسبقاً","{count} عناوين بريد إلكتروني مضافة مسبقاً","{count} عناوين بريد إلكتروني مضافة مسبقاً","{count} عناوين بريد إلكتروني مضافة مسبقاً"],
    "_{count} email address added_::_{count} email addresses added_" : ["تمت إضافة {count} عنوان بريد إلكتروني ","تم إضافة {count} عنوان بريد إلكتروني ","تم إضافة {count} عناوين بريد إلكتروني ","تمت  إضافة {count} عناوين بريد إلكتروني ","تمت  إضافة {count} عناوين بريد إلكتروني ","تمت إضافة {count} عناوين بريد إلكتروني "],
    "You can now share the link below to allow people to upload files to your directory." : "يمكنك الآن مشاركة الرابط أدناه للسماح للأشخاص برفع الملفات إلى دليلك.",
    "Share link" : "رابط المشاركة",
    "Copy" : "إنسَخ",
    "Send link via email" : "إرسال رابط عبر الإيميل",
    "Enter an email address or paste a list" : "أدخِل عنوان إيميل أو إلصِق قائمةً",
    "Remove email" : "حذف  البريد الإلكتروني",
    "Select a destination" : "اختر وجهة",
    "Select" : "تحديد",
    "What are you requesting?" : "ماذا تطلب؟",
    "Request subject" : "موضوع الطلب",
    "Birthday party photos, History assignment…" : "صور حفلات الميلاد، أو تاريخ المهام...",
    "Where should these files go?" : "أين يجب أن يتم نقل هذه الملفات؟",
    "Upload destination" : "وجهة رفع الملفات",
    "Revert to default" : "عُد إلى التلقائي",
    "The uploaded files are visible only to you unless you choose to share them." : "الملفات المرفوعة تكون ظاهرة لك فقط إلا إذا قررت مشاركتها",
    "Add a note" : "إضافة ملاحظة",
    "Note for recipient" : "ملاحظة للمستلم",
    "Add a note to help people understand what you are requesting." : "إضافة ملاحظة لتوضح للآخرين ما تطلبه",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "يمكنك إضافة روابط أو تاريخ أو أي معلومات أخرى من شأنها أن تساعد المستلم على فهم ما تطلبه.",
    "Close" : "إغلاق",
    "_Send email and close_::_Send {count} emails and close_" : ["أرسِل {count} إيميل ثم أغلِق","أرسِل الإيميل ثم أغلِق","أرسِل {count} إيميل ثم أغلِق","أرسِل {count} إيميلات ثم أغلِق","أرسِل {count} إيميلات ثم أغلِق","أرسِل {count} إيميلات ثم أغلِق"],
    "Please select a folder, you cannot share the root directory." : "من فضلك، إختر مجلداً. لا يمكنك مشاركة المجلد الجذر.",
    "File request created" : "تمّ إنشاء طلب لملف",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["تمّ إنشاء طلب للملف، و تمّ إرسال {count} إيميل","تمّ إنشاء طلب للملف، و تمّ إرسال الإيميل","تمّ إنشاء طلب للملف، و تمّ إرسال {count} إيميل","تمّ إنشاء طلب للملف، و تمّ إرسال {count} إيميلات","تمّ إنشاء طلب للملف، و تمّ إرسال {count} إيميلات","تمّ إنشاء طلب للملف، و تمّ إرسال {count} إيميلات"],
    "Error creating the share: {errorMessage}" : "خطأ في إنشاء المشاركة: {errorMessage}",
    "Error creating the share" : "خطأ في إنشاء المشاركة",
    "Error sending emails: {errorMessage}" : "حدث خطأ في إرسال الإيميلات: {errorMessage}",
    "Error sending emails" : "حدث خطأ في إرسال الإيميلات",
    "Create a file request" : "إنشاء طلب لملف",
    "Collect files from others even if they do not have an account." : "قم بجمع الملفات من الآخرين حتى لو لم يكونوا يملكون حسابات مسجلة",
    "To ensure you can receive files, verify you have enough storage available." : "لضمان استلامك للملفات، تحقَّق من كفاية حصتك التخزينية.",
    "File request" : "طلب الملف",
    "Previous step" : "الخطوة السابقة",
    "Cancel" : "إلغاء",
    "Cancel the file request creation" : "إلغاء عملية إنشاء طلب الملف",
    "Close without sending emails" : "أغلِق بدون إرسال إيميلات",
    "Continue" : "متابعة",
    "Error while toggling options" : "خطأ أثناء تبديل الخيارات",
    "Accept shares from other accounts and groups by default" : "قبول المشاركات من الحسابات والمجموعات الأخرى تلقائياً وبشكل افتراضي",
    "Choose a default folder for accepted shares" : "إختر مجلداً افتراضياً لقبول المشاركات",
    "Invalid path selected" : "المسار المُحدَّد غير صحيح",
    "Unknown error" : "خطأ غير معروف",
    "Set default folder for accepted shares" : "تعيين المجلد الافتراضي للمشاركات المقبولة",
    "Reset" : "إعادة تعيين",
    "Reset folder to system default" : "إعادة تعيين المجلد إلى افتراضات النظام",
    "Share Expiration" : "تاريخ انتهاء صلاحية المشاركة",
    "group" : "مجموعة",
    "conversation" : "محادثة",
    "remote" : "قَصِيٌّ remote",
    "remote group" : "مجموعة قَصِيّة remote",
    "guest" : "ضيف",
    "by {initiator}" : "من قِبَل{initiator}",
    "Shared with the group {user} by {owner}" : "تمّت مشاركته مع المجموعة {user} من قِبَل {owner}",
    "Shared with the conversation {user} by {owner}" : "تمّت مشاركته مع المحادثة {user} من قِبَل {owner}",
    "Shared with {user} by {owner}" : "تمّت مشاركته مع {user} من قِبَل {owner}",
    "Open Sharing Details" : "فتح تفاصيل المشاركة",
    "Added by {initiator}" : "تمّت الإضافةمن قِبَل {initiator}",
    "Via “{folder}”" : "عبر “{folder}”",
    "Unshare" : "إلغاء المشاركة",
    "Cannot copy, please copy the link manually" : "يتعذّر النسخ. يُرجى نسخ الرابط يدويًا",
    "Copy internal link" : "إنسخ الرابط الداخلي",
    "Internal link" : "رابط داخلي",
    "{shareWith} by {initiator}" : "{shareWith} مِن قِبَل {initiator}",
    "Shared via link by {initiator}" : "تمّت المشاركة عبر رابط من قِبَل {initiator}",
    "File request ({label})" : "طلب الملف ({label})",
    "Mail share ({label})" : "مشاركة البريد ({label})",
    "Share link ({label})" : "رابط المشاركة ({label})",
    "Mail share" : "مشاركة الإيميل",
    "Share link ({index})" : "رابط المشاركة ({index})",
    "Create public link" : "إنشاء رابط عمومي",
    "Actions for \"{title}\"" : "إجراءات لـ \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "خطأ؛ يرجى إدخال كلمة المرور الصحيحة أو تاريخ انتهاء الصلاحية",
    "Link share created" : "تمّ إنشاء رابط مشاركة",
    "Error while creating the share" : "خطأ أثناء إنشاء المشاركة",
    "Please enter the following required information before creating the share" : "الرجاء إدخال المعلومات المطلوبة التالية قبل إنشاء المشاركة",
    "Password protection (enforced)" : "الحماية بكلمة مرور (إلزامي)",
    "Password protection" : "الحماية بكلمة مرور",
    "Enter a password" : "إدخِل كلمة المرور",
    "Enable link expiration (enforced)" : "تمكين انتهاء صلاحية الرابط (مُفعَّل)",
    "Enable link expiration" : "تمكين انتهاء صلاحية الرابط",
    "Enter expiration date (enforced)" : "أدخِل تاريخ انتهاء الصلاحية (مُفعَّل)",
    "Enter expiration date" : "أدخِل تاريخ انتهاء الصلاحية",
    "Create share" : "إنشاء مشاركة",
    "Customize link" : "تخصيص الرابط",
    "Generate QR code" : "توليد رمز استجابة سريعة QR",
    "Add another link" : "إضافة رابط آخر",
    "Create a new share link" : "إنشاء رابط مشاركة جديد",
    "Quick share options, the current selected is \"{selectedOption}\"" : "خيارات المشاركة السريعة. الاختيار الحالي هو \"{selectedOption}\"",
    "View only" : "للعرض فقط",
    "Can edit" : "يمكنه التعديل",
    "Custom permissions" : "أذونات مخصصة",
    "Resharing is not allowed" : "لا يسمح بإعادة المشاركة",
    "No elements found." : "لم يتم العثور على أي عناصر",
    "Search everywhere" : "البحث الشامل",
    "Guest" : "ضيف",
    "Group" : "المجموعة",
    "Email" : "البريد الإلكتروني",
    "Team" : "الفريق",
    "Talk conversation" : "المحادثات",
    "Deck board" : "لوحة البطاقات",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "على {server}",
    "Enter external recipients" : "إدخال مُستَلِمين خارجيين",
    "Search for internal recipients" : "البحث عن مُستَلِمين خارجيين",
    "Note from" : "ملاحظة من",
    "Note:" : "ملاحظة:",
    "File drop" : "إسقاط الملف",
    "Upload files to {foldername}." : "رفع الملفات إلى {foldername}.",
    "By uploading files, you agree to the terms of service." : "بمجرد رفعك للملفات، أنت تعتبر موافقاً على شروط الخدمة.",
    "View terms of service" : "عرض شروط الخدمة",
    "Terms of service" : "شروط الخدمة",
    "Share with email {email}" : "مشاركة مع صاحب البريد الإلكتروني {email}",
    "Share with group" : "شارِك مع مجموعة",
    "Share in conversation" : "شارِك في محادثة",
    "Share with {user} on remote server {server}" : "مشاركة مع المستخدِم {user} على خادم البعيد {server}",
    "Share with remote group" : "شارِك مع مجموعة قَصِيّة",
    "Share with guest" : "شارِك مع ضيف",
    "Update share" : "تحديث المشاركة",
    "Save share" : "حفظ المشاركة",
    "Read" : "قراءة",
    "Create" : "إنشاء ",
    "Edit" : "تعديل",
    "Share" : "مشاركة",
    "Delete" : "حذف",
    "Password field cannot be empty" : "خانة كلمة المرور يجب ألّا تكون فارغةً",
    "Replace current password" : "استبدال كلمة المرور الحالية",
    "Failed to generate a new token" : "تعذّر توليد أَمَارَة جديدة",
    "Allow upload and editing" : "السماح بالرفع و التعديل",
    "Allow editing" : "السماح بالتعديل",
    "Upload only" : "رفع فقط",
    "Advanced settings" : "الإعدادات المتقدمة",
    "Share label" : "علامة رابط المشاركة",
    "Share link token" : "أَمَارَة رابط المشاركة",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "عيّن أَمَارَة رابط المشارَكة العامة على شيء يسهل تذكره أو أنشئ أَمَارَة جديدة. لا يُنصح باستعمال أَمَارَة يمكن تخمينها للمشارَكات التي تحتوي على معلومات حساسة.",
    "Generating…" : "توليد ...",
    "Generate new token" : "توليد أَمَارَة جديدة",
    "Set password" : "تعيين كلمة المرور",
    "Password expires {passwordExpirationTime}" : "صلاحية كلمة المرور تنتهي في {passwordExpirationTime}",
    "Password expired" : "كلمة المرور إنتهت صلاحيتها",
    "Video verification" : "التحقق بواسطة الفيديو",
    "Expiration date (enforced)" : "تاريخ انتهاء الصلاحية (إلزامي)",
    "Set expiration date" : "تعيين تاريخ إنتهاء الصلاحية",
    "Hide download" : "إخفاء التنزيل",
    "Allow download and sync" : "السماح بالتنزيل و المزامنة",
    "Note to recipient" : "ملاحظة للمستلم",
    "Enter a note for the share recipient" : "أدخل ملاحظة لمستلم المشاركة",
    "Show files in grid view" : "عرض الملفات في وضعية الشبكة",
    "Delete share" : "حذف المشاركة",
    "Others with access" : "الآخرون الذين لديهم حق الوصول",
    "No other accounts with access found" : "لا يوجد أي أشخاص آخرين يمكنهم الوصول إلى هذا الملف",
    "Toggle list of others with access to this directory" : "تعطيل/تفعيل قائمة الآخرين الذين لديهم حق الوصول إلى هذا الدليل",
    "Toggle list of others with access to this file" : "تعطيل/تفعيل قائمة الآخرين الذين لديهم حق الوصول إلى هذا الملف",
    "Unable to fetch inherited shares" : "تعذّر جلب المشاركات الموروثة inherited shares",
    "Link shares" : "ربط المشاركات",
    "Shares" : "مشاركات",
    "Unable to load the shares list" : "تعذّر تحميل قائمة المشاركات",
    "Expires {relativetime}" : "تنتهي الصلاحية في {relativetime}",
    "this share just expired." : "صلاحية هذه المشاركة إنتَهَت للتَّوّ.",
    "Shared with you by {owner}" : "تمّت مشاركته معك من قِبَل {owner}",
    "Internal shares" : "مشاركات داخلية",
    "Internal shares explanation" : "شرح المشاركات الداخلية",
    "External shares" : "مشاركات خارجية",
    "External shares explanation" : "شرح مشاركات خارجية",
    "Additional shares" : "مشاركات إضافية",
    "Additional shares explanation" : "شرح مشاركات إضافية",
    "Link to a file" : "رابط إلى ملف",
    "_Accept share_::_Accept shares_" : ["قبول المشاركات","قبول المشاركة","قبول المشاركات","قبول المشاركات","قبول المشاركات","قبول المشاركات"],
    "Open in Files" : "إفتَح في \"الملفات\"",
    "_Reject share_::_Reject shares_" : ["رفض المشاركات","رفض المشاركة","رفض المشاركات","رفض المشاركات","رفض المشاركات","أرفُض المشاركات"],
    "_Restore share_::_Restore shares_" : ["استعادة المشاركات","استعادة المشاركة","استعادة المشاركات","استعادة المشاركات","استعادة المشاركات","إستعادة المشاركات"],
    "Shared" : "مشاركة",
    "Shared by {ownerDisplayName}" : "تمّت مشاركته من قِبَل {ownerDisplayName}",
    "Shared multiple times with different people" : "تمّت مشاركته عدة مرات مع أشخاص متعددين",
    "Shared with others" : "قمت بمشاركته مع آخرين",
    "People" : "الأشخاص",
    "Create file request" : "إنشاء طلب ملف",
    "Upload files to {foldername}" : "رفع الملفات إلى{foldername}",
    "Public file share" : "مشاركة ملفات عامة",
    "Publicly shared file." : "ملفات مشتركة عامة.",
    "No file" : "لا يوجد ملف",
    "The file shared with you will show up here" : "الملفات المشتركة معك سوف تظهر هنا",
    "Public share" : "مشاركة عامة",
    "Publicly shared files." : "ملفات مشتركة عامة.",
    "No files" : "لا ملفات",
    "Files and folders shared with you will show up here" : "الملفات و المجلدات المشتركة معك ستظهر هنا",
    "Overview of shared files." : "إستعراض الملفات المُشَارَكَة",
    "No shares" : "لا توجد مشاركات",
    "Files and folders you shared or have been shared with you will show up here" : "الملفات و المجلدات التي شاركتها مع آخرين أو شاركها آخرون معك ستظهر هنا",
    "Shared with you" : "تمت مشاركته معك",
    "List of files that are shared with you." : "قائمة بالملفات التي تمّت مُشارَكتها معك.",
    "Nothing shared with you yet" : "لم تتمّ مشاركة شيء معك حتى الآن",
    "Files and folders others shared with you will show up here" : "الملفات و المجلدات التي شاركها آخرون معك ستظهر هنا",
    "List of files that you shared with others." : "قائمة بالملفات التي شاركتها أنت مع الآخرين.",
    "Nothing shared yet" : "لا توجد مشاركة حتى الآن",
    "Files and folders you shared will show up here" : "الملفات و المجلدات التي شاركتها أنت مع آخرين ستظهر هنا",
    "Shared by link" : "تمت مشاركته عبر رابط",
    "List of files that are shared by link." : "قائمة بالملفات التي تمّت مشاركتها عبر رابط.",
    "No shared links" : "لا توجد روابط لمشاركات",
    "Files and folders you shared by link will show up here" : "الملفات و المجلدات التي شاركتها أنت مع آخرين عن طريق رابط ستظهر هنا",
    "File requests" : "طلبات الملفات",
    "List of file requests." : "قائمة طلبات الملفات.",
    "No file requests" : "لا توجد أي طلبات للملفات",
    "File requests you have created will show up here" : "طلبات الملفات التي أنشأتها سيتم عرضها هنا",
    "Deleted shares" : "مشاركات محذوفة",
    "List of shares you left." : "قائمة بالمشاركات التي قمت بإلغائها",
    "No deleted shares" : "لا توجد أي مشاركات محذوفة",
    "Shares you have left will show up here" : "المشاركات التي ألغيتها ستظهر هنا",
    "Pending shares" : "مشاركات بانتظار الموافقة",
    "List of unapproved shares." : "قائمة بالمشاركات بانتظار الموافقة.",
    "No pending shares" : "لا توجد مشاركات بانتظار الموافقة",
    "Shares you have received but not approved will show up here" : "المشاركات التي تلقيت دعواتها لكنك لم توافق عليها ستظهر هنا",
    "Error updating the share" : "خطأ في تحديث المشاركة",
    "File \"{path}\" has been unshared" : "الملف \"{path}\" تمّ إلغاء مشاركته",
    "Folder \"{path}\" has been unshared" : "المجلّد \"{path}\" تمّ إلغاء مشاركته",
    "Could not update share" : "يتعذّر تحديث المشاركة",
    "Share saved" : "تمّ حفظ المشاركة",
    "Share expiry date saved" : "تمّ حفظ تاريخ انتهاء صلاحية المشاركة",
    "Share hide-download state saved" : "تمّ حفظ حالة إخفاء تنزيل المشاركة",
    "Share label saved" : "تمّ حفظ عنوان المشاركة",
    "Share note for recipient saved" : "تمّ حفظ ملاحظة المشاركة الموجهة إلى المستلم",
    "Share password saved" : "تمّ حفظ كلمة مرور المشاركة",
    "Share permissions saved" : "تمّ حفظ إذونات المشاركة",
    "Upload files to {folder}" : "رفع ملفات إلى {folder}",
    "{ownerDisplayName} shared a folder with you." : "قام {ownerDisplayName} بمشاركة مجلد معك.",
    "Password created successfully" : "تمّ إنشاء كلمة المرور بنجاح",
    "Error generating password from password policy" : "خطأ في توليد كلمة المرور بسبب مخالفة سياسة كلمات المرور",
    "Shared with you and the group {group} by {owner}" : "تمّت مشاركته معك ومع المجموعة {group} من قِبَل {owner}",
    "Shared with you and {circle} by {owner}" : "تمّت مشاركته معك و مع الدائرة {circle} من قِبَل {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "تمّت مشاركته معك و مع المحادثة {conversation} من قِبَل {owner}",
    "Shared with you in a conversation by {owner}" : "تمّت مشاركته معك في محادثة من قِبَل {owner}",
    "Share not found" : "مشاركة غير موجودة",
    "Back to %s" : "عودة إلى %s",
    "Add to your Nextcloud" : "إضافة إلى حسابك على نكست كلاود",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : " المشاركة %s فشلت بسبب أن الخادم لا يدعم مشاركات ScienceMesh",
    "Name or email …" : "الاسم أو الإيميل …",
    "Name, email, or Federated Cloud ID …" : "الاسم أو البريد أو المعرف السحابي الموحد",
    "Searching …" : "البحث جارٍ …"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
