OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "восстановлен",
    "Deleted files" : "Корзина",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Удаленные файлы и папки в корзине (могут быть исключены во время экспорта, если мало свободного места)",
    "This application enables people to restore files that were deleted from the system." : "Это приложение позволяет людям восстанавливать файлы, которые были удалены из системы.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Это приложение позволяет пользователям восстанавливать файлы, которые были удалены из системы. Оно отображает список удаленных файлов в веб-интерфейсе и содержит опции для восстановления этих удаленных файлов обратно в каталоги файлов people или для их окончательного удаления из системы. При восстановлении файла также восстанавливаются версии связанных файлов, если включено приложение \"Версии\". Когда файл удаляется из общего доступа, его можно восстановить тем же способом, хотя он больше не является общим. По умолчанию эти файлы остаются в корзине в течение 30 дней.\nЧтобы предотвратить нехватку дискового пространства в учетной записи, приложение \"Удаленные файлы\" не будет использовать более 50% доступной в данный момент бесплатной квоты для удаленных файлов. Если количество удаленных файлов превышает это ограничение, приложение удаляет самые старые файлы до тех пор, пока оно не станет меньше этого ограничения. Более подробная информация доступна в документации по удаленным файлам.",
    "Restore" : "Восстановить",
    "Not enough free space to restore the file/folder" : "Недостаточно свободного места для восстановления файла/папки",
    "Empty deleted files" : "Очистить удаленные файлы",
    "Confirm permanent deletion" : "Подтвердите окончательное удаление",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Вы уверены, что хотите навсегда удалить все файлы и папки в корзине? Это действие нельзя отменить.",
    "Cancel" : "Отмена",
    "Original location" : "Исходный путь",
    "Deleted by" : "Удалено",
    "Deleted" : "Удалён",
    "few seconds ago" : "только что",
    "A long time ago" : "Очень давно",
    "Unknown" : "Неизвестно",
    "All files" : "Все файлы",
    "You" : "Вы",
    "List of files that have been deleted." : "Список файлов, которые были удалены.",
    "No deleted files" : "Нет удалённых файлов",
    "Files and folders you have deleted will show up here" : "Файлы и каталоги, которые вы удалили, будут отображаться здесь",
    "All files have been permanently deleted" : "Все файлы были удалены без возможности восстановления",
    "Failed to empty deleted files" : "Не удалось очистить удалённые файлы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
