OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Prihlásený používateľ musí byť správcom, alebo musí mať špeciálne právo na uprávu k tohoto nastavenia.",
    "Could not create non-existing user ID" : "Nie je možné vytvoriť neexistujúce ID užívateľa",
    "User already exists" : "Používateľ už existuje",
    "Group %1$s does not exist" : "Skupina %1$s neexistuje",
    "Insufficient privileges for group %1$s" : "Nedostatočné práva pre skupinu %1$s",
    "No group specified (required for sub-admins)" : "Nebola zadaná žiadna skupina (potrebné pre sub-administrátorov)",
    "Sub-admin group does not exist" : "Pod-administrátorská skupina neexistuje",
    "Cannot create sub-admins for admin group" : "Nemôžem vytvoriť pod-administrátorskú skupinu pre administrátorskú skupinu",
    "No permissions to promote sub-admins" : "Na povýšenie pod-administrátorov nie sú práva",
    "Invalid password value" : "Neplatná hodnota hesla",
    "An email address is required, to send a password link to the user." : "E-mail adresa je vyžadovaná pre poslanie odkazu uživateľovi pre reset hesla.",
    "Required email address was not provided" : "Nebola zadaná požadovaná e-mailová adresa",
    "User creation failed" : "Vytvorenie používateľa zlyhalo",
    "Invalid quota value: %1$s" : "Neplatná hodnota kvóty: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Neplatná hodnota pre kvótu %1$s je väčšia ako maximálna kvóta",
    "Unlimited quota is forbidden on this instance" : "Kvóta bez limitu nie je na tejto inštancii povolená",
    "Setting the password is not supported by the users backend" : "Nastavenie hesla nie je pre podporované uživateľským backenom",
    "Invalid language" : "Neplatný jazyk",
    "Invalid locale" : "Neplatné miestne nastavenie",
    "Invalid timezone" : "Neplatné časové pásmo",
    "Invalid first day of week" : "Neplatný prvý deň týždňa",
    "Cannot remove yourself from the admin group" : "Nemôžete odstrániť samého seba zo skupiny administrátorov",
    "Cannot remove yourself from this group as you are a sub-admin" : "Nemôžete odstrániť samého seba z tejto skupiny, pretože ste sub-administrátor",
    "Not viable to remove user from the last group you are sub-admin of" : "Nie je možné odstrániť používateľa z poslednej skupiny, ktorej je pod-správcom",
    "User does not exist" : "Užívateľ neexistuje",
    "Group does not exist" : "Skupina neexistuje",
    "User is not a sub-admin of this group" : "Užívateľ nie je sub-administrátor tejto skupiny",
    "Email address not available" : "E-mailová adresa nie je dostupná",
    "Sending email failed" : "Odosielanie e-mailu zlyhalo",
    "Logged in account is not mail address owner" : "Prihlásený účet nie je vlastníkom e-mailovej adresy",
    "Email confirmation" : "Overenie e-mailu",
    "To enable the email address %s please click the button below." : "Pre povolenie e-mailovej adresy %s prosím kliknite na tlačítko nižšie.",
    "Confirm" : "Potvrdiť",
    "Email was already removed from account and cannot be confirmed anymore." : "E-mail bol odobraný z účtu a už nemôže byť overený.",
    "Could not verify mail because the token is expired." : "Nepodarilo sa overiť e-mail, pretože platnosť tokenu uplynula.",
    "Could not verify mail because the token is invalid." : "Nepodarilo sa overiť e-mail, pretože token je neplatný.",
    "An unexpected error occurred. Please contact your admin." : "Vyskytla sa chyba. Prosím, kontaktujte svojho správcu.",
    "Email confirmation successful" : "Overenie e-mailu bolo úspešné",
    "Provisioning API" : "Provisioning API",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Táto aplikácia poskytuje sadu rozhraní API, ktoré môžu externé systémy používať na správu účtov, skupín a aplikácií.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Táto aplikácia poskytuje množinu rozhraní API, ktoré môžu externé systémy použiť pre vytváranie, úpravu, odstraňovanie a získavanie informácii o účte\natribúty, dotazovanie, nastavenie a odstránenie skupín, nastavenie kvóty a dotaz na celkové úložisko používané v Nextcloud. Skupinové správcovské účty\nmôžu tiež dopytovať Nextcloud a vykonávať rovnaké funkcie ako správca pre skupiny, ktoré spravujú. Rozhranie API tiež poskytuje\nsprávcu, ktorý bude vyhľadávať aktívne aplikácie Nextcloud, informácie o aplikácii a povolí alebo zakázuje aplikácie na diaľku.\nKeď je aplikácia povolená, požiadavky HTTP možno použiť prostredníctvom hlavičky Basic Auth na vykonanie ktorejkoľvek z funkcií\nuvedených vyššie. Viac informácií je k dispozícii v dokumentácii Provisioning API vrátane príkladov volaní\na odpovedí servera."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
