import{g as i}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as c}from"./armasm-B7RMNLpU.chunk.mjs";function p(t,a){for(var o=0;o<a.length;o++){const e=a[o];if(typeof e!="string"&&!Array.isArray(e)){for(const r in e)if(r!=="default"&&!(r in t)){const n=Object.getOwnPropertyDescriptor(e,r);n&&Object.defineProperty(t,r,n.get?n:{enumerable:!0,get:()=>e[r]})}}}return Object.freeze(Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}))}var f=c();const s=i(f),u=p({__proto__:null,default:s},[f]);export{u as a};
//# sourceMappingURL=armasm-BnQa_bGd.chunk.mjs.map
