OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Версії",
    "This application automatically maintains older versions of files that are changed." : "Цей застосунок підтримує роботу з попередніми версіями файлів, які було змінено.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Ця програма автоматично зберігає старі версії файлів, які були змінені. Коли ця функція увімкнена, у каталозі кожного користувача створюється прихований каталог «версії», яка використовується для зберігання старих версій файлів. Користувач може в будь-який час повернутися до старішої версії через веб-інтерфейс, а замінений файл стане версією. Програма автоматично керує каталогом «версії», щоб уникнути перевищення квоти облікового запису через версії.\n\nОкрім терміну дії версій, програма «Версії» гарантує, що ніколи не буде використовуватися більше 50% вільного місця, доступного на даний момент в обліковому записі. Якщо збережені версії перевищують цей ліміт, програма спочатку видалить найстаріші версії, доки не буде досягнуто цього ліміту. Більше інформації можна знайти в документації «Версії».",
    "Current version" : "Поточна версія",
    "Initial version" : "Початкова версія",
    "You" : "Ви",
    "Actions for version from {versionHumanExplicitDate}" : "Дії для версії від {versionHumanExplicitDate}",
    "Name this version" : "Назвіть цю версію",
    "Edit version name" : "Редагуйте назву версії",
    "Compare to current version" : "Порівняти з поточною версією",
    "Restore version" : "Відновити версію",
    "Download version" : "Звантажити версію",
    "Delete version" : "Вилучити версію",
    "Cancel" : "Скасувати",
    "Remove version name" : "Вилучити назву версії",
    "Save version name" : "Зберегти назву версії",
    "Version name" : "Назва версії",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Версії з назвами є постійними та їх виключено з автоматичного очищення після переповнення квоти у сховищі.",
    "Initial version restored" : "Початкову версію відновлено",
    "Version restored" : "Версію відновлено",
    "Could not restore version" : "Не вдалося відновити версію",
    "Could not set version label" : "Не вдалося встановити ярлик версії",
    "Could not delete version" : "Не вдалося вилучити версію",
    "File versions" : "Версії файлу"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
