OC.L10N.register(
    "lookup_server_connector",
    {
    "Lookup Server Connector" : "Lookup Server Connector",
    "Sync public account information with the lookup server" : "공용 계정 정보를 Lookup Server와 동기화합니다"
},
"nplurals=1; plural=0;");
