OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Nextcloud aankondigingen",
    "Nextcloud announcement" : "Nextcloud aankondiging",
    "Read more" : "Lees meer",
    "Disable announcements" : "Uitschakelen meldingen",
    "(These announcements are only shown to administrators)" : "(Deze meldingen worden alleen getoond aan beheerders)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Nextcloud notificaties brengt het laatste nieuws van Nextcloud in je meldingen"
},
"nplurals=2; plural=(n != 1);");
