OC.L10N.register(
    "provisioning_api",
    {
    "Could not create non-existing user ID" : "Tidak dapat membuat ID pengguna yang tidak ada",
    "User already exists" : "Pengguna sudah ada",
    "Group %1$s does not exist" : "Grup %1$s tidak ada",
    "Insufficient privileges for group %1$s" : "Hak istimewa tidak mencukupi untuk grup %1$s",
    "No group specified (required for sub-admins)" : "Tidak ada grup yang ditentukan (diperlukan untuk sub-admin)",
    "Sub-admin group does not exist" : "Grup sub-admin tidak ada",
    "Cannot create sub-admins for admin group" : "Tidak dapat membuat sub-admin untuk grup admin",
    "No permissions to promote sub-admins" : "Tidak ada izin untuk mempromosikan sub-admin",
    "Invalid password value" : "Nilai kata sandi tidak valid",
    "An email address is required, to send a password link to the user." : "Alamat email diperlukan, untuk mengirim tautan kata sandi kepada pengguna.",
    "Required email address was not provided" : "Alamat email yang diperlukan tidak diberikan",
    "User creation failed" : "Pembuatan pengguna gagal",
    "Invalid quota value: %1$s" : "Nilai kuota tidak valid: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Nilai kuota tidak valid. %1$s melampaui kuota maksimum",
    "Unlimited quota is forbidden on this instance" : "Kuota tak terbatas dilarang pada instans ini",
    "Setting the password is not supported by the users backend" : "Penetapan kata sandi tidak didukung oleh backend pengguna",
    "Invalid language" : "Bahasa tidak valid",
    "Invalid locale" : "Locale tidak valid",
    "Invalid timezone" : "Zona waktu tidak valid",
    "Invalid first day of week" : "Hari pertama dalam seminggu tidak valid",
    "Cannot remove yourself from the admin group" : "Tidak dapat menghapus diri Anda sendiri dari grup admin",
    "Cannot remove yourself from this group as you are a sub-admin" : "Tidak dapat menghapus diri Anda sendiri dari grup ini karena Anda adalah sub-admin",
    "Not viable to remove user from the last group you are sub-admin of" : "Tidak memungkinkan untuk menghapus pengguna dari grup terakhir tempat Anda menjadi sub-admin",
    "User does not exist" : "Pengguna tidak ada",
    "Group does not exist" : "Grup tidak ada",
    "User is not a sub-admin of this group" : "Pengguna bukan sub-admin dari grup ini",
    "Email address not available" : "Alamat email tidak tersedia",
    "Sending email failed" : "Pengiriman email gagal",
    "Logged in account is not mail address owner" : "Akun yang login bukan pemilik alamat email",
    "Email confirmation" : "Konfirmasi email",
    "To enable the email address %s please click the button below." : "Untuk mengaktifkan alamat email %s silakan klik tombol di bawah ini.",
    "Confirm" : "Konfirmasi",
    "Email was already removed from account and cannot be confirmed anymore." : "Email sudah dihapus dari akun dan tidak dapat dikonfirmasi lagi.",
    "Could not verify mail because the token is expired." : "Tidak dapat memverifikasi email karena token telah kedaluwarsa.",
    "Could not verify mail because the token is invalid." : "Tidak dapat memverifikasi email karena token tidak valid.",
    "An unexpected error occurred. Please contact your admin." : "Terjadi kesalahan tak terduga. Silakan hubungi admin Anda.",
    "Email confirmation successful" : "Konfirmasi email berhasil",
    "Provisioning API" : "API Provisioning",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Aplikasi ini mengaktifkan serangkaian API yang dapat digunakan sistem eksternal untuk mengelola akun, grup, dan aplikasi.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Aplikasi ini mengaktifkan serangkaian API yang dapat digunakan sistem eksternal untuk membuat, mengedit, menghapus, dan mengkueri atribut\n\t\takun, mengkueri, menetapkan dan menghapus grup, menetapkan kuota dan mengkueri total penyimpanan yang digunakan di Nextcloud. Akun admin grup\n\t\tjuga dapat mengkueri Nextcloud dan melakukan fungsi yang sama seperti admin untuk grup yang mereka kelola. API ini juga memungkinkan\n\t\tadmin untuk mengkueri aplikasi Nextcloud yang aktif, info aplikasi, serta mengaktifkan atau menonaktifkan aplikasi dari jarak jauh.\n\t\tSetelah aplikasi diaktifkan, permintaan HTTP dapat digunakan melalui header Basic Auth untuk menjalankan fungsi-fungsi\n\t\tyang tercantum di atas. Informasi lebih lanjut tersedia dalam dokumentasi API Provisioning, termasuk contoh pemanggilan\n\t\tdan respons server."
},
"nplurals=1; plural=0;");
