OC.L10N.register(
    "comments",
    {
    "Comments" : "باھا",
    "You commented" : "باھا بەردىڭىز",
    "{author} commented" : "{author} باھا بەردى",
    "You commented on %1$s" : "سىز %1$s غا باھا بەردىڭىز",
    "You commented on {file}" : "سىز {file} گە باھا بەردىڭىز",
    "%1$s commented on %2$s" : "%1$s بولسا %2$s غا باھا بەردى",
    "{author} commented on {file}" : "{author} بولسا {file} گە باھا بەردى",
    "<strong>Comments</strong> for files" : "ھۆججەتلەر ئۈچۈن <strong> باھا </strong>",
    "Files" : "ھۆججەتلەر",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "سىز ئۆچۈرۈلگەن ھېساباتنىڭ ئىزاھاتىدا سىز «{file}» دە تىلغا ئېلىندى",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} سىزنى \"{file}\" دىكى باھادا تىلغا ئالدى",
    "Files app plugin to add comments to files" : "ھۆججەتلەرگە باھا قوشۇش ئۈچۈن ھۆججەت قىستۇرمىسى",
    "Edit comment" : "باھا تەھرىرلەش",
    "Delete comment" : "باھانى ئۆچۈرۈڭ",
    "Cancel edit" : "تەھرىرلەشنى ئەمەلدىن قالدۇرۇڭ",
    "New comment" : "يېڭى باھا",
    "Write a comment …" : "بىر ئىنكاس يېزىڭ  ...",
    "Post comment" : "ئىنكاس يېزىڭ",
    "@ for mentions, : for emoji, / for smart picker" : "@ تىلغا ئېلىش ئۈچۈن ،: emoji ئۈچۈن ، / ئەقلىي ئىقتىدارلىق تاللىغۇچ ئۈچۈن",
    "Could not reload comments" : "ئىنكاسلارنى قايتا يۈكلىيەلمىدى",
    "Failed to mark comments as read" : "ئىنكاسلارنى ئوقۇشقا بەلگە قويمىدى",
    "Unable to load the comments list" : "باھا تىزىملىكىنى يۈكلىيەلمىدى",
    "No comments yet, start the conversation!" : "تېخى باھا يوق ، سۆھبەتنى باشلاڭ!",
    "No more messages" : "باشقا ئۇچۇر يوق",
    "Retry" : "قايتا سىناڭ",
    "_1 new comment_::_{unread} new comments_" : ["1 يېڭى ئىنكاس","{unread} يېڭى ئىنكاسلار"],
    "Comment" : "باھا",
    "An error occurred while trying to edit the comment" : "باھانى تەھرىرلىمەكچى بولغاندا خاتالىق كۆرۈلدى",
    "Comment deleted" : "باھا ئۆچۈرۈلدى",
    "An error occurred while trying to delete the comment" : "باھانى ئۆچۈرمەكچى بولغاندا خاتالىق كۆرۈلدى",
    "An error occurred while trying to create the comment" : "باھا قۇرماقچى بولغاندا خاتالىق كۆرۈلدى",
    "Write a comment …" : "باھا يېزىڭ…"
},
"nplurals=2; plural=(n != 1);");
