OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Aufgaben",
    "Personal" : "Persönlich",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Du hast den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Du hast den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Du hast den Kalender {calendar} aktualisiert",
    "{actor} restored calendar {calendar}" : "{actor} hat den Kalender {calendar} wiederhergestellt",
    "You restored calendar {calendar}" : "Du hast den Kalender {calendar} wiederhergestellt",
    "You shared calendar {calendar} as public link" : "Du hast den Kalender {calendar} als öffentlichen Link geteilt",
    "You removed public link for calendar {calendar}" : "Du hast den öffentlichen Link für Kalender {calendar} entfernt",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit dir geteilt",
    "You shared calendar {calendar} with {user}" : "Du hast den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit dir",
    "You unshared calendar {calendar} from {user}" : "Du teilst den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Du hast den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Du teilst den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "Untitled event" : "Unbenannter Termin",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} aktualisiert",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} hat das Ereignis {event} vom Kalender {sourceCalendar} in den Kalender {targetCalendar} verschoben",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Du hast das Ereignis {event} vom Kalender {sourceCalendar} in den Kalender {targetCalendar} verschoben",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} hat den Termin {event} in Kalender {calendar} wiederhergestellt",
    "You restored event {event} of calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} wiederhergestellt",
    "Busy" : "Beschäftigt",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created to-do {todo} in list {calendar}" : "Du hast eine Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} aus der Liste {calendar} gelöscht",
    "You deleted to-do {todo} from list {calendar}" : "Du hast die Aufgabe {todo} aus der Liste {calendar} gelöscht",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated to-do {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved to-do {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "You reopened to-do {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} hat die Aufgabe {todo} von der Liste {sourceCalendar} in die Liste {targetCalendar} verschoben",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du hast die Aufgabe {todo} von der Liste {sourceCalendar} in die Liste {targetCalendar} verschoben",
    "Calendar, contacts and tasks" : "Kalender, Kontakte und Aufgaben",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Termin</strong> wurde bearbeitet",
    "A calendar <strong>to-do</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde geändert",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "Death of %s" : "Todestag von %s",
    "Untitled calendar" : "Unbenannter Kalender",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Wo:",
    "Description:" : "Beschreibung:",
    "_%n year_::_%n years_" : ["%n Jahr","%n Jahre"],
    "_%n month_::_%n months_" : ["%n Monat","%n Monate"],
    "_%n day_::_%n days_" : ["%n Tag","%n Tage"],
    "_%n hour_::_%n hours_" : ["%n Stunde","%n Stunden"],
    "_%n minute_::_%n minutes_" : ["%n Minute","%n Minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (vor %s)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschreibung: %s",
    "Where: %s" : "Ort: %s",
    "%1$s via %2$s" : "%1$s über %2$s",
    "In the past on %1$s for the entire day" : "In der Vergangenheit am %1$s für den ganzen Tag",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["In %n Minute am %1$s ganztägig","In %n Minuten am %1$s ganztägig"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["In %n Stunde am %1$s ganztägig","In %n Stunden am %1$s ganztägig"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["In %n Tag am %1$s ganztägig","In %n Tagen am %1$s ganztägig"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["In %n Woche am %1$s ganztägig","In %n Wochen am %1$s ganztägig"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["In %n Monat am %1$s ganztägig","In %n Monaten am %1$s ganztägig"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["In %n Jahr am %1$s ganztägig","In %n Jahren am %1$s ganztägig"],
    "In the past on %1$s between %2$s - %3$s" : "In der Vergangenheit am %1$s zwischen %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["In %n Minute am %1$s zwischen %2$s - %3$s","In %n Minuten am %1$s zwischen %2$s - %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["In %n Stunde am %1$s zwischen %2$s - %3$s","In %n Stunden am %1$s zwischen %2$s - %3$s"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["In %n Tag am %1$s zwischen %2$s - %3$s","In %n Tagen am %1$s zwischen %2$s - %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["In %n Woche am %1$s zwischen %2$s - %3$s","In %n Wochen am %1$s zwischen %2$s - %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["In %n Monat am %1$s zwischen %2$s - %3$s","In %n Monaten am %1$s zwischen %2$s - %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["In %n Jahr am %1$s zwischen %2$s - %3$s","In %n Jahren am %1$s zwischen %2$s - %3$s"],
    "Could not generate when statement" : "Wann-Angabe konnte nicht erzeugt werden.",
    "Every Day for the entire day" : "Jeden Tag für den ganzen Tag",
    "Every Day for the entire day until %1$s" : "Jeden Tag für den ganzen Tag bis %1$s",
    "Every Day between %1$s - %2$s" : "Jeden Tag zwischen %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Jeden Tag zwischen %1$s - %2$s bis %3$s",
    "Every %1$d Days for the entire day" : "Alle %1$d Tage für den ganzen Tag",
    "Every %1$d Days for the entire day until %2$s" : "Alle %1$d Tage für den ganzen Tag bis %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Alle %1$d Tage zwischen %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Alle %1$d Tage zwischen %2$s - %3$s bis %4$s",
    "Could not generate event recurrence statement" : "Angabe für Terminwiederholung konnte nicht erzeugt werden.",
    "Every Week on %1$s for the entire day" : "Jede Woche am %1$s für den ganzen Tag",
    "Every Week on %1$s for the entire day until %2$s" : "Jede Woche am %1$s für den ganzen Tag bis %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Jede Woche am %1$s zwischen %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Jede Woche am %1$s zwischen %2$s - %3$s bis %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Alle %1$d Wochen am %2$s für den ganzen Tag",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Alle %1$d Wochen am %2$s für den ganzen Tag bis %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Alle %1$d Wochen am %2$s zwischen %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Alle %1$d Wochen am %2$s zwischen %3$s - %4$s bis %5$s",
    "Every Month on the %1$s for the entire day" : "Jeden Monat am %1$s für den ganzen Tag",
    "Every Month on the %1$s for the entire day until %2$s" : "Jeden Monat am %1$s für den ganzen Tag bis %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Jeden Monat am %1$s zwischen %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Jeden Monat am %1$s zwischen %2$s - %3$s bis %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Alle %1$d Monate am %2$s für den ganzen Tag",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Alle %1$d Monate am %2$s für den ganzen Tag bis %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Alle %1$d Monate am %2$s zwischen %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Alle %1$d Monate am %2$s zwischen %3$s - %4$s bis %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Jedes Jahr im %1$s am %2$s für den ganzen Tag",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Jedes Jahr im %1$s am %2$s für den ganzen Tag bis %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Jedes Jahr im %1$s am %2$s zwischen %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Jedes Jahr im %1$s am %2$s zwischen %3$s - %4$s bis %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Alle %1$d Jahre im %2$s am %3$s für den ganzen Tag",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Alle %1$d Jahre im %2$s am %3$s für den ganzen Tag bis %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Alle %1$d Jahre im %2$s am %3$s zwischen %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Alle %1$d Jahre im %2$s am %3$s zwischen %4$s - %5$s bis %6$s",
    "On specific dates for the entire day until %1$s" : "An bestimmten Tagen für den ganzen Tag bis %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "An bestimmten Tagen zwischen %1$s - %2$s bis %3$s",
    "In the past on %1$s" : "In der Vergangenheit am %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["In %n Minute am %1$s","In %n Minuten am %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["In %n Stunde am %1$s","In %n Stunden am %1$s "],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["In %n Tag am %1$s","In %n Tagen am %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["In %n Woche am %1$s","In %n Wochen am %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["In %n Monat am %1$s","In %n Monaten am %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["In %n Jahr am %1$s","In %n Jahren am %1$s"],
    "In the past on %1$s then on %2$s" : "In der Vergangenheit am %1$s danach am %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["In %n Minute am %1$s danach am %2$s","In %n Minuten am %1$s danach am %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["In %n Stunde am %1$s danach am %2$s","In %n Stunden am %1$s danach am %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["In %n Tag am %1$s danach am %2$s","In %n Tagen am %1$s danach am %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["In %n Woche am %1$s danach am %2$s","In %n Wochen am %1$s danach am %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["In %n Monat am %1$s danach am %2$s","In %n Monaten am %1$s danach am %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["In %n Jahr am %1$s danach am %2$s","In %n Jahren am %1$s danach am %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "In der Vergangenheit am %1$s danach am %2$s und %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["In %n Minute am %1$s danach am %2$s und %3$s","In %n Minuten am %1$s danach am %2$s und %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["In %n Stunde am %1$s danach am %2$s und %3$s","In %n Stunden am %1$s danach am %2$s und %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["In %n Tag am %1$s danach am %2$s und %3$s","In %n Tagen am %1$s danach am %2$s und %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["In %n Woche am %1$s danach am %2$s und %3$s","In %n Wochen am %1$s danach am %2$s und %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["In %n Monat am %1$s danach am %2$s und %3$s","In %n Monaten am %1$s danach am %2$s und %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["In %n Jahr am %1$s danach am %2$s und %3$s","In %n Jahren am %1$s danach am %2$s und %3$s"],
    "Could not generate next recurrence statement" : "Angabe für nächste Wiederholung konnte nicht erzeugt werden.",
    "Cancelled: %1$s" : "Abgesagt: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" wurde abgesagt.",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s hat deine Einladung angenommen.",
    "%1$s has tentatively accepted your invitation" : "%1$s hat deine Einladung vorläufig angenommen.",
    "%1$s has declined your invitation" : "%1$s hat deine Einladung abgelehnt.",
    "%1$s has responded to your invitation" : "%1$s hat auf deine Einladung geantwortet.",
    "Invitation updated: %1$s" : "Einladung aktualisiert: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s hat die Veranstaltung \"%2$s\" aktualisiert",
    "Invitation: %1$s" : "Einladung: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s möchte dich zu \"%2$s\" einladen.",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Teilnehmer:",
    "Title:" : "Titel:",
    "When:" : "Wann:",
    "Location:" : "Ort:",
    "Link:" : "Link:",
    "Occurring:" : "Findet statt:",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "More options …" : "Weitere Optionen …",
    "More options at %s" : "Weitere Optionen unter %s",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sunday" : "Sonntag",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "First" : "Erste",
    "Second" : "Zweite",
    "Third" : "Dritte",
    "Fourth" : "Vierte",
    "Fifth" : "Fünften",
    "Last" : "Letzte",
    "Second Last" : "Vorletztes",
    "Third Last" : "Drittletztes",
    "Fourth Last" : "Viertletztes",
    "Fifth Last" : "Fünftletztes",
    "Contacts" : "Kontakte",
    "{actor} created address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} erstellt",
    "You created address book {addressbook}" : "Du hast das Adressbuch {addressbook} erstellt",
    "{actor} deleted address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} gelöscht",
    "You deleted address book {addressbook}" : "Du hast das Adressbuch {addressbook} gelöscht",
    "{actor} updated address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} aktualisiert",
    "You updated address book {addressbook}" : "Du hast das Adressbuch {addressbook} aktualisiert",
    "{actor} shared address book {addressbook} with you" : "{actor} hat das Adressbuch {addressbook} mit dir geteilt",
    "You shared address book {addressbook} with {user}" : "Du hast das Adressbuch {addressbook} geteilt",
    "{actor} shared address book {addressbook} with {user}" : "{actor} hat das Adressbuch {addressbook} mit {user} geteilt",
    "{actor} unshared address book {addressbook} from you" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit dir.",
    "You unshared address book {addressbook} from {user}" : "Du teilst das Adressbuch {addressbook} nicht mehr mit {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit dir.",
    "You shared address book {addressbook} with group {group}" : "Du hast das Adressbuch {addressbook} mit der Gruppe {group} geteilt",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} hat das Adressbuch {addressbook} mit der Gruppe {group} geteilt",
    "You unshared address book {addressbook} from group {group}" : "Du teilst das Adressbuch {addressbook} nicht mehr mit der Gruppe {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit der Gruppe {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} hat den Kontakt {card} im Adressbuch {addressbook} erstellt",
    "You created contact {card} in address book {addressbook}" : "Du hast den Kontakt {card} im Adressbuch {addressbook} erstellt",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} hat den Kontakt {card} im Adressbuch {addressbook} gelöscht",
    "You deleted contact {card} from address book {addressbook}" : "Du hast den Kontakt {card} im Adressbuch {addressbook} gelöscht",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} hat den Kontakt {card} im Adressbuch {addressbook} aktualisiert",
    "You updated contact {card} in address book {addressbook}" : "Du hast den Kontakt {card} im Adressbuch {addressbook} aktualisiert",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Ein <strong>Kontakt</strong> oder ein <strong>Adressbuch</strong> wurde geändert",
    "System address book disabled" : "Systemadressbuch deaktiviert",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Das Adressbuch der Systemkontakte wurde während des Upgrades automatisch deaktiviert. Dies bedeutet, dass das Adressbuch den Benutzern in der Kontakt-App oder anderen Clients nicht mehr zur Verfügung steht. Das Adressbuch der Systemkontakte wurde deaktiviert, da die Anzahl der Kontakte im Adressbuch die maximal empfohlene Anzahl an Kontakten überschritt. Diese Grenze wird festgelegt, um Leistungsprobleme zu vermeiden. Das Systemadressbuch kann mit dem Befehl {command} wieder aktiviert werden",
    "Accounts" : "Konten",
    "System address book which holds all accounts" : "Systemadressbuch, das alle Konten enthält",
    "File is not updatable: %1$s" : "Datei kann nicht aktualisiert werden: %1$s",
    "Failed to get storage for file" : "Speicherplatz für Datei konnte nicht abgerufen werden",
    "Could not write to final file, canceled by hook" : "In die endgültige Datei konnte nicht geschrieben werden, wurde durch einen Hook abgebrochen",
    "Could not write file contents" : "Dateiinhalt konnte nicht  geschrieben werden",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Fehler beim Kopieren der Datei in den Zielspeicherort (kopiert: %1$s, erwartete Dateigröße: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Erwartete Dateigröße von %1$s, aber %2$s gelesen (vom Nextcloud-Client) und geschrieben (in den Nextcloud-Speicher). Dies kann entweder ein Netzwerkproblem auf der sendenden Seite oder ein Problem beim Schreiben in den Speicher auf der Serverseite sein.",
    "Could not rename part file to final file, canceled by hook" : "Konnte temporäre Datei nicht in die endgültige Datei umbenennen, wurde durch einen Hook abgebrochen",
    "Could not rename part file to final file" : "Konnte temporäre Datei nicht in die endgültige Datei umbenennen",
    "Failed to check file size: %1$s" : "Dateigröße konnte nicht überprüft werden: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Datei konnte nicht geöffnet werden: %1$s (%2$d), Datei scheint aber zu existieren",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Datei konnte nicht geöffnet werden: %1$s (%2$d), Datei scheint nicht zu existieren",
    "Failed to get size for : %1$s" : "Größe konnte nicht ermittelt werden für: %1$s",
    "Encryption not ready: %1$s" : "Verschlüsselung nicht bereit: %1$s",
    "Failed to open file: %1$s" : "Datei konnte nicht geöffnet werden: %1$s",
    "Failed to unlink: %1$s" : "Fehler beim Aufheben der Verknüpfung: %1$s",
    "Failed to write file contents: %1$s" : "Fehler beim Schreiben des Dateiinhaltes: %1$s",
    "File not found: %1$s" : "Datei nicht gefunden: %1$s",
    "Invalid target path" : "Ungültiger Ziel-Pfad",
    "System is in maintenance mode." : "Das System befindet sich im Wartungsmodus.",
    "Upgrade needed" : "Aktualisierung erforderlich",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Dein %s muss konfiguriert werden, um HTTPS zusammen mit CalDAV und CardDAV unter iOS/macOS nutzen zu können.",
    "Configures a CalDAV account" : "Ein CalDAV-Konto einrichten",
    "Configures a CardDAV account" : "Ein CardDAV-Konto einrichten",
    "Events" : "Ereignisse",
    "Untitled task" : "Unbenannte Aufgabe",
    "Completed on %s" : "Erledigt am %s",
    "Due on %s by %s" : "Fällig am %s von %s",
    "Due on %s" : "Fällig am %s",
    "This is an example contact" : "Dies ist ein Beispielkontakt",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Willkommen bei Nextcloud Calendar!\n\nDies ist ein Beispielereignis – entdecke die Flexibilität der Planung mit Nextcloud Calendar und nimm beliebige Änderungen vor!\n\nMit Nextcloud Calendar kannst du:\n– Ereignisse mühelos erstellen, bearbeiten und verwalten.\n– Mehrere Kalender erstellen und mit Teamkollegen, Freunden oder der Familie teilen.\n– Verfügbarkeit prüfen und deine Termine anderen anzeigen.\n– Nahtlose Integration mit Apps und Geräten über CalDAV.\n– Individuelle Gestaltung: Plane wiederkehrende Ereignisse, passe Benachrichtigungen und andere Einstellungen an.",
    "Example event - open me!" : "Beispielereignis – öffne mich!",
    "System Address Book" : "Systemadressbuch",
    "The system address book contains contact information for all users in your instance." : "Das Systemadressbuch enthält Kontaktinformationen für alle Benutzer in dieser Instanz.",
    "Enable System Address Book" : "Systemadressbuch aktivieren",
    "DAV system address book" : "DAV-Systemadressbuch",
    "No outstanding DAV system address book sync." : "Keine ausstehende Synchronisierung des DAV-Systemadressbuchs",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da diese Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte manuell ausführen, mittels \"occ dav:sync-system-addressbook\".",
    "DAV system address book size" : "Größe des DAV-Systemadressbuchs",
    "The system address book is disabled" : "Das Systemadressbuch ist deaktiviert",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Das Systemadressbuch ist aktiviert, enthält aber mehr als die eingestellte Obergrenze von %d Kontakten",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Das Systemadressbuch ist aktiviert und enthält weniger als die eingerichtete Obergrenze von %d Kontakten",
    "WebDAV endpoint" : "WebDAV-Endpunkt",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Es konnte nicht überprüft werden, ob der Webserver ordnungsgemäß eingerichtet ist, um Dateisynchronisation über WebDAV zu ermöglichen. Bitte dies manuell überprüfen.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Der Webserver ist noch nicht hinreichend für Datei-Synchronisierung konfiguriert, da die WebDAV-Schnittstelle vermutlich nicht funktioniert.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Der Webserver ist ordnungsgemäß eingerichtet um Dateisynchronisation über WebDAV zu ermöglichen.",
    "Calendars including events, details and attendees" : "Kalender mit Terminen, Details und Teilnehmern",
    "Migrated calendar (%1$s)" : "Migrierter Kalender (%1$s)",
    "Contacts and groups" : "Kontakte und Gruppen",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Abwesenheit gespeichert",
    "Failed to save your absence settings" : "Deine Abwesenheitseinstellungen konnten nicht gespeichert werden.",
    "Absence cleared" : "Abwesenheit gelöscht",
    "Failed to clear your absence settings" : "Deine Abwesenheitseinstellungen konnten nicht gelöscht werden.",
    "First day" : "Erster Tag",
    "Last day (inclusive)" : "Letzter Tag (inklusiv)",
    "Out of office replacement (optional)" : "Abwesenheitsvertretung (optional)",
    "Name of the replacement" : "Name der Vertretung",
    "Short absence status" : "Kurzer Abwesenheitsstatus",
    "Long absence Message" : "Lange Abwesenheitsnachricht",
    "Save" : "Speichern",
    "Disable absence" : "Abwesenheit deaktivieren",
    "Failed to load availability" : "Verfügbarkeit konnte nicht geladen werden",
    "Saved availability" : "Verfügbarkeit gespeichert",
    "Failed to save availability" : "Verfügbarkeit konnte nicht gespeichert werden",
    "to" : "bis",
    "Delete slot" : "Slot löschen",
    "No working hours set" : "Keine Arbeitszeiten konfiguriert",
    "Add slot" : "Slot hinzufügen",
    "Weekdays" : "Wochentage",
    "Pick a start time for {dayName}" : "Eine Startzeit für {dayName} wählen",
    "Pick a end time for {dayName}" : "Eine Endezeit für {dayName} wählen",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setze den Benutzerstatus außerhalb deiner Verfügbarkeit automatisch auf \"Nicht stören\", um alle Benachrichtigungen stumm zu schalten.",
    "Cancel" : "Abbrechen",
    "Import" : "Importieren",
    "Error while saving settings" : "Fehler beim Speichern der Einstellungen",
    "Contact reset successfully" : "Kontakt zurückgesetzt",
    "Error while resetting contact" : "Fehler beim Zurücksetzen des Kontakts",
    "Contact imported successfully" : "Kontakt importiert",
    "Error while importing contact" : "Fehler beim Import des Kontakts",
    "Import contact" : "Kontakt importieren",
    "Reset to default" : "Auf Standard zurücksetzen ",
    "Import contacts" : "Kontakte importieren",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Durch das Importieren einer neuen VCF-Datei wird der vorhandene Standardkontakt gelöscht und durch den neuen ersetzt. Fortsetzen?",
    "Failed to save example event creation setting" : "Einstellung für die Beispiels-Terminerstellung konnte nicht gespeichert werden",
    "Failed to upload the example event" : "Der Beispieltermin konnte nicht hochgeladen werden",
    "Custom example event was saved successfully" : "Benutzerdefinierter Beispieltermin gespeichert",
    "Failed to delete the custom example event" : "Benutzerdefinierter Beispieltermin konnte nicht gelöscht werden",
    "Custom example event was deleted successfully" : "Benutzerdefinierter Beispieltermin wurde gelöscht",
    "Import calendar event" : "Kalenderereignis importieren",
    "Uploading a new event will overwrite the existing one." : "Das Hochladen eines neuen Termins wird den bestehenden Termin überschreiben.",
    "Upload event" : "Termin hochladen",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installiere außerdem die {calendarappstoreopen}Kalender-App{linkclose} oder {calendardocopen}verbinde deinen Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stelle sicher, dass du {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtest.",
    "Calendar server" : "Kalender-Server",
    "Send invitations to attendees" : "Einladungen an die Teilnehmer senden",
    "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einer Hintergrundaufgabe erstellt",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es bis zur Anzeige ein wenig dauern.",
    "Send notifications for events" : "Sende Benachrichtigungen für Termine",
    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundaufgaben gesendet, so dass diese häufig genug ausgeführt werden.",
    "Send reminder notifications to calendar sharees as well" : "Erinnerungsbenachrichtigungen auch an die freigegebenen Kalender senden",
    "Reminders are always sent to organizers and attendees." : "Erinnerungen werden immer an Organisatoren und Teilnehmer gesendet.",
    "Enable notifications for events via push" : "Benachrichtigungen für Termine per Push aktivieren",
    "Example content" : "Beispielsinhalt",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Beispielinhalte dienen dazu, die Funktionen von Nextcloud vorzustellen. Standardinhalte werden mit Nextcloud ausgeliefert und können durch benutzerdefinierte Inhalte ersetzt werden.",
    "Availability" : "Verfügbarkeit",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten angibst, können andere beim Buchen einer Besprechung sehen, wann du nicht im Büro bist.",
    "Absence" : "Abwesenheit",
    "Configure your next absence period." : "Richte deinen nächsten Abwesenheitszeitraum ein.",
    "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren deines Teilnehmerstatus aufgetreten.",
    "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
    "Are you accepting the invitation?" : "Die Einladung annehmen?",
    "Tentative" : "Vorläufig",
    "Your attendance was updated successfully." : "Dein Teilnehmerstatus wurde aktualisiert.",
    "No results." : "Keine Ergebnisse",
    "Start typing." : "Mit dem Schreiben beginnen."
},
"nplurals=2; plural=(n != 1);");
