OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Daemon configuration introuvable",
    "Error starting install of ExApp" : "Erreur lors du démarrage de l'installation d'ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp n'a pas réussi à s'inscrire, vérifiez les logs NC",
    "ExApp not found, failed to get status" : "ExApp introuvable, échec d'obtention du statut",
    "Could not perform installation of ExApp" : "Impossible d'effectuer l'installation d'ExApp",
    "Failed to enable ExApp" : "Échec de l'activation d'ExApp",
    "Failed to disable ExApp" : "Échec de la désactivation d'ExApp",
    "Could not update ExApp" : "Impossible de mettre à jour ExApp",
    "Error starting update of ExApp" : "Erreur lors du démarrage de la mise à jour d'ExApp",
    "Could not perform update of ExApp" : "Impossible d'effectuer la mise à jour d'ExApp",
    "ExApp not found, failed to get logs" : "ExApp introuvable, échec d'obtention des logs",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Échec de l'obtention des logs du conteneur. Remarque: Le téléchargement du conteneur Docker fonctionne uniquement pour les conteneurs dotés du pilote de journalisation json-file ou journald. Erreur: %s",
    "AppAPI authentication failed" : "Échec de l'authentification AppAPI",
    "AppAPI ExApp notifier" : "Notificateur AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Équipe d'intégration de l'IA",
    "ExApps Settings" : "Paramètres ExApps",
    "Nextcloud AppAPI" : "AppAPI Nextcloud",
    "External Apps management" : "Gestion des applications externes",
    "Admin options saved" : "Options d'administration sauvegardées",
    "Failed to save admin options" : "Échec de l'enregistrement des options d'administration",
    "ExApp init timeout (minutes)" : "Temp initial d'ExApp (minutes)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Délai d'expiration du processus d'initialisation ExApp, après quoi AppAPI le marquera comme ayant échoué",
    "ExApp init timeout" : "ExApp initialisation expirer",
    "ExApp container restart policy" : "Politique de redémarrage du conteneur ExApp",
    "Cancel" : "Annuler",
    "Delete" : "Supprimer",
    "Password confirmation failed" : "Échec de la confirmation du mot de passe",
    "Default" : "Défaut",
    "Set as default" : "Définir comme valeur par défaut",
    "Test deploy" : "Tester le déploiement",
    "Docker registries" : "Registres Docker",
    "Edit" : "Modifier",
    "Daemon connection successful" : "Connexion au Deamon réussie",
    "Unlimited" : "Illimité",
    "Default daemon. ExApps will be installed on it" : "Service par défaut. ExApps y sera installé",
    "ExApps installed" : "ExApps installés",
    "Name" : "Nom",
    "Protocol" : "Protocole",
    "Host" : "Hôte",
    "Deploy options" : "Options de déploiement",
    "Docker network" : "Réseau Docker",
    "Nextcloud URL" : "URL Nextcloud",
    "HaProxy password" : "Mot de passe HAProxy",
    "Memory limit" : "Limite de mémoire",
    "Additional options" : "Options supplémentaires",
    "Check connection" : "Vérifier la connexion",
    "Registered Deploy daemons list" : "Liste des services de déploiement enregistrés",
    "Register ExApp in Nextcloud" : "Enregistrez ExApp dans Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Vérifiez si l'ExApp est enregistré dans Nextcloud avant le déploiement",
    "Image pull" : "Extraction d'image",
    "Check if the image is successfully pulled" : "Vérifiez si l'image est extraite avec succès",
    "Container started" : "Conteneur démarré",
    "Check if the image successfully pulled and container is created and started" : "Vérifiez si l'image a été extraite avec succès et si le conteneur est créé et démarré",
    "Heartbeat" : "Test de vie",
    "Check for the heartbeat is finished and healthy" : "Vérifiez que le test de vie est concluant",
    "Init step" : "Étape d'initialisation",
    "Wait for initialization step to finish" : "Attendez la fin de l'étape d'initialisation",
    "Enabled" : "Activé",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Vérifiez si ExApp a géré avec succès l'événement activé et a enregistré tous les éléments correctement",
    "Only if ExApp container is preset" : "Seulement si le conteneur ExApp est prérégler",
    "Deploy test passed successfully!" : "Test de déploiement réussi !",
    "Deploy test failed at step \"{step}\"" : "Le test de déploiement échoue à l'étape \"{step}\"",
    "More information" : "Plus d'informations",
    "Download ExApp logs" : "Télécharger les logs d'ExApp",
    "Please enter a registry domain" : "Veuillez saisir un domaine de registre",
    "Remove" : "Retirer",
    "From" : "De",
    "To" : "À",
    "Add" : "Ajouter",
    "AppAPI Docker Socket Proxy authentication password" : "Mot de passe d'authentification du proxy AppAPI Docker Socket",
    "DaemonConfig successfully registered" : "DaemonConfig enregistré avec succès",
    "Failed to register DaemonConfig. Check the logs" : "Échec de l'enregistrement de DaemonConfig. Vérifiez les logs",
    "DaemonConfig successfully updated" : "DaemonConfig mis à jour avec succès",
    "Failed to update DaemonConfig. Check the logs" : "Échec de la mise à jour de DaemonConfig. Vérifiez les logs",
    "Failed to connect to Daemon. Check the logs" : "Échec de la connexion au Daemon. Vérifiez les logs",
    "Failed to check connection to Daemon. Check the logs" : "Échec de la vérification de la connexion au Daemon. Vérifiez les logs",
    "Daemon configuration template" : "Modèle de configuration de Daemon",
    "Daemon registration form" : "Formulaire d'inscription du service",
    "Display name" : "Nom d’affichage",
    "Deployment method" : "Méthode de déploiement",
    "HaRP host" : "Hôte HaRP",
    "Daemon host" : "Hôte du Deamon",
    "Enable HaRP" : "Activer HaRP",
    "FRP server address" : "Adresse du serveur FRP",
    "Disable FRP" : "Désactiver FRP",
    "Compute device" : "Equipement de calcul",
    "Add additional option" : "Ajouter une option supplémentaire",
    "Option key (unique)" : "Clé d'option (unique)",
    "Option key (unique, e.g. my_key)" : "Clé d'option (unique, par exemple my_key)",
    "Option key is required" : "L'option clé est requise",
    "Option value" : "Valeur d'options",
    "Option value is required" : "Valeur d'option requise",
    "Confirm" : "Confirmer",
    "Save" : "Enregistrer",
    "Register" : "S’inscrire",
    "External Apps" : "Applications externes",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Le projet AppAPI est une initiative passionnante qui vise à révolutionner la manière dont les applications sont développées pour Nextcloud.",
    "Deploy Daemons" : "Déployer Daemons",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemon (DaemonConfig) est un service d'orchestration ExApps.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Déployez Daemons. Deploy Daemon (DaemonConfig) est un service d'orchestration ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Le Daemon de déploiement par défaut n'est pas accessible. Veuillez vérifier sa configuration",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Spécifiez la politique de redémarrage du conteneur, par ex. \"toujours\" pour garantir qu'ExApp fonctionne après le redémarrage du serveur daemon",
    "This settings changes are reflected only for newly created containers" : "Ces modifications de paramètres reflètes uniquement les conteneurs nouvellement créés",
    "{license}-licensed" : "Sous licence {license}",
    "Update to {version}" : "Mettre à jour vers {version}",
    "Delete data on remove" : "Supprimer les données lors de la désinstallation",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version minimum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Cette application n’a pas de version maximum Nextcloud exigée. Ce sera considéré comme une erreur à l’avenir.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
    "View in store" : "Afficher dans le magasin d’applications",
    "Visit website" : "Visiter le site web",
    "Report a bug" : "Signaler un bug",
    "User documentation" : "Documentation utilisateur",
    "Admin documentation" : "Documentation administrateur",
    "Developer documentation" : "Documentation développeurs",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Cette application n'est pas enregistrée dans l'AppStore. Aucune information supplémentaire disponible. Seules les actions d'activation/désactivation et de suppression sont autorisées.",
    "This app is supported via your current Nextcloud subscription." : "Cette application bénéficie d'un support grâce à votre abonnement Nextcloud.",
    "Supported" : "Prise en charge",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les applications en vedette sont développées par la communauté. Elles proposent des fonctionnalités centrales et sont prêtes pour la production.",
    "Featured" : "En vedette",
    "Update to {update}" : "Mettre à jour vers {update}",
    "All ExApps are up-to-date." : "Tous les ExApps sont à jour.",
    "Default Deploy daemon is not accessible" : "Le service de déploiement par défaut n'est pas accessible",
    "Icon" : "Icône",
    "Version" : "Version",
    "Daemon" : "Processus",
    "Level" : "Niveau",
    "Actions" : "Actions",
    "Results from other categories" : "Résultats d’autres catégories",
    "No apps found" : "Aucune application trouvée",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp a une mise à jour disponible","%n applications ont une mise à jour disponible","%n applications ont une mise à jour disponible"],
    "_Update_::_Update all_" : ["Mettre à jour","Tout mettre à jour","Tout mettre à jour"],
    "Deploy Daemon" : "Deamon de déploiement",
    "Type" : "Type",
    "Display Name" : "Nom affiché",
    "GPUs support" : "Prise en charge des cartes graphiques",
    "Are you sure you want delete Deploy Daemon" : "Êtes-vous sûr de vouloir supprimer le service de déploiement?",
    "All ExApps on this daemon will be removed" : "Tous les ExApps sur ce service seront supprimés",
    "All ExApps installed on this daemon will be removed" : "Tous les ExApps installés sur ce service seront supprimés",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "Le service de déploiement \"installation manuelle\" ne peut pas être défini par défaut",
    "Failed to save admin options. Check the logs" : "Échec de l'enregistrement des options d'administration. Vérifiez les logs",
    "Deploy daemon config details" : "Déployer les détails de la configuration du service",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Service d'installation manuelle généralement utilisé pour le développement. Il ne peut pas être défini comme service par défaut.",
    "Deploy config" : "Déployer la configuration",
    "Verify connection" : "Vérifier la connexion",
    "No Deploy daemons configured" : "Aucun service de déploiement configuré",
    "Register a custom one or setup from available templates" : "Enregistrez-en un personnalisé ou une configuration à partir des modèles disponibles",
    "Register Daemon" : "Inscrire Daemon",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI tentera d'installer le petit squelette ExApp pour vérifier que le Daemon est correctement configuré et que les étapes de déploiement sont en cours.",
    "The following Deploy test checks must be passed to succeed:" : "Le test de déploiement suivant les contrôles doivent être passés en réussi:",
    "More info" : "Plus d'informations",
    "Remove test ExApp" : "Supprimer le test ExApp",
    "Start Deploy test" : "Démarrer le test de déploiement",
    "Stop Deploy test" : "Arrêt du test de déploiement",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp n'est pas enregistré et le conteneur est supprimé lors de l' \"Arrêt du test de déploiement\"",
    "Hostname to access ExApps" : "Nom d'hôte pour accéder à ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nom d’hôte ou chemin d’accès au daemon Docker (par ex. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Un service du même nom existe déjà",
    "Password must be at least 12 characters long" : "Le mot de passe doit comporter au moins 12 caractères",
    "With https enabled network is set to host" : "Avec https activé, le réseau est en mode « hôte »",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Les modifications seraient appliquées uniquement aux ExApps nouvellement installées. Pour les ExApps existantes, les conteneurs Docker doivent être recréés.",
    "URL should start with http:// or https://" : "L'URL doit commencer par http:// ou https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Pour le service HTTPS, l'URL Nextcloud doit être HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Tous les périphériques GPU disponibles sur le service d'hôte devront être activés dans les conteneurs ExApp par Docker.",
    "Edit Deploy Daemon" : "Modifier le déploiement Daemon",
    "Register Deploy Daemon" : "Enregistrer le service de déploiement",
    "Select daemon configuration template" : "Sélectionnez le modèle de configuration du service",
    "Unique Deploy Daemon Name" : "Nom unique de déploiement du service",
    "Select daemon deploy method" : "Sélectionner la méthode de déploiement du service",
    "Set daemon as default" : "Définir comme service par défaut",
    "Set as default daemon" : "Définir ce deamon par défaut",
    "Enable https" : "Activer https",
    "Show deploy config" : "Afficher la configuration de déploiement",
    "Hide deploy config" : "Masquer la configuration de déploiement",
    "Network" : "Réseau",
    "Docker network name" : "Nom du réseau Docker",
    "Additional option" : "Option supplémentaire",
    "by {author}\n{license}" : "par {author}\n{license}",
    "Your apps" : "Vos applications",
    "Documentation" : "Documentation",
    "Details" : "Détails",
    "Changelog" : "Journal des modifications",
    "Active apps" : "Applications actives",
    "Disabled apps" : "Applications désactivées",
    "Updates" : "Mises à jour",
    "Featured apps" : "Applications en vedette",
    "Supported apps" : "Applications supportées",
    "manual-install apps cannot be updated" : "les applications installées manuellement ne peuvent pas être mises à jour",
    "{progress}% Deploying" : "{progress}% de déploiement",
    "{progress}% Initializing" : "{progress}% Initialisation",
    "Healthchecking" : "Vérification de l'état",
    "Deploy and Enable" : "Déployer et Activer",
    "Enable" : "Activer",
    "Disable" : "Désactiver",
    "Allow untested app" : "Autoriser l'application non testée",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Le service de déploiement par défaut n’est pas accessible. Veuillez vérifier la configuration",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "L'application sera téléchargée depuis l'App Store et déployée sur le Daemon de déploiement par défaut.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Cette application n'est pas indiquée comme étant compatible avec votre version de Nextcloud. Si vous continuez vous pourrez toujours installer l'app. Notez cependant qu'elle pourrait ne pas fonctionner comme prévu.",
    "Your ExApps" : "Vos ExApps",
    "An error occurred during the request. Unable to proceed." : "Une erreur est survenue pendant la demande. Impossible de poursuivre.",
    "The app has been enabled but needs to be updated." : "L'application a été activée mais doit être mise à jour.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erreur : cette application ne peut être activée car elle rend le serveur instable",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Boostez votre Nextcloud avec AppAPI et ses applications spécialement conçues.\n\n\nL'AppAPI est un projet au sein de l'écosystème Nextcloud conçu pour rationaliser et améliorer le processus de\ndéveloppement, déploiement et gestion d'applications.\n\nIl introduit une nouvelle méthodologie qui permet aux développeurs de créer\napplications utilisant une variété de langages de programmation, sans se limiter à PHP, qui était traditionnellement utilisé dans le développement Nextcloud.\n\n\n### Liste des applications qui nécessitent AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Si vous souhaitez développer une application, nous serons heureux de vous aider et de vous assister._\n\n### Assistance\n\nNous apprécions tout soutien pour ce projet:\n\n- ⭐ Star notre travail sur GitHub\n- ❗ Créer un problème ou une demande de fonctionnalité\n- 💁 Résoudre un problème et créer un Pull Request\n- 🧑‍💻 Développez votre propre application à l'aide d'AppAPI\n\nNous sommes véritablement enthousiasmés par l'avenir du projet AppAPI et son potentiel de transformation\nla façon dont les applications sont développées et expérimentées dans Nextcloud.\n\nAlors que nous entreprenons ce voyage, nous vous invitons chaleureusement - développeurs, penseurs, créateurs et visionnaires -\nà nous rejoindre dans la création d'un paysage d'applications plus polyvalent, stable et sécurisé.\n\n*Vos idées, suggestions et contributions nous sont inestimables.*"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
