OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "חסרה סיסמת מפתח שחזור",
    "Please repeat the recovery key password" : "יש לחזור על סיסמת מפתח השחזור",
    "Repeated recovery key password does not match the provided recovery key password" : "סיסמת מפתח השחזור החוזרת אינה מתאימה לסיסמת מפתח השחזור הקיימת",
    "Recovery key successfully enabled" : "מפתח השחזור אופשר בהצלחה",
    "Could not enable recovery key. Please check your recovery key password!" : "איפשור מפתח השחזור נכשל. יש לבדוק את סיסמת מפתח השחזור שלך!",
    "Recovery key successfully disabled" : "מפתח השחזור נוטרל בהצלחה",
    "Could not disable recovery key. Please check your recovery key password!" : "נטרול מפתח השחזור נכשל. יש לבדוק את סיסמת מפתח השחזור שלך!",
    "Please provide the old recovery password" : "יש לספק את סיסמת השחזור הישנה",
    "Please provide a new recovery password" : "יש לספק את סיסמת השחזור החדשה",
    "Please repeat the new recovery password" : "יש לספק את סיסמת השחזור החדשה",
    "Password successfully changed." : "הסיסמא שונתה בהצלחה.",
    "Could not change the password. Maybe the old password was not correct." : "שינוי הסיסמא נכשל. יתכן שהסיסמא הישנה לא נכונה.",
    "Recovery Key disabled" : "מפתח שחזור מנוטרל",
    "Recovery Key enabled" : "מפתח שחזור מאופשר",
    "Could not enable the recovery key, please try again or contact your administrator" : "איפשור מפתח השחזור נכשל. יש לנסות שנית או לפנות למנהל שלך",
    "Could not update the private key password." : "לא ניתן לעדכן את סיסמת המפתח האישי",
    "The old password was not correct, please try again." : "הסיסמא הישנה לא נכונה, יש לנסות שנית.",
    "The current log-in password was not correct, please try again." : "סיסמת ההתחברות הנוכחית אינה נכונה, יש לנסות שנית.",
    "Private key password successfully updated." : "סיסמת מפתח אישי עודכנה בהצלחה.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "מפתח פרטי שגוי ליישומון הצפנה. נא לעדכן את ססמת המפתח הפרטי בהגדרות האישיות שלך כדי לשחזר את הגישה לקבצים המוצפנים שלך.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "יישומון ההצפנה מופעל אך המפתחות שלך לא אותחלו. נא לצאת מהחשבון ולהיכנס שוב.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "נא להפעיל הצפנה מצד השרת בהגדרות הניהול כדי להשתמש במודול ההצפנה.",
    "Encryption app is enabled and ready" : "יישומון ההצפנה מופעל ומוכן",
    "Bad Signature" : "חתימה שגויה",
    "Missing Signature" : "חתימה חסרה",
    "one-time password for server-side-encryption" : "סיסמא חד פעמית עבור הצפנת צד השרת",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "הפעלת אפשרות זו מצפינה את כל הקבצים המאוחסנים באחסון המרכזי, אחרת רק הקבצים המאוחסנים בהתקנים חיצוניים יוצפנו",
    "Encrypt the home storage" : "הצפנת אחסון הבית",
    "Disable recovery key" : "מנטרל מפתח שחזור",
    "Enable recovery key" : "מאפשר מפתח שחזור",
    "Recovery key password" : "סיסמת מפתח השחזור",
    "Repeat recovery key password" : "יש לחזור על סיסמת מפתח השחזור",
    "Old recovery key password" : "סיסמת מפתח שחזור ישנה",
    "New recovery key password" : "סיסמת מפתח שחזור חדשה",
    "Repeat new recovery key password" : "יש לחזור על סיסמת מפתח השחזור החדשה",
    "Old log-in password" : "סיסמת התחברות ישנה",
    "Current log-in password" : "סיסמת התחברות נוכחית",
    "Update" : "עדכון",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "הפעלת אפשרות זו תאפשר לך לקבל מחדש גישה לקבצים המוצפנים שלך במקרה שסיסמא נשכחת",
    "Default encryption module" : "מודול ההצפנה כבררת מחדל",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "יישומון ההצפנה פעיל אך המפתחות שלך לא אותחלו, נא לצאת מהחשבון ולהיכנס שוב.",
    "Basic encryption module" : "מודול הצפנה בסיסי",
    "Missing parameters" : "פרמטרים חסרים",
    "Default encryption module for server-side encryption" : "מודול הצפנה כבררת מחדל להצפנה מצד השרת",
    "Change recovery key password:" : "החלפת סיסמת מפתח השחזור:",
    "Change Password" : "שינוי סיסמא",
    "Your private key password no longer matches your log-in password." : "סיסמת המפתח האישי שלך כבר אינה מתאימה לסיסמת ההתחברות שלך.",
    "Set your old private key password to your current log-in password:" : "יש להחליף את סיסמת המפתח האישי הישנה בסיסמת ההתחברות הנוכחית:",
    "Update Private Key Password" : "עדכון סיסמת המפתח האישי",
    "Enable password recovery:" : "מאפשר שחזור סיסמא:",
    "Enabled" : "מופעל",
    "Disabled" : "מנוטרל"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
