.material-design-icon[data-v-5fe0f834]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.color-picker[data-v-5fe0f834]{display:flex;overflow:hidden;align-content:flex-end;flex-direction:column;justify-content:space-between;box-sizing:content-box!important;width:176px;padding:8px;border-radius:3px}.color-picker--advanced-fields[data-v-5fe0f834]{width:264px}.color-picker__simple[data-v-5fe0f834]{display:grid;grid-template-columns:repeat(auto-fit,var(--default-clickable-area));grid-auto-rows:var(--default-clickable-area)}.color-picker__simple-color-circle[data-v-5fe0f834]{display:flex;align-items:center;justify-content:center;width:calc(var(--default-clickable-area) - 10px);height:calc(var(--default-clickable-area) - 10px);min-height:calc(var(--default-clickable-area) - 10px);margin:auto;padding:0;color:#fff;border:1px solid rgba(0,0,0,.25);border-radius:50%;font-size:16px}.color-picker__simple-color-circle[data-v-5fe0f834]:focus-within{outline:2px solid var(--color-main-text)}.color-picker__simple-color-circle[data-v-5fe0f834]:hover{opacity:.6}.color-picker__simple-color-circle--active[data-v-5fe0f834]{width:calc(var(--default-clickable-area) - 6px);height:calc(var(--default-clickable-area) - 6px);min-height:calc(var(--default-clickable-area) - 6px);transition:all .1s ease-in-out;opacity:1!important}.color-picker__advanced[data-v-5fe0f834]{box-shadow:none!important}.color-picker__navigation[data-v-5fe0f834]{display:flex;flex-direction:row;justify-content:space-between;margin-top:10px}[data-v-5fe0f834] .vc-chrome{width:unset;background-color:var(--color-main-background)}[data-v-5fe0f834] .vc-chrome-color-wrap{width:30px;height:30px}[data-v-5fe0f834] .vc-chrome-active-color{border-radius:17px}[data-v-5fe0f834] .vc-chrome-body{padding:14px 0 0;background-color:var(--color-main-background)}[data-v-5fe0f834] .vc-chrome-body .vc-input__input{--input-border-radius: var(--border-radius-element, var(--border-radius-large));--input-border-width-offset: calc(var(--border-width-input-focused, 2px) - var(--border-width-input, 2px));width:100%;height:var(--default-clickable-area);margin:0;padding-inline:calc(var(--border-radius-large) + var(--input-border-width-offset));padding-block:var(--input-border-width-offset);border:var(--border-width-input, 2px) solid var(--color-border-maxcontrast);border-radius:var(--input-border-radius);font-size:var(--default-font-size);color:var(--color-main-text);box-shadow:none}[data-v-5fe0f834] .vc-chrome-body .vc-input__input:active:not([disabled]),[data-v-5fe0f834] .vc-chrome-body .vc-input__input:hover:not([disabled]),[data-v-5fe0f834] .vc-chrome-body .vc-input__input:focus:not([disabled]){--input-border-width-offset: 0px;border-color:var(--color-main-text);border-width:var(--border-width-input-focused, 2px);box-shadow:0 0 0 2px var(--color-main-background)!important}[data-v-5fe0f834] .vc-chrome-body .vc-input__input:active:not([disabled])+.vc-input__label,[data-v-5fe0f834] .vc-chrome-body .vc-input__input:hover:not([disabled])+.vc-input__label,[data-v-5fe0f834] .vc-chrome-body .vc-input__input:focus:not([disabled])+.vc-input__label{color:var(--color-main-text)}[data-v-5fe0f834] .vc-chrome-body .vc-input__label{position:absolute;inset-inline:var(--border-width-input-focused, 2px);inset-block-start:calc(-1.5 * var(--font-size-small, 13px) / 2);max-width:fit-content;margin-inline:calc(var(--border-radius-large) - var(--default-grid-baseline));margin-block:0;padding-inline:var(--default-grid-baseline);font-family:var(--font-face);font-size:var(--font-size-small, 13px);line-height:1.5;font-weight:500;color:var(--color-text-maxcontrast);background-color:var(--color-main-background);pointer-events:none}[data-v-5fe0f834] .vc-chrome-toggle-btn{display:flex;justify-content:center;align-items:center;width:var(--default-clickable-area);height:var(--default-clickable-area);margin-left:6px;filter:var(--background-invert-if-dark)}[data-v-5fe0f834] .vc-chrome-toggle-icon{width:24px;height:24px;margin:0}[data-v-5fe0f834] .vc-chrome-toggle-icon-highlight{width:var(--default-clickable-area);height:var(--default-clickable-area);inset:0}[data-v-5fe0f834] .vc-chrome-saturation-wrap{border-radius:3px}[data-v-5fe0f834] .vc-chrome-saturation-circle{width:20px;height:20px}.slide-enter[data-v-5fe0f834]{transform:translate(-50%);opacity:0}.slide-enter-to[data-v-5fe0f834],.slide-leave[data-v-5fe0f834]{transform:translate(0);opacity:1}.slide-leave-to[data-v-5fe0f834]{transform:translate(-50%);opacity:0}.slide-enter-active[data-v-5fe0f834],.slide-leave-active[data-v-5fe0f834]{transition:all 50ms ease-in-out}
