OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Password is expired, please use forgot password method to reset",
    "Password must not have been used recently before." : "Password must not have been used recently before.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Password is among the 1,000,000 most common ones. Please make it unique.",
    "Password is present in compromised password list. Please choose a different password." : "Password is present in compromised password list. Please choose a different password.",
    "Password needs to be at least %s characters long." : "Password needs to be at least %s characters long.",
    "Password needs to contain at least one numeric character." : "Password needs to contain at least one numeric character.",
    "Password needs to contain at least one special character." : "Password needs to contain at least one special character.",
    "Password needs to contain at least one lower and one upper case character." : "Password needs to contain at least one lower and one upper case character.",
    "Password policy" : "Password policy",
    "Allows admins to configure a password policy" : "Allows admins to configure a password policy",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length",
    "General password policies" : "General password policies",
    "Add policy set" : "Add policy set",
    "Login policies" : "Login policies",
    "Password history size" : "Password history size",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords.",
    "Maximum login attempts" : "Maximum login attempts",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting.",
    "Number of days until user password expires" : "Number of days until user password expires",
    "Password expiration" : "Password expiration",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Warning: enabling password expiration is nowadays considered a security risk by several security agencies.",
    "Remove policy" : "Remove policy",
    "Minimum password length" : "Minimum password length",
    "Forbid common passwords" : "Forbid common passwords",
    "Enforce upper and lower case characters" : "Enforce upper and lower case characters",
    "Enforce numeric characters" : "Enforce numeric characters",
    "Enforce special characters" : "Enforce special characters",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Check password against the list of breached passwords from haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set.",
    "Account password policies" : "Account password policies",
    "Share password policies" : "Share password policies"
},
"nplurals=2; plural=(n != 1);");
