var c,e;function E(){if(e)return c;e=1;function t(o){const a=o.regex,s=/^[a-zA-Z][a-zA-Z0-9-]*/,r=["ALPHA","BIT","CHAR","CR","CRLF","CTL","DIGIT","DQUOTE","HEXDIG","HTAB","LF","LWSP","OCTET","SP","VCHAR","WSP"],n=o.COMMENT(/;/,/$/),m={scope:"symbol",match:/%b[0-1]+(-[0-1]+|(\.[0-1]+)+)?/},A={scope:"symbol",match:/%d[0-9]+(-[0-9]+|(\.[0-9]+)+)?/},T={scope:"symbol",match:/%x[0-9A-F]+(-[0-9A-F]+|(\.[0-9A-F]+)+)?/},p={scope:"symbol",match:/%[si](?=".*")/},u={scope:"attribute",match:a.concat(s,/(?=\s*=)/)};return{name:"Augmented Backus-Naur Form",illegal:/[!@#$^&',?+~`|:]/,keywords:r,contains:[{scope:"operator",match:/=\/?/},u,n,m,A,T,p,o.QUOTE_STRING_MODE,o.NUMBER_MODE]}}return c=t,c}export{E as r};
//# sourceMappingURL=abnf-CinNQjEv.chunk.mjs.map
