OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Parolanın geçerlilik süresi dolmuş. Lütfen sıfırlamak için parolamı unuttum yöntemini kullanın",
    "Password must not have been used recently before." : "Parola son kullandığınız parolalardan farklı olmalıdır.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen eşsiz bir parola seçin.",
    "Password is present in compromised password list. Please choose a different password." : "Yazdığınız parola bilinen parolalar listesinde. Lütfen başka bir parola seçin.",
    "Password needs to be at least %s characters long." : "Parola en az %s karakter uzunluğunda olmalıdır.",
    "Password needs to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password needs to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password needs to contain at least one lower and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password policy" : "Parola ilkesi",
    "Allows admins to configure a password policy" : "Yöneticilerin bir parola ilkesi yapılandırmasını sağlar",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Yöneticilerin parolalar için en kısa uzunluk gibi çeşitli ön koşulları zorunlu kılmasını sağlar.",
    "General password policies" : "Genel parola ilkeleri",
    "Add policy set" : "İlke kümesi ekle",
    "Login policies" : "Oturum açma ilkeleri",
    "Password history size" : "Parola geçmişi boyutu",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Kullanıcıların daha önce kullandıkları parolaları yeniden kullanmasını önlemek için tutulması gereken (güvenli bir şekilde karıştırılmış) parola sayısı.",
    "Maximum login attempts" : "En fazla oturum açma girişimi sayısı",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Kullanıcı hesabı el ile işlem yapılana kadar kullanımdan kaldırılmadan önce yapılabilecek oturum açma girişimlerinin sayısı (sınır olmaması için 0).",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Lütfen bu seçeneğin saldırıya uğrayan hesapları koruma amaçlı olduğunu unutmayın. Kullanımdan kaldırılmış hesapların yönetim tarafından el ile yeniden kullanıma alınması gerekir. Hesapların parolalarını bulmaya çalışan saldırganların IP adresleri, bu ayardan bağımsız olarak kaba kuvvet saldırısı koruması tarafından engellenir.",
    "Number of days until user password expires" : "Kullanıcı parolasının geçerlilik süresinin dolmasına kalan gün",
    "Password expiration" : "Parola geçerlilik süresi",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Uyarı: Parola geçerlilik süresini kullanmak günümüzde birçok güvenlik kuruluşu tarafından bir güvenlik riski olarak kabul ediliyor.",
    "Remove policy" : "İlkeyi kaldır",
    "Minimum password length" : "En kısa parola uzunluğu",
    "Forbid common passwords" : "Sık kullanılan parolalar kullanılamasın",
    "Enforce upper and lower case characters" : "Parolada büyük ve küçük harflerin bulunması zorunlu kılınsın",
    "Enforce numeric characters" : "Parolada rakam bulunması zorunlu kılınsın",
    "Enforce special characters" : "Parolada simge karakterlerinin bulunması zorunlu kılınsın",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Parolalar haveibeenpwned.com üzerindeki bilinen parolalar listesi ile denetlensin",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Bu denetim paroladan bir sağlama değeri üretir ve ilk 5 karakterini haveibeenpwned.com API uygulamasına göndererek bu 5 karakter ile başlayan karmaların listesini alır. Ardından Nexctcloud kopyasında parola karmasının sonuç kümesinde olup olmadığını denetler.",
    "Account password policies" : "Hesap parolası ilkeleri",
    "Share password policies" : "Paylaşım parolası ilkeleri"
},
"nplurals=2; plural=(n > 1);");
