OC.L10N.register(
    "dav",
    {
    "Calendar" : "Féilire",
    "Tasks" : "Tascanna",
    "Personal" : "Pearsanta",
    "{actor} created calendar {calendar}" : "{actor} féilire cruthaithe {calendar}",
    "You created calendar {calendar}" : "Chruthaigh tú féilire {calendar}",
    "{actor} deleted calendar {calendar}" : "Scriosadh {actor} féilire {calendar}",
    "You deleted calendar {calendar}" : "Scrios tú an féilire {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} féilire nuashonraithe {calendar}",
    "You updated calendar {calendar}" : "Nuashonraigh tú an féilire {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} féilire athchóirithe {calendar}",
    "You restored calendar {calendar}" : "D'athchóirigh tú an féilire {calendar}",
    "You shared calendar {calendar} as public link" : "Roinn tú féilire {calendar} mar nasc poiblí",
    "You removed public link for calendar {calendar}" : "Bhain tú nasc poiblí don fhéilire {calendar}",
    "{actor} shared calendar {calendar} with you" : "Roinn {actor} féilire {calendar} leat",
    "You shared calendar {calendar} with {user}" : "Roinn tú féilire {calendar} le {user} ",
    "{actor} shared calendar {calendar} with {user}" : "Roinn {actor} féilire {calendar} le {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} féilire {calendar} neamhroinnte uait",
    "You unshared calendar {calendar} from {user}" : "Dhíroinn tú {calendar} ó {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} féilire {calendar} neamhroinnte ó {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} féilire {calendar} neamhroinnte astu féin",
    "You shared calendar {calendar} with group {group}" : "Roinn tú féilire {calendar} le grúpa {group}",
    "{actor} shared calendar {calendar} with group {group}" : "Roinn {actor} féilire {calendar} le grúpa {group}",
    "You unshared calendar {calendar} from group {group}" : "Dhíroinn tú féilire {calendar} ón ngrúpa {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} féilire {calendar} neamhroinnte ó ghrúpa {group}",
    "Untitled event" : "Imeacht gan teideal",
    "{actor} created event {event} in calendar {calendar}" : "Chruthaigh {actor} imeacht {event} san fhéilire {calendar}",
    "You created event {event} in calendar {calendar}" : "Chruthaigh tú {event} imeacht san fhéilire {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "Scrios {actor} imeacht {event} ón bhféilire {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Scrios tú {event} imeacht ón bhféilire {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} imeacht nuashonraithe {event} san fhéilire {calendar}",
    "You updated event {event} in calendar {calendar}" : "Nuashonraigh tú {event} imeacht san fhéilire {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Bhog {actor} imeacht {event} ó fhéilire {sourceCalendar} go féilire {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Bhog tú {event} imeacht ó fhéilire {sourceCalendar} go féilire {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "D'aischuir {actor} imeacht {event} den fhéilire {calendar}",
    "You restored event {event} of calendar {calendar}" : "D'aischuir tú imeacht {event} den fhéilire {calendar}",
    "Busy" : "Gnóthach",
    "{actor} created to-do {todo} in list {calendar}" : "Chruthaigh {actor} to-do {todo} sa liosta {calendar}",
    "You created to-do {todo} in list {calendar}" : "Chruthaigh tú to-do {todo} sa liosta {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "Scriosadh {actor} to-do {todo} ón liosta {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Scrios tú to-do {todo} ón liosta {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "Nuashonraigh {actor} to-do {todo} sa liosta {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Nuashonraigh tú to-do {todo} sa liosta {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "Réitigh {actor} to-do {todo} sa liosta {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Réitigh tú le déanamh {todo} sa liosta {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "D'athoscail {actor} to-do {todo} sa liosta {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "D'oscail tú to-do {todo} sa liosta {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Bhog {actor} {todo} ó liosta {sourceCalendar} chun {targetCalendar} a liostú",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Bhog tú chun {todo} a dhéanamh ón liosta {sourceCalendar} go dtí an liosta {targetCalendar}",
    "Calendar, contacts and tasks" : "Féilire, teagmhálacha agus tascanna",
    "A <strong>calendar</strong> was modified" : "Athraíodh <strong>calendar</strong>  ",
    "A calendar <strong>event</strong> was modified" : "Athraíodh féilire <strong>event</strong>  ",
    "A calendar <strong>to-do</strong> was modified" : "Athraíodh féilire<strong>to-do</strong> ",
    "Contact birthdays" : "Déan teagmháil le breithlaethanta",
    "Death of %s" : "Bás%s",
    "Untitled calendar" : "Féilire gan teideal",
    "Calendar:" : "Féilire:",
    "Date:" : "Dáta:",
    "Where:" : "Cá háit:",
    "Description:" : "Cur síos:",
    "_%n year_::_%n years_" : ["%n bhliain","%n bliain","%n bliain","%n bliain","%n bliain"],
    "_%n month_::_%n months_" : ["%n mí","%n míonna","%n míonna","%n míonna","%n míonna"],
    "_%n day_::_%n days_" : ["%n lá","%n laethanta","%n laethanta","%n laethanta","%n laethanta"],
    "_%n hour_::_%n hours_" : ["%n uair an chloig","%n uair an chloig","%n uair an chloig","%n uair an chloig","%n uair an chloig"],
    "_%n minute_::_%n minutes_" : ["%n nóiméad","%n nóiméad","%n nóiméad","%n nóiméad","%n nóiméad"],
    "%s (in %s)" : "%s (i %s)",
    "%s (%s ago)" : "%s (%s ó shin)",
    "Calendar: %s" : "Féilire: %s",
    "Date: %s" : "Dáta: %s",
    "Description: %s" : "Cur síos: %s",
    "Where: %s" : "Cá: %s",
    "%1$s via %2$s" : "%1$s trí %2$s",
    "In the past on %1$s for the entire day" : "San am atá thart ar %1$s don lá ar fad",
    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["I %n nóiméad ar %1$s don lá ar fad","I %n nóiméad ar %1$s don lá ar fad","I %n nóiméad ar %1$s don lá ar fad","I %n nóiméad ar %1$s don lá ar fad","I %n nóiméad ar %1$s don lá ar fad"],
    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["I %n uair an chloig ar %1$s don lá ar fad","I %n uair an chloig ar %1$s don lá ar fad","I %n uair an chloig ar %1$s don lá ar fad","I %n uair an chloig ar %1$s don lá ar fad","I %n uair an chloig ar %1$s don lá ar fad"],
    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["I %n lá ar %1$s don lá ar fad","I %n lá ar %1$s don lá ar fad","I %n lá ar %1$s don lá ar fad","I %n lá ar %1$s don lá ar fad","I %n lá ar %1$s don lá ar fad"],
    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["I %n seachtain ar %1$s don lá ar fad","I %n seachtain ar %1$s don lá ar fad","I %n seachtain ar %1$s don lá ar fad","I %n seachtain ar %1$s don lá ar fad","I %n seachtain ar %1$s don lá ar fad"],
    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["I %n mí ar %1$s don lá ar fad","I %n mí ar %1$s don lá ar fad","I %n mí ar %1$s don lá ar fad","I %n mí ar %1$s don lá ar fad","I %n mí ar %1$s don lá ar fad"],
    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["I %n bliain ar %1$s don lá ar fad","I %n bliain ar %1$s don lá ar fad","I %n bliain ar %1$s don lá ar fad","I %n bliain ar %1$s don lá ar fad","I %n bliain ar %1$s don lá ar fad"],
    "In the past on %1$s between %2$s - %3$s" : "San am a chuaigh thart ar %1$s idir %2$s - %3$s",
    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["I %n nóiméad ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s","I %n nóiméad ar %1$s idir %2$s - %3$s"],
    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["I %n uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s","I %n uair an chloig ar %1$s idir %2$s - %3$s"],
    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["I %n lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s","I %n lá ar %1$s idir %2$s - %3$s"],
    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["I %n seachtain ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s","I %n seachtain ar %1$s idir %2$s - %3$s"],
    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["I %n mí ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s","I %n mí ar %1$s idir %2$s - %3$s"],
    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["I %n bliain ar %1$s idir %2$s - %3$s","I %n bliain ar %1$s idir %2$s - %3$s","I %n bliain ar %1$s idir %2$s - %3$s","I %n bliain ar %1$s idir %2$s - %3$s","I %n bliain ar %1$s idir %2$s - %3$s"],
    "Could not generate when statement" : "Níorbh fhéidir a ghiniúint nuair a ráiteas",
    "Every Day for the entire day" : "Gach Lá don lá ar fad",
    "Every Day for the entire day until %1$s" : "Gach Lá ar feadh an lae ar fad go dtí %1$s",
    "Every Day between %1$s - %2$s" : "Gach Lá idir %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Gach Lá idir %1$s - %2$s go %3$s",
    "Every %1$d Days for the entire day" : "Gach %1$d lá don lá ar fad",
    "Every %1$d Days for the entire day until %2$s" : "Gach %1$d Laethanta don lá iomlán go dtí %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Gach %1$d Laethanta idir %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Gach %1$d Laethanta idir %2$s - %3$s go %4$s",
    "Could not generate event recurrence statement" : "Níorbh fhéidir ráiteas atarlaithe teagmhais a ghiniúint",
    "Every Week on %1$s for the entire day" : "Gach seachtain ar %1$s don lá ar fad",
    "Every Week on %1$s for the entire day until %2$s" : "Gach seachtain ar %1$s don lá ar fad go dtí %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Gach Seachtain ar %1$s idir %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Gach Seachtain ar %1$s idir %2$s - %3$s go %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Gach %1$d seachtain ar %2$s don lá ar fad",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Gach %1$d seachtain ar %2$s ar feadh an lae ar fad go dtí %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Gach %1$d Seachtain ar %2$s idir %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Gach %1$d Seachtain ar %2$s idir %3$s - %4$s go %5$s",
    "Every Month on the %1$s for the entire day" : "Gach Mí ar an %1$s don lá ar fad",
    "Every Month on the %1$s for the entire day until %2$s" : "Gach Mí ar an %1$s don lá iomlán go dtí %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Gach Mí ar an %1$s idir %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Gach Mí ar an %1$s idir %2$s - %3$s go %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Gach %1$d Míonna ar an %2$s ar feadh an lae ar fad",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Gach %1$d Míonna ar an %2$s ar feadh an lae ar fad go dtí %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Gach %1$d Mí ar an %2$s idir %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Gach %1$d Mí ar an %2$s idir %3$s - %4$s go %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Gach Bliain i %1$s ar an %2$s ar feadh an lae ar fad",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Gach Bliain i %1$s ar an %2$s ar feadh an lae ar fad go dtí %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Gach Bliain i %1$s ar an %2$s idir %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Gach Bliain i %1$s ar an %2$s idir %3$s - %4$s go %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Gach %1$d Bliain i %2$s ar an %3$s don lá ar fad",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Gach %1$d Bliain i %2$s ar an %3$s don lá ar fad go dtí %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Gach %1$d Bliain i %2$s ar an %3$s idir %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Gach %1$d Bliain i %2$s ar an %3$s idir %4$s - %5$s go %6$s",
    "On specific dates for the entire day until %1$s" : "Ar dhátaí ar leith don lá iomlán go dtí %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "Ar dhátaí sonracha idir %1$s - %2$s go %3$s",
    "In the past on %1$s" : "San am a chuaigh thart ar %1$s",
    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["I %n nóiméad ar %1$s","I %n nóiméad ar %1$s","I %n nóiméad ar %1$s","I %n nóiméad ar %1$s","I %n nóiméad ar %1$s"],
    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["I %n uair an chloig ar %1$s","I %n uair an chloig ar %1$s","I %n uair an chloig ar %1$s","I %n uair an chloig ar %1$s","I %n uair an chloig ar %1$s"],
    "_In %n day on %1$s_::_In %n days on %1$s_" : ["I %n lá ar %1$s","I %n lá ar %1$s","I %n lá ar %1$s","I %n lá ar %1$s","I %n lá ar %1$s"],
    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["I %n seachtain ar %1$s","I %n seachtain ar %1$s","I %n seachtain ar %1$s","I %n seachtain ar %1$s","I %n seachtain ar %1$s"],
    "_In %n month on %1$s_::_In %n months on %1$s_" : ["I %n mí ar %1$s","I %n mí ar %1$s","I %n mí ar %1$s","I %n mí ar %1$s","I %n mí ar %1$s"],
    "_In %n year on %1$s_::_In %n years on %1$s_" : ["I %n bliain ar %1$s","I %n bliain ar %1$s","I %n bliain ar %1$s","I %n bliain ar %1$s","I %n bliain ar %1$s"],
    "In the past on %1$s then on %2$s" : "San am a chuaigh thart ar %1$s agus ansin ar %2$s",
    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["I %n nóiméad ar %1$s ansin ar %2$s","I %n nóiméad ar %1$s ansin ar %2$s","I %n nóiméad ar %1$s ansin ar %2$s","I %n nóiméad ar %1$s ansin ar %2$s","I %n nóiméad ar %1$s ansin ar %2$s"],
    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["I %n uair an chloig ar %1$s ansin ar %2$s","I %n uair an chloig ar %1$s ansin ar %2$s","I %n uair an chloig ar %1$s ansin ar %2$s","I %n uair an chloig ar %1$s ansin ar %2$s","I %n uair an chloig ar %1$s ansin ar %2$s"],
    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["I %n lá ar %1$s ansin ar %2$s","I %n lá ar %1$s ansin ar %2$s","I %n lá ar %1$s ansin ar %2$s","I %n lá ar %1$s ansin ar %2$s","I %n lá ar %1$s ansin ar %2$s"],
    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["I %n seachtain ar %1$s ansin ar %2$s","I %n seachtain ar %1$s ansin ar %2$s","I %n seachtain ar %1$s ansin ar %2$s","I %n seachtain ar %1$s ansin ar %2$s","I %n seachtain ar %1$s ansin ar %2$s"],
    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["I %n mí ar %1$s ansin ar %2$s","I %n mí ar %1$s ansin ar %2$s","I %n mí ar %1$s ansin ar %2$s","I %n mí ar %1$s ansin ar %2$s","I %n mí ar %1$s ansin ar %2$s"],
    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["I %n bliain ar %1$s ansin ar %2$s","I %n bliain ar %1$s ansin ar %2$s","I %n bliain ar %1$s ansin ar %2$s","I %n bliain ar %1$s ansin ar %2$s","I %n bliain ar %1$s ansin ar %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "San am a chuaigh thart ar %1$s ansin ar %2$s agus %3$s",
    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["I %n nóiméad ar %1$s ansin ar %2$s agus %3$s","I %n nóiméad ar %1$s ansin ar %2$s agus %3$s","I %n nóiméad ar %1$s ansin ar %2$s agus %3$s","I %n nóiméad ar %1$s ansin ar %2$s agus %3$s","I %n nóiméad ar %1$s ansin ar %2$s agus %3$s"],
    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["I %n uair an chloig ar %1$s ansin ar %2$s agus %3$s","I %n uair an chloig ar %1$s ansin ar %2$s agus %3$s","I %n uair an chloig ar %1$s ansin ar %2$s agus %3$s","I %n uair an chloig ar %1$s ansin ar %2$s agus %3$s","I %n uair an chloig ar %1$s ansin ar %2$s agus %3$s"],
    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["I %n lá ar %1$s ansin ar %2$s agus %3$s","I %n lá ar %1$s ansin ar %2$s agus %3$s","I %n lá ar %1$s ansin ar %2$s agus %3$s","I %n lá ar %1$s ansin ar %2$s agus %3$s","I %n lá ar %1$s ansin ar %2$s agus %3$s"],
    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["I %n seachtain ar %1$s ansin ar %2$s agus %3$s","I %n seachtain ar %1$s ansin ar %2$s agus %3$s","I %n seachtain ar %1$s ansin ar %2$s agus %3$s","I %n seachtain ar %1$s ansin ar %2$s agus %3$s","I %n seachtain ar %1$s ansin ar %2$s agus %3$s"],
    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["I %n mí ar %1$s ansin ar %2$s agus %3$s","I %n mí ar %1$s ansin ar %2$s agus %3$s","I %n mí ar %1$s ansin ar %2$s agus %3$s","I %n mí ar %1$s ansin ar %2$s agus %3$s","I %n mí ar %1$s ansin ar %2$s agus %3$s"],
    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["I %n bliain ar %1$s ansin ar %2$s agus %3$s","I %n bliain ar %1$s ansin ar %2$s agus %3$s","I %n bliain ar %1$s ansin ar %2$s agus %3$s","I %n bliain ar %1$s ansin ar %2$s agus %3$s","I %n bliain ar %1$s ansin ar %2$s agus %3$s"],
    "Could not generate next recurrence statement" : "Níorbh fhéidir an chéad ráiteas atarlaithe eile a ghiniúint",
    "Cancelled: %1$s" : "Ar ceal: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" curtha ar ceal",
    "Re: %1$s" : "Maidir le: %1$s",
    "%1$s has accepted your invitation" : "%1$s ghlac sé le do chuireadh",
    "%1$s has tentatively accepted your invitation" : "Ghlac %1$s sé go sealadach le do chuireadh",
    "%1$s has declined your invitation" : "Dhiúltaigh %1$s do chuireadh",
    "%1$s has responded to your invitation" : "D'fhreagair %1$s do chuireadh",
    "Invitation updated: %1$s" : "Nuashonraíodh an cuireadh: %1$s",
    "%1$s updated the event \"%2$s\"" : "Nuashonraigh %1$s imeacht \"%2$s\"",
    "Invitation: %1$s" : "Cuireadh: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "Ba mhaith le %1$s cuireadh a thabhairt duit chuig \"%2$s\"",
    "Organizer:" : "Eagraí:",
    "Attendees:" : "Lucht freastail:",
    "Title:" : "Teideal:",
    "When:" : "Cathain:",
    "Location:" : "Suíomh:",
    "Link:" : "Nasc:",
    "Occurring:" : "Ag tarlú:",
    "Accept" : "Glac",
    "Decline" : "Meath",
    "More options …" : "Tuilleadh roghanna…",
    "More options at %s" : "Tuilleadh roghanna ag %s",
    "Monday" : "Luan",
    "Tuesday" : "Máirt",
    "Wednesday" : "Céadaoin",
    "Thursday" : "Déardaoin",
    "Friday" : "Aoine",
    "Saturday" : "Sathairn",
    "Sunday" : "Domhnach",
    "January" : "Eanáir",
    "February" : "Feabhra",
    "March" : "Márta",
    "April" : "Aibreán",
    "May" : "Bealtaine",
    "June" : "Meitheamh",
    "July" : "Iúil",
    "August" : "Lúnasa",
    "September" : "Meán Fómhair",
    "October" : "Deireadh Fómhair",
    "November" : "Samhain",
    "December" : "Nollaig",
    "First" : "Ar dtús",
    "Second" : "Dara",
    "Third" : "Tríú",
    "Fourth" : "Ceathrú",
    "Fifth" : "Cúigiú",
    "Last" : "Seo caite",
    "Second Last" : "Dara Deireanach",
    "Third Last" : "An Tríú Deireanach",
    "Fourth Last" : "Ceathrú Deireanach",
    "Fifth Last" : "An Cúigiú Deireanach",
    "Contacts" : "Teagmhálaithe",
    "{actor} created address book {addressbook}" : "chruthaigh {actor} leabhar seoltaí {addressbook}",
    "You created address book {addressbook}" : "Chruthaigh tú leabhar seoltaí {addressbook}",
    "{actor} deleted address book {addressbook}" : "Scrios {actor} leabhar seoltaí {addressbook}",
    "You deleted address book {addressbook}" : "Scrios tú leabhar seoltaí {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} leabhar seoltaí nuashonraithe {addressbook}",
    "You updated address book {addressbook}" : "Nuashonraigh tú leabhar seoltaí {addressbook}",
    "{actor} shared address book {addressbook} with you" : "Roinn {actor} leabhar seoltaí {addressbook} leat",
    "You shared address book {addressbook} with {user}" : "Roinn tú leabhar seoltaí {addressbook} le {user}",
    "{actor} shared address book {addressbook} with {user}" : "Roinn {actor} leabhar seoltaí {addressbook} le {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} leabhar seoltaí neamhroinnte {addressbook} uait",
    "You unshared address book {addressbook} from {user}" : "Dhíroinn tú leabhar seoltaí {addressbook} ó {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} leabhar seoltaí neamhroinnte {addressbook} ó {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} leabhar seoltaí neamhroinnte {addressbook} uathu féin",
    "You shared address book {addressbook} with group {group}" : "Roinn tú leabhar seoltaí {addressbook} le grúpa {group}",
    "{actor} shared address book {addressbook} with group {group}" : "Roinn {actor} leabhar seoltaí {addressbook} le grúpa {group}",
    "You unshared address book {addressbook} from group {group}" : "Dhíroinn tú leabhar seoltaí {addressbook} ó ghrúpa {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} leabhar seoltaí neamhroinnte {addressbook} ó ghrúpa {group}",
    "{actor} created contact {card} in address book {addressbook}" : "Chruthaigh {actor} teagmhálaí {card} sa leabhar seoltaí {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Chruthaigh tú teagmhálaí {card} sa leabhar seoltaí {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "Scrios {actor} teagmhálaí {card} ón leabhar seoltaí {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Scrios tú teagmhálaí {card} ón leabhar seoltaí {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "Nuashonraigh {actor} teagmhálaí {card} sa leabhar seoltaí {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Nuashonraigh tú teagmhálaí {card} sa leabhar seoltaí {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Athraíodh <strong>contact</strong> nó <strong>address book</strong> seoltaí",
    "System address book disabled" : "Leabhar seoltaí an chórais díchumasaithe",
    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "Díchumasaíodh leabhar seoltaí teagmhálacha an chórais go huathoibríoch le linn an uasghrádaithe. Ciallaíonn sé seo nach mbeidh an leabhar seoltaí ar fáil a thuilleadh d'úsáideoirí san aip teagmhálacha ná do chliaint eile. Díchumasaíodh leabhar seoltaí teagmhálacha an chórais mar gur sháraigh líon na dteagmhálaithe sa leabhar seoltaí an líon teagmhálacha uasta a mholtar. Socraítear an teorainn seo chun fadhbanna feidhmíochta a chosc. Is féidir leat leabhar seoltaí an chórais a athchumasú leis an ordú seo a leanas {command}",
    "Accounts" : "Cuntais",
    "System address book which holds all accounts" : "Leabhar seoltaí córais ina bhfuil gach cuntas",
    "File is not updatable: %1$s" : "Ní féidir an comhad a nuashonrú: %1$s",
    "Failed to get storage for file" : "Theip ar stóras a fháil don chomhad",
    "Could not write to final file, canceled by hook" : "Níorbh fhéidir scríobh chuig an gcomhad deiridh, cealaithe le hook",
    "Could not write file contents" : "Níorbh fhéidir inneachar an chomhaid a scríobh",
    "_%n byte_::_%n bytes_" : ["%n beart ","%n bearta ","%n bearta","%n bearta","%n bearta"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Earráid agus an comhad á chóipeáil go dtí an suíomh sprice (cóipeáladh: %1$s, bhíothas ag súil le méid comhaid: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Bhíothas ag súil le méid comhaid de %1$s ach léite (ó chliant Nextcloud) agus scríobh (go stóras Nextcloud) %2$s. D'fhéadfadh fadhb líonra a bheith ann ar an taobh seolta nó fadhb ag scríobh chuig an stóras ar thaobh an fhreastalaí.",
    "Could not rename part file to final file, canceled by hook" : "Níorbh fhéidir páirtchomhad a athainmniú go comhad deiridh, curtha ar ceal le hook",
    "Could not rename part file to final file" : "Níorbh fhéidir páirtchomhad a athainmniú go dtí an comhad deiridh",
    "Failed to check file size: %1$s" : "Níorbh fhéidir méid an chomhaid a sheiceáil: %1$s",
    "Could not open file: %1$s (%2$d), file does seem to exist" : "Níorbh fhéidir an comhad a oscailt: %1$s (%2$d), is cosúil go bhfuil an comhad ann",
    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "Níorbh fhéidir an comhad a oscailt: %1$s (%2$d), is cosúil nach bhfuil an comhad ann.",
    "Failed to get size for : %1$s" : "Theip ar mhéid a fháil le haghaidh: %1$s",
    "Encryption not ready: %1$s" : "Níl an criptiúchán réidh: %1$s",
    "Failed to open file: %1$s" : "Níorbh fhéidir an comhad a oscailt: %1$s",
    "Failed to unlink: %1$s" : "Theip ar dhínascadh: %1$s",
    "Failed to write file contents: %1$s" : "Níorbh fhéidir inneachar an chomhaid a scríobh: %1$s",
    "File not found: %1$s" : "Comhad gan aimsiú: %1$s",
    "Invalid target path" : "Conair sprice neamhbhailí",
    "System is in maintenance mode." : "Tá an córas i mód cothabhála.",
    "Upgrade needed" : "Uasghrádú ag teastáil",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ní mór do %s a chumrú le HTTPS a úsáid chun CalDAV agus CardDAV a úsáid le iOS/macOS.",
    "Configures a CalDAV account" : "Cumraíonn sé cuntas CalDAV",
    "Configures a CardDAV account" : "Cumraíonn sé cuntas CardDAV",
    "Events" : "Imeachtaí",
    "Untitled task" : "Tasc gan teideal",
    "Completed on %s" : "Críochnaithe ar %s",
    "Due on %s by %s" : "Dlite ar %s faoi %s",
    "Due on %s" : "Dlite ar %s",
    "This is an example contact" : "Seo sampla teagmhála",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Fáilte go Féilire Nextcloud!\n\nSeo sampla imeachta - déan iniúchadh ar sholúbthacht na pleanála le Féilire Nextcloud trí aon eagarthóireacht is mian leat a dhéanamh!\n\nLe Féilire Nextcloud, is féidir leat:\n- Imeachtaí a chruthú, a chur in eagar agus a bhainistiú gan stró.\n- Ilfhéilirí a chruthú agus iad a roinnt le comhghleacaithe foirne, cairde nó teaghlach.\n- Infhaighteacht a sheiceáil agus do chuid amanna gnóthacha a thaispeáint do dhaoine eile.\n- Comhtháthú gan uaim le haipeanna agus gléasanna trí CalDAV.\n- Do thaithí a shaincheapadh: imeachtaí athfhillteacha a sceidealú, fógraí agus socruithe eile a choigeartú.",
    "Example event - open me!" : "Imeacht shamplach - oscail mé!",
    "System Address Book" : "Leabhar Seoltaí Córais",
    "The system address book contains contact information for all users in your instance." : "Tá faisnéis teagmhála i leabhar seoltaí an chórais do gach úsáideoir i do chás.",
    "Enable System Address Book" : "Cumasaigh Leabhar Seoltaí an Chórais",
    "DAV system address book" : "Leabhar seoltaí córas DAV",
    "No outstanding DAV system address book sync." : "Níl sioncronú leabhar seoltaí córais DAV gan íoc.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Níor rith sioncronú leabhar seoltaí an chórais DAV fós toisc go bhfuil níos mó ná 1000 úsáideoir ag do chás nó toisc gur tharla earráid. Rith de láimh é le do thoil trí ghlao a chur ar \"occ dav:sync-system-addressbook\".",
    "DAV system address book size" : "Méid leabhar seoltaí córas DAV",
    "The system address book is disabled" : "Tá leabhar seoltaí an chórais díchumasaithe",
    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "Tá leabhar seoltaí an chórais cumasaithe, ach tá níos mó ná an teorainn chumraithe de %d teagmhálaí ann",
    "The system address book is enabled and contains less than the configured limit of %d contacts" : "Tá leabhar seoltaí an chórais cumasaithe agus tá níos lú ná an teorainn chumraithe de %d teagmhálaí ann",
    "WebDAV endpoint" : "Críochphointe WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Níorbh fhéidir a sheiceáil go bhfuil do fhreastalaí gréasáin socraithe i gceart chun sioncrónú comhad thar WebDAV a cheadú. Seiceáil le do thoil de láimh.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Níl do fhreastalaí gréasáin socraithe i gceart fós chun sioncrónú comhad a cheadú, mar is cosúil go bhfuil comhéadan WebDAV briste.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Tá do fhreastalaí gréasáin socraithe i gceart chun sioncrónú comhad thar WebDAV a cheadú.",
    "Calendars including events, details and attendees" : "Féilirí lena n-áirítear imeachtaí, sonraí agus lucht freastail",
    "Migrated calendar (%1$s)" : "Féilire aistrithe (%1$s)",
    "Contacts and groups" : "Teagmhálaithe agus grúpaí",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Neamhláithreacht shábháil",
    "Failed to save your absence settings" : "Theip ar do shocruithe asláithreachta a shábháil",
    "Absence cleared" : "Neamhláithreacht glanta",
    "Failed to clear your absence settings" : "Theip ar do shocruithe asláithreachta a ghlanadh",
    "First day" : "Céad lá",
    "Last day (inclusive)" : "Lá deiridh (san áireamh)",
    "Out of office replacement (optional)" : "Athsholáthar as oifig (roghnach)",
    "Name of the replacement" : "Ainm an athsholáthair",
    "Short absence status" : "Stádas asláithreachta gearr",
    "Long absence Message" : "Neamhláithreacht fada Teachtaireacht",
    "Save" : "Sábháil",
    "Disable absence" : "Díchumasaigh neamhláithreacht",
    "Failed to load availability" : "Theip ar infhaighteacht a lódáil",
    "Saved availability" : "Infhaighteacht shábháilte",
    "Failed to save availability" : "Theip ar infhaighteacht a shábháil",
    "to" : "chun",
    "Delete slot" : "Scrios sliotán",
    "No working hours set" : "Níl aon uaireanta oibre socraithe",
    "Add slot" : "Cuir sliotán",
    "Weekdays" : "Laethanta na seachtaine",
    "Pick a start time for {dayName}" : "Roghnaigh am tosaithe le haghaidh {dayName}",
    "Pick a end time for {dayName}" : "Roghnaigh am críochnaithe le haghaidh {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Socraigh stádas úsáideora go huathoibríoch mar \"Ná cuir isteach\" taobh amuigh den infhaighteacht chun gach fógra a bhalbhú.",
    "Cancel" : "Cealaigh",
    "Import" : "Iompórtáil",
    "Error while saving settings" : "Earráid agus na socruithe á sábháil",
    "Contact reset successfully" : "D'éirigh le hathshocrú teagmhála",
    "Error while resetting contact" : "Earráid agus an teagmhálaí á athshocrú",
    "Contact imported successfully" : "D'éirigh le hiompórtáil an teagmhálaí",
    "Error while importing contact" : "Earráid agus an teagmhálaí á iompórtáil",
    "Import contact" : "Iompórtáil teagmhála",
    "Reset to default" : "Athshocraigh go réamhshocrú",
    "Import contacts" : "Teagmhálaithe a allmhairiú",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Má dhéantar comhad .vcf nua a iompórtáil, scriosfar an teagmhálaí réamhshocraithe atá ann cheana féin agus cuirfear an ceann nua ina ionad. Ar mhaith leat leanúint ar aghaidh?",
    "Failed to save example event creation setting" : "Theip ar shocrú cruthaithe imeachta samplach a shábháil",
    "Failed to upload the example event" : "Theip ar an imeacht samplach a uaslódáil",
    "Custom example event was saved successfully" : "Sábháladh imeacht samplach saincheaptha go rathúil",
    "Failed to delete the custom example event" : "Theip ar an imeacht samplach saincheaptha a scriosadh",
    "Custom example event was deleted successfully" : "Scriosadh imeacht samplach saincheaptha go rathúil",
    "Import calendar event" : "Imeacht féilire a allmhairiú",
    "Uploading a new event will overwrite the existing one." : "Scríobhfar an ceann atá ann cheana má uaslódálann tú imeacht nua.",
    "Upload event" : "Uaslódáil imeacht",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Suiteáil an {calendarappstoreopen}Féilire aip{linkclose} freisin, nó {calendardocopen}ceangail do dheasc & do ghutháin phóca le haghaidh sioncronaithe ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Cinntigh le do thoil go socróidh tú {emailopen}an freastalaí ríomhphoist{linkclose} i gceart.",
    "Calendar server" : "Freastalaí féilire",
    "Send invitations to attendees" : "Seol cuirí chuig an lucht freastail",
    "Automatically generate a birthday calendar" : "Gin féilire lá breithe go huathoibríoch",
    "Birthday calendars will be generated by a background job." : "Ginfear féilirí lá breithe le post cúlra.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Mar sin ní bheidh siad ar fáil díreach tar éis iad a chumasú ach taispeánfar iad tar éis roinnt ama.",
    "Send notifications for events" : "Seol fógraí le haghaidh imeachtaí",
    "Notifications are sent via background jobs, so these must occur often enough." : "Seoltar fógraí trí phoist chúlra, mar sin caithfidh siad tarlú minic go leor.",
    "Send reminder notifications to calendar sharees as well" : "Seol fógraí meabhrúcháin chuig scaireanna féilire freisin",
    "Reminders are always sent to organizers and attendees." : "Seoltar meabhrúcháin chuig na heagraithe agus an lucht freastail i gcónaí.",
    "Enable notifications for events via push" : "Cumasaigh fógraí le haghaidh imeachtaí trí bhrú",
    "Example content" : "Ábhar samplach",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Feidhmíonn ábhar samplach chun gnéithe Nextcloud a thaispeáint. Seoltar ábhar réamhshocraithe le Nextcloud, agus is féidir ábhar saincheaptha a chur ina áit.",
    "Availability" : "Infhaighteacht",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Má dhéanann tú do chuid uaireanta oibre a chumrú, feicfidh daoine eile nuair a bhíonn tú as oifig nuair a chuireann siad cruinniú in áirithe.",
    "Absence" : "Neamhláithreacht",
    "Configure your next absence period." : "Cumraigh do chéad tréimhse neamhláithreachta eile.",
    "There was an error updating your attendance status." : "Tharla earráid agus do stádas freastail á nuashonrú.",
    "Please contact the organizer directly." : "Téigh i dteagmháil leis an eagraí go díreach le do thoil.",
    "Are you accepting the invitation?" : "An bhfuil tú ag glacadh leis an gcuireadh?",
    "Tentative" : "Sealadach",
    "Your attendance was updated successfully." : "D'éirigh le do thinreamh a nuashonrú.",
    "No results." : "Gan torthaí.",
    "Start typing." : "Tosaigh ag clóscríobh."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
